(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     73530,       5892]*)
(*NotebookOutlinePosition[     74401,       5924]*)
(*  CellTagsIndexPosition[     74357,       5920]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Creating Fuzzy Relations
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of convenient ways to create fuzzy \
relations. In this chapter, we will demonstrate these functions and the \
options associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Relation from a Function", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CreateFuzzyRelation[func,{{va,vb},{wa,wb}},opts] returns a new fuzzy relation \
with membership grades that are the result of applying func to all the \
elements in the specified range, {{va,vb},{wa,wb}}. If no range is given, the \
function is applied to all of the elements in the universal space. Be sure \
the function provided causes membership grades to be in the correct range, 0 \
to 1.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Following is an example of creating a fuzzy relation from a function. The \
first command defines the function, and the second command creates the fuzzy \
relation. We explicitly declare a universal space in this function rather \
that accept the default setting. Because fuzzy relations are quite large, we \
suppress the output by putting a semicolon at the end of the function. To \
examine the relation, we use one of the Fuzzy Logic Pack's graphing \
functions. More information about graphing fuzzy relations can be found in a \
later section of this manual.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MyFunc2[x_,y_] := (Sin[x+y]+1)/2", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel1 = CreateFuzzyRelation[MyFunc2,
         UniversalSpace->{{0,7},{0,8}}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .15136 .17979 -0.11692 1 Msboxa
[(2)] .24096 .15541 -0.09106 1 Msboxa
[(3)] .3351 .1298 -0.06348 1 Msboxa
[(4)] .43412 .10286 -0.03402 1 Msboxa
[(5)] .53842 .07451 -0.00246 1 Msboxa
[(6)] .64843 .04461 .03143 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .80923 .08269 -1 .25481 Msboxa
[(2)] .83729 .13681 -1 .24065 Msboxa
[(3)] .86271 .18585 -1 .22798 Msboxa
[(4)] .88584 .23047 -1 .21657 Msboxa
[(5)] .90697 .27125 -1 .20626 Msboxa
[(6)] .92637 .30866 -1 .19688 Msboxa
[(7)] .94422 .34311 -1 .18832 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.14985 .19271 m
.14909 .19918 L
s
P
[(1)] .15136 .17979 -0.11692 1 Mshowa
p
.002 w
.23978 .16837 m
.23919 .17484 L
s
P
[(2)] .24096 .15541 -0.09106 1 Mshowa
p
.002 w
.33427 .14278 m
.33386 .14927 L
s
P
[(3)] .3351 .1298 -0.06348 1 Mshowa
p
.002 w
.43368 .11587 m
.43346 .12237 L
s
P
[(4)] .43412 .10286 -0.03402 1 Mshowa
p
.002 w
.53839 .08752 m
.53837 .09402 L
s
P
[(5)] .53842 .07451 -0.00246 1 Mshowa
p
.002 w
.64884 .05761 m
.64905 .06412 L
s
P
[(6)] .64843 .04461 .03143 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.79662 .0859 m
.79031 .08751 L
s
P
[(1)] .80923 .08269 -1 .25481 Mshowa
p
.002 w
.82464 .13986 m
.81831 .14138 L
s
P
[(2)] .83729 .13681 -1 .24065 Mshowa
p
.002 w
.85002 .18874 m
.84368 .19018 L
s
P
[(3)] .86271 .18585 -1 .22798 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(4)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.89423 .27388 m
.88786 .27519 L
s
P
[(5)] .90697 .27125 -1 .20626 Mshowa
p
.002 w
.9136 .31118 m
.90722 .31243 L
s
P
[(6)] .92637 .30866 -1 .19688 Mshowa
p
.002 w
.93143 .34552 m
.92504 .34673 L
s
P
[(7)] .94422 .34311 -1 .18832 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.23978 .16837 m
.55187 .44872 L
s
P
p
.4 g
.43368 .11587 m
.70149 .42172 L
s
P
p
.4 g
.64884 .05761 m
.86261 .39264 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.17318 .29663 m
.82464 .13986 L
s
P
p
.4 g
.26533 .36485 m
.87312 .23322 L
s
P
p
.4 g
.34424 .42327 m
.9136 .31118 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.59897 .45708 m .62532 .43547 L .55194 .49546 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.55194 .49546 m .52167 .5757 L .59897 .45708 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.52167 .5757 m .55194 .49546 L .47838 .60805 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.67676 .39348 m .70358 .47065 L .62532 .43547 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.62532 .43547 m .59897 .45708 L .67676 .39348 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.44409 .65243 m .47838 .60805 L .40503 .6806 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.40503 .6806 m .37156 .62507 L .44409 .65243 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.47838 .60805 m .44409 .65243 L .52167 .5757 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.40976 .59286 m .44409 .65243 L .37156 .62507 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.37156 .62507 m .33996 .4998 L .40976 .59286 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.76136 .42929 m .7907 .56412 L .70358 .47065 L p
.402 .487 .832 r
F P
1 0 0 r
s
P
p
.002 w
.70358 .47065 m .67676 .39348 L .76136 .42929 L p
.402 .487 .832 r
F P
1 0 0 r
s
P
p
.002 w
.37669 .45991 m .40976 .59286 L .33996 .4998 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.33996 .4998 m .30596 .39955 L .37669 .45991 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.6516 .41413 m .67676 .39348 L .59897 .45708 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59897 .45708 m .57018 .53946 L .6516 .41413 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.57018 .53946 m .59897 .45708 L .52167 .5757 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.34131 .35295 m .37669 .45991 L .30596 .39955 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.30596 .39955 m .2632 .39187 L .34131 .35295 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.73437 .34647 m .76136 .42929 L .67676 .39348 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.67676 .39348 m .6516 .41413 L .73437 .34647 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.48783 .62087 m .52167 .5757 L .44409 .65243 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.44409 .65243 m .40976 .59286 L .48783 .62087 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.52167 .5757 m .48783 .62087 L .57018 .53946 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.85683 .52635 m .8826 .61976 L .7907 .56412 L p
.326 .342 .723 r
F P
1 0 0 r
s
P
p
.002 w
.7907 .56412 m .76136 .42929 L .85683 .52635 L p
.326 .342 .723 r
F P
1 0 0 r
s
P
p
.002 w
.4527 .55667 m .48783 .62087 L .40976 .59286 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.40976 .59286 m .37669 .45991 L .4527 .55667 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.82631 .38279 m .85683 .52635 L .76136 .42929 L p
.402 .487 .832 r
F P
1 0 0 r
s
P
p
.002 w
.76136 .42929 m .73437 .34647 L .82631 .38279 L p
.402 .487 .832 r
F P
1 0 0 r
s
P
p
.002 w
.418 .41504 m .4527 .55667 L .37669 .45991 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.37669 .45991 m .34131 .35295 L .418 .41504 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.29757 .34253 m .34131 .35295 L .2632 .39187 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.2632 .39187 m .20871 .46673 L .29757 .34253 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.71091 .36574 m .73437 .34647 L .6516 .41413 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.6516 .41413 m .62489 .49858 L .71091 .36574 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.62489 .49858 m .6516 .41413 L .57018 .53946 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.38116 .3004 m .418 .41504 L .34131 .35295 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.34131 .35295 m .29757 .34253 L .38116 .3004 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.79932 .29345 m .82631 .38279 L .73437 .34647 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.73437 .34647 m .71091 .36574 L .79932 .29345 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.53717 .58528 m .57018 .53946 L .48783 .62087 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.48783 .62087 m .4527 .55667 L .53717 .58528 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.57018 .53946 m .53717 .58528 L .62489 .49858 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.95733 .58401 m .96916 .56655 L .8826 .61976 L p
.37 .439 .802 r
F P
1 0 0 r
s
P
p
.002 w
.8826 .61976 m .85683 .52635 L .95733 .58401 L p
.37 .439 .802 r
F P
1 0 0 r
s
P
p
.002 w
.93163 .48364 m .95733 .58401 L .85683 .52635 L p
.326 .342 .723 r
F P
1 0 0 r
s
P
p
.002 w
.85683 .52635 m .82631 .38279 L .93163 .48364 L p
.326 .342 .723 r
F P
1 0 0 r
s
P
p
.002 w
.50129 .51571 m .53717 .58528 L .4527 .55667 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.4527 .55667 m .418 .41504 L .50129 .51571 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.89986 .33013 m .93163 .48364 L .82631 .38279 L p
.402 .487 .832 r
F P
1 0 0 r
s
P
p
.002 w
.82631 .38279 m .79932 .29345 L .89986 .33013 L p
.402 .487 .832 r
F P
1 0 0 r
s
P
p
.002 w
.46482 .36419 m .50129 .51571 L .418 .41504 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.418 .41504 m .38116 .3004 L .46482 .36419 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.33654 .28659 m .38116 .3004 L .29757 .34253 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.29757 .34253 m .24203 .41867 L .33654 .28659 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.24203 .41867 m .29757 .34253 L .20871 .46673 L p
.613 .861 .505 r
F P
1 0 0 r
s
P
p
.002 w
.20871 .46673 m .14765 .53572 L .24203 .41867 L p
.613 .861 .505 r
F P
1 0 0 r
s
P
p
.002 w
.77823 .3108 m .79932 .29345 L .71091 .36574 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.71091 .36574 m .68709 .4521 L .77823 .3108 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.68709 .4521 m .71091 .36574 L .62489 .49858 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.42644 .24071 m .46482 .36419 L .38116 .3004 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.38116 .3004 m .33654 .28659 L .42644 .24071 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .89986 .33013 L .79932 .29345 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.79932 .29345 m .77823 .3108 L .87312 .23322 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59323 .54484 m .62489 .49858 L .53717 .58528 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.53717 .58528 m .50129 .51571 L .59323 .54484 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.62489 .49858 m .59323 .54484 L .68709 .4521 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.55675 .46898 m .59323 .54484 L .50129 .51571 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.50129 .51571 m .46482 .36419 L .55675 .46898 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.51833 .30608 m .55675 .46898 L .46482 .36419 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.46482 .36419 m .42644 .24071 L .51833 .30608 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.3811 .22263 m .42644 .24071 L .33654 .28659 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.33654 .28659 m .28018 .36365 L .3811 .22263 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.28018 .36365 m .33654 .28659 L .24203 .41867 L p
.613 .861 .505 r
F P
1 0 0 r
s
P
p
.002 w
.24203 .41867 m .17911 .48896 L .28018 .36365 L p
.613 .861 .505 r
F P
1 0 0 r
s
P
p
.002 w
.17911 .48896 m .24203 .41867 L .14765 .53572 L p
.421 .752 .994 r
F P
1 0 0 r
s
P
p
.002 w
.85532 .24789 m .87312 .23322 L .77823 .3108 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.77823 .3108 m .75843 .39881 L .85532 .24789 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.75843 .39881 m .77823 .3108 L .68709 .4521 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.14765 .53572 m .09175 .49618 L .17911 .48896 L p
.421 .752 .994 r
F P
1 0 0 r
s
P
p
.002 w
.47832 .1723 m .51833 .30608 L .42644 .24071 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.42644 .24071 m .3811 .22263 L .47832 .1723 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.65751 .49847 m .68709 .4521 L .59323 .54484 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.59323 .54484 m .55675 .46898 L .65751 .49847 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.68709 .4521 m .65751 .49847 L .75843 .39881 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.62062 .41514 m .65751 .49847 L .55675 .46898 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.55675 .46898 m .51833 .30608 L .62062 .41514 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.12045 .44418 m .17911 .48896 L .09175 .49618 L p
0 .091 .631 r
F P
1 0 0 r
s
P
p
.002 w
.09175 .49618 m .04583 .34565 L .12045 .44418 L p
0 .091 .631 r
F P
1 0 0 r
s
P
p
.002 w
.58007 .23903 m .62062 .41514 L .51833 .30608 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.51833 .30608 m .47832 .1723 L .58007 .23903 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.43256 .14877 m .47832 .1723 L .3811 .22263 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.3811 .22263 m .32429 .30003 L .43256 .14877 L p
.588 .816 .424 r
F P
1 0 0 r
s
P
p
.002 w
.32429 .30003 m .3811 .22263 L .28018 .36365 L p
.613 .861 .505 r
F P
1 0 0 r
s
P
p
.002 w
.28018 .36365 m .21552 .43485 L .32429 .30003 L p
.613 .861 .505 r
F P
1 0 0 r
s
P
p
.002 w
.21552 .43485 m .28018 .36365 L .17911 .48896 L p
.421 .752 .994 r
F P
1 0 0 r
s
P
p
.002 w
.84106 .33706 m .85532 .24789 L .75843 .39881 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.17911 .48896 m .12045 .44418 L .21552 .43485 L p
.421 .752 .994 r
F P
1 0 0 r
s
P
p
.002 w
.53838 .09313 m .58007 .23903 L .47832 .1723 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.47832 .1723 m .43256 .14877 L .53838 .09313 L p
.657 .945 .959 r
F P
1 0 0 r
s
P
p
.002 w
.73194 .44477 m .75843 .39881 L .65751 .49847 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.65751 .49847 m .62062 .41514 L .73194 .44477 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.75843 .39881 m .73194 .44477 L .84106 .33706 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.69499 .35245 m .73194 .44477 L .62062 .41514 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.62062 .41514 m .58007 .23903 L .69499 .35245 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.65209 .1608 m .69499 .35245 L .58007 .23903 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.58007 .23903 m .53838 .09313 L .65209 .1608 L p
.231 .334 .764 r
F P
1 0 0 r
s
P
p
.002 w
.81915 .38186 m .84106 .33706 L .73194 .44477 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.73194 .44477 m .69499 .35245 L .81915 .38186 L p
.33 .523 .893 r
F P
1 0 0 r
s
P
p
.002 w
.78267 .27855 m .81915 .38186 L .69499 .35245 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.69499 .35245 m .65209 .1608 L .78267 .27855 L p
.172 .243 .695 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.14985 .19271 m
.14909 .19918 L
s
P
[(1)] .15136 .17979 -0.11692 1 Mshowa
p
.002 w
.23978 .16837 m
.23919 .17484 L
s
P
[(2)] .24096 .15541 -0.09106 1 Mshowa
p
.002 w
.33427 .14278 m
.33386 .14927 L
s
P
[(3)] .3351 .1298 -0.06348 1 Mshowa
p
.002 w
.43368 .11587 m
.43346 .12237 L
s
P
[(4)] .43412 .10286 -0.03402 1 Mshowa
p
.002 w
.53839 .08752 m
.53837 .09402 L
s
P
[(5)] .53842 .07451 -0.00246 1 Mshowa
p
.002 w
.64884 .05761 m
.64905 .06412 L
s
P
[(6)] .64843 .04461 .03143 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Relation Using Trapezoidal Descriptions", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyTrapezoid[{ax,bx,cx,dx},{ay,by,cy,dy},h,opts] returns a new trapezoidal \
fuzzy relation with membership grades that linearly increases from 0 to h in \
both the x and y directions from a to b, is h from b to c, and linearly \
decreases from h to 0 from c to d. If h is not explicitly given, the function \
uses h = 1. As with fuzzy sets, it is possible to explicitly define the \
universal space or to accept the default setting for fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel2 = FuzzyTrapezoid[{1,3,5,7},{0,3,6,8},0.8,
         UniversalSpace->{{0,7},{0,8}}];\
\>", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .15136 .17979 -0.11692 1 Msboxa
[(2)] .24096 .15541 -0.09106 1 Msboxa
[(3)] .3351 .1298 -0.06348 1 Msboxa
[(4)] .43412 .10286 -0.03402 1 Msboxa
[(5)] .53842 .07451 -0.00246 1 Msboxa
[(6)] .64843 .04461 .03143 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .80923 .08269 -1 .25481 Msboxa
[(2)] .83729 .13681 -1 .24065 Msboxa
[(3)] .86271 .18585 -1 .22798 Msboxa
[(4)] .88584 .23047 -1 .21657 Msboxa
[(5)] .90697 .27125 -1 .20626 Msboxa
[(6)] .92637 .30866 -1 .19688 Msboxa
[(7)] .94422 .34311 -1 .18832 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.14985 .19271 m
.14909 .19918 L
s
P
[(1)] .15136 .17979 -0.11692 1 Mshowa
p
.002 w
.23978 .16837 m
.23919 .17484 L
s
P
[(2)] .24096 .15541 -0.09106 1 Mshowa
p
.002 w
.33427 .14278 m
.33386 .14927 L
s
P
[(3)] .3351 .1298 -0.06348 1 Mshowa
p
.002 w
.43368 .11587 m
.43346 .12237 L
s
P
[(4)] .43412 .10286 -0.03402 1 Mshowa
p
.002 w
.53839 .08752 m
.53837 .09402 L
s
P
[(5)] .53842 .07451 -0.00246 1 Mshowa
p
.002 w
.64884 .05761 m
.64905 .06412 L
s
P
[(6)] .64843 .04461 .03143 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.79662 .0859 m
.79031 .08751 L
s
P
[(1)] .80923 .08269 -1 .25481 Mshowa
p
.002 w
.82464 .13986 m
.81831 .14138 L
s
P
[(2)] .83729 .13681 -1 .24065 Mshowa
p
.002 w
.85002 .18874 m
.84368 .19018 L
s
P
[(3)] .86271 .18585 -1 .22798 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(4)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.89423 .27388 m
.88786 .27519 L
s
P
[(5)] .90697 .27125 -1 .20626 Mshowa
p
.002 w
.9136 .31118 m
.90722 .31243 L
s
P
[(6)] .92637 .30866 -1 .19688 Mshowa
p
.002 w
.93143 .34552 m
.92504 .34673 L
s
P
[(7)] .94422 .34311 -1 .18832 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.23978 .16837 m
.55187 .44872 L
s
P
p
.4 g
.43368 .11587 m
.70149 .42172 L
s
P
p
.4 g
.64884 .05761 m
.86261 .39264 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.17318 .29663 m
.82464 .13986 L
s
P
p
.4 g
.26533 .36485 m
.87312 .23322 L
s
P
p
.4 g
.34424 .42327 m
.9136 .31118 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.44983 .43622 m .481 .46151 L .41257 .47386 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .37959 .44944 L .44983 .43622 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.52212 .50773 m .55187 .44872 L .481 .46151 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.481 .46151 m .44983 .43622 L .52212 .50773 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.41639 .40907 m .44983 .43622 L .37959 .44944 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.37959 .44944 m .34424 .42327 L .41639 .40907 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.59951 .4948 m .62532 .43547 L .55187 .44872 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.55187 .44872 m .52212 .50773 L .59951 .4948 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.48996 .48212 m .52212 .50773 L .44983 .43622 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.44983 .43622 m .41639 .40907 L .48996 .48212 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.67995 .48135 m .70149 .42172 L .62532 .43547 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.62532 .43547 m .59951 .4948 L .67995 .48135 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.3804 .37986 m .41639 .40907 L .34424 .42327 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.34424 .42327 m .30625 .39515 L .3804 .37986 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76361 .46737 m .78053 .40746 L .70149 .42172 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.70149 .42172 m .67995 .48135 L .76361 .46737 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.45525 .45447 m .48996 .48212 L .41639 .40907 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.41639 .40907 m .3804 .37986 L .45525 .45447 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.85071 .45282 m .86261 .39264 L .78053 .40746 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.78053 .40746 m .76361 .46737 L .85071 .45282 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.57032 .5619 m .59951 .4948 L .52212 .50773 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.52212 .50773 m .48996 .48212 L .57032 .5619 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.34157 .34834 m .3804 .37986 L .30625 .39515 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.30625 .39515 m .26533 .36485 L .34157 .34834 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.93143 .34552 m .94791 .37725 L .86261 .39264 L p
0 0 .055 r
F P
1 0 0 r
s
P
p
.002 w
.86261 .39264 m .85071 .45282 L .93143 .34552 L p
0 0 .055 r
F P
1 0 0 r
s
P
p
.002 w
.65553 .54897 m .67995 .48135 L .59951 .4948 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.59951 .4948 m .57032 .5619 L .65553 .54897 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.41766 .42453 m .45525 .45447 L .3804 .37986 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.3804 .37986 m .34157 .34834 L .41766 .42453 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.53729 .53625 m .57032 .5619 L .48996 .48212 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.48996 .48212 m .45525 .45447 L .53729 .53625 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.74439 .53548 m .76361 .46737 L .67995 .48135 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.67995 .48135 m .65553 .54897 L .74439 .53548 L p
.418 .018 .171 r
F P
1 0 0 r
s
P
p
.002 w
.29955 .31423 m .34157 .34834 L .26533 .36485 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .22111 .33212 L .29955 .31423 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.82943 .42275 m .85071 .45282 L .76361 .46737 L p
0 0 .008 r
F P
1 0 0 r
s
P
p
.002 w
.76361 .46737 m .74439 .53548 L .82943 .42275 L p
0 0 .008 r
F P
1 0 0 r
s
P
p
.002 w
.37684 .39202 m .41766 .42453 L .34157 .34834 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.34157 .34834 m .29955 .31423 L .37684 .39202 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.9136 .31118 m .93143 .34552 L .85071 .45282 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.50138 .50836 m .53729 .53625 L .45525 .45447 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.45525 .45447 m .41766 .42453 L .50138 .50836 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.85071 .45282 m .82943 .42275 L .9136 .31118 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.62539 .5222 m .65553 .54897 L .57032 .5619 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.57032 .5619 m .53729 .53625 L .62539 .5222 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.25393 .2772 m .29955 .31423 L .22111 .33212 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.22111 .33212 m .17318 .29663 L .25393 .2772 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71745 .50753 m .74439 .53548 L .65553 .54897 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.65553 .54897 m .62539 .5222 L .71745 .50753 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.33232 .35656 m .37684 .39202 L .29955 .31423 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.29955 .31423 m .25393 .2772 L .33232 .35656 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.89423 .27388 m .9136 .31118 L .82943 .42275 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.46222 .47795 m .50138 .50836 L .41766 .42453 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.41766 .42453 m .37684 .39202 L .46222 .47795 L p
.573 .048 0 r
F P
1 0 0 r
s
P
p
.002 w
.82943 .42275 m .80632 .39007 L .89423 .27388 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.80632 .39007 m .82943 .42275 L .74439 .53548 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.59259 .49306 m .62539 .5222 L .53729 .53625 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.53729 .53625 m .50138 .50836 L .59259 .49306 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.74439 .53548 m .71745 .50753 L .80632 .39007 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.20422 .23685 m .25393 .2772 L .17318 .29663 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.17318 .29663 m .12105 .25804 L .20422 .23685 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.68805 .47704 m .71745 .50753 L .62539 .5222 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.62539 .5222 m .59259 .49306 L .68805 .47704 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.28623 .28271 m .33232 .35656 L .25393 .2772 L p
0 .282 .725 r
F P
1 0 0 r
s
P
p
.002 w
.25393 .2772 m .20422 .23685 L .28623 .28271 L p
0 .282 .725 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .89423 .27388 L .80632 .39007 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.42185 .3722 m .46222 .47795 L .37684 .39202 L p
.167 .602 .937 r
F P
1 0 0 r
s
P
p
.002 w
.37684 .39202 m .33232 .35656 L .42185 .3722 L p
.167 .602 .937 r
F P
1 0 0 r
s
P
p
.002 w
.80632 .39007 m .78111 .35444 L .87312 .23322 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.78111 .35444 m .80632 .39007 L .71745 .50753 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.55672 .46121 m .59259 .49306 L .50138 .50836 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.50138 .50836 m .46222 .47795 L .55672 .46121 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.71745 .50753 m .68805 .47704 L .78111 .35444 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.14985 .19271 m .20422 .23685 L .12105 .25804 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.12105 .25804 m .06415 .21592 L .14985 .19271 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.65586 .44364 m .68805 .47704 L .59259 .49306 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.59259 .49306 m .55672 .46121 L .65586 .44364 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.23978 .16837 m .28623 .28271 L .20422 .23685 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.20422 .23685 m .14985 .19271 L .23978 .16837 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.85002 .18874 m .87312 .23322 L .78111 .35444 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.37927 .26065 m .42185 .3722 L .33232 .35656 L p
.586 .701 .922 r
F P
1 0 0 r
s
P
p
.002 w
.33232 .35656 m .28623 .28271 L .37927 .26065 L p
.586 .701 .922 r
F P
1 0 0 r
s
P
p
.002 w
.78111 .35444 m .75352 .31543 L .85002 .18874 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.75352 .31543 m .78111 .35444 L .68805 .47704 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.51796 .3524 m .55672 .46121 L .46222 .47795 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.46222 .47795 m .42185 .3722 L .51796 .3524 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.68805 .47704 m .65586 .44364 L .75352 .31543 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.61891 .33161 m .65586 .44364 L .55672 .46121 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.55672 .46121 m .51796 .3524 L .61891 .33161 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.47701 .23747 m .51796 .3524 L .42185 .3722 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.42185 .3722 m .37927 .26065 L .47701 .23747 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.33427 .14278 m .37927 .26065 L .28623 .28271 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.28623 .28271 m .23978 .16837 L .33427 .14278 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.82464 .13986 m .85002 .18874 L .75352 .31543 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.75352 .31543 m .72318 .27255 L .82464 .13986 L p
.913 .946 .81 r
F P
1 0 0 r
s
P
p
.002 w
.72318 .27255 m .75352 .31543 L .65586 .44364 L p
.692 .674 .828 r
F P
1 0 0 r
s
P
p
.002 w
.65586 .44364 m .61891 .33161 L .72318 .27255 L p
.692 .674 .828 r
F P
1 0 0 r
s
P
p
.002 w
.57981 .21309 m .61891 .33161 L .51796 .3524 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.51796 .3524 m .47701 .23747 L .57981 .21309 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.43368 .11587 m .47701 .23747 L .37927 .26065 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.37927 .26065 m .33427 .14278 L .43368 .11587 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.68809 .18742 m .72318 .27255 L .61891 .33161 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.61891 .33161 m .57981 .21309 L .68809 .18742 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.53839 .08752 m .57981 .21309 L .47701 .23747 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.47701 .23747 m .43368 .11587 L .53839 .08752 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.79662 .0859 m .82464 .13986 L .72318 .27255 L p
.817 .821 .853 r
F P
1 0 0 r
s
P
p
.002 w
.72318 .27255 m .68809 .18742 L .79662 .0859 L p
.817 .821 .853 r
F P
1 0 0 r
s
P
p
.002 w
.64884 .05761 m .68809 .18742 L .57981 .21309 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.57981 .21309 m .53839 .08752 L .64884 .05761 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .79662 .0859 L .68809 .18742 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.68809 .18742 m .64884 .05761 L .76552 .02602 L p
.585 .61 .843 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.14985 .19271 m
.14909 .19918 L
s
P
[(1)] .15136 .17979 -0.11692 1 Mshowa
p
.002 w
.23978 .16837 m
.23919 .17484 L
s
P
[(2)] .24096 .15541 -0.09106 1 Mshowa
p
.002 w
.33427 .14278 m
.33386 .14927 L
s
P
[(3)] .3351 .1298 -0.06348 1 Mshowa
p
.002 w
.43368 .11587 m
.43346 .12237 L
s
P
[(4)] .43412 .10286 -0.03402 1 Mshowa
p
.002 w
.53839 .08752 m
.53837 .09402 L
s
P
[(5)] .53842 .07451 -0.00246 1 Mshowa
p
.002 w
.64884 .05761 m
.64905 .06412 L
s
P
[(6)] .64843 .04461 .03143 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Relation from Two Fuzzy Sets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
SetsToRelation[func,A,B] returns a new fuzzy relation with elements from the \
Cartesian product of the universal spaces of fuzzy sets A and B. The \
membership grades for the elements are arrived at by applying func to the \
corresponding membership grades of A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To demonstrate this function, we first need to create a couple of fuzzy sets. \
We use a couple of the fuzzy set creation functions described earlier in this \
manual to create two fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS1 = FuzzyGaussian[4,2,UniversalSpace->{1,7}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 0.1053992245618643}, {2, 0.3678794411714423}, 
 
   {3, 0.7788007830714049}, {4, 1.}, 
 
   {5, 0.7788007830714049}, {6, 0.3678794411714423}, 
 
   {7, 0.1053992245618643}}, UniversalSpace -> {1, 7}]











\
\>", "\<\
FuzzySet[{{1, 0.105399}, {2, 0.367879}, {3, 0.778801}, 
 
   {4, 1.}, {5, 0.778801}, {6, 0.367879}, {7, 0.105399}}, 
 
  UniversalSpace -> {1, 7}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FS2 = FuzzyTrapezoid[1,3,5,8,UniversalSpace->{1,8}]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 1/2}, {3, 1}, {4, 1}, {5, 1}, {6, 2/3}, 
 
   {7, 1/3}}, UniversalSpace -> {1, 8}]











\
\>", "\<\
              1                               2       1
FuzzySet[{{2, -}, {3, 1}, {4, 1}, {5, 1}, {6, -}, {7, -}}, 
              2                               3       3
 
  UniversalSpace -> {1, 8}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
With two fuzzy sets, we can now use the SetsToRelation command to create a \
fuzzy relation. In this example, we use Mathematica's Min function to combine \
the fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Rel3 = SetsToRelation[Min,FS1,FS2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel3];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .81341 .09076 -1 .25269 Msboxa
[(3)] .8448 .15131 -1 .23689 Msboxa
[(4)] .87288 .20547 -1 .22295 Msboxa
[(5)] .89814 .25421 -1 .21056 Msboxa
[(6)] .92099 .29829 -1 .19947 Msboxa
[(7)] .94176 .33836 -1 .18949 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(2)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(3)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(4)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(5)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(6)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(7)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.12877 .26376 m
.8008 .09395 L
s
P
p
.4 g
.24049 .34646 m
.86018 .20831 L
s
P
p
.4 g
.33366 .41545 m
.90823 .30084 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.45548 .50034 m .49264 .45941 L .41257 .47386 L p
.396 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .37367 .46734 L .45548 .50034 L p
.396 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.54326 .48526 m .57606 .44436 L .49264 .45941 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .45548 .50034 L .54326 .48526 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.63504 .4695 m .66306 .42866 L .57606 .44436 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .54326 .48526 L .63504 .4695 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.37297 .44703 m .41592 .47872 L .33236 .43769 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.41592 .47872 m .37297 .44703 L .38962 .46181 L p
.531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.4396 .49394 m .37367 .46734 L p
.41592 .47872 L 0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.37367 .46734 m .33236 .43769 L .41592 .47872 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.38962 .46181 m .46492 .52867 L p
.41592 .47872 L .531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41592 .47872 m .45548 .50034 L .4396 .49394 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.73109 .453 m .75386 .41227 L .66306 .42866 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63504 .4695 L .73109 .453 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.50611 .53159 m .54326 .48526 L .45548 .50034 L p
.377 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.45548 .50034 m .41592 .47872 L .50611 .53159 L p
.377 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.83172 .43571 m .84871 .39515 L .75386 .41227 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .73109 .453 L .83172 .43571 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.33236 .43769 m .28744 .40544 L .37297 .44703 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.60322 .51588 m .63504 .4695 L .54326 .48526 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.54326 .48526 m .50611 .53159 L .60322 .51588 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.94791 .37725 m .84871 .39515 L p
.92239 .36808 L 0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.93156 .36471 m .93974 .37099 L p
.92239 .36808 L 0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.93974 .37099 m .94791 .37725 L p
.92239 .36808 L 0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .83172 .43571 L .93156 .36471 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.83172 .43571 m .80701 .40868 L .86893 .35913 L p
.807 .965 .908 r
F P
1 0 0 r
s
P
p
.002 w
.86893 .35913 m .91079 .32563 L p
.88482 .36179 L .807 .965 .908 r
F P
1 0 0 r
s
P
p
.88482 .36179 m .83172 .43571 L .86893 .35913 L .807 .965 .908 r
F
P
p
.002 w
.46492 .52867 m .50611 .53159 L .41592 .47872 L p
.531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.70516 .49939 m .73109 .453 L .63504 .4695 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.63504 .4695 m .60322 .51588 L .70516 .49939 L p
.305 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32595 .41234 m .37297 .44703 L .28744 .40544 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.28744 .40544 m .23843 .37027 L .32595 .41234 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.70516 .49939 m .67335 .49444 L .77026 .38058 L p
.853 .997 .781 r
F P
1 0 0 r
s
P
p
.002 w
.77026 .38058 m .77913 .37016 L p
.77109 .38421 L .853 .997 .781 r
F P
1 0 0 r
s
P
p
.002 w
.78467 .44379 m .73109 .453 L p
.78023 .42431 L 0 0 0 r
F P
1 0 0 r
s
P
p
.78023 .42431 m .80701 .40868 L .78467 .44379 L 0 0 0 r
F
P
p
.002 w
.73109 .453 m .70516 .49939 L .80701 .40868 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.70516 .49939 m .77026 .38058 L .77109 .38421 L .853 .997 .781 r
F
P
p
.002 w
.80701 .40868 m .83172 .43571 L .78467 .44379 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.56676 .56902 m .60322 .51588 L .50611 .53159 L p
.396 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.50611 .53159 m .46492 .52867 L .56676 .56902 L p
.396 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41991 .49615 m .46492 .52867 L .37297 .44703 L p
.531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.37297 .44703 m .32595 .41234 L .41991 .49615 L p
.531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.91079 .32563 m .93156 .36471 L .83172 .43571 L p
.807 .965 .908 r
F P
1 0 0 r
s
P
p
.002 w
.27424 .37418 m .32595 .41234 L .23843 .37027 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.23843 .37027 m .18475 .33173 L .27424 .37418 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.67335 .49444 m .70516 .49939 L .60322 .51588 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.60322 .51588 m .56676 .56902 L .67335 .49444 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.77913 .37016 m .80701 .40868 L .70516 .49939 L p
.853 .997 .781 r
F P
1 0 0 r
s
P
p
.002 w
.37016 .46021 m .41991 .49615 L .32595 .41234 L p
.531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32595 .41234 m .27424 .37418 L .37016 .46021 L p
.531 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.52511 .53719 m .56676 .56902 L .46492 .52867 L p
0 .419 .809 r
F P
1 0 0 r
s
P
p
.002 w
.46492 .52867 m .41991 .49615 L .52511 .53719 L p
0 .419 .809 r
F P
1 0 0 r
s
P
p
.002 w
.88793 .28261 m .91079 .32563 L .80701 .40868 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.80701 .40868 m .77913 .37016 L .88793 .28261 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.21711 .33203 m .27424 .37418 L .18475 .33173 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.18475 .33173 m .12569 .28934 L .21711 .33203 L p
0 .346 .762 r
F P
1 0 0 r
s
P
p
.002 w
.63686 .45831 m .67335 .49444 L .56676 .56902 L p
.782 .935 .931 r
F P
1 0 0 r
s
P
p
.002 w
.56676 .56902 m .52511 .53719 L .63686 .45831 L p
.782 .935 .931 r
F P
1 0 0 r
s
P
p
.002 w
.31978 .34339 m .37016 .46021 L .27424 .37418 L p
.219 .641 .955 r
F P
1 0 0 r
s
P
p
.002 w
.27424 .37418 m .21711 .33203 L .31978 .34339 L p
.219 .641 .955 r
F P
1 0 0 r
s
P
p
.002 w
.47887 .50186 m .52511 .53719 L .41991 .49615 L p
0 .419 .809 r
F P
1 0 0 r
s
P
p
.002 w
.41991 .49615 m .37016 .46021 L .47887 .50186 L p
0 .419 .809 r
F P
1 0 0 r
s
P
p
.002 w
.86264 .23501 m .88793 .28261 L .77913 .37016 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.77913 .37016 m .74831 .32757 L .86264 .23501 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.74831 .32757 m .77913 .37016 L .67335 .49444 L p
.892 .944 .837 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .21711 .33203 L .12569 .28934 L p
.588 .732 .943 r
F P
1 0 0 r
s
P
p
.002 w
.12569 .28934 m .06415 .21592 L .16454 .18874 L p
.588 .732 .943 r
F P
1 0 0 r
s
P
p
.002 w
.67335 .49444 m .63686 .45831 L .74831 .32757 L p
.892 .944 .837 r
F P
1 0 0 r
s
P
p
.002 w
.5963 .41815 m .63686 .45831 L .52511 .53719 L p
.782 .935 .931 r
F P
1 0 0 r
s
P
p
.002 w
.52511 .53719 m .47887 .50186 L .5963 .41815 L p
.782 .935 .931 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .31978 .34339 L .21711 .33203 L p
.581 .581 .817 r
F P
1 0 0 r
s
P
p
.002 w
.21711 .33203 m .16454 .18874 L .27076 .15998 L p
.581 .581 .817 r
F P
1 0 0 r
s
P
p
.002 w
.43191 .31882 m .47887 .50186 L .37016 .46021 L p
.582 .624 .859 r
F P
1 0 0 r
s
P
p
.002 w
.37016 .46021 m .31978 .34339 L .43191 .31882 L p
.582 .624 .859 r
F P
1 0 0 r
s
P
p
.002 w
.83451 .18207 m .86264 .23501 L .74831 .32757 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.74831 .32757 m .71407 .28025 L .83451 .18207 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.71407 .28025 m .74831 .32757 L .63686 .45831 L p
.892 .944 .837 r
F P
1 0 0 r
s
P
p
.002 w
.63686 .45831 m .5963 .41815 L .71407 .28025 L p
.892 .944 .837 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .43191 .31882 L .31978 .34339 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.31978 .34339 m .27076 .15998 L .38334 .1295 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.55084 .29276 m .5963 .41815 L .47887 .50186 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.47887 .50186 m .43191 .31882 L .55084 .29276 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.80303 .12283 m .83451 .18207 L .71407 .28025 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.71407 .28025 m .67578 .22734 L .80303 .12283 L p
.815 .935 .909 r
F P
1 0 0 r
s
P
p
.002 w
.67578 .22734 m .71407 .28025 L .5963 .41815 L p
.682 .682 .844 r
F P
1 0 0 r
s
P
p
.002 w
.5963 .41815 m .55084 .29276 L .67578 .22734 L p
.682 .682 .844 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .55084 .29276 L .43191 .31882 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.43191 .31882 m .38334 .1295 L .50287 .09714 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .67578 .22734 L .55084 .29276 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.55084 .29276 m .50287 .09714 L .63002 .06271 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .80303 .12283 L .67578 .22734 L p
.581 .581 .817 r
F P
1 0 0 r
s
P
p
.002 w
.67578 .22734 m .63002 .06271 L .76552 .02602 L p
.581 .581 .817 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{396, 279},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Relation from a Membership Matrix", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FromMembershipMatrix[mat, {{va,vb},{wa,wb}}] returns a new fuzzy relation by \
combining the matrix of membership grades, mat, with the elements specified \
by the ranges {va,vb} and {wa,wb}. If no ranges are given, the function \
assumes the membership grades are for the elements starting at 1 with a size \
corresponding to the dimension of the matrix, mat.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To demonstrate the FromMembershipMatrix function, we first create a \
membership matrix that contains the membership grades that will be used in \
the relation. We then call our function with the matrix as the argument.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MyMembMat := {{.1, .2, .3, .4, .5},
              {.2, .3, .4, .5, .6},
              {.3, .4, .5, .6, .7},
              {.4, .5, .6, .7, .8}}\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Rel4 = FromMembershipMatrix[MyMembMat];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel4];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .27182 .14701 -0.08207 1 Msboxa
[(3)] .50304 .08413 -0.01322 1 Msboxa
[(4)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .83729 .13681 -1 .24065 Msboxa
[(3)] .88584 .23047 -1 .21657 Msboxa
[(4)] .92637 .30866 -1 .19688 Msboxa
[(5)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(2)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(3)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(4)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.82464 .13986 m
.81831 .14138 L
s
P
[(2)] .83729 .13681 -1 .24065 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(3)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.9136 .31118 m
.90722 .31243 L
s
P
[(4)] .92637 .30866 -1 .19688 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(5)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.27076 .15998 m
.57606 .44436 L
s
P
p
.4 g
.50287 .09714 m
.75386 .41227 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.17318 .29663 m
.82464 .13986 L
s
P
p
.4 g
.26533 .36485 m
.87312 .23322 L
s
P
p
.4 g
.34424 .42327 m
.9136 .31118 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.51601 .50027 m .57709 .57061 L .40888 .57496 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.40888 .57496 m .33948 .50843 L .51601 .50027 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.71215 .49121 m .76267 .56581 L .57709 .57061 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.57709 .57061 m .51601 .50027 L .71215 .49121 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.44557 .41915 m .51601 .50027 L .33948 .50843 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.33948 .50843 m .26001 .43225 L .44557 .41915 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.93137 .48107 m .96848 .56049 L .76267 .56581 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.76267 .56581 m .71215 .49121 L .93137 .48107 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.65342 .40448 m .71215 .49121 L .51601 .50027 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.51601 .50027 m .44557 .41915 L .65342 .40448 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.36343 .32456 m .44557 .41915 L .26001 .43225 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.26001 .43225 m .1681 .34415 L .36343 .32456 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.88784 .38793 m .93137 .48107 L .71215 .49121 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.71215 .49121 m .65342 .40448 L .88784 .38793 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.5843 .3024 m .65342 .40448 L .44557 .41915 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.44557 .41915 m .36343 .32456 L .5843 .3024 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.26642 .21283 m .36343 .32456 L .1681 .34415 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.1681 .34415 m .06059 .2411 L .26642 .21283 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.83607 .27714 m .88784 .38793 L .65342 .40448 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.65342 .40448 m .5843 .3024 L .83607 .27714 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.50177 .18051 m .5843 .3024 L .36343 .32456 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.36343 .32456 m .26642 .21283 L .50177 .18051 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.77348 .1432 m .83607 .27714 L .5843 .3024 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.5843 .3024 m .50177 .18051 L .77348 .1432 L p
.492 .733 .979 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(2)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(3)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(4)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Create a Fuzzy Relation Manually", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Like fuzzy sets, fuzzy relations can also be created manually by surrounding \
the appropriate descriptors with the FuzzyRelation head. Here we create a \
simple fuzzy relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
Rel5 = FuzzyRelation[{{{1,1},.4},{{2,1},.6},
         {{2,2},.2}},UniversalSpace->{{0,5},{0,4}}] \
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzyRelation[{{{1, 1}, 0.4}, {{2, 1}, 0.6}, 
 
   {{2, 2}, 0.2}}, UniversalSpace -> {{0, 5}, {0, 4}}]











\
\>", "\<\
FuzzyRelation[{{{1, 1}, 0.4}, {{2, 1}, 0.6}, 
 
   {{2, 2}, 0.2}}, UniversalSpace -> {{0, 5}, {0, 4}}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel5];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(1)] .18668 .17018 -0.10677 1 Msboxa
[(2)] .31589 .13502 -0.06914 1 Msboxa
[(3)] .45455 .09731 -0.02788 1 Msboxa
[(4)] .60371 .05676 .01758 1 Msboxa
[(5)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .83729 .13681 -1 .24065 Msboxa
[(2)] .88584 .23047 -1 .21657 Msboxa
[(3)] .92637 .30866 -1 .19688 Msboxa
[(4)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.1853 .18312 m
.18461 .18959 L
s
P
[(1)] .18668 .17018 -0.10677 1 Mshowa
p
.002 w
.31499 .148 m
.31455 .15449 L
s
P
[(2)] .31589 .13502 -0.06914 1 Mshowa
p
.002 w
.45418 .11032 m
.454 .11682 L
s
P
[(3)] .45455 .09731 -0.02788 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(4)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(5)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.82464 .13986 m
.81831 .14138 L
s
P
[(1)] .83729 .13681 -1 .24065 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(2)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.9136 .31118 m
.90722 .31243 L
s
P
[(3)] .92637 .30866 -1 .19688 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(4)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.1853 .18312 m
.50905 .45645 L
s
P
p
.4 g
.31499 .148 m
.61042 .43816 L
s
P
p
.4 g
.45418 .11032 m
.71706 .41891 L
s
P
p
.4 g
.60394 .06977 m
.8294 .39864 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.17318 .29663 m
.82464 .13986 L
s
P
p
.4 g
.26533 .36485 m
.87312 .23322 L
s
P
p
.4 g
.34424 .42327 m
.9136 .31118 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.44602 .40323 m .50905 .45645 L .41257 .47386 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .34424 .42327 L .44602 .40323 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.55335 .3821 m .61042 .43816 L .50905 .45645 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.50905 .45645 m .44602 .40323 L .55335 .3821 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.6667 .35979 m .71706 .41891 L .61042 .43816 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.61042 .43816 m .55335 .3821 L .6667 .35979 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.37295 .34155 m .44602 .40323 L .34424 .42327 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.34424 .42327 m .26533 .36485 L .37295 .34155 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.78659 .33618 m .8294 .39864 L .71706 .41891 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71706 .41891 m .6667 .35979 L .78659 .33618 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.48613 .36355 m .55335 .3821 L .44602 .40323 L p
.199 .607 .947 r
F P
1 0 0 r
s
P
p
.002 w
.44602 .40323 m .37295 .34155 L .48613 .36355 L p
.199 .607 .947 r
F P
1 0 0 r
s
P
p
.002 w
.9136 .31118 m .94791 .37725 L .8294 .39864 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.8294 .39864 m .78659 .33618 L .9136 .31118 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.60783 .29068 m .6667 .35979 L .55335 .3821 L p
.697 .968 .934 r
F P
1 0 0 r
s
P
p
.002 w
.55335 .3821 m .48613 .36355 L .60783 .29068 L p
.697 .968 .934 r
F P
1 0 0 r
s
P
p
.002 w
.27987 .36784 m .37295 .34155 L .26533 .36485 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .17318 .29663 L .27987 .36784 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.73631 .26285 m .78659 .33618 L .6667 .35979 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.6667 .35979 m .60783 .29068 L .73631 .26285 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.40247 .39382 m .48613 .36355 L .37295 .34155 L p
.347 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.37295 .34155 m .27987 .36784 L .40247 .39382 L p
.347 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .9136 .31118 L .78659 .33618 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.78659 .33618 m .73631 .26285 L .87312 .23322 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.53809 .20882 m .60783 .29068 L .48613 .36355 L p
.867 .988 .719 r
F P
1 0 0 r
s
P
p
.002 w
.48613 .36355 m .40247 .39382 L .53809 .20882 L p
.867 .988 .719 r
F P
1 0 0 r
s
P
p
.002 w
.1853 .18312 m .27987 .36784 L .17318 .29663 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.17318 .29663 m .06415 .21592 L .1853 .18312 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67644 .17552 m .73631 .26285 L .60783 .29068 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.60783 .29068 m .53809 .20882 L .67644 .17552 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.82464 .13986 m .87312 .23322 L .73631 .26285 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.73631 .26285 m .67644 .17552 L .82464 .13986 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.31499 .148 m .40247 .39382 L .27987 .36784 L p
.589 .651 .879 r
F P
1 0 0 r
s
P
p
.002 w
.27987 .36784 m .1853 .18312 L .31499 .148 L p
.589 .651 .879 r
F P
1 0 0 r
s
P
p
.002 w
.60394 .06977 m .67644 .17552 L .53809 .20882 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.53809 .20882 m .45418 .11032 L .60394 .06977 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.45418 .11032 m .53809 .20882 L .40247 .39382 L p
.583 .592 .827 r
F P
1 0 0 r
s
P
p
.002 w
.40247 .39382 m .31499 .148 L .45418 .11032 L p
.583 .592 .827 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .82464 .13986 L .67644 .17552 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67644 .17552 m .60394 .06977 L .76552 .02602 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.1853 .18312 m
.18461 .18959 L
s
P
[(1)] .18668 .17018 -0.10677 1 Mshowa
p
.002 w
.31499 .148 m
.31455 .15449 L
s
P
[(2)] .31589 .13502 -0.06914 1 Mshowa
p
.002 w
.45418 .11032 m
.454 .11682 L
s
P
[(3)] .45455 .09731 -0.02788 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(4)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(5)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 280},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 116}, {23, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 90, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1852, 60, 67, 1, 70, "Subsection"],
Cell[1922, 63, 246, 5, 70, "Text"],
Cell[2171, 70, 143, 4, 70, "Text"],
Cell[2317, 76, 102, 2, 70, "Input"],
Cell[2422, 80, 304, 6, 70, "SmallText"]
}, Open  ]],
Cell[2738, 88, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[2811, 91, 94, 1, 70, "Subsection"],
Cell[2908, 94, 451, 8, 70, "Text"],
Cell[3362, 104, 621, 10, 70, "Text"],
Cell[3986, 116, 105, 2, 70, "Input"],
Cell[4094, 120, 157, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[4274, 127, 96, 2, 70, "Input"],
Cell[4373, 131, 16254, 1430, 70, 16096, 1425, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[20648, 1563, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[20721, 1566, 109, 1, 70, "Subsection"],
Cell[20833, 1569, 512, 8, 70, "Text"],
Cell[21348, 1579, 192, 6, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[21563, 1587, 96, 2, 70, "Input"],
Cell[21662, 1591, 16407, 1430, 70, 16249, 1425, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[38090, 3023, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[38163, 3026, 98, 1, 70, "Subsection"],
Cell[38264, 3029, 326, 6, 70, "Text"],
Cell[38593, 3037, 249, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[38865, 3044, 119, 2, 70, "Input"],
Cell[38987, 3048, 481, 28, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39500, 3078, 124, 2, 70, "Input"],
Cell[39627, 3082, 419, 24, 70, "Output"]
}, Open  ]],
Cell[40058, 3108, 229, 5, 70, "Text"],
Cell[40290, 3115, 108, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[40421, 3119, 96, 2, 70, "Input"],
Cell[40520, 3123, 14164, 1239, 70, 14006, 1234, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[54705, 4364, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[54778, 4367, 103, 1, 70, "Subsection"],
Cell[54884, 4370, 417, 7, 70, "Text"],
Cell[55304, 4379, 276, 5, 70, "Text"],
Cell[55583, 4386, 224, 7, 70, "Input"],
Cell[55810, 4395, 112, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[55945, 4399, 96, 2, 70, "Input"],
Cell[56044, 4403, 7230, 634, 70, 7072, 629, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[63295, 5039, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[63368, 5042, 87, 1, 70, "Subsection"],
Cell[63458, 5045, 234, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[63715, 5052, 178, 5, 70, "Input"],
Cell[63896, 5059, 326, 22, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64254, 5083, 96, 2, 70, "Input"],
Cell[64353, 5087, 9147, 804, 70, 8989, 799, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
