(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    139835,      12000]*)
(*NotebookOutlinePosition[    140705,      12032]*)
(*  CellTagsIndexPosition[    140661,      12028]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Operations
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack contains a wide variety of operations that can be \
performed on fuzzy sets and fuzzy relations. This chapter introduces these \
functions and demonstrates how to use them.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Set Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This section describes operations that can be performed on individual fuzzy \
sets. To demonstrate the various operations, we first create two fuzzy sets. \
We use the FuzzyTrapezoid function, described earlier in this manual, to \
create the fuzzy sets. To examine the fuzzy sets we created, we use the \
FuzzyPlot graphing function. The graphing functions are described later in \
this manual.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS1 = FuzzyTrapezoid[1,6,13,17]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 1/5}, {3, 2/5}, {4, 3/5}, {5, 4/5}, {6, 1}, 
 
   {7, 1}, {8, 1}, {9, 1}, {10, 1}, {11, 1}, {12, 1}, {13, 1}, 
 
   {14, 3/4}, {15, 1/2}, {16, 1/4}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              1       2       3       4
FuzzySet[{{2, -}, {3, -}, {4, -}, {5, -}, {6, 1}, {7, 1}, 
              5       5       5       5
 
   {8, 1}, {9, 1}, {10, 1}, {11, 1}, {12, 1}, {13, 1}, 
 
        3        1        1
   {14, -}, {15, -}, {16, -}}, UniversalSpace -> {0, 20}]
        4        2        4\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FS2 = FuzzyTrapezoid[0,5,5,15,0.8]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{1, 0.16}, {2, 0.32}, {3, 0.48}, 
 
   {4, 0.6400000000000001}, {5, 0.8}, {6, 0.72}, 
 
   {7, 0.6399999999999999}, {8, 0.56}, {9, 0.48}, {10, 0.4}, 
 
   {11, 0.3199999999999999}, {12, 0.2399999999999999}, 
 
   {13, 0.16}, {14, 0.0799999999999999}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
FuzzySet[{{1, 0.16}, {2, 0.32}, {3, 0.48}, {4, 0.64}, 
 
   {5, 0.8}, {6, 0.72}, {7, 0.64}, {8, 0.56}, {9, 0.48}, 
 
   {10, 0.4}, {11, 0.32}, {12, 0.24}, {13, 0.16}, {14, 0.08}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .12361 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .24721 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .37082 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .49443 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .61803 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .61803 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .61803 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .46353 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .30902 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .15451 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 0 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 0 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 0 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 .09889 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 .19777 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 .29666 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .39554 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .49443 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .44498 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .39554 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .3461 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .29666 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .24721 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .19777 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .14833 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .09889 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .04944 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 0 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 0 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 0 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 0 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 0 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 0 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
In this graph, FS1 is the trapezoid shaped fuzzy set, and FS2 is the \
triangular fuzzy set. These fuzzy sets are plotted in red and blue, \
respectively, in a Mathematica session.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Height", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Height[A] returns the value of the largest membership grade in fuzzy set A. A \
fuzzy set with a height of 1 is called a normal fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
When we call this function with the fuzzy sets we created earler, we see that \
FS1 is a normal fuzzy set, and FS2 is a subnormal fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Height[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
1











\
\>", "\<\
1\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Height[FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
0.8











\
\>", "\<\
0.8\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Cardinality", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Cardinality[A] returns the sum of all of the membership grades in fuzzy set \
A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Cardinality[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
23/2











\
\>", "\<\
23
--
2\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Relative Cardinality", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
RelativeCardinality[A] returns the cardinality of fuzzy set A divided by the \
total number of elements in the universal space of A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["RelativeCardinality[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
23/42











\
\>", "\<\
23
--
42\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Center of Area (Defuzzification)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CenterOfArea[A,opts] returns the center of area defuzzification of fuzzy set \
A. If the option ShowGraph is set to True, this function returns a plot of \
fuzzy set A with a dot along the base axis indicating where the center of \
area is located.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In the following examples, we first find the center of area of FS2. The \
second example demonstrates the use of the ShowGraph option. The graph \
produced by the ShowGraph option can be customized using any of the options \
available with Mathematica's standard Plot function. To demonstrate this, we \
give the plot a label with the PlotLabel option.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["CenterOfArea[FS2]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
6.666666666666666











\
\>", "\<\
6.66667\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["CenterOfArea[FS2,ShowGraph->True,PlotLabel->\"COA\"];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Center of area is 6.66667", "Print",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(COA)] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
[(COA)] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 .09889 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 .19777 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 .29666 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .39554 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .49443 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .44498 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .39554 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .3461 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .29666 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .24721 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .19777 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .14833 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .09889 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .04944 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 0 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 0 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 0 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 0 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
P
p
.2 0 1 r
7 Mabswid
.34848 0 Mdot
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Mean of Max (Defuzzification)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
MeanOfMax[A,opts] returns the mean of maximum defuzzification of fuzzy set A. \
This function also has a ShowGraph option for visualizing the defuzzification \
(see CenterOfArea).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["MeanOfMax[FS1,ShowGraph->True,PlotLabel->\"MOM\"];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
               19
Mean of max is --
               2\
\>", "Print",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(MOM)] .5 .61803 0 -2 0 0 1 Mouter Mrotsboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
[(MOM)] .5 .61803 0 -2 0 0 1 Mouter Mrotshowa
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 .12361 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 .24721 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .37082 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .49443 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .61803 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .61803 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .61803 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .46353 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .30902 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .15451 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 0 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 0 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
P
p
.2 0 1 r
7 Mabswid
.47727 0 Mdot
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Support", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Support[A] returns a list of all elements of fuzzy set A with nonzero \
membership grades.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Support[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}











\
\>", "\<\
{2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Nucleus", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Nucleus[A] returns a list of all elements of fuzzy set A with a membership \
grade equal to 1.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Nucleus[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{6, 7, 8, 9, 10, 11, 12, 13}











\
\>", "\<\
{6, 7, 8, 9, 10, 11, 12, 13}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Alpha Level Set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
AlphaLevelSet[A, alpha] returns a list of all elements of fuzzy set A with \
membership grades greater than or equal to alpha.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["AlphaLevelSet[FS1,0.6]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}











\
\>", "\<\
{4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Strong Alpha Level Set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
StrongAlphaLevelSet[A, alpha] returns a list of all elements of fuzzy set A \
with membership grades greater than alpha.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["StrongAlphaLevelSet[FS1,0.6]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}











\
\>", "\<\
{5, 6, 7, 8, 9, 10, 11, 12, 13, 14}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Equilibrium Set", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
EquilibriumSet[A] returns a list of all elements of fuzzy set A with \
membership grades equal to 0.5.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["EquilibriumSet[FS1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
{15}











\
\>", "\<\
{15}\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Relation Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This section describes operations that can be performed on individual fuzzy \
relations. To demonstrate these operations, we create a new fuzzy relation \
with the FuzzyTrapezoid function. We use the FuzzySurfacePlot function to \
show the new fuzzy relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel1 = FuzzyTrapezoid[{1,3,5,7},{1,3,6,9},
         UniversalSpace->{{1,7},{0,9}}];\
\>", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .80593 .07632 -1 .25649 Msboxa
[(2)] .83129 .12525 -1 .24366 Msboxa
[(3)] .8545 .17002 -1 .23205 Msboxa
[(4)] .87582 .21114 -1 .2215 Msboxa
[(5)] .89546 .24904 -1 .21186 Msboxa
[(6)] .91362 .28407 -1 .20303 Msboxa
[(7)] .93046 .31656 -1 .19491 Msboxa
[(8)] .94612 .34677 -1 .18741 Msboxa
[(9)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.79332 .07956 m
.78702 .08117 L
s
P
[(1)] .80593 .07632 -1 .25649 Mshowa
p
.002 w
.81865 .12833 m
.81233 .12987 L
s
P
[(2)] .83129 .12525 -1 .24366 Mshowa
p
.002 w
.84183 .17296 m
.83549 .17444 L
s
P
[(3)] .8545 .17002 -1 .23205 Mshowa
p
.002 w
.86311 .21395 m
.85676 .21536 L
s
P
[(4)] .87582 .21114 -1 .2215 Mshowa
p
.002 w
.88273 .25173 m
.87637 .25308 L
s
P
[(5)] .89546 .24904 -1 .21186 Mshowa
p
.002 w
.90087 .28666 m
.89449 .28796 L
s
P
[(6)] .91362 .28407 -1 .20303 Mshowa
p
.002 w
.91769 .31905 m
.9113 .3203 L
s
P
[(7)] .93046 .31656 -1 .19491 Mshowa
p
.002 w
.93333 .34917 m
.92694 .35037 L
s
P
[(8)] .94612 .34677 -1 .18741 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(9)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.16197 .28834 m
.81865 .12833 L
s
P
p
.4 g
.2461 .35062 m
.86311 .21395 L
s
P
p
.4 g
.31922 .40476 m
.90087 .28666 L
s
P
p
.4 g
.38336 .45224 m
.93333 .34917 L
s
P
P
p
.002 w
.46377 .50653 m .49264 .45941 L .41257 .47386 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .38336 .45224 L .46377 .50653 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.55092 .49173 m .57606 .44436 L .49264 .45941 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .46377 .50653 L .55092 .49173 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.43294 .52117 m .46377 .50653 L .38336 .45224 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.38336 .45224 m .35231 .42925 L .43294 .52117 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.64199 .47626 m .66306 .42866 L .57606 .44436 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .55092 .49173 L .64199 .47626 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.40084 .49852 m .43294 .52117 L .35231 .42925 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.35231 .42925 m .31922 .40476 L .40084 .49852 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.73727 .46007 m .75386 .41227 L .66306 .42866 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .64199 .47626 L .73727 .46007 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.523 .54432 m .55092 .49173 L .46377 .50653 L p
.465 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.46377 .50653 m .43294 .52117 L .523 .54432 L p
.465 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.83704 .44313 m .84871 .39515 L .75386 .41227 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .73727 .46007 L .83704 .44313 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.61855 .52923 m .64199 .47626 L .55092 .49173 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.55092 .49173 m .523 .54432 L .61855 .52923 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.36645 .47425 m .40084 .49852 L .31922 .40476 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.31922 .40476 m .2839 .3786 L .36645 .47425 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.93333 .34917 m .94791 .37725 L .84871 .39515 L p
.04 0 .038 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .83704 .44313 L .93333 .34917 L p
.04 0 .038 r
F P
1 0 0 r
s
P
p
.002 w
.49183 .60305 m .523 .54432 L .43294 .52117 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.43294 .52117 m .40084 .49852 L .49183 .60305 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.71876 .5134 m .73727 .46007 L .64199 .47626 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.64199 .47626 m .61855 .52923 L .71876 .5134 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.3295 .44818 m .36645 .47425 L .2839 .3786 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.2839 .3786 m .2461 .35062 L .3295 .44818 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.82093 .4562 m .83704 .44313 L .73727 .46007 L p
.212 0 .068 r
F P
1 0 0 r
s
P
p
.002 w
.73727 .46007 m .71876 .5134 L .82093 .4562 L p
.212 0 .068 r
F P
1 0 0 r
s
P
p
.002 w
.5923 .58854 m .61855 .52923 L .523 .54432 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.523 .54432 m .49183 .60305 L .5923 .58854 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.45883 .58128 m .49183 .60305 L .40084 .49852 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.40084 .49852 m .36645 .47425 L .45883 .58128 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.91769 .31905 m .93333 .34917 L .83704 .44313 L p
.704 .898 .53 r
F P
1 0 0 r
s
P
p
.002 w
.83704 .44313 m .82093 .4562 L .91769 .31905 L p
.704 .898 .53 r
F P
1 0 0 r
s
P
p
.002 w
.28972 .4201 m .3295 .44818 L .2461 .35062 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.2461 .35062 m .20556 .32061 L .28972 .4201 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.69798 .57327 m .71876 .5134 L .61855 .52923 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.61855 .52923 m .5923 .58854 L .69798 .57327 L p
.4 0 .133 r
F P
1 0 0 r
s
P
p
.002 w
.42323 .55781 m .45883 .58128 L .36645 .47425 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.36645 .47425 m .3295 .44818 L .42323 .55781 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.80029 .42875 m .82093 .4562 L .71876 .5134 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.71876 .5134 m .69798 .57327 L .80029 .42875 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.24675 .38978 m .28972 .4201 L .20556 .32061 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.20556 .32061 m .16197 .28834 L .24675 .38978 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.90087 .28666 m .91769 .31905 L .82093 .4562 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.56234 .56564 m .5923 .58854 L .49183 .60305 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.49183 .60305 m .45883 .58128 L .56234 .56564 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.82093 .4562 m .80029 .42875 L .90087 .28666 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.38472 .53241 m .42323 .55781 L .3295 .44818 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.3295 .44818 m .28972 .4201 L .38472 .53241 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.67143 .54915 m .69798 .57327 L .5923 .58854 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.5923 .58854 m .56234 .56564 L .67143 .54915 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.21271 .22848 m .24675 .38978 L .16197 .28834 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.16197 .28834 m .11498 .25354 L .21271 .22848 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.88273 .25173 m .90087 .28666 L .80029 .42875 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.52996 .54089 m .56234 .56564 L .45883 .58128 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.45883 .58128 m .42323 .55781 L .52996 .54089 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.80029 .42875 m .77801 .39912 L .88273 .25173 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.77801 .39912 m .80029 .42875 L .69798 .57327 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.69798 .57327 m .67143 .54915 L .77801 .39912 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.35044 .3679 m .38472 .53241 L .28972 .4201 L p
.523 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.28972 .4201 m .24675 .38978 L .35044 .3679 L p
.523 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.64267 .52303 m .67143 .54915 L .56234 .56564 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.56234 .56564 m .52996 .54089 L .64267 .52303 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .21271 .22848 L .11498 .25354 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.11498 .25354 m .06415 .21592 L .16454 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86311 .21395 m .88273 .25173 L .77801 .39912 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.49484 .51406 m .52996 .54089 L .42323 .55781 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.42323 .55781 m .38472 .53241 L .49484 .51406 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.77801 .39912 m .75391 .36706 L .86311 .21395 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.75391 .36706 m .77801 .39912 L .67143 .54915 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.67143 .54915 m .64267 .52303 L .75391 .36706 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.31588 .20201 m .35044 .3679 L .24675 .38978 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.24675 .38978 m .21271 .22848 L .31588 .20201 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .31588 .20201 L .21271 .22848 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.21271 .22848 m .16454 .18874 L .27076 .15998 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.61141 .49463 m .64267 .52303 L .52996 .54089 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.52996 .54089 m .49484 .51406 L .61141 .49463 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.84183 .17296 m .86311 .21395 L .75391 .36706 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.46006 .34477 m .49484 .51406 L .38472 .53241 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.38472 .53241 m .35044 .3679 L .46006 .34477 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.42498 .17403 m .46006 .34477 L .35044 .3679 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.35044 .3679 m .31588 .20201 L .42498 .17403 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.75391 .36706 m .72773 .33225 L .84183 .17296 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.72773 .33225 m .75391 .36706 L .64267 .52303 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .42498 .17403 L .31588 .20201 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.31588 .20201 m .27076 .15998 L .38334 .1295 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.64267 .52303 m .61141 .49463 L .72773 .33225 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.57612 .32029 m .61141 .49463 L .49484 .51406 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.49484 .51406 m .46006 .34477 L .57612 .32029 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.54051 .1444 m .57612 .32029 L .46006 .34477 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.46006 .34477 m .42498 .17403 L .54051 .1444 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .54051 .1444 L .42498 .17403 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.42498 .17403 m .38334 .1295 L .50287 .09714 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.81865 .12833 m .84183 .17296 L .72773 .33225 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.72773 .33225 m .6992 .29432 L .81865 .12833 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.6992 .29432 m .72773 .33225 L .61141 .49463 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.61141 .49463 m .57612 .32029 L .6992 .29432 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.66307 .11296 m .6992 .29432 L .57612 .32029 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.57612 .32029 m .54051 .1444 L .66307 .11296 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .66307 .11296 L .54051 .1444 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.54051 .1444 m .50287 .09714 L .63002 .06271 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.79332 .07956 m .81865 .12833 L .6992 .29432 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.6992 .29432 m .66307 .11296 L .79332 .07956 L p
.57 .497 .734 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .79332 .07956 L .66307 .11296 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.66307 .11296 m .63002 .06271 L .76552 .02602 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 282},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Projections", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FirstProjection[A] returns a fuzzy set which is the projection of fuzzy \
relation A onto the first space of the relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Proj1 = FirstProjection[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 1/2}, {3, 1}, {4, 1}, {5, 1}, {6, 1/2}}, 
 
  UniversalSpace -> {1, 7}]











\
\>", "\<\
              1                               1
FuzzySet[{{2, -}, {3, 1}, {4, 1}, {5, 1}, {6, -}}, 
              2                               2
 
  UniversalSpace -> {1, 7}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["We can plot the first projection using FuzzyPlot.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Proj1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 0.125 0 0.618034 [
[(1)] .125 0 0 2 Msboxa
[(2)] .25 0 0 2 Msboxa
[(3)] .375 0 0 2 Msboxa
[(4)] .5 0 0 2 Msboxa
[(5)] .625 0 0 2 Msboxa
[(6)] .75 0 0 2 Msboxa
[(7)] .875 0 0 2 Msboxa
[(8)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.125 0 m
.125 .00625 L
s
P
[(1)] .125 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(2)] .25 0 0 2 Mshowa
p
.002 w
.375 0 m
.375 .00625 L
s
P
[(3)] .375 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(4)] .5 0 0 2 Mshowa
p
.002 w
.625 0 m
.625 .00625 L
s
P
[(5)] .625 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(6)] .75 0 0 2 Mshowa
p
.002 w
.875 0 m
.875 .00625 L
s
P
[(7)] .875 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(8)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.125 0 m
.125 0 L
s
P
p
2.5 Mabswid
.25 .30902 m
.25 0 L
s
P
p
2.5 Mabswid
.375 .61803 m
.375 0 L
s
P
p
2.5 Mabswid
.5 .61803 m
.5 0 L
s
P
p
2.5 Mabswid
.625 .61803 m
.625 0 L
s
P
p
2.5 Mabswid
.75 .30902 m
.75 0 L
s
P
p
2.5 Mabswid
.875 0 m
.875 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
SecondProjection[A] returns a fuzzy set that is the projection of fuzzy \
relation A onto the second space of the relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Proj2 = SecondProjection[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 1/2}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, {7, 2/3}, 
 
   {8, 1/3}}, UniversalSpace -> {0, 9}]











\
\>", "\<\
              1                                       2
FuzzySet[{{2, -}, {3, 1}, {4, 1}, {5, 1}, {6, 1}, {7, -}, 
              2                                       3
 
       1
   {8, -}}, UniversalSpace -> {0, 9}]
       3\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[Proj2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0909091 0.0909091 0 0.618034 [
[(0)] .09091 0 0 2 Msboxa
[(1)] .18182 0 0 2 Msboxa
[(2)] .27273 0 0 2 Msboxa
[(3)] .36364 0 0 2 Msboxa
[(4)] .45455 0 0 2 Msboxa
[(5)] .54545 0 0 2 Msboxa
[(6)] .63636 0 0 2 Msboxa
[(7)] .72727 0 0 2 Msboxa
[(8)] .81818 0 0 2 Msboxa
[(9)] .90909 0 0 2 Msboxa
[(10)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(0)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(1)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(2)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(3)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(4)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(5)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(6)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(7)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(8)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(9)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(10)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.18182 0 m
.18182 0 L
s
P
p
2.5 Mabswid
.27273 .30902 m
.27273 0 L
s
P
p
2.5 Mabswid
.36364 .61803 m
.36364 0 L
s
P
p
2.5 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
2.5 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
2.5 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
2.5 Mabswid
.72727 .41202 m
.72727 0 L
s
P
p
2.5 Mabswid
.81818 .20601 m
.81818 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
GlobalProjection[A] returns a value which represents the maximum membership \
grade in fuzzy relation A. This is analogous to the Height function for fuzzy \
sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["GlobalProjection[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
1











\
\>", "\<\
1\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Set or Fuzzy Relation Operations", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
This section describes operations that can be performed on either individual \
fuzzy sets or individual fuzzy relations. To demonstrate these operations, we \
create one new fuzzy set and one new fuzzy relation to operate on. In some of \
the examples that follow, we demonstrate functions operating on just a fuzzy \
set or just a fuzzy relation, but keep in mind that all the operators in this \
section work for both fuzzy sets and fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FS = FuzzyTrapezoid[1,8,13,19];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 .08829 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 .17658 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .26487 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .35316 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .44145 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .52974 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .61803 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .51503 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .41202 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .30902 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 .20601 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 .10301 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Rel = FuzzyTrapezoid[{1,3,5,7},{0,2,5,7},0.8,
        UniversalSpace->{{1,7},{0,7}}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .81341 .09076 -1 .25269 Msboxa
[(2)] .8448 .15131 -1 .23689 Msboxa
[(3)] .87288 .20547 -1 .22295 Msboxa
[(4)] .89814 .25421 -1 .21056 Msboxa
[(5)] .92099 .29829 -1 .19947 Msboxa
[(6)] .94176 .33836 -1 .18949 Msboxa
[(7)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(1)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(2)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(3)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(4)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(5)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(6)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(7)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.18728 .30707 m
.83214 .15431 L
s
P
p
.4 g
.28909 .38245 m
.88541 .25689 L
s
P
p
.4 g
.37469 .44582 m
.92897 .34078 L
s
P
P
p
.002 w
.45513 .5147 m .49264 .45941 L .41257 .47386 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .37469 .44582 L .45513 .5147 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.54325 .49988 m .57606 .44436 L .49264 .45941 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .45513 .5147 L .54325 .49988 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.41566 .48589 m .45513 .5147 L .37469 .44582 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.37469 .44582 m .33366 .41545 L .41566 .48589 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.6354 .48439 m .66306 .42866 L .57606 .44436 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .54325 .49988 L .6354 .48439 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.73186 .46817 m .75386 .41227 L .66306 .42866 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .6354 .48439 L .73186 .46817 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.37262 .45447 m .41566 .48589 L .33366 .41545 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.33366 .41545 m .28909 .38245 L .37262 .45447 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.50577 .5633 m .54325 .49988 L .45513 .5147 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.45513 .5147 m .41566 .48589 L .50577 .5633 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.83294 .45117 m .84871 .39515 L .75386 .41227 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .73186 .46817 L .83294 .45117 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.60371 .54823 m .6354 .48439 L .54325 .49988 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.54325 .49988 m .50577 .5633 L .60371 .54823 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.92897 .34078 m .94791 .37725 L .84871 .39515 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .83294 .45117 L .92897 .34078 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32548 .42005 m .37262 .45447 L .28909 .38245 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.28909 .38245 m .24049 .34646 L .32548 .42005 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.4648 .53395 m .50577 .5633 L .41566 .48589 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41566 .48589 m .37262 .45447 L .4648 .53395 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.70657 .53241 m .73186 .46817 L .6354 .48439 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.6354 .48439 m .60371 .54823 L .70657 .53241 L p
.378 0 .088 r
F P
1 0 0 r
s
P
p
.002 w
.80757 .41643 m .83294 .45117 L .73186 .46817 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.73186 .46817 m .70657 .53241 L .80757 .41643 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.27363 .3822 m .32548 .42005 L .24049 .34646 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.24049 .34646 m .18728 .30707 L .27363 .3822 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41972 .50165 m .4648 .53395 L .37262 .45447 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.37262 .45447 m .32548 .42005 L .41972 .50165 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.90823 .30084 m .92897 .34078 L .83294 .45117 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.56648 .51738 m .60371 .54823 L .50577 .5633 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.50577 .5633 m .4648 .53395 L .56648 .51738 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.83294 .45117 m .80757 .41643 L .90823 .30084 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.67354 .49995 m .70657 .53241 L .60371 .54823 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.60371 .54823 m .56648 .51738 L .67354 .49995 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.21634 .34037 m .27363 .3822 L .18728 .30707 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.18728 .30707 m .12877 .26376 L .21634 .34037 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.36988 .46594 m .41972 .50165 L .32548 .42005 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32548 .42005 m .27363 .3822 L .36988 .46594 L p
.517 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.88541 .25689 m .90823 .30084 L .80757 .41643 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.52542 .48336 m .56648 .51738 L .4648 .53395 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.4648 .53395 m .41972 .50165 L .52542 .48336 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.80757 .41643 m .77966 .37821 L .88541 .25689 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.77966 .37821 m .80757 .41643 L .70657 .53241 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.70657 .53241 m .67354 .49995 L .77966 .37821 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.637 .46405 m .67354 .49995 L .56648 .51738 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.56648 .51738 m .52542 .48336 L .637 .46405 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .21634 .34037 L .12877 .26376 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.12877 .26376 m .06415 .21592 L .16454 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.3215 .3166 m .36988 .46594 L .27363 .3822 L p
.532 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.27363 .3822 m .21634 .34037 L .3215 .3166 L p
.532 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.86018 .20831 m .88541 .25689 L .77966 .37821 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.4799 .44564 m .52542 .48336 L .41972 .50165 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.41972 .50165 m .36988 .46594 L .4799 .44564 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.77966 .37821 m .74879 .33595 L .86018 .20831 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.74879 .33595 m .77966 .37821 L .67354 .49995 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.67354 .49995 m .637 .46405 L .74879 .33595 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.59638 .42414 m .637 .46405 L .52542 .48336 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.52542 .48336 m .4799 .44564 L .59638 .42414 L p
.492 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .3215 .3166 L .21634 .34037 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.21634 .34037 m .16454 .18874 L .27076 .15998 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.83214 .15431 m .86018 .20831 L .74879 .33595 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.4328 .29144 m .4799 .44564 L .36988 .46594 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.36988 .46594 m .3215 .3166 L .4328 .29144 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.74879 .33595 m .71449 .28897 L .83214 .15431 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.71449 .28897 m .74879 .33595 L .637 .46405 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.637 .46405 m .59638 .42414 L .71449 .28897 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .4328 .29144 L .3215 .3166 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.3215 .3166 m .27076 .15998 L .38334 .1295 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.5508 .26477 m .59638 .42414 L .4799 .44564 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.4799 .44564 m .4328 .29144 L .5508 .26477 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .5508 .26477 L .4328 .29144 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.4328 .29144 m .38334 .1295 L .50287 .09714 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.8008 .09395 m .83214 .15431 L .71449 .28897 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.71449 .28897 m .67613 .23644 L .8008 .09395 L p
.888 .945 .842 r
F P
1 0 0 r
s
P
p
.002 w
.67613 .23644 m .71449 .28897 L .59638 .42414 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.59638 .42414 m .5508 .26477 L .67613 .23644 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .67613 .23644 L .5508 .26477 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.5508 .26477 m .50287 .09714 L .63002 .06271 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .8008 .09395 L .67613 .23644 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.67613 .23644 m .63002 .06271 L .76552 .02602 L p
.579 .568 .805 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 280},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Concentration", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Concentrate[A] concentrates the membership grades of A, where A is a fuzzy \
set or a fuzzy relation. The concentration function squares the membership \
grades for each element of A. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We find the concentration of our newly created fuzzy set here, and plot the \
original fuzzy set with its concentration on the same graph to show the \
effects of the operation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Con = Concentrate[FS];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS,Con];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .08829 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .17658 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .26487 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .35316 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .44145 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .52974 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .61803 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .51503 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .41202 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .30902 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 .20601 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 .10301 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 0 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 0 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 .01261 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 .05045 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .11352 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .20181 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .31532 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .45407 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .61803 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .61803 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .61803 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .61803 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .61803 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .61803 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .42919 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .27468 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .15451 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .06867 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 .01717 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 0 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 0 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
In the graph, the concentrated fuzzy set is included in the original fuzzy \
set, and it looks like a concentrated version of the original fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Dilation", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Dilate[A] dilates the membership grades of A, where A is a fuzzy set or fuzzy \
relation. The dilation function takes the square root of the membership \
grades for each element in A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Dil = Dilate[Rel];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Dil];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .81341 .09076 -1 .25269 Msboxa
[(2)] .8448 .15131 -1 .23689 Msboxa
[(3)] .87288 .20547 -1 .22295 Msboxa
[(4)] .89814 .25421 -1 .21056 Msboxa
[(5)] .92099 .29829 -1 .19947 Msboxa
[(6)] .94176 .33836 -1 .18949 Msboxa
[(7)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(1)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(2)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(3)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(4)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(5)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(6)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(7)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.18728 .30707 m
.83214 .15431 L
s
P
p
.4 g
.28909 .38245 m
.88541 .25689 L
s
P
p
.4 g
.37469 .44582 m
.92897 .34078 L
s
P
P
p
.002 w
.45387 .56565 m .49264 .45941 L .41257 .47386 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .37469 .44582 L .45387 .56565 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.5432 .55178 m .57606 .44436 L .49264 .45941 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .45387 .56565 L .5432 .55178 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.41379 .53868 m .45387 .56565 L .37469 .44582 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.37469 .44582 m .33366 .41545 L .41379 .53868 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.63667 .53727 m .66306 .42866 L .57606 .44436 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .5432 .55178 L .63667 .53727 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.73458 .52206 m .75386 .41227 L .66306 .42866 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63667 .53727 L .73458 .52206 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.37002 .50921 m .41379 .53868 L .33366 .41545 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.33366 .41545 m .28909 .38245 L .37002 .50921 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.83725 .50612 m .84871 .39515 L .75386 .41227 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .73458 .52206 L .83725 .50612 L p
.482 .145 .317 r
F P
1 0 0 r
s
P
p
.002 w
.50552 .58609 m .5432 .55178 L .45387 .56565 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.45387 .56565 m .41379 .53868 L .50552 .58609 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.92897 .34078 m .94791 .37725 L .84871 .39515 L p
.052 0 .215 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .83725 .50612 L .92897 .34078 L p
.052 0 .215 r
F P
1 0 0 r
s
P
p
.002 w
.60407 .57149 m .63667 .53727 L .5432 .55178 L p
.233 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.5432 .55178 m .50552 .58609 L .60407 .57149 L p
.233 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.32201 .4769 m .37002 .50921 L .28909 .38245 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.28909 .38245 m .24049 .34646 L .32201 .4769 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.46428 .55764 m .50552 .58609 L .41379 .53868 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.41379 .53868 m .37002 .50921 L .46428 .55764 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.70759 .55615 m .73458 .52206 L .63667 .53727 L p
.233 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.63667 .53727 m .60407 .57149 L .70759 .55615 L p
.233 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.81169 .4735 m .83725 .50612 L .73458 .52206 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.73458 .52206 m .70759 .55615 L .81169 .4735 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.26913 .44131 m .32201 .4769 L .24049 .34646 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.24049 .34646 m .18728 .30707 L .26913 .44131 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.90823 .30084 m .92897 .34078 L .83725 .50612 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.56661 .54159 m .60407 .57149 L .50552 .58609 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.50552 .58609 m .46428 .55764 L .56661 .54159 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.41887 .52632 m .46428 .55764 L .37002 .50921 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.37002 .50921 m .32201 .4769 L .41887 .52632 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.83725 .50612 m .81169 .4735 L .90823 .30084 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.67439 .52467 m .70759 .55615 L .60407 .57149 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.60407 .57149 m .56661 .54159 L .67439 .52467 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.2106 .40192 m .26913 .44131 L .18728 .30707 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.18728 .30707 m .12877 .26376 L .2106 .40192 L p
.802 .323 0 r
F P
1 0 0 r
s
P
p
.002 w
.88541 .25689 m .90823 .30084 L .81169 .4735 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.52528 .50858 m .56661 .54159 L .46428 .55764 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.46428 .55764 m .41887 .52632 L .52528 .50858 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.78352 .43755 m .81169 .4735 L .70759 .55615 L p
.812 .946 .911 r
F P
1 0 0 r
s
P
p
.002 w
.70759 .55615 m .67439 .52467 L .78352 .43755 L p
.812 .946 .911 r
F P
1 0 0 r
s
P
p
.002 w
.36864 .49167 m .41887 .52632 L .32201 .4769 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.32201 .4769 m .26913 .44131 L .36864 .49167 L p
0 .302 .713 r
F P
1 0 0 r
s
P
p
.002 w
.81169 .4735 m .78352 .43755 L .88541 .25689 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.63764 .48984 m .67439 .52467 L .56661 .54159 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.56661 .54159 m .52528 .50858 L .63764 .48984 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .2106 .40192 L .12877 .26376 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.12877 .26376 m .06415 .21592 L .16454 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86018 .20831 m .88541 .25689 L .78352 .43755 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.47942 .47197 m .52528 .50858 L .41887 .52632 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.41887 .52632 m .36864 .49167 L .47942 .47197 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.75233 .39774 m .78352 .43755 L .67439 .52467 L p
.812 .946 .911 r
F P
1 0 0 r
s
P
p
.002 w
.67439 .52467 m .63764 .48984 L .75233 .39774 L p
.812 .946 .911 r
F P
1 0 0 r
s
P
p
.002 w
.31747 .3795 m .36864 .49167 L .26913 .44131 L p
.51 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.26913 .44131 m .2106 .40192 L .31747 .3795 L p
.51 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.78352 .43755 m .75233 .39774 L .86018 .20831 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.59675 .45109 m .63764 .48984 L .52528 .50858 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.52528 .50858 m .47942 .47197 L .59675 .45109 L p
.48 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.83214 .15431 m .86018 .20831 L .75233 .39774 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.43071 .35574 m .47942 .47197 L .36864 .49167 L p
.578 .634 .87 r
F P
1 0 0 r
s
P
p
.002 w
.36864 .49167 m .31747 .3795 L .43071 .35574 L p
.578 .634 .87 r
F P
1 0 0 r
s
P
p
.002 w
.71759 .35341 m .75233 .39774 L .63764 .48984 L p
.812 .946 .911 r
F P
1 0 0 r
s
P
p
.002 w
.63764 .48984 m .59675 .45109 L .71759 .35341 L p
.812 .946 .911 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .31747 .3795 L .2106 .40192 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.2106 .40192 m .16454 .18874 L .27076 .15998 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.75233 .39774 m .71759 .35341 L .83214 .15431 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.55089 .33054 m .59675 .45109 L .47942 .47197 L p
.578 .634 .87 r
F P
1 0 0 r
s
P
p
.002 w
.47942 .47197 m .43071 .35574 L .55089 .33054 L p
.578 .634 .87 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .43071 .35574 L .31747 .3795 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.31747 .3795 m .27076 .15998 L .38334 .1295 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.8008 .09395 m .83214 .15431 L .71759 .35341 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.67867 .30373 m .71759 .35341 L .59675 .45109 L p
.578 .634 .87 r
F P
1 0 0 r
s
P
p
.002 w
.59675 .45109 m .55089 .33054 L .67867 .30373 L p
.578 .634 .87 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .55089 .33054 L .43071 .35574 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.43071 .35574 m .38334 .1295 L .50287 .09714 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.71759 .35341 m .67867 .30373 L .8008 .09395 L p
.953 .937 .735 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .67867 .30373 L .55089 .33054 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.55089 .33054 m .50287 .09714 L .63002 .06271 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .8008 .09395 L .67867 .30373 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.67867 .30373 m .63002 .06271 L .76552 .02602 L p
.563 .495 .737 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
From the graph we see that the new fuzzy relation is a dilated version of the \
original fuzzy relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Intensify Contrast", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
IntensifyContrast[A] intensifies the contrast between the membership grades \
of A. The new membership grades are calculated as follows.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
    2*(xn)^2           if xn < =  0.5,
    1-2 (1-xn)^2      otherwise,           xn = original membership grade\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["IC = IntensifyContrast[FS]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 2/49}, {3, 8/49}, {4, 18/49}, {5, 31/49}, 
 
   {6, 41/49}, {7, 47/49}, {8, 1}, {9, 1}, {10, 1}, {11, 1}, 
 
   {12, 1}, {13, 1}, {14, 17/18}, {15, 7/9}, {16, 1/2}, 
 
   {17, 2/9}, {18, 1/18}}, UniversalSpace -> {0, 20}]











\
\>", "\<\
              2        8        18       31       41
FuzzySet[{{2, --}, {3, --}, {4, --}, {5, --}, {6, --}, 
              49       49       49       49       49
 
       47
   {7, --}, {8, 1}, {9, 1}, {10, 1}, {11, 1}, {12, 1}, 
       49
 
                 17        7        1        2        1
   {13, 1}, {14, --}, {15, -}, {16, -}, {17, -}, {18, --}}, 
                 18        9        2        9        18
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS,IC];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .08829 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .17658 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .26487 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .35316 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .44145 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .52974 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .61803 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .51503 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .41202 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .30902 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 .20601 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 .10301 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 0 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 0 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 .02523 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 .1009 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .22703 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .391 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .51713 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .59281 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .61803 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .61803 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .61803 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .61803 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .61803 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .61803 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .5837 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .48069 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .30902 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .13734 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 .03434 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 0 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 0 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Normalize", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Normalize[A] adjusts the membership grades of A to create a normalized fuzzy \
set or fuzzy relation with a height of 1.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Norm = Normalize[Rel];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Norm];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .81341 .09076 -1 .25269 Msboxa
[(2)] .8448 .15131 -1 .23689 Msboxa
[(3)] .87288 .20547 -1 .22295 Msboxa
[(4)] .89814 .25421 -1 .21056 Msboxa
[(5)] .92099 .29829 -1 .19947 Msboxa
[(6)] .94176 .33836 -1 .18949 Msboxa
[(7)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(1)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(2)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(3)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(4)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(5)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(6)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(7)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.18728 .30707 m
.83214 .15431 L
s
P
p
.4 g
.28909 .38245 m
.88541 .25689 L
s
P
p
.4 g
.37469 .44582 m
.92897 .34078 L
s
P
P
p
.002 w
.45459 .53645 m .49264 .45941 L .41257 .47386 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .37469 .44582 L .45459 .53645 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.54323 .52203 m .57606 .44436 L .49264 .45941 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .45459 .53645 L .54323 .52203 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.41487 .50842 m .45459 .53645 L .37469 .44582 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.37469 .44582 m .33366 .41545 L .41487 .50842 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.63594 .50695 m .66306 .42866 L .57606 .44436 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .54323 .52203 L .63594 .50695 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.73302 .49116 m .75386 .41227 L .66306 .42866 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63594 .50695 L .73302 .49116 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.37151 .47782 m .41487 .50842 L .33366 .41545 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.33366 .41545 m .28909 .38245 L .37151 .47782 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.83477 .47461 m .84871 .39515 L .75386 .41227 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .73302 .49116 L .83477 .47461 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.50525 .6119 m .54323 .52203 L .45459 .53645 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.45459 .53645 m .41487 .50842 L .50525 .6119 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.92897 .34078 m .94791 .37725 L .84871 .39515 L p
0 0 .103 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .83477 .47461 L .92897 .34078 L p
0 0 .103 r
F P
1 0 0 r
s
P
p
.002 w
.60447 .59783 m .63594 .50695 L .54323 .52203 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.54323 .52203 m .50525 .6119 L .60447 .59783 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.324 .44429 m .37151 .47782 L .28909 .38245 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.28909 .38245 m .24049 .34646 L .324 .44429 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.46369 .58449 m .50525 .6119 L .41487 .50842 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.41487 .50842 m .37151 .47782 L .46369 .58449 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.70875 .58305 m .73302 .49116 L .63594 .50695 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.63594 .50695 m .60447 .59783 L .70875 .58305 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.80933 .44076 m .83477 .47461 L .73302 .49116 L p
0 0 .051 r
F P
1 0 0 r
s
P
p
.002 w
.73302 .49116 m .70875 .58305 L .80933 .44076 L p
0 0 .051 r
F P
1 0 0 r
s
P
p
.002 w
.27171 .40739 m .324 .44429 L .24049 .34646 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.24049 .34646 m .18728 .30707 L .27171 .40739 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.90823 .30084 m .92897 .34078 L .83477 .47461 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.41792 .5543 m .46369 .58449 L .37151 .47782 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.37151 .47782 m .324 .44429 L .41792 .5543 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.83477 .47461 m .80933 .44076 L .90823 .30084 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.56676 .56902 m .60447 .59783 L .50525 .6119 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.50525 .6119 m .46369 .58449 L .56676 .56902 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.67535 .55271 m .70875 .58305 L .60447 .59783 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.60447 .59783 m .56676 .56902 L .67535 .55271 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.21389 .36659 m .27171 .40739 L .18728 .30707 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.18728 .30707 m .12877 .26376 L .21389 .36659 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.88541 .25689 m .90823 .30084 L .80933 .44076 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.36723 .52088 m .41792 .5543 L .324 .44429 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.324 .44429 m .27171 .40739 L .36723 .52088 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.80933 .44076 m .7813 .4035 L .88541 .25689 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.7813 .4035 m .80933 .44076 L .70875 .58305 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.52511 .53719 m .56676 .56902 L .46369 .58449 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.46369 .58449 m .41792 .5543 L .52511 .53719 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.70875 .58305 m .67535 .55271 L .7813 .4035 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.63836 .51912 m .67535 .55271 L .56676 .56902 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.56676 .56902 m .52511 .53719 L .63836 .51912 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .21389 .36659 L .12877 .26376 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.12877 .26376 m .06415 .21592 L .16454 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86018 .20831 m .88541 .25689 L .7813 .4035 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.31978 .34339 m .36723 .52088 L .27171 .40739 L p
.523 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.27171 .40739 m .21389 .36659 L .31978 .34339 L p
.523 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.7813 .4035 m .7503 .36227 L .86018 .20831 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.7503 .36227 m .7813 .4035 L .67535 .55271 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.47887 .50186 m .52511 .53719 L .41792 .5543 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.41792 .5543 m .36723 .52088 L .47887 .50186 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.67535 .55271 m .63836 .51912 L .7503 .36227 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.59717 .4817 m .63836 .51912 L .52511 .53719 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.52511 .53719 m .47887 .50186 L .59717 .4817 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.83214 .15431 m .86018 .20831 L .7503 .36227 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .31978 .34339 L .21389 .36659 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.21389 .36659 m .16454 .18874 L .27076 .15998 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.7503 .36227 m .71581 .3164 L .83214 .15431 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.71581 .3164 m .7503 .36227 L .63836 .51912 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.43191 .31882 m .47887 .50186 L .36723 .52088 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.36723 .52088 m .31978 .34339 L .43191 .31882 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.63836 .51912 m .59717 .4817 L .71581 .3164 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .43191 .31882 L .31978 .34339 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.31978 .34339 m .27076 .15998 L .38334 .1295 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.55084 .29276 m .59717 .4817 L .47887 .50186 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.47887 .50186 m .43191 .31882 L .55084 .29276 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.8008 .09395 m .83214 .15431 L .71581 .3164 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .55084 .29276 L .43191 .31882 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.43191 .31882 m .38334 .1295 L .50287 .09714 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.71581 .3164 m .67721 .26507 L .8008 .09395 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.67721 .26507 m .71581 .3164 L .59717 .4817 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.59717 .4817 m .55084 .29276 L .67721 .26507 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .67721 .26507 L .55084 .29276 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.55084 .29276 m .50287 .09714 L .63002 .06271 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .8008 .09395 L .67721 .26507 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.67721 .26507 m .63002 .06271 L .76552 .02602 L p
.572 .532 .772 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Complement (Standard and Nonstandard)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Complement[A,opts] returns the complement of A, where A can be a fuzzy set or \
a fuzzy relation. The Type option specifies the type of complement to be \
performed. The Standard complement is the default, but the following \
parameterized complements are also available.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
   Type\t\t\t\tParameter
    Sugeno[alpha]\t\talpha in the range -1 to infinity
    Yager[w]\t\t\tw in the range 0 to infinity\
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In this example, we find the Complement of our fuzzy set. Since we have not \
specified a Type, the function performs the Standard complement.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Comp1 = Complement[FS];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS,Comp1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .08829 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .17658 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .26487 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .35316 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .44145 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .52974 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .61803 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .51503 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .41202 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .30902 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 .20601 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 .10301 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 .61803 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 .61803 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 .52974 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 .44145 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .35316 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .26487 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .17658 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .08829 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 0 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 0 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 0 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 0 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 0 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 0 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .10301 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .20601 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .30902 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .41202 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 .51503 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 .61803 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 .61803 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
For this example, we use a Yager complement of our fuzzy relation with the \
parameter w set to 2. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Comp2 = Complement[Rel,Type->Yager[2]];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Comp2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(1)] .81341 .09076 -1 .25269 Msboxa
[(2)] .8448 .15131 -1 .23689 Msboxa
[(3)] .87288 .20547 -1 .22295 Msboxa
[(4)] .89814 .25421 -1 .21056 Msboxa
[(5)] .92099 .29829 -1 .19947 Msboxa
[(6)] .94176 .33836 -1 .18949 Msboxa
[(7)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(1)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(2)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(3)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(4)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(5)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(6)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(7)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.18728 .30707 m
.83214 .15431 L
s
P
p
.4 g
.28909 .38245 m
.88541 .25689 L
s
P
p
.4 g
.37469 .44582 m
.92897 .34078 L
s
P
P
p
.002 w
.45229 .62985 m .48952 .671 L .40499 .68177 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.40499 .68177 m .36455 .66084 L .45229 .62985 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.54315 .61721 m .57781 .65975 L .48952 .671 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.48952 .671 m .45229 .62985 L .54315 .61721 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.41143 .60527 m .45229 .62985 L .36455 .66084 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.36455 .66084 m .32056 .63807 L .41143 .60527 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.63828 .60398 m .6701 .64799 L .57781 .65975 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.57781 .65975 m .54315 .61721 L .63828 .60398 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.50628 .51593 m .54315 .61721 L .45229 .62985 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.45229 .62985 m .41143 .60527 L .50628 .51593 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.73802 .59011 m .76668 .63568 L .6701 .64799 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.6701 .64799 m .63828 .60398 L .73802 .59011 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.60297 .49991 m .63828 .60398 L .54315 .61721 L p
.603 .603 .824 r
F P
1 0 0 r
s
P
p
.002 w
.54315 .61721 m .50628 .51593 L .60297 .49991 L p
.603 .603 .824 r
F P
1 0 0 r
s
P
p
.002 w
.36672 .57838 m .41143 .60527 L .32056 .63807 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.32056 .63807 m .27251 .6132 L .36672 .57838 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.8427 .57555 m .86785 .62279 L .76668 .63568 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.76668 .63568 m .73802 .59011 L .8427 .57555 L p
.565 .755 .967 r
F P
1 0 0 r
s
P
p
.002 w
.46588 .48473 m .50628 .51593 L .41143 .60527 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.41143 .60527 m .36672 .57838 L .46588 .48473 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.70446 .4831 m .73802 .59011 L .63828 .60398 L p
.603 .603 .824 r
F P
1 0 0 r
s
P
p
.002 w
.63828 .60398 m .60297 .49991 L .70446 .4831 L p
.603 .603 .824 r
F P
1 0 0 r
s
P
p
.002 w
.56621 .46715 m .60297 .49991 L .50628 .51593 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.50628 .51593 m .46588 .48473 L .56621 .46715 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.95499 .58161 m .97395 .60927 L .86785 .62279 L p
.451 .685 .966 r
F P
1 0 0 r
s
P
p
.002 w
.86785 .62279 m .8427 .57555 L .95499 .58161 L p
.451 .685 .966 r
F P
1 0 0 r
s
P
p
.002 w
.8169 .54573 m .8427 .57555 L .73802 .59011 L p
.345 .433 .809 r
F P
1 0 0 r
s
P
p
.002 w
.73802 .59011 m .70446 .4831 L .8169 .54573 L p
.345 .433 .809 r
F P
1 0 0 r
s
P
p
.002 w
.31762 .54884 m .36672 .57838 L .27251 .6132 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.27251 .6132 m .21982 .58593 L .31762 .54884 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.67177 .44864 m .70446 .4831 L .60297 .49991 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.60297 .49991 m .56621 .46715 L .67177 .44864 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.42147 .45045 m .46588 .48473 L .36672 .57838 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.36672 .57838 m .31762 .54884 L .42147 .45045 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.52572 .43105 m .56621 .46715 L .46588 .48473 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.46588 .48473 m .42147 .45045 L .52572 .43105 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.9341 .55112 m .95499 .58161 L .8427 .57555 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.8427 .57555 m .8169 .54573 L .9341 .55112 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.78843 .5128 m .8169 .54573 L .70446 .4831 L p
0 .33 .778 r
F P
1 0 0 r
s
P
p
.002 w
.70446 .4831 m .67177 .44864 L .78843 .5128 L p
0 .33 .778 r
F P
1 0 0 r
s
P
p
.002 w
.26342 .51625 m .31762 .54884 L .21982 .58593 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.21982 .58593 m .16179 .55589 L .26342 .51625 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.63568 .41059 m .67177 .44864 L .56621 .46715 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.56621 .46715 m .52572 .43105 L .63568 .41059 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.37245 .41259 m .42147 .45045 L .31762 .54884 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.31762 .54884 m .26342 .51625 L .37245 .41259 L p
.847 .911 .878 r
F P
1 0 0 r
s
P
p
.002 w
.4809 .3911 m .52572 .43105 L .42147 .45045 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.42147 .45045 m .37245 .41259 L .4809 .3911 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.91095 .51734 m .9341 .55112 L .8169 .54573 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.8169 .54573 m .78843 .5128 L .91095 .51734 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.75682 .47626 m .78843 .5128 L .67177 .44864 L p
0 .33 .778 r
F P
1 0 0 r
s
P
p
.002 w
.67177 .44864 m .63568 .41059 L .75682 .47626 L p
0 .33 .778 r
F P
1 0 0 r
s
P
p
.002 w
.20331 .48009 m .26342 .51625 L .16179 .55589 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.16179 .55589 m .09755 .52264 L .20331 .48009 L p
.637 .88 .986 r
F P
1 0 0 r
s
P
p
.002 w
.59561 .36836 m .63568 .41059 L .52572 .43105 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.52572 .43105 m .4809 .3911 L .59561 .36836 L p
.513 .816 1 r
F P
1 0 0 r
s
P
p
.002 w
.31236 .45948 m .24761 .442 L .33637 .42451 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.31236 .45948 m .37245 .41259 L .29209 .48899 L p
.478 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.37245 .41259 m .31236 .45948 L .42804 .43761 L p
.127 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.33637 .42451 m .3692 .41805 L p
.31236 .45948 L .351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.29209 .48899 m .26342 .51625 L p
.31236 .45948 L .478 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.26342 .51625 m .20331 .48009 L .31236 .45948 L p
.478 .816 .999 r
F P
1 0 0 r
s
P
p
.002 w
.42804 .43761 m .4809 .3911 L .37245 .41259 L p
.127 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.88516 .47972 m .91095 .51734 L .78843 .5128 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.78843 .5128 m .75682 .47626 L .88516 .47972 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.72154 .43546 m .75682 .47626 L .63568 .41059 L p
0 .33 .778 r
F P
1 0 0 r
s
P
p
.002 w
.63568 .41059 m .59561 .36836 L .72154 .43546 L p
0 .33 .778 r
F P
1 0 0 r
s
P
p
.002 w
.13345 .46448 m .20331 .48009 L .09755 .52264 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.09755 .52264 m .02606 .48563 L .13345 .46448 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.55099 .41438 m .59561 .36836 L .4809 .3911 L p
.127 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.4809 .3911 m .42804 .43761 L .55099 .41438 L p
.127 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.24761 .442 m .31236 .45948 L .20331 .48009 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.20331 .48009 m .13345 .46448 L .24761 .442 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.85627 .43755 m .88516 .47972 L .75682 .47626 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.75682 .47626 m .72154 .43546 L .85627 .43755 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.68191 .38963 m .72154 .43546 L .59561 .36836 L p
.127 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59561 .36836 m .55099 .41438 L .68191 .38963 L p
.127 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.3692 .41805 m .42804 .43761 L .31236 .45948 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.49896 .39249 m .55099 .41438 L .42804 .43761 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.42804 .43761 m .3692 .41805 L .49896 .39249 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.82366 .38997 m .85627 .43755 L .72154 .43546 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.72154 .43546 m .68191 .38963 L .82366 .38997 L p
.317 .712 .98 r
F P
1 0 0 r
s
P
p
.002 w
.63776 .36515 m .68191 .38963 L .55099 .41438 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.55099 .41438 m .49896 .39249 L .63776 .36515 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.78656 .33584 m .82366 .38997 L .68191 .38963 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.68191 .38963 m .63776 .36515 L .78656 .33584 L p
.351 .811 .932 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["User-defined Operator", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyModify[func,A] modifies the membership grades of A according to the \
supplied function func. A may be either a fuzzy set or a fuzzy relation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In this example, we first define a function that cubes its input. We then \
perform the FuzzyModify operation using the cubing function to modify the \
membership grades of our original fuzzy set.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["MyModFun[x_] := x^3", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FM = FuzzyModify[MyModFun,FS]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 1/343}, {3, 8/343}, {4, 27/343}, {5, 64/343}, 
 
   {6, 125/343}, {7, 216/343}, {8, 1}, {9, 1}, {10, 1}, 
 
   {11, 1}, {12, 1}, {13, 1}, {14, 125/216}, {15, 8/27}, 
 
   {16, 1/8}, {17, 1/27}, {18, 1/216}}, 
 
  UniversalSpace -> {0, 20}]











\
\>", "\<\
               1         8        27        64        125
FuzzySet[{{2, ---}, {3, ---}, {4, ---}, {5, ---}, {6, ---}, 
              343       343       343       343       343
 
       216
   {7, ---}, {8, 1}, {9, 1}, {10, 1}, {11, 1}, {12, 1}, 
       343
 
                 125        8         1        1          1
   {13, 1}, {14, ---}, {15, --}, {16, -}, {17, --}, {18, ---}}
                 216        27        8        27        216
 
   , UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FM];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 .0018 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 .01441 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .04865 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .11532 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .22523 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .3892 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .61803 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .61803 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .61803 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .61803 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .61803 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .35766 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .18312 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .07725 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 .02289 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 .00286 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Equality", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Equality[A,B] returns True if A and B are equal, and False otherwise.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Equality[FS,FS]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
True











\
\>", "\<\
True\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Inclusion", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Included[A,B] returns True if A is included in B and False otherwise. To be \
included, the membership grades of A must be less than or equal to the \
membership grades of B for all elements.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Included[FS,FS]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
True











\
\>", "\<\
True\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 153}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 82, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1844, 60, 67, 1, 70, "Subsection"],
Cell[1914, 63, 250, 5, 70, "Text"],
Cell[2167, 70, 143, 4, 70, "Text"],
Cell[2313, 76, 102, 2, 70, "Input"],
Cell[2418, 80, 304, 6, 70, "SmallText"]
}, Open  ]],
Cell[2734, 88, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[2807, 91, 75, 1, 70, "Subsection"],
Cell[2885, 94, 452, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[3360, 104, 104, 2, 70, "Input"],
Cell[3467, 108, 624, 30, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4123, 140, 107, 2, 70, "Input"],
Cell[4233, 144, 626, 34, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4891, 180, 92, 2, 70, "Input"],
Cell[4986, 184, 5115, 571, 70, 4957, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[10113, 757, 237, 5, 70, "Text"],
Cell[10353, 764, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[10426, 767, 64, 1, 70, "Subsubsection"],
Cell[10493, 770, 195, 4, 70, "Text"],
Cell[10691, 776, 197, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[10911, 782, 84, 2, 70, "Input"],
Cell[10998, 786, 124, 18, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11154, 806, 84, 2, 70, "Input"],
Cell[11241, 810, 128, 18, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[11390, 830, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[11463, 833, 69, 1, 70, "Subsubsection"],
Cell[11535, 836, 137, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[11695, 842, 89, 2, 70, "Input"],
Cell[11787, 846, 133, 20, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[11941, 868, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[12014, 871, 78, 1, 70, "Subsubsection"],
Cell[12095, 874, 189, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[12307, 880, 97, 2, 70, "Input"],
Cell[12407, 884, 135, 20, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[12563, 906, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[12636, 909, 90, 1, 70, "Subsubsection"],
Cell[12729, 912, 305, 6, 70, "Text"],
Cell[13037, 920, 409, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[13469, 929, 90, 2, 70, "Input"],
Cell[13562, 933, 146, 18, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13740, 953, 126, 2, 70, "Input"],
Cell[13869, 957, 98, 2, 70, "Print"],
Cell[13970, 961, 4278, 449, 70, 4120, 444, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[18269, 1412, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[18342, 1415, 87, 1, 70, "Subsubsection"],
Cell[18432, 1418, 236, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[18691, 1425, 123, 2, 70, "Input"],
Cell[18817, 1429, 133, 6, 70, "Print"],
Cell[18953, 1437, 4284, 449, 70, 4126, 444, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[23258, 1888, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[23331, 1891, 65, 1, 70, "Subsubsection"],
Cell[23399, 1894, 147, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[23569, 1900, 85, 2, 70, "Input"],
Cell[23657, 1904, 226, 18, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[23904, 1924, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[23977, 1927, 65, 1, 70, "Subsubsection"],
Cell[24045, 1930, 151, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[24219, 1936, 85, 2, 70, "Input"],
Cell[24307, 1940, 178, 18, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[24506, 1960, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[24579, 1963, 73, 1, 70, "Subsubsection"],
Cell[24655, 1966, 183, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[24861, 1972, 95, 2, 70, "Input"],
Cell[24959, 1976, 198, 18, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[25178, 1996, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[25251, 1999, 80, 1, 70, "Subsubsection"],
Cell[25334, 2002, 177, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[25534, 2008, 101, 2, 70, "Input"],
Cell[25638, 2012, 192, 18, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[25851, 2032, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[25924, 2035, 73, 1, 70, "Subsubsection"],
Cell[26000, 2038, 159, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[26182, 2044, 92, 2, 70, "Input"],
Cell[26277, 2048, 130, 18, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[26437, 2068, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[26510, 2071, 80, 1, 70, "Subsection"],
Cell[26593, 2074, 316, 6, 70, "Text"],
Cell[26912, 2082, 188, 6, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[27123, 2090, 96, 2, 70, "Input"],
Cell[27222, 2094, 15827, 1385, 70, 15669, 1380, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[43061, 3481, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[43134, 3484, 69, 1, 70, "Subsubsection"],
Cell[43206, 3487, 179, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[43408, 3493, 102, 2, 70, "Input"],
Cell[43513, 3497, 384, 24, 70, "Output"]
}, Open  ]],
Cell[43909, 3523, 98, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[44030, 3526, 90, 2, 70, "Input"],
Cell[44123, 3530, 3142, 332, 70, 2984, 327, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[47277, 3864, 180, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[47480, 3870, 103, 2, 70, "Input"],
Cell[47586, 3874, 454, 26, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48072, 3902, 90, 2, 70, "Input"],
Cell[48165, 3906, 3669, 374, 70, 3511, 369, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[51846, 4282, 220, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[52089, 4289, 95, 2, 70, "Input"],
Cell[52187, 4293, 124, 18, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[52341, 4313, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[52414, 4316, 93, 1, 70, "Subsection"],
Cell[52510, 4319, 508, 8, 70, "Text"],
Cell[53021, 4329, 128, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[53172, 4334, 87, 2, 70, "Input"],
Cell[53262, 4338, 4161, 440, 70, 4003, 435, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[57435, 4780, 166, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[57624, 4787, 95, 2, 70, "Input"],
Cell[57722, 4791, 13316, 1171, 70, 13158, 1166, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[71050, 5964, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[71123, 5967, 71, 1, 70, "Subsubsection"],
Cell[71197, 5970, 241, 5, 70, "Text"],
Cell[71441, 5977, 234, 5, 70, "Text"],
Cell[71678, 5984, 95, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[71796, 5988, 91, 2, 70, "Input"],
Cell[71890, 5992, 5141, 571, 70, 4983, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[77043, 6565, 206, 4, 70, "Text"]
}, Open  ]],
Cell[77261, 6571, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[77334, 6574, 66, 1, 70, "Subsubsection"],
Cell[77403, 6577, 240, 5, 70, "Text"],
Cell[77646, 6584, 115, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[77784, 6589, 95, 2, 70, "Input"],
Cell[77882, 6593, 13452, 1171, 70, 13294, 1166, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[91346, 7766, 161, 4, 70, "Text"]
}, Open  ]],
Cell[91519, 7772, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[91592, 7775, 76, 1, 70, "Subsubsection"],
Cell[91671, 7778, 193, 4, 70, "Text"],
Cell[91867, 7784, 169, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[92059, 7790, 99, 2, 70, "Input"],
Cell[92161, 7794, 803, 36, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[92996, 7832, 90, 2, 70, "Input"],
Cell[93089, 7836, 5137, 571, 70, 4979, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[98247, 8409, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[98320, 8412, 67, 1, 70, "Subsubsection"],
Cell[98390, 8415, 177, 4, 70, "Text"],
Cell[98570, 8421, 119, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[98712, 8426, 96, 2, 70, "Input"],
Cell[98811, 8430, 13466, 1171, 70, 13308, 1166, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[112298, 9603, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[112371, 9606, 95, 1, 70, "Subsubsection"],
Cell[112469, 9609, 328, 6, 70, "Text"],
Cell[112800, 9617, 206, 6, 70, "Special3"],
Cell[113009, 9625, 199, 4, 70, "Text"],
Cell[113211, 9631, 120, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[113354, 9636, 93, 2, 70, "Input"],
Cell[113450, 9640, 5131, 571, 70, 4973, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[118593, 10213, 156, 4, 70, "Text"],
Cell[118752, 10219, 112, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[118887, 10223, 97, 2, 70, "Input"],
Cell[118987, 10227, 13628, 1187, 70, 13470, 1182, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]],
Cell[132636, 11416, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[132709, 11419, 79, 1, 70, "Subsubsection"],
Cell[132791, 11422, 204, 4, 70, "Text"],
Cell[132998, 11428, 253, 5, 70, "Text"],
Cell[133254, 11435, 92, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[133369, 11439, 102, 2, 70, "Input"],
Cell[133474, 11443, 852, 38, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134358, 11483, 87, 2, 70, "Input"],
Cell[134448, 11487, 4159, 440, 70, 4001, 435, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[138628, 11929, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[138701, 11932, 66, 1, 70, "Subsubsection"],
Cell[138770, 11935, 126, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[138919, 11940, 88, 2, 70, "Input"],
Cell[139010, 11944, 130, 18, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[139161, 11964, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[139234, 11967, 67, 1, 70, "Subsubsection"],
Cell[139304, 11970, 248, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[139575, 11977, 88, 2, 70, "Input"],
Cell[139666, 11981, 130, 18, 70, "Output"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
