(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     41894,       3622]*)
(*NotebookOutlinePosition[     42763,       3654]*)
(*  CellTagsIndexPosition[     42719,       3650]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Set Visualization
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of functions that can be used to \
visualize fuzzy sets. In this chapter, we demonstrate these functions and the \
options associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To demonstrate the various fuzzy set graphing functions, we must first create \
some fuzzy sets to view. We use some of the fuzzy set creation functions from \
the Fuzzy Logic Pack to accomplish this. The functions which follow create a \
trapezoidal fuzzy set, a Gaussian fuzzy set, and a crisp set in that order.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FS1 = FuzzyTrapezoid[1,6,12,17,0.9]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{2, 0.18}, {3, 0.36}, {4, 0.5400000000000001}, 
 
   {5, 0.72}, {6, 0.9}, {7, 0.9}, {8, 0.9}, {9, 0.9}, 
 
   {10, 0.9}, {11, 0.9}, {12, 0.9}, {13, 0.72}, 
 
   {14, 0.5400000000000003}, {15, 0.3600000000000001}, 
 
   {16, 0.1800000000000001}}, UniversalSpace -> {0, 20}]

















\
\>", "\<\
FuzzySet[{{2, 0.18}, {3, 0.36}, {4, 0.54}, {5, 0.72}, {6, 0.9}, 
 
   {7, 0.9}, {8, 0.9}, {9, 0.9}, {10, 0.9}, {11, 0.9}, 
 
   {12, 0.9}, {13, 0.72}, {14, 0.54}, {15, 0.36}, {16, 0.18}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FS2 = FuzzyGaussian[11,5]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{0, 0.007907054051593434}, {1, 0.01831563888873418}, 
 
   {2, 0.03916389509898707}, {3, 0.07730474044329972}, 
 
   {4, 0.1408584209210449}, {5, 0.2369277586821217}, 
 
   {6, 0.3678794411714423}, {7, 0.5272924240430483}, 
 
   {8, 0.6976763260710309}, {9, 0.852143788966211}, 
 
   {10, 0.960789439152323}, {11, 1.}, {12, 0.960789439152323}, 
 
   {13, 0.852143788966211}, {14, 0.6976763260710309}, 
 
   {15, 0.5272924240430483}, {16, 0.3678794411714423}, 
 
   {17, 0.2369277586821217}, {18, 0.1408584209210449}, 
 
   {19, 0.07730474044329972}, {20, 0.03916389509898707}}, 
 
  UniversalSpace -> {0, 20}]

















\
\>", "\<\
FuzzySet[{{0, 0.00790705}, {1, 0.0183156}, {2, 0.0391639}, 
 
   {3, 0.0773047}, {4, 0.140858}, {5, 0.236928}, {6, 0.367879}, 
 
   {7, 0.527292}, {8, 0.697676}, {9, 0.852144}, {10, 0.960789}, 
 
   {11, 1.}, {12, 0.960789}, {13, 0.852144}, {14, 0.697676}, 
 
   {15, 0.527292}, {16, 0.367879}, {17, 0.236928}, 
 
   {18, 0.140858}, {19, 0.0773047}, {20, 0.0391639}}, 
 
  UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["FS3 = FuzzyTrapezoid[4,4,12,12]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 1}, {5, 1}, {6, 1}, {7, 1}, {8, 1}, {9, 1}, 
 
   {10, 1}, {11, 1}, {12, 1}}, UniversalSpace -> {0, 20}]

















\
\>", "\<\
FuzzySet[{{4, 1}, {5, 1}, {6, 1}, {7, 1}, {8, 1}, {9, 1}, 
 
   {10, 1}, {11, 1}, {12, 1}}, UniversalSpace -> {0, 20}]\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Plotting Fuzzy Sets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlot[A1,A2,...,An,opts] plots fuzzy sets A1, A2, ..., An. This function \
is only for use with fuzzy sets, and the fuzzy sets it graphs must by defined \
on the same universal space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There are numerous options for this function which we will demonstrate in the \
following examples.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Discrete Plots", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the FuzzyPlot function is called with one or more fuzzy sets and no \
options, the function will return a plot of vertical lines with heights \
representing the membership grades of the corresponding elements. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
When more than one fuzzy set is graphed at a time, each successive fuzzy set \
is graphed in a new color and shifted slightly to the right to avoid \
overwriting a previous fuzzy set. For this reason, it is important to \
remember that all of the elements of the fuzzy sets are integers. Therefore, \
even though a line representing the membership grade is offset to the right \
of the integer on the graph, the line corresponds to the integer to the left \
of the plotted line.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Now let us look at some examples. ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 0 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 0 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 .11125 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 .22249 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .33374 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .44498 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .55623 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .55623 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .55623 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .55623 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .55623 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .55623 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .55623 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .44498 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .33374 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .22249 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .11125 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 0 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 0 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 0 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
P
p
1.25 Mabswid
.13636 .11125 m
.13636 0 L
s
P
p
1.25 Mabswid
.18182 .22249 m
.18182 0 L
s
P
p
1.25 Mabswid
.22727 .33374 m
.22727 0 L
s
P
p
1.25 Mabswid
.27273 .44498 m
.27273 0 L
s
P
p
1.25 Mabswid
.31818 .55623 m
.31818 0 L
s
P
p
1.25 Mabswid
.36364 .55623 m
.36364 0 L
s
P
p
1.25 Mabswid
.40909 .55623 m
.40909 0 L
s
P
p
1.25 Mabswid
.45455 .55623 m
.45455 0 L
s
P
p
1.25 Mabswid
.5 .55623 m
.5 0 L
s
P
p
1.25 Mabswid
.54545 .55623 m
.54545 0 L
s
P
p
1.25 Mabswid
.59091 .55623 m
.59091 0 L
s
P
p
1.25 Mabswid
.63636 .44498 m
.63636 0 L
s
P
p
1.25 Mabswid
.68182 .33374 m
.68182 0 L
s
P
p
1.25 Mabswid
.72727 .22249 m
.72727 0 L
s
P
p
1.25 Mabswid
.77273 .11125 m
.77273 0 L
s
P
p
1.25 Mabswid
.81818 0 m
.81818 0 L
s
P
p
1.25 Mabswid
.86364 0 m
.86364 0 L
s
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 .00489 m
.06061 0 L
s
P
p
1.25 Mabswid
.10606 .01132 m
.10606 0 L
s
P
p
1.25 Mabswid
.15152 .0242 m
.15152 0 L
s
P
p
1.25 Mabswid
.19697 .04778 m
.19697 0 L
s
P
p
1.25 Mabswid
.24242 .08706 m
.24242 0 L
s
P
p
1.25 Mabswid
.28788 .14643 m
.28788 0 L
s
P
p
1.25 Mabswid
.33333 .22736 m
.33333 0 L
s
P
p
1.25 Mabswid
.37879 .32588 m
.37879 0 L
s
P
p
1.25 Mabswid
.42424 .43119 m
.42424 0 L
s
P
p
1.25 Mabswid
.4697 .52665 m
.4697 0 L
s
P
p
1.25 Mabswid
.51515 .5938 m
.51515 0 L
s
P
p
1.25 Mabswid
.56061 .61803 m
.56061 0 L
s
P
p
1.25 Mabswid
.60606 .5938 m
.60606 0 L
s
P
p
1.25 Mabswid
.65152 .52665 m
.65152 0 L
s
P
p
1.25 Mabswid
.69697 .43119 m
.69697 0 L
s
P
p
1.25 Mabswid
.74242 .32588 m
.74242 0 L
s
P
p
1.25 Mabswid
.78788 .22736 m
.78788 0 L
s
P
p
1.25 Mabswid
.83333 .14643 m
.83333 0 L
s
P
p
1.25 Mabswid
.87879 .08706 m
.87879 0 L
s
P
p
1.25 Mabswid
.92424 .04778 m
.92424 0 L
s
P
p
1.25 Mabswid
.9697 .0242 m
.9697 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
To resize a graph, click on the graph and drag one of the dark squares to a \
new position.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The FuzzyPlot command uses the following order of colors when plotting more \
than one fuzzy set on the same graph: red, blue, green, orange, purple, \
turquoise, yellow, dark pink, light blue, and yellow-green. For more than ten \
fuzzy sets plotted on the same graph, the color pattern above repeats, so the \
eleventh fuzzy set will again be red.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As more and more fuzzy sets are plotted on the same graph, the graph becomes \
more and more cluttered, and the fuzzy sets become increasingly difficult to \
distinguish from one another. Setting the ShowDots option to True causes a \
dot to be placed at the top of each of the vertical lines representing the \
membership grades. This option sometimes makes it easier to distinguish fuzzy \
sets in a cluttered graph. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,ShowDots->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.04545 0 m
.04545 0 L
s
5 Mabswid
.04545 0 Mdot
P
p
1.25 Mabswid
.09091 0 m
.09091 0 L
s
5 Mabswid
.09091 0 Mdot
P
p
1.25 Mabswid
.13636 .11125 m
.13636 0 L
s
5 Mabswid
.13636 .11125 Mdot
P
p
1.25 Mabswid
.18182 .22249 m
.18182 0 L
s
5 Mabswid
.18182 .22249 Mdot
P
p
1.25 Mabswid
.22727 .33374 m
.22727 0 L
s
5 Mabswid
.22727 .33374 Mdot
P
p
1.25 Mabswid
.27273 .44498 m
.27273 0 L
s
5 Mabswid
.27273 .44498 Mdot
P
p
1.25 Mabswid
.31818 .55623 m
.31818 0 L
s
5 Mabswid
.31818 .55623 Mdot
P
p
1.25 Mabswid
.36364 .55623 m
.36364 0 L
s
5 Mabswid
.36364 .55623 Mdot
P
p
1.25 Mabswid
.40909 .55623 m
.40909 0 L
s
5 Mabswid
.40909 .55623 Mdot
P
p
1.25 Mabswid
.45455 .55623 m
.45455 0 L
s
5 Mabswid
.45455 .55623 Mdot
P
p
1.25 Mabswid
.5 .55623 m
.5 0 L
s
5 Mabswid
.5 .55623 Mdot
P
p
1.25 Mabswid
.54545 .55623 m
.54545 0 L
s
5 Mabswid
.54545 .55623 Mdot
P
p
1.25 Mabswid
.59091 .55623 m
.59091 0 L
s
5 Mabswid
.59091 .55623 Mdot
P
p
1.25 Mabswid
.63636 .44498 m
.63636 0 L
s
5 Mabswid
.63636 .44498 Mdot
P
p
1.25 Mabswid
.68182 .33374 m
.68182 0 L
s
5 Mabswid
.68182 .33374 Mdot
P
p
1.25 Mabswid
.72727 .22249 m
.72727 0 L
s
5 Mabswid
.72727 .22249 Mdot
P
p
1.25 Mabswid
.77273 .11125 m
.77273 0 L
s
5 Mabswid
.77273 .11125 Mdot
P
p
1.25 Mabswid
.81818 0 m
.81818 0 L
s
5 Mabswid
.81818 0 Mdot
P
p
1.25 Mabswid
.86364 0 m
.86364 0 L
s
5 Mabswid
.86364 0 Mdot
P
p
1.25 Mabswid
.90909 0 m
.90909 0 L
s
5 Mabswid
.90909 0 Mdot
P
p
1.25 Mabswid
.95455 0 m
.95455 0 L
s
5 Mabswid
.95455 0 Mdot
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.06061 .00489 m
.06061 0 L
s
5 Mabswid
.06061 .00489 Mdot
P
p
1.25 Mabswid
.10606 .01132 m
.10606 0 L
s
5 Mabswid
.10606 .01132 Mdot
P
p
1.25 Mabswid
.15152 .0242 m
.15152 0 L
s
5 Mabswid
.15152 .0242 Mdot
P
p
1.25 Mabswid
.19697 .04778 m
.19697 0 L
s
5 Mabswid
.19697 .04778 Mdot
P
p
1.25 Mabswid
.24242 .08706 m
.24242 0 L
s
5 Mabswid
.24242 .08706 Mdot
P
p
1.25 Mabswid
.28788 .14643 m
.28788 0 L
s
5 Mabswid
.28788 .14643 Mdot
P
p
1.25 Mabswid
.33333 .22736 m
.33333 0 L
s
5 Mabswid
.33333 .22736 Mdot
P
p
1.25 Mabswid
.37879 .32588 m
.37879 0 L
s
5 Mabswid
.37879 .32588 Mdot
P
p
1.25 Mabswid
.42424 .43119 m
.42424 0 L
s
5 Mabswid
.42424 .43119 Mdot
P
p
1.25 Mabswid
.4697 .52665 m
.4697 0 L
s
5 Mabswid
.4697 .52665 Mdot
P
p
1.25 Mabswid
.51515 .5938 m
.51515 0 L
s
5 Mabswid
.51515 .5938 Mdot
P
p
1.25 Mabswid
.56061 .61803 m
.56061 0 L
s
5 Mabswid
.56061 .61803 Mdot
P
p
1.25 Mabswid
.60606 .5938 m
.60606 0 L
s
5 Mabswid
.60606 .5938 Mdot
P
p
1.25 Mabswid
.65152 .52665 m
.65152 0 L
s
5 Mabswid
.65152 .52665 Mdot
P
p
1.25 Mabswid
.69697 .43119 m
.69697 0 L
s
5 Mabswid
.69697 .43119 Mdot
P
p
1.25 Mabswid
.74242 .32588 m
.74242 0 L
s
5 Mabswid
.74242 .32588 Mdot
P
p
1.25 Mabswid
.78788 .22736 m
.78788 0 L
s
5 Mabswid
.78788 .22736 Mdot
P
p
1.25 Mabswid
.83333 .14643 m
.83333 0 L
s
5 Mabswid
.83333 .14643 Mdot
P
p
1.25 Mabswid
.87879 .08706 m
.87879 0 L
s
5 Mabswid
.87879 .08706 Mdot
P
p
1.25 Mabswid
.92424 .04778 m
.92424 0 L
s
5 Mabswid
.92424 .04778 Mdot
P
p
1.25 Mabswid
.9697 .0242 m
.9697 0 L
s
5 Mabswid
.9697 .0242 Mdot
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Line Plots", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Even with the ShowDots option set to True, some graphs with multiple fuzzy \
sets still become too cluttered to easily interpret. Furthermore, if the \
universal space of the fuzzy sets you are plotting is large, the vertical \
line-plotting method does not work well. If this is the case, setting the \
PlotJoined option to True is often your best bet. This will cause the fuzzy \
sets to be plotted as a continuous line. A linear interpolation is used for \
the points between the integer elements, and successive fuzzy sets are not \
offset to the right as is the case for the discrete plots talked about \
earlier in this section. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS1,FS2,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.04545 0 m
.09091 0 L
.13636 .11125 L
.18182 .22249 L
.22727 .33374 L
.27273 .44498 L
.31818 .55623 L
.36364 .55623 L
.40909 .55623 L
.45455 .55623 L
.5 .55623 L
.54545 .55623 L
.59091 .55623 L
.63636 .44498 L
.68182 .33374 L
.72727 .22249 L
.77273 .11125 L
.81818 0 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.76777 Mabswid
.04545 .00489 m
.09091 .01132 L
.13636 .0242 L
.18182 .04778 L
.22727 .08706 L
.27273 .14643 L
.31818 .22736 L
.36364 .32588 L
.40909 .43119 L
.45455 .52665 L
.5 .5938 L
.54545 .61803 L
.59091 .5938 L
.63636 .52665 L
.68182 .43119 L
.72727 .32588 L
.77273 .22736 L
.81818 .14643 L
.86364 .08706 L
.90909 .04778 L
.95455 .0242 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Crisp Plots", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
It is often instructive to work with fuzzy sets alongwith crisp or classical \
sets. Therefore, the Fuzzy Logic Pack includes a graphing option which allows \
crisp sets to be plotted in an accurate manner. To use the crisp plotting \
option, set the Crisp option to True. We demonstrate this option by plotting \
a fuzzy set which is also a crisp set (all membership grades are either 1 or \
0).\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FS3,Crisp->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
2.5 Mabswid
.04545 0 m
.09091 0 L
.09091 0 L
.13636 0 L
.13636 0 L
.18182 0 L
.18182 0 L
.22727 0 L
.22727 .61803 L
.27273 .61803 L
.27273 .61803 L
.31818 .61803 L
.31818 .61803 L
.36364 .61803 L
.36364 .61803 L
.40909 .61803 L
.40909 .61803 L
.45455 .61803 L
.45455 .61803 L
.5 .61803 L
.5 .61803 L
.54545 .61803 L
.54545 .61803 L
.59091 .61803 L
.59091 .61803 L
.59091 0 L
.63636 0 L
.68182 0 L
.68182 0 L
.72727 0 L
.72727 0 L
.77273 0 L
.77273 0 L
.81818 0 L
.81818 0 L
.86364 0 L
.86364 0 L
.90909 0 L
.90909 0 L
.95455 0 L
.95455 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Additional Plotting Options", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In addition to the options mentioned above, the FuzzyPlot function also \
accepts any of the options that Mathematica's standard Plot function accepts. \
If the default options for the fuzzy plotting functions do not produce a \
readable graph, or if you want the graphs presented in a diffferent way, \
these additional options can be used. Here is a list of the options for \
Mathematica's Plot function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 AspectRatio       Axes            AxesLabel
  AxesOrigin        AxesStyle       Background
  ColorOutput       Compiled        DefaultColor
  Epilog            Frame           FrameLabel
  FrameStyle        FrameTicks      GridLines
  MaxBend           PlotDivision    PlotLabel
  PlotPoints        PlotRange       PlotRegion
  PlotStyle         Prolog          RotateLabel
  Ticks             DefaultFont     DisplayFunction    \
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}},
  Background->GrayLevel[1]],

Cell["\<\
Here is one example which uses some of the standard Mathematica plotting \
options.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
FuzzyPlot[FS2,Frame->True,
  GridLines->{None,Automatic},
  PlotLabel->\"Numbers Near 11\"];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(0)] .04545 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(10)] .5 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(20)] .95455 0 0 2 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Numbers Near 11)] .5 .61803 0 -2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
0 0 .5 r
.001 w
0 .12361 m
1 .12361 L
s
P
p
0 0 .5 r
.001 w
0 .24721 m
1 .24721 L
s
P
p
0 0 .5 r
.001 w
0 .37082 m
1 .37082 L
s
P
p
0 0 .5 r
.001 w
0 .49443 m
1 .49443 L
s
P
p
.002 w
.04545 0 m
.04545 .00625 L
s
P
[(0)] .04545 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(10)] .5 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.95455 0 m
.95455 .00625 L
s
P
[(20)] .95455 0 0 2 Mshowa
p
.001 w
.09091 0 m
.09091 .00375 L
s
P
p
.001 w
.13636 0 m
.13636 .00375 L
s
P
p
.001 w
.18182 0 m
.18182 .00375 L
s
P
p
.001 w
.22727 0 m
.22727 .00375 L
s
P
p
.001 w
.31818 0 m
.31818 .00375 L
s
P
p
.001 w
.36364 0 m
.36364 .00375 L
s
P
p
.001 w
.40909 0 m
.40909 .00375 L
s
P
p
.001 w
.45455 0 m
.45455 .00375 L
s
P
p
.001 w
.54545 0 m
.54545 .00375 L
s
P
p
.001 w
.59091 0 m
.59091 .00375 L
s
P
p
.001 w
.63636 0 m
.63636 .00375 L
s
P
p
.001 w
.68182 0 m
.68182 .00375 L
s
P
p
.001 w
.77273 0 m
.77273 .00375 L
s
P
p
.001 w
.81818 0 m
.81818 .00375 L
s
P
p
.001 w
.86364 0 m
.86364 .00375 L
s
P
p
.001 w
.90909 0 m
.90909 .00375 L
s
P
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
p
.002 w
0 0 m
0 .61803 L
s
P
P
p
p
.002 w
.04545 .61178 m
.04545 .61803 L
s
P
p
.002 w
.27273 .61178 m
.27273 .61803 L
s
P
p
.002 w
.5 .61178 m
.5 .61803 L
s
P
p
.002 w
.72727 .61178 m
.72727 .61803 L
s
P
p
.002 w
.95455 .61178 m
.95455 .61803 L
s
P
p
.001 w
.09091 .61428 m
.09091 .61803 L
s
P
p
.001 w
.13636 .61428 m
.13636 .61803 L
s
P
p
.001 w
.18182 .61428 m
.18182 .61803 L
s
P
p
.001 w
.22727 .61428 m
.22727 .61803 L
s
P
p
.001 w
.31818 .61428 m
.31818 .61803 L
s
P
p
.001 w
.36364 .61428 m
.36364 .61803 L
s
P
p
.001 w
.40909 .61428 m
.40909 .61803 L
s
P
p
.001 w
.45455 .61428 m
.45455 .61803 L
s
P
p
.001 w
.54545 .61428 m
.54545 .61803 L
s
P
p
.001 w
.59091 .61428 m
.59091 .61803 L
s
P
p
.001 w
.63636 .61428 m
.63636 .61803 L
s
P
p
.001 w
.68182 .61428 m
.68182 .61803 L
s
P
p
.001 w
.77273 .61428 m
.77273 .61803 L
s
P
p
.001 w
.81818 .61428 m
.81818 .61803 L
s
P
p
.001 w
.86364 .61428 m
.86364 .61803 L
s
P
p
.001 w
.90909 .61428 m
.90909 .61803 L
s
P
p
.002 w
0 .61803 m
1 .61803 L
s
P
[(Numbers Near 11)] .5 .61803 0 -2 Mshowa
p
.002 w
.99375 0 m
1 0 L
s
P
p
.002 w
.99375 .12361 m
1 .12361 L
s
P
p
.002 w
.99375 .24721 m
1 .24721 L
s
P
p
.002 w
.99375 .37082 m
1 .37082 L
s
P
p
.002 w
.99375 .49443 m
1 .49443 L
s
P
p
.001 w
.99625 .02472 m
1 .02472 L
s
P
p
.001 w
.99625 .04944 m
1 .04944 L
s
P
p
.001 w
.99625 .07416 m
1 .07416 L
s
P
p
.001 w
.99625 .09889 m
1 .09889 L
s
P
p
.001 w
.99625 .14833 m
1 .14833 L
s
P
p
.001 w
.99625 .17305 m
1 .17305 L
s
P
p
.001 w
.99625 .19777 m
1 .19777 L
s
P
p
.001 w
.99625 .22249 m
1 .22249 L
s
P
p
.001 w
.99625 .27193 m
1 .27193 L
s
P
p
.001 w
.99625 .29666 m
1 .29666 L
s
P
p
.001 w
.99625 .32138 m
1 .32138 L
s
P
p
.001 w
.99625 .3461 m
1 .3461 L
s
P
p
.001 w
.99625 .39554 m
1 .39554 L
s
P
p
.001 w
.99625 .42026 m
1 .42026 L
s
P
p
.001 w
.99625 .44498 m
1 .44498 L
s
P
p
.001 w
.99625 .46971 m
1 .46971 L
s
P
p
.001 w
.99625 .51915 m
1 .51915 L
s
P
p
.001 w
.99625 .54387 m
1 .54387 L
s
P
p
.001 w
.99625 .56859 m
1 .56859 L
s
P
p
.001 w
.99625 .59331 m
1 .59331 L
s
P
p
.002 w
1 0 m
1 .61803 L
s
P
P
p
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.04545 .00489 m
.04545 0 L
s
P
p
2.5 Mabswid
.09091 .01132 m
.09091 0 L
s
P
p
2.5 Mabswid
.13636 .0242 m
.13636 0 L
s
P
p
2.5 Mabswid
.18182 .04778 m
.18182 0 L
s
P
p
2.5 Mabswid
.22727 .08706 m
.22727 0 L
s
P
p
2.5 Mabswid
.27273 .14643 m
.27273 0 L
s
P
p
2.5 Mabswid
.31818 .22736 m
.31818 0 L
s
P
p
2.5 Mabswid
.36364 .32588 m
.36364 0 L
s
P
p
2.5 Mabswid
.40909 .43119 m
.40909 0 L
s
P
p
2.5 Mabswid
.45455 .52665 m
.45455 0 L
s
P
p
2.5 Mabswid
.5 .5938 m
.5 0 L
s
P
p
2.5 Mabswid
.54545 .61803 m
.54545 0 L
s
P
p
2.5 Mabswid
.59091 .5938 m
.59091 0 L
s
P
p
2.5 Mabswid
.63636 .52665 m
.63636 0 L
s
P
p
2.5 Mabswid
.68182 .43119 m
.68182 0 L
s
P
p
2.5 Mabswid
.72727 .32588 m
.72727 0 L
s
P
p
2.5 Mabswid
.77273 .22736 m
.77273 0 L
s
P
p
2.5 Mabswid
.81818 .14643 m
.81818 0 L
s
P
p
2.5 Mabswid
.86364 .08706 m
.86364 0 L
s
P
p
2.5 Mabswid
.90909 .04778 m
.90909 0 L
s
P
p
2.5 Mabswid
.95455 .0242 m
.95455 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 79}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 89, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1851, 60, 67, 1, 70, "Subsection"],
Cell[1921, 63, 250, 5, 70, "Text"],
Cell[2174, 70, 143, 4, 70, "Text"],
Cell[2320, 76, 102, 2, 70, "Input"],
Cell[2425, 80, 304, 6, 70, "SmallText"],
Cell[2732, 88, 371, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[3126, 96, 108, 2, 70, "Input"],
Cell[3237, 100, 629, 38, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3898, 140, 98, 2, 70, "Input"],
Cell[3999, 144, 1146, 56, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5177, 202, 104, 2, 70, "Input"],
Cell[5284, 206, 364, 28, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[5669, 236, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[5742, 239, 74, 1, 70, "Subsection"],
Cell[5819, 242, 244, 5, 70, "Text"],
Cell[6066, 249, 156, 4, 70, "Text"],
Cell[6225, 255, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[6298, 258, 72, 1, 70, "Subsubsection"],
Cell[6373, 261, 270, 5, 70, "Text"],
Cell[6646, 268, 535, 9, 70, "Text"],
Cell[7184, 279, 83, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[7290, 282, 88, 2, 70, "Input"],
Cell[7381, 286, 4151, 440, 70, 3993, 435, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11564, 728, 92, 2, 70, "Input"],
Cell[11659, 732, 5147, 571, 70, 4989, 566, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[16818, 1305, 148, 4, 70, "Text"],
Cell[16969, 1311, 406, 7, 70, "Text"],
Cell[17378, 1320, 476, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[17877, 1330, 107, 2, 70, "Input"],
Cell[17987, 1334, 6325, 655, 70, 6167, 650, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[24333, 1991, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[24406, 1994, 68, 1, 70, "Subsubsection"],
Cell[24477, 1997, 692, 11, 70, "Text"],

Cell[CellGroupData[{
Cell[25192, 2010, 109, 2, 70, "Input"],
Cell[25304, 2014, 3919, 361, 70, 3761, 356, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[29244, 2377, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[29317, 2380, 69, 1, 70, "Subsubsection"],
Cell[29389, 2383, 453, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[29865, 2393, 100, 2, 70, "Input"],
Cell[29968, 2397, 3782, 355, 70, 3624, 350, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[33771, 2754, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[33844, 2757, 85, 1, 70, "Subsubsection"],
Cell[33932, 2760, 464, 8, 70, "Text"],
Cell[34399, 2770, 538, 13, 70, "Special3"],
Cell[34940, 2785, 140, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[35103, 2791, 173, 6, 70, "Input"],
Cell[35279, 2799, 6576, 822, 70, 6418, 817, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
