(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     93199,       8606]*)
(*NotebookOutlinePosition[     94069,       8638]*)
(*  CellTagsIndexPosition[     94025,       8634]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Relation Visualization
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of functions that can be used to \
visualize fuzzy relations. In this chapter, we demonstrate these functions \
and the options associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To demonstrate the various functions for visualizing fuzzy relations, we must \
first create some fuzzy relations. We use the FuzzyTrapezoid function here to \
create two fuzzy relations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel1 = FuzzyTrapezoid[{1,3,5,7},{1,4,6,8},
         UniversalSpace->{{1,7},{1,8}}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Rel2 = FuzzyTrapezoid[{1,1,4,7},{1,1,5,8},
         UniversalSpace->{{1,7},{1,8}}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Discrete 3D Plot", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyPlot3D[A1,A2,...,An,opts] plots the fuzzy relations A1, A2, ..., An, as \
a collection of vertical lines with heights representing the membership \
grades of the elements. This function is only for fuzzy relations, and all of \
the fuzzy relations A1, A2, ..., An must be defined on the same universal \
space. Here we demonstrate the function with our two fuzzy relations, Rel1 \
and Rel2.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot3D[Rel1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .81341 .09076 -1 .25269 Msboxa
[(3)] .8448 .15131 -1 .23689 Msboxa
[(4)] .87288 .20547 -1 .22295 Msboxa
[(5)] .89814 .25421 -1 .21056 Msboxa
[(6)] .92099 .29829 -1 .19947 Msboxa
[(7)] .94176 .33836 -1 .18949 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.2)] .04438 .26994 1 -0.25697 Msboxa
[(0.4)] .03695 .3221 1 -0.24273 Msboxa
[(0.6)] .02929 .37585 1 -0.22798 Msboxa
[(0.8)] .0214 .43127 1 -0.21271 Msboxa
[(1)] .01326 .48844 1 -0.19688 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(2)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(3)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(4)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(5)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(6)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(7)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05698 .26671 m
.06328 .26509 L
s
P
[(0.2)] .04438 .26994 1 -0.25697 Mshowa
p
.002 w
.04959 .31903 m
.05591 .31749 L
s
P
[(0.4)] .03695 .3221 1 -0.24273 Mshowa
p
.002 w
.04197 .37295 m
.04832 .37151 L
s
P
[(0.6)] .02929 .37585 1 -0.22798 Mshowa
p
.002 w
.03412 .42856 m
.04049 .42721 L
s
P
[(0.8)] .0214 .43127 1 -0.21271 Mshowa
p
.002 w
.02602 .48592 m
.03241 .48467 L
s
P
[(1)] .01326 .48844 1 -0.19688 Mshowa
p
.001 w
.06273 .22596 m
.0665 .22494 L
s
P
p
.001 w
.06131 .23605 m
.06508 .23505 L
s
P
p
.001 w
.05987 .24621 m
.06365 .24522 L
s
P
p
.001 w
.05843 .25643 m
.06221 .25545 L
s
P
p
.001 w
.05552 .27705 m
.0593 .27608 L
s
P
p
.001 w
.05405 .28745 m
.05783 .2865 L
s
P
p
.001 w
.05257 .29791 m
.05636 .29697 L
s
P
p
.001 w
.05109 .30844 m
.05488 .30751 L
s
P
p
.001 w
.04809 .32968 m
.05188 .32877 L
s
P
p
.001 w
.04657 .3404 m
.05037 .3395 L
s
P
p
.001 w
.04505 .35119 m
.04885 .3503 L
s
P
p
.001 w
.04352 .36204 m
.04732 .36116 L
s
P
p
.001 w
.04042 .38394 m
.04423 .38308 L
s
P
p
.001 w
.03886 .39499 m
.04267 .39415 L
s
P
p
.001 w
.03729 .40611 m
.04111 .40528 L
s
P
p
.001 w
.03571 .4173 m
.03953 .41648 L
s
P
p
.001 w
.03252 .43989 m
.03634 .43909 L
s
P
p
.001 w
.03091 .45129 m
.03474 .4505 L
s
P
p
.001 w
.02929 .46276 m
.03312 .46198 L
s
P
p
.001 w
.02766 .47431 m
.03149 .47354 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.12877 .26376 m
.8008 .09395 L
s
P
p
.4 g
.24049 .34646 m
.86018 .20831 L
s
P
p
.4 g
.33366 .41545 m
.90823 .30084 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
1 0 0 r
1.53846 Mabswid
.41257 .47386 m
.41257 .47386 L
s
P
p
1 0 0 r
1.53846 Mabswid
.49264 .45941 m
.49264 .45941 L
s
P
p
1 0 0 r
1.53846 Mabswid
.37469 .44582 m
.37469 .44582 L
s
P
p
1 0 0 r
1.53846 Mabswid
.57606 .44436 m
.57606 .44436 L
s
P
p
1 0 0 r
1.53846 Mabswid
.45459 .53656 m
.4572 .43018 L
s
P
p
1 0 0 r
1.53846 Mabswid
.66306 .42866 m
.66306 .42866 L
s
P
p
1 0 0 r
1.53846 Mabswid
.33366 .41545 m
.33366 .41545 L
s
P
p
1 0 0 r
1.53846 Mabswid
.54323 .52214 m
.54332 .41386 L
s
P
p
1 0 0 r
1.53846 Mabswid
.75386 .41227 m
.75386 .41227 L
s
P
p
1 0 0 r
1.53846 Mabswid
.41486 .50853 m
.41877 .39847 L
s
P
p
1 0 0 r
1.53846 Mabswid
.63595 .50706 m
.63328 .39682 L
s
P
p
1 0 0 r
1.53846 Mabswid
.84871 .39515 m
.84871 .39515 L
s
P
p
1 0 0 r
1.53846 Mabswid
.28909 .38245 m
.28909 .38245 L
s
P
p
1 0 0 r
1.53846 Mabswid
.50524 .61214 m
.50775 .38072 L
s
P
p
1 0 0 r
1.53846 Mabswid
.73302 .49127 m
.72735 .37899 L
s
P
p
1 0 0 r
1.53846 Mabswid
.94791 .37725 m
.94791 .37725 L
s
P
p
1 0 0 r
1.53846 Mabswid
.3715 .47794 m
.37693 .36395 L
s
P
p
1 0 0 r
1.53846 Mabswid
.60447 .59808 m
.60087 .36215 L
s
P
p
1 0 0 r
1.53846 Mabswid
.83478 .47472 m
.82581 .36033 L
s
P
p
1 0 0 r
1.53846 Mabswid
.24049 .34646 m
.24049 .34646 L
s
P
p
1 0 0 r
1.53846 Mabswid
.46369 .58475 m
.46894 .34458 L
s
P
p
1 0 0 r
1.53846 Mabswid
.70876 .58331 m
.69844 .34269 L
s
P
p
1 0 0 r
1.53846 Mabswid
.92897 .34078 m
.92897 .34078 L
s
P
p
1 0 0 r
1.53846 Mabswid
.32399 .44441 m
.33121 .32624 L
s
P
p
1 0 0 r
1.53846 Mabswid
.56676 .56928 m
.56544 .32426 L
s
P
p
1 0 0 r
1.53846 Mabswid
.80933 .44089 m
.80077 .32227 L
s
P
p
1 0 0 r
1.53846 Mabswid
.18728 .30707 m
.18728 .30707 L
s
P
p
1 0 0 r
1.53846 Mabswid
.41791 .55457 m
.42645 .305 L
s
P
p
1 0 0 r
1.53846 Mabswid
.67536 .55298 m
.66677 .30293 L
s
P
p
1 0 0 r
1.53846 Mabswid
.90823 .30084 m
.90823 .30084 L
s
P
p
1 0 0 r
1.53846 Mabswid
.27171 .40752 m
.28105 .28486 L
s
P
p
1 0 0 r
1.53846 Mabswid
.52511 .53747 m
.52657 .28268 L
s
P
p
1 0 0 r
1.53846 Mabswid
.78131 .40363 m
.77329 .2805 L
s
P
p
1 0 0 r
1.53846 Mabswid
.12877 .26376 m
.12877 .26376 L
s
P
p
1 0 0 r
1.53846 Mabswid
.37159 .43038 m
.37973 .26148 L
s
P
p
1 0 0 r
1.53846 Mabswid
.63837 .51939 m
.63194 .25919 L
s
P
p
1 0 0 r
1.53846 Mabswid
.88541 .25689 m
.88541 .25689 L
s
P
p
1 0 0 r
1.53846 Mabswid
.21794 .32319 m
.22577 .23925 L
s
P
p
1 0 0 r
1.53846 Mabswid
.48056 .40927 m
.48371 .23685 L
s
P
p
1 0 0 r
1.53846 Mabswid
.75031 .3624 m
.74298 .23443 L
s
P
p
1 0 0 r
1.53846 Mabswid
.06415 .21592 m
.06415 .21592 L
s
P
p
1 0 0 r
1.53846 Mabswid
.32262 .29906 m
.3281 .21339 L
s
P
p
1 0 0 r
1.53846 Mabswid
.59587 .38695 m
.59344 .21086 L
s
P
p
1 0 0 r
1.53846 Mabswid
.86018 .20831 m
.86018 .20831 L
s
P
p
1 0 0 r
1.53846 Mabswid
.16454 .18874 m
.16454 .18874 L
s
P
p
1 0 0 r
1.53846 Mabswid
.43339 .27352 m
.43623 .18607 L
s
P
p
1 0 0 r
1.53846 Mabswid
.71581 .31654 m
.7094 .18339 L
s
P
p
1 0 0 r
1.53846 Mabswid
.27076 .15998 m
.27076 .15998 L
s
P
p
1 0 0 r
1.53846 Mabswid
.55078 .24645 m
.55067 .15715 L
s
P
p
1 0 0 r
1.53846 Mabswid
.83214 .15431 m
.83214 .15431 L
s
P
p
1 0 0 r
1.53846 Mabswid
.38334 .1295 m
.38334 .1295 L
s
P
p
1 0 0 r
1.53846 Mabswid
.67542 .21771 m
.67198 .1265 L
s
P
p
1 0 0 r
1.53846 Mabswid
.50287 .09714 m
.50287 .09714 L
s
P
p
1 0 0 r
1.53846 Mabswid
.8008 .09395 m
.8008 .09395 L
s
P
p
1 0 0 r
1.53846 Mabswid
.63002 .06271 m
.63002 .06271 L
s
P
p
1 0 0 r
1.53846 Mabswid
.76552 .02602 m
.76552 .02602 L
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 282},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
As with fuzzy sets, when multiple fuzzy relations are shown on the same \
graph, the graph of each successive fuzzy relation is shifted a little to the \
right along the V axis. Even though there is a shift in the location of each \
line, the line still corresponds to the integer to the left of the plotted \
line. We can see this in the next example.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot3D[Rel1,Rel2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16188 .17693 -0.1139 1 Msboxa
[(3)] .26313 .14938 -0.0846 1 Msboxa
[(4)] .37016 .12026 -0.05311 1 Msboxa
[(5)] .4835 .08944 -0.01914 1 Msboxa
[(6)] .60371 .05676 .01758 1 Msboxa
[(7)] .73145 .02206 .05742 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .81341 .09076 -1 .25269 Msboxa
[(3)] .8448 .15131 -1 .23689 Msboxa
[(4)] .87288 .20547 -1 .22295 Msboxa
[(5)] .89814 .25421 -1 .21056 Msboxa
[(6)] .92099 .29829 -1 .19947 Msboxa
[(7)] .94176 .33836 -1 .18949 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.2)] .04438 .26994 1 -0.25697 Msboxa
[(0.4)] .03695 .3221 1 -0.24273 Msboxa
[(0.6)] .02929 .37585 1 -0.22798 Msboxa
[(0.8)] .0214 .43127 1 -0.21271 Msboxa
[(1)] .01326 .48844 1 -0.19688 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16041 .18985 m
.15967 .19632 L
s
P
[(2)] .16188 .17693 -0.1139 1 Mshowa
p
.002 w
.26203 .16234 m
.26148 .16882 L
s
P
[(3)] .26313 .14938 -0.0846 1 Mshowa
p
.002 w
.36947 .13325 m
.36913 .13975 L
s
P
[(4)] .37016 .12026 -0.05311 1 Mshowa
p
.002 w
.48325 .10245 m
.48313 .10895 L
s
P
[(5)] .4835 .08944 -0.01914 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(6)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.7322 .03505 m
.73257 .04154 L
s
P
[(7)] .73145 .02206 .05742 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(2)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(3)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(4)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(5)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(6)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(7)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05698 .26671 m
.06328 .26509 L
s
P
[(0.2)] .04438 .26994 1 -0.25697 Mshowa
p
.002 w
.04959 .31903 m
.05591 .31749 L
s
P
[(0.4)] .03695 .3221 1 -0.24273 Mshowa
p
.002 w
.04197 .37295 m
.04832 .37151 L
s
P
[(0.6)] .02929 .37585 1 -0.22798 Mshowa
p
.002 w
.03412 .42856 m
.04049 .42721 L
s
P
[(0.8)] .0214 .43127 1 -0.21271 Mshowa
p
.002 w
.02602 .48592 m
.03241 .48467 L
s
P
[(1)] .01326 .48844 1 -0.19688 Mshowa
p
.001 w
.06273 .22596 m
.0665 .22494 L
s
P
p
.001 w
.06131 .23605 m
.06508 .23505 L
s
P
p
.001 w
.05987 .24621 m
.06365 .24522 L
s
P
p
.001 w
.05843 .25643 m
.06221 .25545 L
s
P
p
.001 w
.05552 .27705 m
.0593 .27608 L
s
P
p
.001 w
.05405 .28745 m
.05783 .2865 L
s
P
p
.001 w
.05257 .29791 m
.05636 .29697 L
s
P
p
.001 w
.05109 .30844 m
.05488 .30751 L
s
P
p
.001 w
.04809 .32968 m
.05188 .32877 L
s
P
p
.001 w
.04657 .3404 m
.05037 .3395 L
s
P
p
.001 w
.04505 .35119 m
.04885 .3503 L
s
P
p
.001 w
.04352 .36204 m
.04732 .36116 L
s
P
p
.001 w
.04042 .38394 m
.04423 .38308 L
s
P
p
.001 w
.03886 .39499 m
.04267 .39415 L
s
P
p
.001 w
.03729 .40611 m
.04111 .40528 L
s
P
p
.001 w
.03571 .4173 m
.03953 .41648 L
s
P
p
.001 w
.03252 .43989 m
.03634 .43909 L
s
P
p
.001 w
.03091 .45129 m
.03474 .4505 L
s
P
p
.001 w
.02929 .46276 m
.03312 .46198 L
s
P
p
.001 w
.02766 .47431 m
.03149 .47354 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16041 .18985 m
.48937 .46 L
s
P
p
.4 g
.36947 .13325 m
.65242 .43058 L
s
P
p
.4 g
.60394 .06977 m
.8294 .39864 L
s
P
p
.4 g
.12877 .26376 m
.8008 .09395 L
s
P
p
.4 g
.24049 .34646 m
.86018 .20831 L
s
P
p
.4 g
.33366 .41545 m
.90823 .30084 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
1 0 0 r
.76923 Mabswid
.41257 .47386 m
.41257 .47386 L
s
P
p
.2 0 1 r
.76923 Mabswid
.43149 .47045 m
.43149 .47045 L
s
P
p
1 0 0 r
.76923 Mabswid
.48937 .46 m
.48937 .46 L
s
P
p
.2 0 1 r
.76923 Mabswid
.50905 .45645 m
.50905 .45645 L
s
P
p
1 0 0 r
.76923 Mabswid
.37469 .44582 m
.37469 .44582 L
s
P
p
1 0 0 r
.76923 Mabswid
.56926 .44558 m
.56926 .44558 L
s
P
p
.2 0 1 r
.76923 Mabswid
.39128 .51144 m
.39418 .44212 L
s
P
p
.2 0 1 r
.76923 Mabswid
.58973 .44189 m
.58973 .44189 L
s
P
p
1 0 0 r
.76923 Mabswid
.45112 .53712 m
.45384 .43082 L
s
P
p
1 0 0 r
.76923 Mabswid
.65242 .43058 m
.65242 .43058 L
s
P
p
.2 0 1 r
.76923 Mabswid
.47273 .49745 m
.47413 .42697 L
s
P
p
.2 0 1 r
.76923 Mabswid
.67375 .42673 m
.67375 .42673 L
s
P
p
1 0 0 r
.76923 Mabswid
.33366 .41545 m
.33366 .41545 L
s
P
p
1 0 0 r
.76923 Mabswid
.53599 .52332 m
.5363 .41519 L
s
P
p
1 0 0 r
.76923 Mabswid
.73906 .41494 m
.73906 .41494 L
s
P
p
.2 0 1 r
.76923 Mabswid
.34595 .55766 m
.35375 .41144 L
s
P
p
.2 0 1 r
.76923 Mabswid
.55767 .48286 m
.55745 .41118 L
s
P
p
.2 0 1 r
.76923 Mabswid
.76129 .41093 m
.76129 .41093 L
s
P
p
1 0 0 r
.76923 Mabswid
.41128 .50914 m
.41529 .39916 L
s
P
p
1 0 0 r
.76923 Mabswid
.62459 .50891 m
.62228 .3989 L
s
P
p
1 0 0 r
.76923 Mabswid
.8294 .39864 m
.8294 .39864 L
s
P
p
.2 0 1 r
.76923 Mabswid
.43168 .54379 m
.43624 .39499 L
s
P
p
.2 0 1 r
.76923 Mabswid
.64634 .46763 m
.64435 .39472 L
s
P
p
.2 0 1 r
.76923 Mabswid
.8526 .39445 m
.8526 .39445 L
s
P
p
1 0 0 r
.76923 Mabswid
.28909 .38245 m
.28909 .38245 L
s
P
p
1 0 0 r
.76923 Mabswid
.49751 .61324 m
.50048 .38217 L
s
P
p
1 0 0 r
.76923 Mabswid
.71719 .49385 m
.71201 .3819 L
s
P
p
1 0 0 r
.76923 Mabswid
.92369 .38162 m
.92369 .38162 L
s
P
p
.2 0 1 r
.76923 Mabswid
.29446 .61015 m
.30981 .37809 L
s
P
p
.2 0 1 r
.76923 Mabswid
.52134 .52929 m
.52236 .37781 L
s
P
p
.2 0 1 r
.76923 Mabswid
.73897 .45172 m
.73506 .37753 L
s
P
p
.2 0 1 r
.76923 Mabswid
.94791 .37725 m
.94791 .37725 L
s
P
p
1 0 0 r
.76923 Mabswid
.3678 .47861 m
.37333 .36471 L
s
P
p
1 0 0 r
.76923 Mabswid
.59231 .59981 m
.58947 .36442 L
s
P
p
1 0 0 r
.76923 Mabswid
.81404 .4781 m
.80575 .36413 L
s
P
p
.2 0 1 r
.76923 Mabswid
.38493 .59657 m
.39499 .36015 L
s
P
p
.2 0 1 r
.76923 Mabswid
.61519 .5141 m
.61234 .35986 L
s
P
p
.2 0 1 r
.76923 Mabswid
.83585 .43508 m
.82984 .35957 L
s
P
p
1 0 0 r
.76923 Mabswid
.24049 .34646 m
.24049 .34646 L
s
P
p
1 0 0 r
.76923 Mabswid
.45567 .58595 m
.46142 .34616 L
s
P
p
1 0 0 r
.76923 Mabswid
.69172 .58572 m
.68251 .34586 L
s
P
p
1 0 0 r
.76923 Mabswid
.90377 .34556 m
.90377 .34556 L
s
P
p
.2 0 1 r
.76923 Mabswid
.24251 .58256 m
.26186 .3417 L
s
P
p
.2 0 1 r
.76923 Mabswid
.47983 .58233 m
.48407 .34139 L
s
P
p
.2 0 1 r
.76923 Mabswid
.71354 .4982 m
.70644 .34109 L
s
P
p
.2 0 1 r
.76923 Mabswid
.92897 .34078 m
.92897 .34078 L
s
P
p
1 0 0 r
.76923 Mabswid
.32016 .44515 m
.32749 .32707 L
s
P
p
1 0 0 r
.76923 Mabswid
.55411 .57118 m
.55362 .32675 L
s
P
p
1 0 0 r
.76923 Mabswid
.78773 .44459 m
.7799 .32644 L
s
P
p
.2 0 1 r
.76923 Mabswid
.33618 .56761 m
.34988 .32207 L
s
P
p
.2 0 1 r
.76923 Mabswid
.57949 .56737 m
.57734 .32176 L
s
P
p
.2 0 1 r
.76923 Mabswid
.81071 .39969 m
.80497 .32144 L
s
P
p
1 0 0 r
.76923 Mabswid
.18728 .30707 m
.18728 .30707 L
s
P
p
1 0 0 r
.76923 Mabswid
.40958 .5559 m
.41866 .30674 L
s
P
p
1 0 0 r
.76923 Mabswid
.65759 .55565 m
.65022 .30641 L
s
P
p
1 0 0 r
.76923 Mabswid
.88195 .30608 m
.88195 .30608 L
s
P
p
.2 0 1 r
.76923 Mabswid
.18525 .55215 m
.20935 .30184 L
s
P
p
.2 0 1 r
.76923 Mabswid
.43467 .5519 m
.44214 .30151 L
s
P
p
.2 0 1 r
.76923 Mabswid
.68109 .46426 m
.67509 .30117 L
s
P
p
.2 0 1 r
.76923 Mabswid
.90823 .30084 m
.90823 .30084 L
s
P
p
1 0 0 r
.76923 Mabswid
.26774 .40833 m
.27721 .28577 L
s
P
p
1 0 0 r
.76923 Mabswid
.51194 .53957 m
.51429 .28542 L
s
P
p
1 0 0 r
.76923 Mabswid
.75877 .40771 m
.75155 .28507 L
s
P
p
.2 0 1 r
.76923 Mabswid
.28232 .53562 m
.30038 .28028 L
s
P
p
.2 0 1 r
.76923 Mabswid
.53837 .53535 m
.53893 .27993 L
s
P
p
.2 0 1 r
.76923 Mabswid
.78306 .36077 m
.77766 .27958 L
s
P
p
1 0 0 r
.76923 Mabswid
.12877 .26376 m
.12877 .26376 L
s
P
p
1 0 0 r
.76923 Mabswid
.36313 .43201 m
.37164 .2634 L
s
P
p
1 0 0 r
.76923 Mabswid
.61982 .52235 m
.61471 .26303 L
s
P
p
1 0 0 r
.76923 Mabswid
.85797 .26267 m
.85797 .26267 L
s
P
p
.2 0 1 r
.76923 Mabswid
.12184 .51847 m
.15159 .258 L
s
P
p
.2 0 1 r
.76923 Mabswid
.38466 .51819 m
.396 .25763 L
s
P
p
.2 0 1 r
.76923 Mabswid
.64522 .42676 m
.64061 .25726 L
s
P
p
.2 0 1 r
.76923 Mabswid
.88541 .25689 m
.88541 .25689 L
s
P
p
1 0 0 r
.76923 Mabswid
.21387 .32413 m
.22179 .24026 L
s
P
p
1 0 0 r
.76923 Mabswid
.46716 .41187 m
.47094 .23987 L
s
P
p
1 0 0 r
.76923 Mabswid
.72674 .36693 m
.7203 .23949 L
s
P
p
.2 0 1 r
.76923 Mabswid
.22251 .50009 m
.24579 .23419 L
s
P
p
.2 0 1 r
.76923 Mabswid
.4927 .49979 m
.49657 .2338 L
s
P
p
.2 0 1 r
.76923 Mabswid
.75249 .31775 m
.74755 .23342 L
s
P
p
1 0 0 r
.76923 Mabswid
.06415 .21592 m
.06415 .21592 L
s
P
p
1 0 0 r
.76923 Mabswid
.31403 .30104 m
.31971 .21551 L
s
P
p
1 0 0 r
.76923 Mabswid
.57697 .39061 m
.57548 .21511 L
s
P
p
1 0 0 r
.76923 Mabswid
.83147 .21471 m
.83147 .21471 L
s
P
p
.2 0 1 r
.76923 Mabswid
.05121 .48096 m
.08774 .20953 L
s
P
p
.2 0 1 r
.76923 Mabswid
.32895 .48065 m
.345 .20912 L
s
P
p
.2 0 1 r
.76923 Mabswid
.60538 .3851 m
.60248 .20871 L
s
P
p
.2 0 1 r
.76923 Mabswid
.86018 .20831 m
.86018 .20831 L
s
P
p
1 0 0 r
.76923 Mabswid
.16041 .18985 m
.16041 .18985 L
s
P
p
1 0 0 r
.76923 Mabswid
.41976 .27666 m
.42294 .18943 L
s
P
p
1 0 0 r
.76923 Mabswid
.69113 .3216 m
.68569 .189 L
s
P
p
.2 0 1 r
.76923 Mabswid
.15569 .46039 m
.1853 .18312 L
s
P
p
.2 0 1 r
.76923 Mabswid
.44168 .46006 m
.44962 .18269 L
s
P
p
.2 0 1 r
.76923 Mabswid
.71853 .26995 m
.71418 .18225 L
s
P
p
1 0 0 r
.76923 Mabswid
.26203 .16234 m
.26203 .16234 L
s
P
p
1 0 0 r
.76923 Mabswid
.53153 .25089 m
.53191 .16189 L
s
P
p
1 0 0 r
.76923 Mabswid
.80203 .16144 m
.80203 .16144 L
s
P
p
.2 0 1 r
.76923 Mabswid
.26653 .43857 m
.28833 .15522 L
s
P
p
.2 0 1 r
.76923 Mabswid
.56086 .33856 m
.56011 .15477 L
s
P
p
.2 0 1 r
.76923 Mabswid
.83214 .15431 m
.83214 .15431 L
s
P
p
1 0 0 r
.76923 Mabswid
.36947 .13325 m
.36947 .13325 L
s
P
p
1 0 0 r
.76923 Mabswid
.64988 .2236 m
.64714 .13278 L
s
P
p
.2 0 1 r
.76923 Mabswid
.38431 .41538 m
.3973 .12572 L
s
P
p
.2 0 1 r
.76923 Mabswid
.68057 .21652 m
.67698 .12523 L
s
P
p
1 0 0 r
.76923 Mabswid
.48325 .10245 m
.48325 .10245 L
s
P
p
1 0 0 r
.76923 Mabswid
.76916 .10194 m
.76916 .10194 L
s
P
p
.2 0 1 r
.76923 Mabswid
.51079 .2862 m
.51275 .09446 L
s
P
p
.2 0 1 r
.76923 Mabswid
.8008 .09395 m
.8008 .09395 L
s
P
p
1 0 0 r
.76923 Mabswid
.60394 .06977 m
.60394 .06977 L
s
P
p
.2 0 1 r
.76923 Mabswid
.63786 .15642 m
.63527 .06129 L
s
P
p
1 0 0 r
.76923 Mabswid
.7322 .03505 m
.7322 .03505 L
s
P
p
.2 0 1 r
.76923 Mabswid
.76552 .02602 m
.76552 .02602 L
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16041 .18985 m
.15967 .19632 L
s
P
[(2)] .16188 .17693 -0.1139 1 Mshowa
p
.002 w
.26203 .16234 m
.26148 .16882 L
s
P
[(3)] .26313 .14938 -0.0846 1 Mshowa
p
.002 w
.36947 .13325 m
.36913 .13975 L
s
P
[(4)] .37016 .12026 -0.05311 1 Mshowa
p
.002 w
.48325 .10245 m
.48313 .10895 L
s
P
[(5)] .4835 .08944 -0.01914 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(6)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.7322 .03505 m
.73257 .04154 L
s
P
[(7)] .73145 .02206 .05742 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
As with fuzzy sets, graphs of multiple fuzzy relations tend to become \
cluttered, and it becomes difficult to visualize the different fuzzy \
relations. One option which may help clear up the graph is the ShowDots \
option. When set to True, this option plots a dot at the top of each vertical \
line. This is shown in the following example. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot3D[Rel1,Rel2,ShowDots->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16188 .17693 -0.1139 1 Msboxa
[(3)] .26313 .14938 -0.0846 1 Msboxa
[(4)] .37016 .12026 -0.05311 1 Msboxa
[(5)] .4835 .08944 -0.01914 1 Msboxa
[(6)] .60371 .05676 .01758 1 Msboxa
[(7)] .73145 .02206 .05742 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .81341 .09076 -1 .25269 Msboxa
[(3)] .8448 .15131 -1 .23689 Msboxa
[(4)] .87288 .20547 -1 .22295 Msboxa
[(5)] .89814 .25421 -1 .21056 Msboxa
[(6)] .92099 .29829 -1 .19947 Msboxa
[(7)] .94176 .33836 -1 .18949 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.2)] .04438 .26994 1 -0.25697 Msboxa
[(0.4)] .03695 .3221 1 -0.24273 Msboxa
[(0.6)] .02929 .37585 1 -0.22798 Msboxa
[(0.8)] .0214 .43127 1 -0.21271 Msboxa
[(1)] .01326 .48844 1 -0.19688 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16041 .18985 m
.15967 .19632 L
s
P
[(2)] .16188 .17693 -0.1139 1 Mshowa
p
.002 w
.26203 .16234 m
.26148 .16882 L
s
P
[(3)] .26313 .14938 -0.0846 1 Mshowa
p
.002 w
.36947 .13325 m
.36913 .13975 L
s
P
[(4)] .37016 .12026 -0.05311 1 Mshowa
p
.002 w
.48325 .10245 m
.48313 .10895 L
s
P
[(5)] .4835 .08944 -0.01914 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(6)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.7322 .03505 m
.73257 .04154 L
s
P
[(7)] .73145 .02206 .05742 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(2)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(3)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(4)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(5)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(6)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(7)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05698 .26671 m
.06328 .26509 L
s
P
[(0.2)] .04438 .26994 1 -0.25697 Mshowa
p
.002 w
.04959 .31903 m
.05591 .31749 L
s
P
[(0.4)] .03695 .3221 1 -0.24273 Mshowa
p
.002 w
.04197 .37295 m
.04832 .37151 L
s
P
[(0.6)] .02929 .37585 1 -0.22798 Mshowa
p
.002 w
.03412 .42856 m
.04049 .42721 L
s
P
[(0.8)] .0214 .43127 1 -0.21271 Mshowa
p
.002 w
.02602 .48592 m
.03241 .48467 L
s
P
[(1)] .01326 .48844 1 -0.19688 Mshowa
p
.001 w
.06273 .22596 m
.0665 .22494 L
s
P
p
.001 w
.06131 .23605 m
.06508 .23505 L
s
P
p
.001 w
.05987 .24621 m
.06365 .24522 L
s
P
p
.001 w
.05843 .25643 m
.06221 .25545 L
s
P
p
.001 w
.05552 .27705 m
.0593 .27608 L
s
P
p
.001 w
.05405 .28745 m
.05783 .2865 L
s
P
p
.001 w
.05257 .29791 m
.05636 .29697 L
s
P
p
.001 w
.05109 .30844 m
.05488 .30751 L
s
P
p
.001 w
.04809 .32968 m
.05188 .32877 L
s
P
p
.001 w
.04657 .3404 m
.05037 .3395 L
s
P
p
.001 w
.04505 .35119 m
.04885 .3503 L
s
P
p
.001 w
.04352 .36204 m
.04732 .36116 L
s
P
p
.001 w
.04042 .38394 m
.04423 .38308 L
s
P
p
.001 w
.03886 .39499 m
.04267 .39415 L
s
P
p
.001 w
.03729 .40611 m
.04111 .40528 L
s
P
p
.001 w
.03571 .4173 m
.03953 .41648 L
s
P
p
.001 w
.03252 .43989 m
.03634 .43909 L
s
P
p
.001 w
.03091 .45129 m
.03474 .4505 L
s
P
p
.001 w
.02929 .46276 m
.03312 .46198 L
s
P
p
.001 w
.02766 .47431 m
.03149 .47354 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16041 .18985 m
.48937 .46 L
s
P
p
.4 g
.36947 .13325 m
.65242 .43058 L
s
P
p
.4 g
.60394 .06977 m
.8294 .39864 L
s
P
p
.4 g
.12877 .26376 m
.8008 .09395 L
s
P
p
.4 g
.24049 .34646 m
.86018 .20831 L
s
P
p
.4 g
.33366 .41545 m
.90823 .30084 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
1 0 0 r
5 Mabswid
.41257 .47386 Mdot
P
p
1 0 0 r
.76923 Mabswid
.41257 .47386 m
.41257 .47386 L
s
P
p
.2 0 1 r
5 Mabswid
.43149 .47045 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.43149 .47045 m
.43149 .47045 L
s
P
p
1 0 0 r
5 Mabswid
.48937 .46 Mdot
P
p
1 0 0 r
.76923 Mabswid
.48937 .46 m
.48937 .46 L
s
P
p
.2 0 1 r
5 Mabswid
.50905 .45645 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.50905 .45645 m
.50905 .45645 L
s
P
p
1 0 0 r
5 Mabswid
.37469 .44582 Mdot
P
p
1 0 0 r
.76923 Mabswid
.37469 .44582 m
.37469 .44582 L
s
P
p
1 0 0 r
5 Mabswid
.56926 .44558 Mdot
P
p
1 0 0 r
.76923 Mabswid
.56926 .44558 m
.56926 .44558 L
s
P
p
.2 0 1 r
.76923 Mabswid
.39128 .51144 m
.39418 .44212 L
s
P
p
.2 0 1 r
5 Mabswid
.58973 .44189 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.58973 .44189 m
.58973 .44189 L
s
P
p
1 0 0 r
.76923 Mabswid
.45112 .53712 m
.45384 .43082 L
s
P
p
1 0 0 r
5 Mabswid
.65242 .43058 Mdot
P
p
1 0 0 r
.76923 Mabswid
.65242 .43058 m
.65242 .43058 L
s
P
p
.2 0 1 r
5 Mabswid
.39128 .51144 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.47273 .49745 m
.47413 .42697 L
s
P
p
.2 0 1 r
5 Mabswid
.67375 .42673 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.67375 .42673 m
.67375 .42673 L
s
P
p
1 0 0 r
5 Mabswid
.33366 .41545 Mdot
P
p
1 0 0 r
.76923 Mabswid
.33366 .41545 m
.33366 .41545 L
s
P
p
1 0 0 r
.76923 Mabswid
.53599 .52332 m
.5363 .41519 L
s
P
p
1 0 0 r
5 Mabswid
.73906 .41494 Mdot
P
p
1 0 0 r
.76923 Mabswid
.73906 .41494 m
.73906 .41494 L
s
P
p
.2 0 1 r
5 Mabswid
.47273 .49745 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.34595 .55766 m
.35375 .41144 L
s
P
p
.2 0 1 r
.76923 Mabswid
.55767 .48286 m
.55745 .41118 L
s
P
p
.2 0 1 r
5 Mabswid
.76129 .41093 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.76129 .41093 m
.76129 .41093 L
s
P
p
1 0 0 r
5 Mabswid
.45112 .53712 Mdot
P
p
1 0 0 r
.76923 Mabswid
.41128 .50914 m
.41529 .39916 L
s
P
p
1 0 0 r
.76923 Mabswid
.62459 .50891 m
.62228 .3989 L
s
P
p
1 0 0 r
5 Mabswid
.8294 .39864 Mdot
P
p
1 0 0 r
.76923 Mabswid
.8294 .39864 m
.8294 .39864 L
s
P
p
.2 0 1 r
5 Mabswid
.55767 .48286 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.43168 .54379 m
.43624 .39499 L
s
P
p
.2 0 1 r
.76923 Mabswid
.64634 .46763 m
.64435 .39472 L
s
P
p
.2 0 1 r
5 Mabswid
.8526 .39445 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.8526 .39445 m
.8526 .39445 L
s
P
p
1 0 0 r
5 Mabswid
.53599 .52332 Mdot
P
p
1 0 0 r
5 Mabswid
.28909 .38245 Mdot
P
p
1 0 0 r
.76923 Mabswid
.28909 .38245 m
.28909 .38245 L
s
P
p
1 0 0 r
.76923 Mabswid
.49751 .61324 m
.50048 .38217 L
s
P
p
1 0 0 r
.76923 Mabswid
.71719 .49385 m
.71201 .3819 L
s
P
p
1 0 0 r
5 Mabswid
.92369 .38162 Mdot
P
p
1 0 0 r
.76923 Mabswid
.92369 .38162 m
.92369 .38162 L
s
P
p
.2 0 1 r
5 Mabswid
.34595 .55766 Mdot
P
p
.2 0 1 r
5 Mabswid
.64634 .46763 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.29446 .61015 m
.30981 .37809 L
s
P
p
.2 0 1 r
.76923 Mabswid
.52134 .52929 m
.52236 .37781 L
s
P
p
.2 0 1 r
.76923 Mabswid
.73897 .45172 m
.73506 .37753 L
s
P
p
.2 0 1 r
5 Mabswid
.94791 .37725 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.94791 .37725 m
.94791 .37725 L
s
P
p
1 0 0 r
5 Mabswid
.41128 .50914 Mdot
P
p
1 0 0 r
5 Mabswid
.62459 .50891 Mdot
P
p
1 0 0 r
.76923 Mabswid
.3678 .47861 m
.37333 .36471 L
s
P
p
1 0 0 r
.76923 Mabswid
.59231 .59981 m
.58947 .36442 L
s
P
p
1 0 0 r
.76923 Mabswid
.81404 .4781 m
.80575 .36413 L
s
P
p
.2 0 1 r
5 Mabswid
.43168 .54379 Mdot
P
p
.2 0 1 r
5 Mabswid
.73897 .45172 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.38493 .59657 m
.39499 .36015 L
s
P
p
.2 0 1 r
.76923 Mabswid
.61519 .5141 m
.61234 .35986 L
s
P
p
.2 0 1 r
.76923 Mabswid
.83585 .43508 m
.82984 .35957 L
s
P
p
1 0 0 r
5 Mabswid
.71719 .49385 Mdot
P
p
1 0 0 r
5 Mabswid
.24049 .34646 Mdot
P
p
1 0 0 r
.76923 Mabswid
.24049 .34646 m
.24049 .34646 L
s
P
p
1 0 0 r
.76923 Mabswid
.45567 .58595 m
.46142 .34616 L
s
P
p
1 0 0 r
.76923 Mabswid
.69172 .58572 m
.68251 .34586 L
s
P
p
1 0 0 r
5 Mabswid
.90377 .34556 Mdot
P
p
1 0 0 r
.76923 Mabswid
.90377 .34556 m
.90377 .34556 L
s
P
p
.2 0 1 r
5 Mabswid
.52134 .52929 Mdot
P
p
.2 0 1 r
5 Mabswid
.83585 .43508 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.24251 .58256 m
.26186 .3417 L
s
P
p
.2 0 1 r
.76923 Mabswid
.47983 .58233 m
.48407 .34139 L
s
P
p
.2 0 1 r
.76923 Mabswid
.71354 .4982 m
.70644 .34109 L
s
P
p
.2 0 1 r
5 Mabswid
.92897 .34078 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.92897 .34078 m
.92897 .34078 L
s
P
p
1 0 0 r
5 Mabswid
.3678 .47861 Mdot
P
p
1 0 0 r
5 Mabswid
.81404 .4781 Mdot
P
p
1 0 0 r
5 Mabswid
.49751 .61324 Mdot
P
p
1 0 0 r
.76923 Mabswid
.32016 .44515 m
.32749 .32707 L
s
P
p
1 0 0 r
.76923 Mabswid
.55411 .57118 m
.55362 .32675 L
s
P
p
1 0 0 r
.76923 Mabswid
.78773 .44459 m
.7799 .32644 L
s
P
p
.2 0 1 r
5 Mabswid
.29446 .61015 Mdot
P
p
.2 0 1 r
5 Mabswid
.61519 .5141 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.33618 .56761 m
.34988 .32207 L
s
P
p
.2 0 1 r
.76923 Mabswid
.57949 .56737 m
.57734 .32176 L
s
P
p
.2 0 1 r
.76923 Mabswid
.81071 .39969 m
.80497 .32144 L
s
P
p
1 0 0 r
5 Mabswid
.59231 .59981 Mdot
P
p
1 0 0 r
5 Mabswid
.18728 .30707 Mdot
P
p
1 0 0 r
.76923 Mabswid
.18728 .30707 m
.18728 .30707 L
s
P
p
1 0 0 r
.76923 Mabswid
.40958 .5559 m
.41866 .30674 L
s
P
p
1 0 0 r
.76923 Mabswid
.65759 .55565 m
.65022 .30641 L
s
P
p
1 0 0 r
5 Mabswid
.88195 .30608 Mdot
P
p
1 0 0 r
.76923 Mabswid
.88195 .30608 m
.88195 .30608 L
s
P
p
.2 0 1 r
5 Mabswid
.38493 .59657 Mdot
P
p
.2 0 1 r
5 Mabswid
.71354 .4982 Mdot
P
p
.2 0 1 r
5 Mabswid
.81071 .39969 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.18525 .55215 m
.20935 .30184 L
s
P
p
.2 0 1 r
.76923 Mabswid
.43467 .5519 m
.44214 .30151 L
s
P
p
.2 0 1 r
.76923 Mabswid
.68109 .46426 m
.67509 .30117 L
s
P
p
.2 0 1 r
5 Mabswid
.90823 .30084 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.90823 .30084 m
.90823 .30084 L
s
P
p
1 0 0 r
5 Mabswid
.32016 .44515 Mdot
P
p
1 0 0 r
5 Mabswid
.78773 .44459 Mdot
P
p
1 0 0 r
5 Mabswid
.45567 .58595 Mdot
P
p
1 0 0 r
5 Mabswid
.69172 .58572 Mdot
P
p
1 0 0 r
.76923 Mabswid
.26774 .40833 m
.27721 .28577 L
s
P
p
1 0 0 r
.76923 Mabswid
.51194 .53957 m
.51429 .28542 L
s
P
p
1 0 0 r
.76923 Mabswid
.75877 .40771 m
.75155 .28507 L
s
P
p
.2 0 1 r
5 Mabswid
.24251 .58256 Mdot
P
p
.2 0 1 r
5 Mabswid
.47983 .58233 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.28232 .53562 m
.30038 .28028 L
s
P
p
.2 0 1 r
.76923 Mabswid
.53837 .53535 m
.53893 .27993 L
s
P
p
.2 0 1 r
.76923 Mabswid
.78306 .36077 m
.77766 .27958 L
s
P
p
1 0 0 r
5 Mabswid
.55411 .57118 Mdot
P
p
1 0 0 r
5 Mabswid
.12877 .26376 Mdot
P
p
1 0 0 r
.76923 Mabswid
.12877 .26376 m
.12877 .26376 L
s
P
p
1 0 0 r
.76923 Mabswid
.36313 .43201 m
.37164 .2634 L
s
P
p
1 0 0 r
.76923 Mabswid
.61982 .52235 m
.61471 .26303 L
s
P
p
1 0 0 r
5 Mabswid
.85797 .26267 Mdot
P
p
1 0 0 r
.76923 Mabswid
.85797 .26267 m
.85797 .26267 L
s
P
p
.2 0 1 r
5 Mabswid
.33618 .56761 Mdot
P
p
.2 0 1 r
5 Mabswid
.57949 .56737 Mdot
P
p
.2 0 1 r
5 Mabswid
.68109 .46426 Mdot
P
p
.2 0 1 r
5 Mabswid
.78306 .36077 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.12184 .51847 m
.15159 .258 L
s
P
p
.2 0 1 r
.76923 Mabswid
.38466 .51819 m
.396 .25763 L
s
P
p
.2 0 1 r
.76923 Mabswid
.64522 .42676 m
.64061 .25726 L
s
P
p
.2 0 1 r
5 Mabswid
.88541 .25689 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.88541 .25689 m
.88541 .25689 L
s
P
p
1 0 0 r
5 Mabswid
.26774 .40833 Mdot
P
p
1 0 0 r
5 Mabswid
.75877 .40771 Mdot
P
p
1 0 0 r
5 Mabswid
.40958 .5559 Mdot
P
p
1 0 0 r
5 Mabswid
.65759 .55565 Mdot
P
p
1 0 0 r
.76923 Mabswid
.21387 .32413 m
.22179 .24026 L
s
P
p
1 0 0 r
.76923 Mabswid
.46716 .41187 m
.47094 .23987 L
s
P
p
1 0 0 r
.76923 Mabswid
.72674 .36693 m
.7203 .23949 L
s
P
p
.2 0 1 r
5 Mabswid
.18525 .55215 Mdot
P
p
.2 0 1 r
5 Mabswid
.43467 .5519 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.22251 .50009 m
.24579 .23419 L
s
P
p
.2 0 1 r
.76923 Mabswid
.4927 .49979 m
.49657 .2338 L
s
P
p
.2 0 1 r
.76923 Mabswid
.75249 .31775 m
.74755 .23342 L
s
P
p
1 0 0 r
5 Mabswid
.51194 .53957 Mdot
P
p
1 0 0 r
5 Mabswid
.36313 .43201 Mdot
P
p
1 0 0 r
5 Mabswid
.21387 .32413 Mdot
P
p
1 0 0 r
5 Mabswid
.06415 .21592 Mdot
P
p
1 0 0 r
.76923 Mabswid
.06415 .21592 m
.06415 .21592 L
s
P
p
1 0 0 r
.76923 Mabswid
.31403 .30104 m
.31971 .21551 L
s
P
p
1 0 0 r
.76923 Mabswid
.57697 .39061 m
.57548 .21511 L
s
P
p
1 0 0 r
5 Mabswid
.83147 .21471 Mdot
P
p
1 0 0 r
.76923 Mabswid
.83147 .21471 m
.83147 .21471 L
s
P
p
.2 0 1 r
5 Mabswid
.28232 .53562 Mdot
P
p
.2 0 1 r
5 Mabswid
.53837 .53535 Mdot
P
p
.2 0 1 r
5 Mabswid
.64522 .42676 Mdot
P
p
.2 0 1 r
5 Mabswid
.75249 .31775 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.05121 .48096 m
.08774 .20953 L
s
P
p
.2 0 1 r
.76923 Mabswid
.32895 .48065 m
.345 .20912 L
s
P
p
.2 0 1 r
.76923 Mabswid
.60538 .3851 m
.60248 .20871 L
s
P
p
.2 0 1 r
5 Mabswid
.86018 .20831 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.86018 .20831 m
.86018 .20831 L
s
P
p
1 0 0 r
5 Mabswid
.72674 .36693 Mdot
P
p
1 0 0 r
5 Mabswid
.61982 .52235 Mdot
P
p
1 0 0 r
5 Mabswid
.46716 .41187 Mdot
P
p
1 0 0 r
5 Mabswid
.31403 .30104 Mdot
P
p
1 0 0 r
5 Mabswid
.16041 .18985 Mdot
P
p
1 0 0 r
.76923 Mabswid
.16041 .18985 m
.16041 .18985 L
s
P
p
1 0 0 r
.76923 Mabswid
.41976 .27666 m
.42294 .18943 L
s
P
p
1 0 0 r
.76923 Mabswid
.69113 .3216 m
.68569 .189 L
s
P
p
.2 0 1 r
5 Mabswid
.12184 .51847 Mdot
P
p
.2 0 1 r
5 Mabswid
.38466 .51819 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.15569 .46039 m
.1853 .18312 L
s
P
p
.2 0 1 r
.76923 Mabswid
.44168 .46006 m
.44962 .18269 L
s
P
p
.2 0 1 r
.76923 Mabswid
.71853 .26995 m
.71418 .18225 L
s
P
p
1 0 0 r
5 Mabswid
.57697 .39061 Mdot
P
p
1 0 0 r
5 Mabswid
.41976 .27666 Mdot
P
p
1 0 0 r
5 Mabswid
.26203 .16234 Mdot
P
p
1 0 0 r
.76923 Mabswid
.26203 .16234 m
.26203 .16234 L
s
P
p
1 0 0 r
.76923 Mabswid
.53153 .25089 m
.53191 .16189 L
s
P
p
1 0 0 r
5 Mabswid
.80203 .16144 Mdot
P
p
1 0 0 r
.76923 Mabswid
.80203 .16144 m
.80203 .16144 L
s
P
p
.2 0 1 r
5 Mabswid
.22251 .50009 Mdot
P
p
.2 0 1 r
5 Mabswid
.4927 .49979 Mdot
P
p
.2 0 1 r
5 Mabswid
.60538 .3851 Mdot
P
p
.2 0 1 r
5 Mabswid
.71853 .26995 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.26653 .43857 m
.28833 .15522 L
s
P
p
.2 0 1 r
.76923 Mabswid
.56086 .33856 m
.56011 .15477 L
s
P
p
.2 0 1 r
5 Mabswid
.83214 .15431 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.83214 .15431 m
.83214 .15431 L
s
P
p
1 0 0 r
5 Mabswid
.69113 .3216 Mdot
P
p
1 0 0 r
5 Mabswid
.53153 .25089 Mdot
P
p
1 0 0 r
5 Mabswid
.36947 .13325 Mdot
P
p
1 0 0 r
.76923 Mabswid
.36947 .13325 m
.36947 .13325 L
s
P
p
1 0 0 r
.76923 Mabswid
.64988 .2236 m
.64714 .13278 L
s
P
p
.2 0 1 r
5 Mabswid
.05121 .48096 Mdot
P
p
.2 0 1 r
5 Mabswid
.32895 .48065 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.38431 .41538 m
.3973 .12572 L
s
P
p
.2 0 1 r
.76923 Mabswid
.68057 .21652 m
.67698 .12523 L
s
P
p
1 0 0 r
5 Mabswid
.64988 .2236 Mdot
P
p
1 0 0 r
5 Mabswid
.48325 .10245 Mdot
P
p
1 0 0 r
.76923 Mabswid
.48325 .10245 m
.48325 .10245 L
s
P
p
1 0 0 r
5 Mabswid
.76916 .10194 Mdot
P
p
1 0 0 r
.76923 Mabswid
.76916 .10194 m
.76916 .10194 L
s
P
p
.2 0 1 r
5 Mabswid
.15569 .46039 Mdot
P
p
.2 0 1 r
5 Mabswid
.44168 .46006 Mdot
P
p
.2 0 1 r
5 Mabswid
.56086 .33856 Mdot
P
p
.2 0 1 r
5 Mabswid
.68057 .21652 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.51079 .2862 m
.51275 .09446 L
s
P
p
.2 0 1 r
5 Mabswid
.8008 .09395 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.8008 .09395 m
.8008 .09395 L
s
P
p
1 0 0 r
5 Mabswid
.60394 .06977 Mdot
P
p
1 0 0 r
.76923 Mabswid
.60394 .06977 m
.60394 .06977 L
s
P
p
.2 0 1 r
5 Mabswid
.26653 .43857 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.63786 .15642 m
.63527 .06129 L
s
P
p
1 0 0 r
5 Mabswid
.7322 .03505 Mdot
P
p
1 0 0 r
.76923 Mabswid
.7322 .03505 m
.7322 .03505 L
s
P
p
.2 0 1 r
5 Mabswid
.38431 .41538 Mdot
P
p
.2 0 1 r
5 Mabswid
.51079 .2862 Mdot
P
p
.2 0 1 r
5 Mabswid
.63786 .15642 Mdot
P
p
.2 0 1 r
5 Mabswid
.76552 .02602 Mdot
P
p
.2 0 1 r
.76923 Mabswid
.76552 .02602 m
.76552 .02602 L
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16041 .18985 m
.15967 .19632 L
s
P
[(2)] .16188 .17693 -0.1139 1 Mshowa
p
.002 w
.26203 .16234 m
.26148 .16882 L
s
P
[(3)] .26313 .14938 -0.0846 1 Mshowa
p
.002 w
.36947 .13325 m
.36913 .13975 L
s
P
[(4)] .37016 .12026 -0.05311 1 Mshowa
p
.002 w
.48325 .10245 m
.48313 .10895 L
s
P
[(5)] .4835 .08944 -0.01914 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(6)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.7322 .03505 m
.73257 .04154 L
s
P
[(7)] .73145 .02206 .05742 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Surface Plot", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzySurfacePlot[A1,A2,...,An,opts] displays a surface plot of fuzzy \
relations A1, A2, ..., An.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The discrete plots shown earlier are fairly messy for plotting large fuzzy \
relations or for plotting multiple fuzzy relations. An alternative graphing \
solution is to plot fuzzy relations as surfaces. Let us replot the first \
fuzzy relation as a surface now with the FuzzySurfacePlot function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .81341 .09076 -1 .25269 Msboxa
[(3)] .8448 .15131 -1 .23689 Msboxa
[(4)] .87288 .20547 -1 .22295 Msboxa
[(5)] .89814 .25421 -1 .21056 Msboxa
[(6)] .92099 .29829 -1 .19947 Msboxa
[(7)] .94176 .33836 -1 .18949 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(2)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(3)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(4)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(5)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(6)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(7)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.12877 .26376 m
.8008 .09395 L
s
P
p
.4 g
.24049 .34646 m
.86018 .20831 L
s
P
p
.4 g
.33366 .41545 m
.90823 .30084 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.45459 .53645 m .49264 .45941 L .41257 .47386 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.41257 .47386 m .37469 .44582 L .45459 .53645 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.54323 .52203 m .57606 .44436 L .49264 .45941 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.49264 .45941 m .45459 .53645 L .54323 .52203 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.41487 .50842 m .45459 .53645 L .37469 .44582 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.37469 .44582 m .33366 .41545 L .41487 .50842 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.63594 .50695 m .66306 .42866 L .57606 .44436 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.57606 .44436 m .54323 .52203 L .63594 .50695 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.73302 .49116 m .75386 .41227 L .66306 .42866 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .63594 .50695 L .73302 .49116 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.37151 .47782 m .41487 .50842 L .33366 .41545 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.33366 .41545 m .28909 .38245 L .37151 .47782 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.83477 .47461 m .84871 .39515 L .75386 .41227 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.75386 .41227 m .73302 .49116 L .83477 .47461 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.50525 .6119 m .54323 .52203 L .45459 .53645 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.45459 .53645 m .41487 .50842 L .50525 .6119 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.92897 .34078 m .94791 .37725 L .84871 .39515 L p
0 0 .103 r
F P
1 0 0 r
s
P
p
.002 w
.84871 .39515 m .83477 .47461 L .92897 .34078 L p
0 0 .103 r
F P
1 0 0 r
s
P
p
.002 w
.60447 .59783 m .63594 .50695 L .54323 .52203 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.54323 .52203 m .50525 .6119 L .60447 .59783 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.324 .44429 m .37151 .47782 L .28909 .38245 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.28909 .38245 m .24049 .34646 L .324 .44429 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.46369 .58449 m .50525 .6119 L .41487 .50842 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.41487 .50842 m .37151 .47782 L .46369 .58449 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.70875 .58305 m .73302 .49116 L .63594 .50695 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.63594 .50695 m .60447 .59783 L .70875 .58305 L p
.44 .059 .219 r
F P
1 0 0 r
s
P
p
.002 w
.80933 .44076 m .83477 .47461 L .73302 .49116 L p
0 0 .051 r
F P
1 0 0 r
s
P
p
.002 w
.73302 .49116 m .70875 .58305 L .80933 .44076 L p
0 0 .051 r
F P
1 0 0 r
s
P
p
.002 w
.27171 .40739 m .324 .44429 L .24049 .34646 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.24049 .34646 m .18728 .30707 L .27171 .40739 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.90823 .30084 m .92897 .34078 L .83477 .47461 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.41792 .5543 m .46369 .58449 L .37151 .47782 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.37151 .47782 m .324 .44429 L .41792 .5543 L p
.681 .162 0 r
F P
1 0 0 r
s
P
p
.002 w
.83477 .47461 m .80933 .44076 L .90823 .30084 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.56676 .56902 m .60447 .59783 L .50525 .6119 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.50525 .6119 m .46369 .58449 L .56676 .56902 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.67535 .55271 m .70875 .58305 L .60447 .59783 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.60447 .59783 m .56676 .56902 L .67535 .55271 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.21795 .32311 m .27171 .40739 L .18728 .30707 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.18728 .30707 m .12877 .26376 L .21795 .32311 L p
0 .18 .624 r
F P
1 0 0 r
s
P
p
.002 w
.88541 .25689 m .90823 .30084 L .80933 .44076 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.3716 .4302 m .41792 .5543 L .324 .44429 L p
.087 .558 .905 r
F P
1 0 0 r
s
P
p
.002 w
.324 .44429 m .27171 .40739 L .3716 .4302 L p
.087 .558 .905 r
F P
1 0 0 r
s
P
p
.002 w
.80933 .44076 m .7813 .4035 L .88541 .25689 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.7813 .4035 m .80933 .44076 L .70875 .58305 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.52511 .53719 m .56676 .56902 L .46369 .58449 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.46369 .58449 m .41792 .5543 L .52511 .53719 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.70875 .58305 m .67535 .55271 L .7813 .4035 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.63836 .51912 m .67535 .55271 L .56676 .56902 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.56676 .56902 m .52511 .53719 L .63836 .51912 L p
.467 .815 .998 r
F P
1 0 0 r
s
P
p
.002 w
.16454 .18874 m .21795 .32311 L .12877 .26376 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.12877 .26376 m .06415 .21592 L .16454 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86018 .20831 m .88541 .25689 L .7813 .4035 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.32263 .29897 m .3716 .4302 L .27171 .40739 L p
.585 .691 .915 r
F P
1 0 0 r
s
P
p
.002 w
.27171 .40739 m .21795 .32311 L .32263 .29897 L p
.585 .691 .915 r
F P
1 0 0 r
s
P
p
.002 w
.7813 .4035 m .7503 .36227 L .86018 .20831 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.7503 .36227 m .7813 .4035 L .67535 .55271 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.48057 .40909 m .52511 .53719 L .41792 .5543 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.41792 .5543 m .3716 .4302 L .48057 .40909 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.67535 .55271 m .63836 .51912 L .7503 .36227 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.59586 .38676 m .63836 .51912 L .52511 .53719 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.52511 .53719 m .48057 .40909 L .59586 .38676 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.43339 .27343 m .48057 .40909 L .3716 .4302 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.3716 .4302 m .32263 .29897 L .43339 .27343 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.27076 .15998 m .32263 .29897 L .21795 .32311 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.21795 .32311 m .16454 .18874 L .27076 .15998 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.83214 .15431 m .86018 .20831 L .7503 .36227 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.7503 .36227 m .71581 .3164 L .83214 .15431 L p
.923 .945 .794 r
F P
1 0 0 r
s
P
p
.002 w
.71581 .3164 m .7503 .36227 L .63836 .51912 L p
.693 .662 .815 r
F P
1 0 0 r
s
P
p
.002 w
.63836 .51912 m .59586 .38676 L .71581 .3164 L p
.693 .662 .815 r
F P
1 0 0 r
s
P
p
.002 w
.55078 .24635 m .59586 .38676 L .48057 .40909 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.48057 .40909 m .43339 .27343 L .55078 .24635 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .43339 .27343 L .32263 .29897 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.32263 .29897 m .27076 .15998 L .38334 .1295 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.67542 .21761 m .71581 .3164 L .59586 .38676 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.59586 .38676 m .55078 .24635 L .67542 .21761 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.50287 .09714 m .55078 .24635 L .43339 .27343 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.43339 .27343 m .38334 .1295 L .50287 .09714 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.8008 .09395 m .83214 .15431 L .71581 .3164 L p
.824 .815 .841 r
F P
1 0 0 r
s
P
p
.002 w
.71581 .3164 m .67542 .21761 L .8008 .09395 L p
.824 .815 .841 r
F P
1 0 0 r
s
P
p
.002 w
.63002 .06271 m .67542 .21761 L .55078 .24635 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.55078 .24635 m .50287 .09714 L .63002 .06271 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .8008 .09395 L .67542 .21761 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.67542 .21761 m .63002 .06271 L .76552 .02602 L p
.584 .596 .831 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 282},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Mesh Plot", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The FuzzySurfacePlot function plots a fuzzy relation as a solid object. \
Therefore, plotting multiple fuzzy relations on the same surface plot causes \
some fuzzy relations to block out regions of other fuzzy relations. To get \
around this problem, the FuzzySurfacePlot function comes with an option that \
plots the surfaces as meshes rather than solid objects. Setting the \
HideSurfaces option to True produces a mesh plot. To demonstrate we will \
replot the first fuzzy relation with the second fuzzy relation, this time \
with the HideSurfaces option set to True.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[Rel1,Rel2,HideSurfaces->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(1)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .16599 .17581 -0.11272 1 Msboxa
[(3)] .27182 .14701 -0.08207 1 Msboxa
[(4)] .38398 .1165 -0.049 1 Msboxa
[(5)] .50304 .08413 -0.01322 1 Msboxa
[(6)] .62968 .0497 .02561 1 Msboxa
[(7)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(1)] .77808 .02262 -1 .27075 Msboxa
[(2)] .81341 .09076 -1 .25269 Msboxa
[(3)] .8448 .15131 -1 .23689 Msboxa
[(4)] .87288 .20547 -1 .22295 Msboxa
[(5)] .89814 .25421 -1 .21056 Msboxa
[(6)] .92099 .29829 -1 .19947 Msboxa
[(7)] .94176 .33836 -1 .18949 Msboxa
[(8)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(1)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.8008 .09395 m
.79449 .09554 L
s
P
[(2)] .81341 .09076 -1 .25269 Mshowa
p
.002 w
.83214 .15431 m
.82581 .15581 L
s
P
[(3)] .8448 .15131 -1 .23689 Mshowa
p
.002 w
.86018 .20831 m
.85383 .20972 L
s
P
[(4)] .87288 .20547 -1 .22295 Mshowa
p
.002 w
.88541 .25689 m
.87904 .25823 L
s
P
[(5)] .89814 .25421 -1 .21056 Mshowa
p
.002 w
.90823 .30084 m
.90185 .30211 L
s
P
[(6)] .92099 .29829 -1 .19947 Mshowa
p
.002 w
.92897 .34078 m
.92258 .342 L
s
P
[(7)] .94176 .33836 -1 .18949 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(8)] .96071 .37494 -1 .18047 Mshowa
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.16454 .18874 m
.49264 .45941 L
s
P
p
.4 g
.38334 .1295 m
.66306 .42866 L
s
P
p
.4 g
.63002 .06271 m
.84871 .39515 L
s
P
p
.4 g
.12877 .26376 m
.8008 .09395 L
s
P
p
.4 g
.24049 .34646 m
.86018 .20831 L
s
P
p
.4 g
.33366 .41545 m
.90823 .30084 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.2 0 1 r
.004 w
.49264 .45941 m
.41257 .47386 L
s
P
p
.2 0 1 r
.004 w
.41257 .47386 m
.37144 .51478 L
s
P
p
1 0 0 r
.004 w
.41257 .47386 m
.37469 .44582 L
s
P
p
.2 0 1 r
.004 w
.57606 .44436 m
.49264 .45941 L
s
P
p
.2 0 1 r
.004 w
.49264 .45941 m
.45548 .50034 L
s
P
p
1 0 0 r
.004 w
.49264 .45941 m
.45459 .53645 L
s
P
p
1 0 0 r
.004 w
.37469 .44582 m
.45459 .53645 L
s
P
p
1 0 0 r
.004 w
.37469 .44582 m
.33366 .41545 L
s
P
p
.2 0 1 r
.004 w
.66306 .42866 m
.57606 .44436 L
s
P
p
.2 0 1 r
.004 w
.57606 .44436 m
.54326 .48526 L
s
P
p
1 0 0 r
.004 w
.57606 .44436 m
.54323 .52203 L
s
P
p
.2 0 1 r
.004 w
.37144 .51478 m
.45548 .50034 L
s
P
p
.2 0 1 r
.004 w
.37144 .51478 m
.3251 .56088 L
s
P
p
.2 0 1 r
.004 w
.75386 .41227 m
.66306 .42866 L
s
P
p
.2 0 1 r
.004 w
.66306 .42866 m
.63504 .4695 L
s
P
p
1 0 0 r
.004 w
.66306 .42866 m
.63594 .50695 L
s
P
p
.2 0 1 r
.004 w
.45548 .50034 m
.54326 .48526 L
s
P
p
.2 0 1 r
.004 w
.45548 .50034 m
.41351 .54657 L
s
P
p
1 0 0 r
.004 w
.33366 .41545 m
.41487 .50842 L
s
P
p
1 0 0 r
.004 w
.33366 .41545 m
.28909 .38245 L
s
P
p
.2 0 1 r
.004 w
.84871 .39515 m
.75386 .41227 L
s
P
p
.2 0 1 r
.004 w
.75386 .41227 m
.73109 .453 L
s
P
p
1 0 0 r
.004 w
.75386 .41227 m
.73302 .49116 L
s
P
p
1 0 0 r
.004 w
.45459 .53645 m
.54323 .52203 L
s
P
p
1 0 0 r
.004 w
.45459 .53645 m
.41487 .50842 L
s
P
p
.2 0 1 r
.004 w
.54326 .48526 m
.63504 .4695 L
s
P
p
.2 0 1 r
.004 w
.54326 .48526 m
.50611 .53159 L
s
P
p
.2 0 1 r
.004 w
.94791 .37725 m
.84871 .39515 L
s
P
p
.2 0 1 r
.004 w
.84871 .39515 m
.83172 .43571 L
s
P
p
1 0 0 r
.004 w
.84871 .39515 m
.83477 .47461 L
s
P
p
1 0 0 r
.004 w
.54323 .52203 m
.63594 .50695 L
s
P
p
1 0 0 r
.004 w
.54323 .52203 m
.50525 .6119 L
s
P
p
.2 0 1 r
.004 w
.3251 .56088 m
.41351 .54657 L
s
P
p
.2 0 1 r
.004 w
.3251 .56088 m
.27251 .6132 L
s
P
p
1 0 0 r
.004 w
.28909 .38245 m
.37151 .47782 L
s
P
p
1 0 0 r
.004 w
.28909 .38245 m
.24049 .34646 L
s
P
p
.2 0 1 r
.004 w
.63504 .4695 m
.73109 .453 L
s
P
p
.2 0 1 r
.004 w
.63504 .4695 m
.60322 .51588 L
s
P
p
.2 0 1 r
.004 w
.92897 .34078 m
.94791 .37725 L
s
P
p
1 0 0 r
.004 w
.41487 .50842 m
.50525 .6119 L
s
P
p
1 0 0 r
.004 w
.41487 .50842 m
.37151 .47782 L
s
P
p
1 0 0 r
.004 w
.63594 .50695 m
.73302 .49116 L
s
P
p
1 0 0 r
.004 w
.63594 .50695 m
.60447 .59783 L
s
P
p
.2 0 1 r
.004 w
.41351 .54657 m
.50611 .53159 L
s
P
p
.2 0 1 r
.004 w
.41351 .54657 m
.36573 .5992 L
s
P
p
.2 0 1 r
.004 w
.73109 .453 m
.83172 .43571 L
s
P
p
.2 0 1 r
.004 w
.73109 .453 m
.70516 .49939 L
s
P
p
1 0 0 r
.004 w
.73302 .49116 m
.83477 .47461 L
s
P
p
1 0 0 r
.004 w
.73302 .49116 m
.70875 .58305 L
s
P
p
.2 0 1 r
.004 w
.50611 .53159 m
.60322 .51588 L
s
P
p
.2 0 1 r
.004 w
.50611 .53159 m
.46369 .58449 L
s
P
p
1 0 0 r
.004 w
.24049 .34646 m
.324 .44429 L
s
P
p
1 0 0 r
.004 w
.24049 .34646 m
.18728 .30707 L
s
P
p
.2 0 1 r
.004 w
.83172 .43571 m
.92897 .34078 L
s
P
p
.2 0 1 r
.004 w
.83172 .43571 m
.80641 .40039 L
s
P
p
.2 0 1 r
.004 w
.90823 .30084 m
.92897 .34078 L
s
P
p
1 0 0 r
.004 w
.83477 .47461 m
.92897 .34078 L
s
P
p
1 0 0 r
.004 w
.37151 .47782 m
.46369 .58449 L
s
P
p
1 0 0 r
.004 w
.37151 .47782 m
.324 .44429 L
s
P
p
1 0 0 r
.004 w
.83477 .47461 m
.80933 .44076 L
s
P
p
.2 0 1 r
.004 w
.27251 .6132 m
.36573 .5992 L
s
P
p
.2 0 1 r
.004 w
.27251 .6132 m
.21982 .58593 L
s
P
p
1 0 0 r
.004 w
.50525 .6119 m
.60447 .59783 L
s
P
p
1 0 0 r
.004 w
.50525 .6119 m
.46369 .58449 L
s
P
p
.2 0 1 r
.004 w
.60322 .51588 m
.70516 .49939 L
s
P
p
.2 0 1 r
.004 w
.60322 .51588 m
.56676 .56902 L
s
P
p
.2 0 1 r
.004 w
.36573 .5992 m
.46369 .58449 L
s
P
p
.2 0 1 r
.004 w
.36573 .5992 m
.31629 .57053 L
s
P
p
1 0 0 r
.004 w
.60447 .59783 m
.70875 .58305 L
s
P
p
1 0 0 r
.004 w
.60447 .59783 m
.56676 .56902 L
s
P
p
1 0 0 r
.004 w
.18728 .30707 m
.27171 .40739 L
s
P
p
1 0 0 r
.004 w
.18728 .30707 m
.12877 .26376 L
s
P
p
.2 0 1 r
.004 w
.70516 .49939 m
.80641 .40039 L
s
P
p
.2 0 1 r
.004 w
.70516 .49939 m
.67236 .46558 L
s
P
p
.2 0 1 r
.004 w
.80641 .40039 m
.90823 .30084 L
s
P
p
.2 0 1 r
.004 w
.80641 .40039 m
.77857 .36154 L
s
P
p
.2 0 1 r
.004 w
.88541 .25689 m
.90823 .30084 L
s
P
p
1 0 0 r
.004 w
.80933 .44076 m
.90823 .30084 L
s
P
p
1 0 0 r
.004 w
.324 .44429 m
.41792 .5543 L
s
P
p
1 0 0 r
.004 w
.324 .44429 m
.27171 .40739 L
s
P
p
1 0 0 r
.004 w
.70875 .58305 m
.80933 .44076 L
s
P
p
1 0 0 r
.004 w
.80933 .44076 m
.7813 .4035 L
s
P
p
.2 0 1 r
.004 w
.21982 .58593 m
.31629 .57053 L
s
P
p
.2 0 1 r
.004 w
.21982 .58593 m
.16179 .55589 L
s
P
p
.2 0 1 r
.004 w
.46369 .58449 m
.56676 .56902 L
s
P
p
.2 0 1 r
.004 w
.46369 .58449 m
.41792 .5543 L
s
P
p
1 0 0 r
.004 w
.70875 .58305 m
.67535 .55271 L
s
P
p
.2 0 1 r
.004 w
.31629 .57053 m
.41792 .5543 L
s
P
p
.2 0 1 r
.004 w
.31629 .57053 m
.2617 .53886 L
s
P
p
.2 0 1 r
.004 w
.56676 .56902 m
.67236 .46558 L
s
P
p
.2 0 1 r
.004 w
.56676 .56902 m
.52511 .53719 L
s
P
p
1 0 0 r
.004 w
.56676 .56902 m
.67535 .55271 L
s
P
p
1 0 0 r
.004 w
.12877 .26376 m
.21795 .32311 L
s
P
p
1 0 0 r
.004 w
.12877 .26376 m
.06415 .21592 L
s
P
p
.2 0 1 r
.004 w
.67236 .46558 m
.77857 .36154 L
s
P
p
.2 0 1 r
.004 w
.67236 .46558 m
.63611 .42824 L
s
P
p
.2 0 1 r
.004 w
.77857 .36154 m
.88541 .25689 L
s
P
p
.2 0 1 r
.004 w
.77857 .36154 m
.7478 .31861 L
s
P
p
.2 0 1 r
.004 w
.86018 .20831 m
.88541 .25689 L
s
P
p
1 0 0 r
.004 w
.7813 .4035 m
.88541 .25689 L
s
P
p
1 0 0 r
.004 w
.27171 .40739 m
.3716 .4302 L
s
P
p
1 0 0 r
.004 w
.27171 .40739 m
.21795 .32311 L
s
P
p
1 0 0 r
.004 w
.67535 .55271 m
.7813 .4035 L
s
P
p
1 0 0 r
.004 w
.7813 .4035 m
.7503 .36227 L
s
P
p
.2 0 1 r
.004 w
.16179 .55589 m
.2617 .53886 L
s
P
p
.2 0 1 r
.004 w
.16179 .55589 m
.09755 .52264 L
s
P
p
.2 0 1 r
.004 w
.41792 .5543 m
.52511 .53719 L
s
P
p
.2 0 1 r
.004 w
.41792 .5543 m
.36723 .52088 L
s
P
p
1 0 0 r
.004 w
.41792 .5543 m
.3716 .4302 L
s
P
p
1 0 0 r
.004 w
.67535 .55271 m
.63836 .51912 L
s
P
p
.2 0 1 r
.004 w
.2617 .53886 m
.36723 .52088 L
s
P
p
.2 0 1 r
.004 w
.2617 .53886 m
.2011 .50372 L
s
P
p
.2 0 1 r
.004 w
.52511 .53719 m
.63611 .42824 L
s
P
p
.2 0 1 r
.004 w
.52511 .53719 m
.47887 .50186 L
s
P
p
1 0 0 r
.004 w
.52511 .53719 m
.63836 .51912 L
s
P
p
1 0 0 r
.004 w
.52511 .53719 m
.48057 .40909 L
s
P
p
1 0 0 r
.004 w
.3716 .4302 m
.48057 .40909 L
s
P
p
1 0 0 r
.004 w
.3716 .4302 m
.32263 .29897 L
s
P
p
1 0 0 r
.004 w
.21795 .32311 m
.32263 .29897 L
s
P
p
1 0 0 r
.004 w
.21795 .32311 m
.16454 .18874 L
s
P
p
1 0 0 r
.004 w
.06415 .21592 m
.16454 .18874 L
s
P
p
.2 0 1 r
.004 w
.63611 .42824 m
.7478 .31861 L
s
P
p
.2 0 1 r
.004 w
.63611 .42824 m
.59586 .38676 L
s
P
p
.2 0 1 r
.004 w
.7478 .31861 m
.86018 .20831 L
s
P
p
.2 0 1 r
.004 w
.7478 .31861 m
.71362 .27092 L
s
P
p
.2 0 1 r
.004 w
.83214 .15431 m
.86018 .20831 L
s
P
p
1 0 0 r
.004 w
.7503 .36227 m
.86018 .20831 L
s
P
p
1 0 0 r
.004 w
.63836 .51912 m
.7503 .36227 L
s
P
p
1 0 0 r
.004 w
.7503 .36227 m
.71581 .3164 L
s
P
p
.2 0 1 r
.004 w
.09755 .52264 m
.2011 .50372 L
s
P
p
.2 0 1 r
.004 w
.09755 .52264 m
.02606 .48563 L
s
P
p
.2 0 1 r
.004 w
.36723 .52088 m
.47887 .50186 L
s
P
p
.2 0 1 r
.004 w
.36723 .52088 m
.31081 .48367 L
s
P
p
1 0 0 r
.004 w
.63836 .51912 m
.59586 .38676 L
s
P
p
1 0 0 r
.004 w
.48057 .40909 m
.59586 .38676 L
s
P
p
1 0 0 r
.004 w
.48057 .40909 m
.43339 .27343 L
s
P
p
1 0 0 r
.004 w
.32263 .29897 m
.43339 .27343 L
s
P
p
1 0 0 r
.004 w
.32263 .29897 m
.27076 .15998 L
s
P
p
1 0 0 r
.004 w
.16454 .18874 m
.27076 .15998 L
s
P
p
.2 0 1 r
.004 w
.2011 .50372 m
.31081 .48367 L
s
P
p
.2 0 1 r
.004 w
.2011 .50372 m
.13345 .46448 L
s
P
p
.2 0 1 r
.004 w
.47887 .50186 m
.59586 .38676 L
s
P
p
.2 0 1 r
.004 w
.47887 .50186 m
.42724 .4624 L
s
P
p
.2 0 1 r
.004 w
.59586 .38676 m
.71362 .27092 L
s
P
p
.2 0 1 r
.004 w
.59586 .38676 m
.5509 .34043 L
s
P
p
1 0 0 r
.004 w
.59586 .38676 m
.71581 .3164 L
s
P
p
1 0 0 r
.004 w
.59586 .38676 m
.55078 .24635 L
s
P
p
1 0 0 r
.004 w
.43339 .27343 m
.55078 .24635 L
s
P
p
1 0 0 r
.004 w
.43339 .27343 m
.38334 .1295 L
s
P
p
1 0 0 r
.004 w
.27076 .15998 m
.38334 .1295 L
s
P
p
.2 0 1 r
.004 w
.71362 .27092 m
.83214 .15431 L
s
P
p
.2 0 1 r
.004 w
.71362 .27092 m
.67542 .21761 L
s
P
p
.2 0 1 r
.004 w
.8008 .09395 m
.83214 .15431 L
s
P
p
1 0 0 r
.004 w
.71581 .3164 m
.83214 .15431 L
s
P
p
1 0 0 r
.004 w
.71581 .3164 m
.67542 .21761 L
s
P
p
.2 0 1 r
.004 w
.02606 .48563 m
.13345 .46448 L
s
P
p
.2 0 1 r
.004 w
.31081 .48367 m
.42724 .4624 L
s
P
p
.2 0 1 r
.004 w
.31081 .48367 m
.24761 .442 L
s
P
p
1 0 0 r
.004 w
.55078 .24635 m
.67542 .21761 L
s
P
p
1 0 0 r
.004 w
.55078 .24635 m
.50287 .09714 L
s
P
p
1 0 0 r
.004 w
.38334 .1295 m
.50287 .09714 L
s
P
p
.2 0 1 r
.004 w
.13345 .46448 m
.24761 .442 L
s
P
p
.2 0 1 r
.004 w
.42724 .4624 m
.5509 .34043 L
s
P
p
.2 0 1 r
.004 w
.42724 .4624 m
.3692 .41805 L
s
P
p
.2 0 1 r
.004 w
.5509 .34043 m
.67542 .21761 L
s
P
p
.2 0 1 r
.004 w
.5509 .34043 m
.50034 .28833 L
s
P
p
.2 0 1 r
.004 w
.67542 .21761 m
.8008 .09395 L
s
P
p
.2 0 1 r
.004 w
.67542 .21761 m
.63245 .15766 L
s
P
p
1 0 0 r
.004 w
.67542 .21761 m
.63002 .06271 L
s
P
p
1 0 0 r
.004 w
.50287 .09714 m
.63002 .06271 L
s
P
p
.2 0 1 r
.004 w
.76552 .02602 m
.8008 .09395 L
s
P
p
.2 0 1 r
.004 w
.24761 .442 m
.3692 .41805 L
s
P
p
1 0 0 r
.004 w
.63002 .06271 m
.76552 .02602 L
s
P
p
.2 0 1 r
.004 w
.3692 .41805 m
.50034 .28833 L
s
P
p
.2 0 1 r
.004 w
.50034 .28833 m
.63245 .15766 L
s
P
p
.2 0 1 r
.004 w
.63245 .15766 m
.76552 .02602 L
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(1)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.16454 .18874 m
.16381 .1952 L
s
P
[(2)] .16599 .17581 -0.11272 1 Mshowa
p
.002 w
.27076 .15998 m
.27022 .16646 L
s
P
[(3)] .27182 .14701 -0.08207 1 Mshowa
p
.002 w
.38334 .1295 m
.38302 .136 L
s
P
[(4)] .38398 .1165 -0.049 1 Mshowa
p
.002 w
.50287 .09714 m
.50278 .10364 L
s
P
[(5)] .50304 .08413 -0.01322 1 Mshowa
p
.002 w
.63002 .06271 m
.63018 .06921 L
s
P
[(6)] .62968 .0497 .02561 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(7)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 280},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Membership Matrix", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ToMembershipMatrix[A] displays the membership matrix of fuzzy relation A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
One last option for viewing a fuzzy relation is to look at its membership \
matrix. A membership matrix is a matrix that shows the membership grades of \
all the elements of a fuzzy relation. This is a convenient way to view fuzzy \
relations. We demonstrate this function on our first fuzzy relation here.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["ToMembershipMatrix[Rel1]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
MatrixForm[{{0, 0, 0, 0, 0, 0, 0, 0}, 
 
   {0, 1/3, 1/2, 1/2, 1/2, 1/2, 1/2, 0}, 
 
   {0, 1/3, 2/3, 1, 1, 1, 1/2, 0}, 
 
   {0, 1/3, 2/3, 1, 1, 1, 1/2, 0}, 
 
   {0, 1/3, 2/3, 1, 1, 1, 1/2, 0}, 
 
   {0, 1/3, 1/2, 1/2, 1/2, 1/2, 1/2, 0}, 
 
   {0, 0, 0, 0, 0, 0, 0, 0}}]















\
\>", "\<\


0   0   0   0   0   0   0   0

    1   1   1   1   1   1
    -   -   -   -   -   -
0   3   2   2   2   2   2   0

    1   2               1
    -   -               -
0   3   3   1   1   1   2   0

    1   2               1
    -   -               -
0   3   3   1   1   1   2   0

    1   2               1
    -   -               -
0   3   3   1   1   1   2   0

    1   1   1   1   1   1
    -   -   -   -   -   -
0   3   2   2   2   2   2   0



0   0   0   0   0   0   0   0\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Additional Plotting Options", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In addition to the options described in this chapter, the FuzzyPlot3D and \
FuzzySurfacePlot functions also accept any of the options that Mathematica's \
standard Plot3D function accepts. Here is a list of these additional options.\
\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 AmbientLight      AspectRatio    Axes
  AxesEdge          AxesLabel      AxesStyle
  Background        Boxed          BoxRatios
  BoxStyle          ClipFill       ColorOutput
  Compiled          DefaultColor   DefaultFont
  DisplayFunction   Epilog         FaceGrids
  HiddenSurface     Lighting       LightSources
  MeshStyle         PlotLabel      PlotPoints
  PlotRange         PlotRegion     Plot3Matrix
  Prolog            Shading        SphericalRegion
  Ticks             ViewCenter     ViewPoint
  ViewVertical                  \
\>", "Special3",
  CellFrame->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For more information on these options see The Mathematica Book (Mathematica: \
A System for Doing Mathematics by Computer by Stephen Wolfram). We \
demonstrate a few of these options in the following example.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
FuzzySurfacePlot[Rel2,ViewPoint->{2,0,1},
  AxesEdge->{{1,-1},{1,-1},{1,-1}},
  MeshStyle->{Thickness[.006],Hue[.7]},
  Background->GrayLevel[.9],
  PlotLabel->\"Rel2\"];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .64558 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Background color
.9 g
MFill
% Scaling calculations
0.0238095 0.952381 -0.105562 0.952381 [
[(Rel2)] .5 .64558 0 -1.5 Msboxa
[(1)] .80376 .39673 -1 0 Msboxa
[(2)] .82035 .35224 -1 0 Msboxa
[(3)] .83893 .30238 -1 0 Msboxa
[(4)] .85989 .24613 -1 0 Msboxa
[(5)] .88372 .18217 -1 0 Msboxa
[(6)] .91106 .10881 -1 0 Msboxa
[(7)] .94274 .02381 -1 0 Msboxa
[(V )] .91941 .24613 -1 0 Msboxa
[(1)] .065 .01265 .37268 1 Msboxa
[(2)] .1892 .01231 .2662 1 Msboxa
[(3)] .31348 .01205 .15972 1 Msboxa
[(4)] .43782 .01192 .05324 1 Msboxa
[(5)] .56218 .01192 -0.05324 1 Msboxa
[(6)] .68652 .01205 -0.15972 1 Msboxa
[(7)] .8108 .01231 -0.2662 1 Msboxa
[(8)] .935 .01265 -0.37268 1 Msboxa
[( W)] .5 -0.04762 0 1 Msboxa
[(0)] .05726 .02381 1 0 Msboxa
[(0.25)] .04676 .09423 1 0 Msboxa
[(0.5)] .03574 .16817 1 0 Msboxa
[(0.75)] .02415 .24589 1 0 Msboxa
[(1)] .01195 .3277 1 0 Msboxa
[(Grade    )] -0.02381 .16832 1 0 Msboxa
[ 0 0 0 0 ]
[ 1 .64558 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
[(Rel2)] .5 .64558 0 -1.5 Mshowa
p
p
.002 w
.79186 .39673 m
.93084 .02381 L
s
P
p
.002 w
.79186 .39673 m
.78591 .39673 L
s
P
[(1)] .80376 .39673 -1 0 Mshowa
p
.002 w
.80844 .35224 m
.80249 .35224 L
s
P
[(2)] .82035 .35224 -1 0 Mshowa
p
.002 w
.82702 .30238 m
.82107 .30238 L
s
P
[(3)] .83893 .30238 -1 0 Mshowa
p
.002 w
.84799 .24613 m
.84203 .24613 L
s
P
[(4)] .85989 .24613 -1 0 Mshowa
p
.002 w
.87182 .18217 m
.86587 .18217 L
s
P
[(5)] .88372 .18217 -1 0 Mshowa
p
.002 w
.89916 .10881 m
.89321 .10881 L
s
P
[(6)] .91106 .10881 -1 0 Mshowa
p
.002 w
.93084 .02381 m
.92489 .02381 L
s
P
[(7)] .94274 .02381 -1 0 Mshowa
[(V )] .91941 .24613 -1 0 Mshowa
P
p
p
.002 w
.06916 .02381 m
.93084 .02381 L
s
P
p
.002 w
.06916 .02381 m
.07124 .02939 L
s
P
[(1)] .065 .01265 .37268 1 Mshowa
p
.002 w
.19226 .02381 m
.19379 .02956 L
s
P
[(2)] .1892 .01231 .2662 1 Mshowa
p
.002 w
.31535 .02381 m
.31629 .02969 L
s
P
[(3)] .31348 .01205 .15972 1 Mshowa
p
.002 w
.43845 .02381 m
.43877 .02975 L
s
P
[(4)] .43782 .01192 .05324 1 Mshowa
p
.002 w
.56155 .02381 m
.56123 .02975 L
s
P
[(5)] .56218 .01192 -0.05324 1 Mshowa
p
.002 w
.68465 .02381 m
.68371 .02969 L
s
P
[(6)] .68652 .01205 -0.15972 1 Mshowa
p
.002 w
.80774 .02381 m
.80621 .02956 L
s
P
[(7)] .8108 .01231 -0.2662 1 Mshowa
p
.002 w
.93084 .02381 m
.92876 .02939 L
s
P
[(8)] .935 .01265 -0.37268 1 Mshowa
[( W)] .5 -0.04762 0 1 Mshowa
P
p
p
.002 w
.06916 .02381 m
.02381 .32804 L
s
P
p
.002 w
.06916 .02381 m
.07511 .02381 L
s
P
[(0)] .05726 .02381 1 0 Mshowa
p
.002 w
.05866 .09423 m
.06462 .09423 L
s
P
[(0.25)] .04676 .09423 1 0 Mshowa
p
.002 w
.04764 .16817 m
.05359 .16817 L
s
P
[(0.5)] .03574 .16817 1 0 Mshowa
p
.002 w
.03606 .24589 m
.04201 .24589 L
s
P
[(0.75)] .02415 .24589 1 0 Mshowa
p
.002 w
.02386 .3277 m
.02981 .3277 L
s
P
[(1)] .01195 .3277 1 0 Mshowa
p
.001 w
.0671 .03762 m
.07067 .03762 L
s
P
p
.001 w
.06502 .05157 m
.06859 .05157 L
s
P
p
.001 w
.06292 .06565 m
.06649 .06565 L
s
P
p
.001 w
.0608 .07987 m
.06438 .07987 L
s
P
p
.001 w
.0565 .10873 m
.06007 .10873 L
s
P
p
.001 w
.05432 .12337 m
.05789 .12337 L
s
P
p
.001 w
.05212 .13815 m
.05569 .13815 L
s
P
p
.001 w
.04989 .15308 m
.05346 .15308 L
s
P
p
.001 w
.04537 .1834 m
.04894 .1834 L
s
P
p
.001 w
.04308 .19878 m
.04665 .19878 L
s
P
p
.001 w
.04076 .21433 m
.04433 .21433 L
s
P
p
.001 w
.03842 .23003 m
.04199 .23003 L
s
P
p
.001 w
.03367 .26192 m
.03724 .26192 L
s
P
p
.001 w
.03125 .27811 m
.03482 .27811 L
s
P
p
.001 w
.02881 .29447 m
.03239 .29447 L
s
P
p
.001 w
.02635 .311 m
.02992 .311 L
s
P
[(Grade    )] -0.02381 .16832 1 0 Mshowa
P
0 0 m
1 0 L
1 .64558 L
0 .64558 L
closepath
clip
newpath
p
.002 w
.20814 .39673 m
.18801 .62177 L
s
.18801 .62177 m
.81199 .62177 L
s
.81199 .62177 m
.79186 .39673 L
s
.79186 .39673 m
.20814 .39673 L
s
.06916 .02381 m
.93084 .02381 L
s
.93084 .02381 m
.97619 .32804 L
s
.97619 .32804 m
.02381 .32804 L
s
.02381 .32804 m
.06916 .02381 L
s
.20814 .39673 m
.18801 .62177 L
s
.18801 .62177 m
.02381 .32804 L
s
.02381 .32804 m
.06916 .02381 L
s
.06916 .02381 m
.20814 .39673 L
s
.79186 .39673 m
.93084 .02381 L
s
.93084 .02381 m
.97619 .32804 L
s
.97619 .32804 m
.81199 .62177 L
s
.81199 .62177 m
.79186 .39673 L
s
p
.4 g
.19156 .35224 m
.80844 .35224 L
s
P
p
.4 g
.15201 .24613 m
.84799 .24613 L
s
P
p
.4 g
.10084 .10881 m
.89916 .10881 L
s
P
p
.4 g
.29153 .39673 m
.19226 .02381 L
s
P
p
.4 g
.45831 .39673 m
.43845 .02381 L
s
P
p
.4 g
.62508 .39673 m
.68465 .02381 L
s
P
p
.4 g
.79186 .39673 m
.93084 .02381 L
s
P
P
p
.006 w
.72543 .42701 m .80844 .35224 L .79186 .39673 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.79186 .39673 m .71305 .46838 L .72543 .42701 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.63848 .50534 m .72543 .42701 L .71305 .46838 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.71305 .46838 m .6307 .54324 L .63848 .50534 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.54728 .58749 m .63848 .50534 L .6307 .54324 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.6307 .54324 m .54457 .62153 L .54728 .58749 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.73935 .38054 m .82702 .30238 L .80844 .35224 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.80844 .35224 m .72543 .42701 L .73935 .38054 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.45272 .58749 m .54728 .58749 L .54457 .62153 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.54457 .62153 m .45543 .62153 L .45272 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.35815 .58749 m .45272 .58749 L .45543 .62153 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.45543 .62153 m .3663 .62153 L .35815 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.26358 .58749 m .35815 .58749 L .3663 .62153 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.3663 .62153 m .27717 .62153 L .26358 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.16901 .58749 m .26358 .58749 L .27717 .62153 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.27717 .62153 m .18803 .62153 L .16901 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.64724 .46265 m .73935 .38054 L .72543 .42701 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.72543 .42701 m .63848 .50534 L .64724 .46265 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.55035 .54903 m .64724 .46265 L .63848 .50534 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.63848 .50534 m .54728 .58749 L .55035 .54903 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.7551 .32795 m .84799 .24613 L .82702 .30238 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.82702 .30238 m .73935 .38054 L .7551 .32795 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.44965 .54903 m .55035 .54903 L .54728 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.54728 .58749 m .45272 .58749 L .44965 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.34894 .54903 m .44965 .54903 L .45272 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.45272 .58749 m .35815 .58749 L .34894 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.24823 .54903 m .34894 .54903 L .35815 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.35815 .58749 m .26358 .58749 L .24823 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.14752 .54903 m .24823 .54903 L .26358 .58749 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.26358 .58749 m .16901 .58749 L .14752 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.65719 .41419 m .7551 .32795 L .73935 .38054 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.73935 .38054 m .64724 .46265 L .65719 .41419 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.55385 .50522 m .65719 .41419 L .64724 .46265 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.64724 .46265 m .55035 .54903 L .55385 .50522 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.77306 .26796 m .87182 .18217 L .84799 .24613 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.84799 .24613 m .7551 .32795 L .77306 .26796 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.44615 .50522 m .55385 .50522 L .55035 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.55035 .54903 m .44965 .54903 L .44615 .50522 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.33845 .50522 m .44615 .50522 L .44965 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.44965 .54903 m .34894 .54903 L .33845 .50522 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.23075 .50522 m .33845 .50522 L .34894 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.34894 .54903 m .24823 .54903 L .23075 .50522 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.12305 .50522 m .23075 .50522 L .24823 .54903 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.24823 .54903 m .14752 .54903 L .12305 .50522 L p
.472 .815 .998 r
F P
.2 0 1 r
s
P
p
.006 w
.66858 .35871 m .77306 .26796 L .7551 .32795 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.7551 .32795 m .65719 .41419 L .66858 .35871 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.55619 .35871 m .66858 .35871 L .65719 .41419 L p
.899 .855 .79 r
F P
.2 0 1 r
s
P
p
.006 w
.65719 .41419 m .55385 .50522 L .55619 .35871 L p
.899 .855 .79 r
F P
.2 0 1 r
s
P
p
.006 w
.79374 .19888 m .89916 .10881 L .87182 .18217 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.87182 .18217 m .77306 .26796 L .79374 .19888 L p
.793 .995 .775 r
F P
.2 0 1 r
s
P
p
.006 w
.44381 .35871 m .55619 .35871 L .55385 .50522 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.55385 .50522 m .44615 .50522 L .44381 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.33142 .35871 m .44381 .35871 L .44615 .50522 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.44615 .50522 m .33845 .50522 L .33142 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.21903 .35871 m .33142 .35871 L .33845 .50522 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.33845 .50522 m .23075 .50522 L .21903 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.10665 .35871 m .21903 .35871 L .23075 .50522 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.23075 .50522 m .12305 .50522 L .10665 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.67625 .19888 m .79374 .19888 L .77306 .26796 L p
.904 .865 .79 r
F P
.2 0 1 r
s
P
p
.006 w
.77306 .26796 m .66858 .35871 L .67625 .19888 L p
.904 .865 .79 r
F P
.2 0 1 r
s
P
p
.006 w
.55875 .19888 m .67625 .19888 L .66858 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.66858 .35871 m .55619 .35871 L .55875 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.44125 .19888 m .55875 .19888 L .55619 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.55619 .35871 m .44381 .35871 L .44125 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.32375 .19888 m .44125 .19888 L .44381 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.44381 .35871 m .33142 .35871 L .32375 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.20626 .19888 m .32375 .19888 L .33142 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.33142 .35871 m .21903 .35871 L .20626 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.08876 .19888 m .20626 .19888 L .21903 .35871 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.21903 .35871 m .10665 .35871 L .08876 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.80774 .02381 m .93084 .02381 L .89916 .10881 L p
.91 .876 .79 r
F P
.2 0 1 r
s
P
p
.006 w
.89916 .10881 m .79374 .19888 L .80774 .02381 L p
.91 .876 .79 r
F P
.2 0 1 r
s
P
p
.006 w
.68465 .02381 m .80774 .02381 L .79374 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.79374 .19888 m .67625 .19888 L .68465 .02381 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.56155 .02381 m .68465 .02381 L .67625 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.67625 .19888 m .55875 .19888 L .56155 .02381 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.43845 .02381 m .56155 .02381 L .55875 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.55875 .19888 m .44125 .19888 L .43845 .02381 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.31535 .02381 m .43845 .02381 L .44125 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.44125 .19888 m .32375 .19888 L .31535 .02381 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.19226 .02381 m .31535 .02381 L .32375 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.32375 .19888 m .20626 .19888 L .19226 .02381 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.06916 .02381 m .19226 .02381 L .20626 .19888 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.006 w
.20626 .19888 m .08876 .19888 L .06916 .02381 L p
.69 .69 .845 r
F P
.2 0 1 r
s
P
p
.002 w
.06916 .02381 m
.93084 .02381 L
s
.93084 .02381 m
.97619 .32804 L
s
.97619 .32804 m
.02381 .32804 L
s
.02381 .32804 m
.06916 .02381 L
s
P
p
p
.002 w
.06916 .02381 m
.02381 .32804 L
s
P
p
.002 w
.06916 .02381 m
.07511 .02381 L
s
P
[(0)] .05726 .02381 1 0 Mshowa
p
.002 w
.05866 .09423 m
.06462 .09423 L
s
P
[(0.25)] .04676 .09423 1 0 Mshowa
p
.002 w
.04764 .16817 m
.05359 .16817 L
s
P
[(0.5)] .03574 .16817 1 0 Mshowa
p
.002 w
.03606 .24589 m
.04201 .24589 L
s
P
[(0.75)] .02415 .24589 1 0 Mshowa
p
.002 w
.02386 .3277 m
.02981 .3277 L
s
P
[(1)] .01195 .3277 1 0 Mshowa
p
.001 w
.0671 .03762 m
.07067 .03762 L
s
P
p
.001 w
.06502 .05157 m
.06859 .05157 L
s
P
p
.001 w
.06292 .06565 m
.06649 .06565 L
s
P
p
.001 w
.0608 .07987 m
.06438 .07987 L
s
P
p
.001 w
.0565 .10873 m
.06007 .10873 L
s
P
p
.001 w
.05432 .12337 m
.05789 .12337 L
s
P
p
.001 w
.05212 .13815 m
.05569 .13815 L
s
P
p
.001 w
.04989 .15308 m
.05346 .15308 L
s
P
p
.001 w
.04537 .1834 m
.04894 .1834 L
s
P
p
.001 w
.04308 .19878 m
.04665 .19878 L
s
P
p
.001 w
.04076 .21433 m
.04433 .21433 L
s
P
p
.001 w
.03842 .23003 m
.04199 .23003 L
s
P
p
.001 w
.03367 .26192 m
.03724 .26192 L
s
P
p
.001 w
.03125 .27811 m
.03482 .27811 L
s
P
p
.001 w
.02881 .29447 m
.03239 .29447 L
s
P
p
.001 w
.02635 .311 m
.02992 .311 L
s
P
[(Grade    )] -0.02381 .16832 1 0 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 257},
  ImageMargins->{{33, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{Automatic, 43}, {23, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 94, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1856, 60, 67, 1, 70, "Subsection"],
Cell[1926, 63, 255, 5, 70, "Text"],
Cell[2184, 70, 143, 4, 70, "Text"],
Cell[2330, 76, 102, 2, 70, "Input"],
Cell[2435, 80, 304, 6, 70, "SmallText"],
Cell[2742, 88, 244, 5, 70, "Text"],
Cell[2989, 95, 164, 5, 70, "Input"],
Cell[3156, 102, 164, 5, 70, "Input"]
}, Open  ]],
Cell[3332, 109, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[3405, 112, 71, 1, 70, "Subsection"],
Cell[3479, 115, 452, 8, 70, "Text"],

Cell[CellGroupData[{
Cell[3954, 125, 91, 2, 70, "Input"],
Cell[4048, 129, 9654, 923, 70, 9496, 918, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[13714, 1054, 409, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[14146, 1063, 96, 2, 70, "Input"],
Cell[14245, 1067, 13046, 1315, 70, 12888, 1310, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[27303, 2384, 400, 7, 70, "Text"],

Cell[CellGroupData[{
Cell[27726, 2393, 111, 2, 70, "Input"],
Cell[27840, 2397, 17676, 1875, 70, 17518, 1870, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[45537, 4274, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[45610, 4277, 67, 1, 70, "Subsection"],
Cell[45680, 4280, 154, 4, 70, "Text"],
Cell[45837, 4286, 355, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[46215, 4294, 96, 2, 70, "Input"],
Cell[46314, 4298, 13463, 1171, 70, 13305, 1166, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[59798, 5471, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[59871, 5474, 64, 1, 70, "Subsection"],
Cell[59938, 5477, 628, 10, 70, "Text"],

Cell[CellGroupData[{
Cell[60589, 5489, 120, 2, 70, "Input"],
Cell[60712, 5493, 15219, 1731, 70, 15061, 1726, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[75952, 7226, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[76025, 7229, 72, 1, 70, "Subsection"],
Cell[76100, 7232, 130, 3, 70, "Text"],
Cell[76233, 7237, 363, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[76619, 7245, 97, 2, 70, "Input"],
Cell[76719, 7249, 877, 60, 70, "Output"]
}, Open  ]]
}, Open  ]],
Cell[77617, 7311, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[77690, 7314, 82, 1, 70, "Subsection"],
Cell[77775, 7317, 291, 6, 70, "Text"],
Cell[78069, 7325, 617, 15, 70, "Special3"],
Cell[78689, 7342, 265, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[78977, 7349, 251, 8, 70, "Input"],
Cell[79231, 7359, 13938, 1246, 70, 13780, 1241, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
