(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    125743,      10241]*)
(*NotebookOutlinePosition[    126613,      10273]*)
(*  CellTagsIndexPosition[    126569,      10269]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Inferencing
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides two different functions for performing fuzzy \
inferencing. In this chapter, we demonstrate these functions and the options \
associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The inferencing functions are a little more involved than the other functions \
in this package, and consequently they need a little more setup than the \
other functions. We will demonstrate here how to set up and use the \
inferencing functions.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Composition-based Inference", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The CompositionBasedInference function works for single input-single output \
systems. To use the CompositionBasedInference function, a fuzzy relation must \
be created which models a system's input-output response. The fuzzy inference \
function then takes a fuzzy set as input and performs a composition to arrive \
at the output. What follows is a description of what is needed to perform a \
CompositionBasedInference and a demonstration of the inferencing operation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Inputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To create the fuzzy relation which we need to perform a \
CompositionBasedInference, we first need to define our collection of input \
fuzzy sets. Each fuzzy set used to define the collection of input fuzzy sets \
can be created individually using one of the techniques discussed in the \
fuzzy set creation section of this manual, or the entire collection of fuzzy \
sets can be created all at once using the CreateFuzzySets function as shown \
here. We look at our input fuzzy sets with the FuzzyPlot function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
INPUT = {NegBig,NegSmall,Zero,PosSmall,PosBig}=
  CreateFuzzySets[5,UniversalSpace->{0,10}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[INPUT,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0833333 0.0833333 0 0.618034 [
[(0)] .08333 0 0 2 Msboxa
[(1)] .16667 0 0 2 Msboxa
[(2)] .25 0 0 2 Msboxa
[(3)] .33333 0 0 2 Msboxa
[(4)] .41667 0 0 2 Msboxa
[(5)] .5 0 0 2 Msboxa
[(6)] .58333 0 0 2 Msboxa
[(7)] .66667 0 0 2 Msboxa
[(8)] .75 0 0 2 Msboxa
[(9)] .83333 0 0 2 Msboxa
[(10)] .91667 0 0 2 Msboxa
[(11)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.08333 0 m
.08333 .00625 L
s
P
[(0)] .08333 0 0 2 Mshowa
p
.002 w
.16667 0 m
.16667 .00625 L
s
P
[(1)] .16667 0 0 2 Mshowa
p
.002 w
.25 0 m
.25 .00625 L
s
P
[(2)] .25 0 0 2 Mshowa
p
.002 w
.33333 0 m
.33333 .00625 L
s
P
[(3)] .33333 0 0 2 Mshowa
p
.002 w
.41667 0 m
.41667 .00625 L
s
P
[(4)] .41667 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(5)] .5 0 0 2 Mshowa
p
.002 w
.58333 0 m
.58333 .00625 L
s
P
[(6)] .58333 0 0 2 Mshowa
p
.002 w
.66667 0 m
.66667 .00625 L
s
P
[(7)] .66667 0 0 2 Mshowa
p
.002 w
.75 0 m
.75 .00625 L
s
P
[(8)] .75 0 0 2 Mshowa
p
.002 w
.83333 0 m
.83333 .00625 L
s
P
[(9)] .83333 0 0 2 Mshowa
p
.002 w
.91667 0 m
.91667 .00625 L
s
P
[(10)] .91667 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(11)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.11803 Mabswid
.08333 .61803 m
.16667 .30902 L
.25 0 L
.33333 0 L
.41667 0 L
.5 0 L
.58333 0 L
.66667 0 L
.75 0 L
.83333 0 L
.91667 0 L
s
P
p
.2 0 1 r
1.11803 Mabswid
.08333 0 m
.16667 .30902 L
.25 .61803 L
.33333 .30902 L
.41667 0 L
.5 0 L
.58333 0 L
.66667 0 L
.75 0 L
.83333 0 L
.91667 0 L
s
P
p
0 1 .4 r
1.11803 Mabswid
.08333 0 m
.16667 0 L
.25 0 L
.33333 .30902 L
.41667 .61803 L
.5 .30902 L
.58333 0 L
.66667 0 L
.75 0 L
.83333 0 L
.91667 0 L
s
P
p
1 .6 0 r
1.11803 Mabswid
.08333 0 m
.16667 0 L
.25 0 L
.33333 0 L
.41667 0 L
.5 .30902 L
.58333 .61803 L
.66667 .30902 L
.75 0 L
.83333 0 L
.91667 0 L
s
P
p
.8 0 1 r
1.11803 Mabswid
.08333 0 m
.16667 0 L
.25 0 L
.33333 0 L
.41667 0 L
.5 0 L
.58333 0 L
.66667 .30902 L
.75 .61803 L
.83333 .30902 L
.91667 0 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
In this example, we have created five fuzzy sets which are named NegBig, \
NegSmall, Zero, PosSmall, and PosBig. Notice that these fuzzy sets are \
labeled with linguistic terms which describe the input's universal space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Outputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
With the input membership functions defined, we must create a set of output \
fuzzy sets. We again use the CreateFuzzySets function for convenience, but \
this time we create a collection of Gaussian fuzzy sets. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
OUTPUT = {NBO,NSO,ZO,PSO,PBO}=
  CreateFuzzySets[5,Type->Gaussian[2]];\
\>", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[OUTPUT,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0454545 0.0454545 0 0.618034 [
[(1)] .09091 0 0 2 Msboxa
[(3)] .18182 0 0 2 Msboxa
[(5)] .27273 0 0 2 Msboxa
[(7)] .36364 0 0 2 Msboxa
[(9)] .45455 0 0 2 Msboxa
[(11)] .54545 0 0 2 Msboxa
[(13)] .63636 0 0 2 Msboxa
[(15)] .72727 0 0 2 Msboxa
[(17)] .81818 0 0 2 Msboxa
[(19)] .90909 0 0 2 Msboxa
[(21)] 1 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.09091 0 m
.09091 .00625 L
s
P
[(1)] .09091 0 0 2 Mshowa
p
.002 w
.18182 0 m
.18182 .00625 L
s
P
[(3)] .18182 0 0 2 Mshowa
p
.002 w
.27273 0 m
.27273 .00625 L
s
P
[(5)] .27273 0 0 2 Mshowa
p
.002 w
.36364 0 m
.36364 .00625 L
s
P
[(7)] .36364 0 0 2 Mshowa
p
.002 w
.45455 0 m
.45455 .00625 L
s
P
[(9)] .45455 0 0 2 Mshowa
p
.002 w
.54545 0 m
.54545 .00625 L
s
P
[(11)] .54545 0 0 2 Mshowa
p
.002 w
.63636 0 m
.63636 .00625 L
s
P
[(13)] .63636 0 0 2 Mshowa
p
.002 w
.72727 0 m
.72727 .00625 L
s
P
[(15)] .72727 0 0 2 Mshowa
p
.002 w
.81818 0 m
.81818 .00625 L
s
P
[(17)] .81818 0 0 2 Mshowa
p
.002 w
.90909 0 m
.90909 .00625 L
s
P
[(19)] .90909 0 0 2 Mshowa
p
.002 w
1 0 m
1 .00625 L
s
P
[(21)] 1 0 0 2 Mshowa
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.11803 Mabswid
.04545 .61803 m
.09091 .48133 L
.13636 .22736 L
.18182 .06514 L
.22727 .01132 L
.27273 .00119 L
.31818 0 L
.36364 0 L
.40909 0 L
.45455 0 L
.5 0 L
.54545 0 L
.59091 0 L
.63636 0 L
.68182 0 L
.72727 0 L
.77273 0 L
.81818 0 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
.2 0 1 r
1.11803 Mabswid
.04545 .00119 m
.09091 .01132 L
.13636 .06514 L
.18182 .22736 L
.22727 .48133 L
.27273 .61803 L
.31818 .48133 L
.36364 .22736 L
.40909 .06514 L
.45455 .01132 L
.5 .00119 L
.54545 0 L
.59091 0 L
.63636 0 L
.68182 0 L
.72727 0 L
.77273 0 L
.81818 0 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
0 1 .4 r
1.11803 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 0 L
.27273 .00119 L
.31818 .01132 L
.36364 .06514 L
.40909 .22736 L
.45455 .48133 L
.5 .61803 L
.54545 .48133 L
.59091 .22736 L
.63636 .06514 L
.68182 .01132 L
.72727 .00119 L
.77273 0 L
.81818 0 L
.86364 0 L
.90909 0 L
.95455 0 L
s
P
p
1 .6 0 r
1.11803 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 0 L
.27273 0 L
.31818 0 L
.36364 0 L
.40909 0 L
.45455 0 L
.5 .00119 L
.54545 .01132 L
.59091 .06514 L
.63636 .22736 L
.68182 .48133 L
.72727 .61803 L
.77273 .48133 L
.81818 .22736 L
.86364 .06514 L
.90909 .01132 L
.95455 .00119 L
s
P
p
.8 0 1 r
1.11803 Mabswid
.04545 0 m
.09091 0 L
.13636 0 L
.18182 0 L
.22727 0 L
.27273 0 L
.31818 0 L
.36364 0 L
.40909 0 L
.45455 0 L
.5 0 L
.54545 0 L
.59091 0 L
.63636 0 L
.68182 0 L
.72727 .00119 L
.77273 .01132 L
.81818 .06514 L
.86364 .22736 L
.90909 .48133 L
.95455 .61803 L
s
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Rules", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The final item we need, to create the fuzzy relation which will define our \
system model, is a set of rules relating the input conditions to the output \
responses. These rules are formed as a list of \"if-then\" pairs, where the \
input condition is the first element of the pair, and the output response is \
the second element. Here is an example of a set of rules for the input and \
output we defined above.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
TheRules = {{NegBig,PBO},{NegSmall,PSO},
  {Zero,ZO},{PosBig,NBO}};\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The rules shown above constitute an if-then pair. For example, the first \
rule, {NegBig,PBO}, would be translated as follows.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
if the INPUT is NegBig (Negative Big), then the OUTPUT should be PBO \
(Positive Big). \
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In general, there can be a rule corresponding to each input membership \
function, but there should not be more than one rule for any one input \
condition.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Building the Model", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To create the fuzzy relation which will serve as our fuzzy model, we call the \
BuildModel function with a set of rules. The BuildModel function creates a \
fuzzy relation which can serve as a system model. This function works by \
applying the SetsToRelation function to each of the rule pairs and performing \
a union with the resulting fuzzy relations to form one universal relation \
describing the set of rules. Let us create a fuzzy model to represent our \
system. We can view the fuzzy model we created with the FuzzySurfacePlot \
function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["FuzzyModel = BuildModel[TheRules];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzySurfacePlot[FuzzyModel];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .70801 
MathPictureStart
%% Graphics3D
/Times-Bold findfont 10  scalefont  setfont
% Scaling calculations
0.0260223 1.04089 -0.0958739 1.04089 [
[(0)] .06597 .20303 -0.14121 1 Msboxa
[(2)] .18668 .17018 -0.10677 1 Msboxa
[(4)] .31589 .13502 -0.06914 1 Msboxa
[(6)] .45455 .09731 -0.02788 1 Msboxa
[(8)] .60371 .05676 .01758 1 Msboxa
[(10)] .76464 .01304 .06791 1 Msboxa
[(V )] .38716 .05152 -0.049 1 Msboxa
[(0)] .77808 .02262 -1 .27075 Msboxa
[(5)] .83729 .13681 -1 .24065 Msboxa
[(10)] .88584 .23047 -1 .21657 Msboxa
[(15)] .92637 .30866 -1 .19688 Msboxa
[(20)] .96071 .37494 -1 .18047 Msboxa
[( W)] .94942 .2167 -1 .21657 Msboxa
[(0)] .05159 .21932 1 -0.27075 Msboxa
[(0.25)] .04255 .28277 1 -0.25347 Msboxa
[(0.5)] .03317 .34863 1 -0.23545 Msboxa
[(0.75)] .02342 .41704 1 -0.21663 Msboxa
[(1)] .0133 .48815 1 -0.19696 Msboxa
[(Grade    )] -0.03018 .36368 1 -0.23542 Msboxa
[ 0 0 0 0 ]
[ 1 .70801 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.1853 .18312 m
.18461 .18959 L
s
P
[(2)] .18668 .17018 -0.10677 1 Mshowa
p
.002 w
.31499 .148 m
.31455 .15449 L
s
P
[(4)] .31589 .13502 -0.06914 1 Mshowa
p
.002 w
.45418 .11032 m
.454 .11682 L
s
P
[(6)] .45455 .09731 -0.02788 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(8)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(10)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
P
p
.002 w
.76552 .02602 m
.75925 .02772 L
s
P
[(0)] .77808 .02262 -1 .27075 Mshowa
p
.002 w
.82464 .13986 m
.81831 .14138 L
s
P
[(5)] .83729 .13681 -1 .24065 Mshowa
p
.002 w
.87312 .23322 m
.86676 .2346 L
s
P
[(10)] .88584 .23047 -1 .21657 Mshowa
p
.002 w
.9136 .31118 m
.90722 .31243 L
s
P
[(15)] .92637 .30866 -1 .19688 Mshowa
p
.002 w
.94791 .37725 m
.94151 .37841 L
s
P
[(20)] .96071 .37494 -1 .18047 Mshowa
p
.001 w
.77836 .05074 m
.77459 .05174 L
s
P
p
.001 w
.79066 .07443 m
.78688 .0754 L
s
P
p
.001 w
.80245 .09714 m
.79867 .09809 L
s
P
p
.001 w
.81377 .11893 m
.80998 .11986 L
s
P
p
.001 w
.83509 .15998 m
.83129 .16087 L
s
P
p
.001 w
.84514 .17933 m
.84133 .18021 L
s
P
p
.001 w
.85481 .19797 m
.851 .19883 L
s
P
p
.001 w
.86413 .21592 m
.86032 .21676 L
s
P
p
.001 w
.88179 .24991 m
.87797 .25073 L
s
P
p
.001 w
.89015 .26603 m
.88633 .26682 L
s
P
p
.001 w
.89824 .28159 m
.89441 .28237 L
s
P
p
.001 w
.90605 .29663 m
.90222 .2974 L
s
P
p
.001 w
.92091 .32525 m
.91708 .32599 L
s
P
p
.001 w
.92798 .33887 m
.92415 .3396 L
s
P
p
.001 w
.93483 .35207 m
.931 .35278 L
s
P
p
.001 w
.94147 .36485 m
.93763 .36556 L
s
P
[( W)] .94942 .2167 -1 .21657 Mshowa
P
p
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
P
p
.002 w
.06415 .21592 m
.07043 .21422 L
s
P
[(0)] .05159 .21932 1 -0.27075 Mshowa
p
.002 w
.05516 .27958 m
.06147 .27798 L
s
P
[(0.25)] .04255 .28277 1 -0.25347 Mshowa
p
.002 w
.04583 .34565 m
.05216 .34416 L
s
P
[(0.5)] .03317 .34863 1 -0.23545 Mshowa
p
.002 w
.03614 .41429 m
.0425 .41291 L
s
P
[(0.75)] .02342 .41704 1 -0.21663 Mshowa
p
.002 w
.02606 .48563 m
.03245 .48437 L
s
P
[(1)] .0133 .48815 1 -0.19696 Mshowa
p
.001 w
.06238 .22846 m
.06615 .22745 L
s
P
p
.001 w
.06059 .2411 m
.06437 .2401 L
s
P
p
.001 w
.0588 .25383 m
.06257 .25285 L
s
P
p
.001 w
.05699 .26665 m
.06077 .26568 L
s
P
p
.001 w
.05332 .29259 m
.05711 .29165 L
s
P
p
.001 w
.05147 .30571 m
.05526 .30477 L
s
P
p
.001 w
.0496 .31892 m
.0534 .318 L
s
P
p
.001 w
.04772 .33224 m
.05152 .33133 L
s
P
p
.001 w
.04392 .35917 m
.04772 .35829 L
s
P
p
.001 w
.042 .37279 m
.0458 .37192 L
s
P
p
.001 w
.04006 .38652 m
.04387 .38566 L
s
P
p
.001 w
.03811 .40035 m
.04192 .39951 L
s
P
p
.001 w
.03415 .42833 m
.03797 .42752 L
s
P
p
.001 w
.03216 .44249 m
.03598 .44169 L
s
P
p
.001 w
.03014 .45676 m
.03396 .45597 L
s
P
p
.001 w
.02811 .47114 m
.03194 .47037 L
s
P
[(Grade    )] -0.03018 .36368 1 -0.23542 Mshowa
P
0 0 m
1 0 L
1 .70801 L
0 .70801 L
closepath
clip
newpath
p
.002 w
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
.41257 .47386 m
.06415 .21592 L
s
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
.41257 .47386 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.40498 .68199 L
s
.40498 .68199 m
.41257 .47386 L
s
p
.4 g
.06415 .21592 m
.41257 .47386 L
s
P
p
.4 g
.1853 .18312 m
.50905 .45645 L
s
P
p
.4 g
.31499 .148 m
.61042 .43816 L
s
P
p
.4 g
.45418 .11032 m
.71706 .41891 L
s
P
p
.4 g
.60394 .06977 m
.8294 .39864 L
s
P
p
.4 g
.76552 .02602 m
.94791 .37725 L
s
P
p
.4 g
.06415 .21592 m
.76552 .02602 L
s
P
p
.4 g
.17318 .29663 m
.82464 .13986 L
s
P
p
.4 g
.26533 .36485 m
.87312 .23322 L
s
P
p
.4 g
.34424 .42327 m
.9136 .31118 L
s
P
p
.4 g
.41257 .47386 m
.94791 .37725 L
s
P
P
p
.002 w
.54775 .44087 m .5591 .44781 L .52539 .45389 L p
.504 .839 .998 r
F P
1 0 0 r
s
P
p
.002 w
.5591 .44781 m .54775 .44087 L .59966 .42759 L p
.563 .865 .996 r
F P
1 0 0 r
s
P
p
.002 w
.58858 .41671 m .59966 .42759 L .54775 .44087 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.54775 .44087 m .53601 .44849 L .57119 .42722 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.57119 .42722 m .58858 .41671 L p
.54775 .44087 L 0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.52539 .45389 m .50904 .45684 L p
.54775 .44087 L .504 .839 .998 r
F P
1 0 0 r
s
P
p
.002 w
.50904 .45684 m .49709 .45012 L .54775 .44087 L p
.504 .839 .998 r
F P
1 0 0 r
s
P
p
.002 w
.49709 .45012 m .50904 .45684 L .45782 .56739 L p
.939 .851 .729 r
F P
1 0 0 r
s
P
p
.002 w
.59966 .42759 m .61042 .43816 L .5591 .44781 L p
.563 .865 .996 r
F P
1 0 0 r
s
P
p
.002 w
.45782 .56739 m .445 .55875 L .49709 .45012 L p
.939 .851 .729 r
F P
1 0 0 r
s
P
p
.002 w
.53601 .44849 m .52357 .49442 L .54925 .45185 L p
.012 0 .164 r
F P
1 0 0 r
s
P
p
.002 w
.53601 .44849 m .54775 .44087 L .52344 .44531 L p
.122 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.57718 .40551 m .58858 .41671 L .53601 .44849 L p
.012 0 .164 r
F P
1 0 0 r
s
P
p
.002 w
.54925 .45185 m .57718 .40551 L p
.53601 .44849 L .012 0 .164 r
F P
1 0 0 r
s
P
p
.002 w
.52344 .44531 m .49709 .45012 L p
.53601 .44849 L .122 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.48453 .45782 m .49709 .45012 L .445 .55875 L p
.776 .672 .749 r
F P
1 0 0 r
s
P
p
.002 w
.49709 .45012 m .48453 .45782 L .53601 .44849 L p
.122 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.445 .55875 m .45782 .56739 L .40499 .68177 L p
.737 .606 .712 r
F P
1 0 0 r
s
P
p
.002 w
.38306 .52998 m .37169 .46592 L .41923 .5122 L p
.398 .36 .699 r
F P
1 0 0 r
s
P
p
.002 w
.39316 .62606 m .38306 .52998 L .43268 .52168 L p
.593 .463 .673 r
F P
1 0 0 r
s
P
p
.002 w
.41894 .52398 m .40098 .52698 L p
.41126 .51866 L .398 .36 .699 r
F P
1 0 0 r
s
P
p
.002 w
.40098 .52698 m .38306 .52998 L p
.39889 .5222 L .398 .36 .699 r
F P
1 0 0 r
s
P
p
.39889 .5222 m .41923 .5122 L .40098 .52698 L .398 .36 .699 r
F
P
p
.41126 .51866 m .41923 .5122 L .41894 .52398 L .398 .36 .699 r
F
P
p
.002 w
.40429 .53131 m .41923 .5122 L .37169 .46592 L p
0 0 .335 r
F P
1 0 0 r
s
P
p
.002 w
.39135 .50487 m .40429 .53131 L p
.39301 .50868 L 0 0 .335 r
F P
1 0 0 r
s
P
p
.37169 .46592 m .39135 .50487 L .39301 .50868 L 0 0 .335 r
F
P
p
.002 w
.38991 .52161 m .40429 .53131 L .39135 .50487 L p
.87 .441 .026 r
F P
1 0 0 r
s
P
p
.002 w
.37169 .46592 m .35848 .43773 L .39135 .50487 L p
0 0 .335 r
F P
1 0 0 r
s
P
p
.002 w
.39135 .50487 m .35848 .43773 L p
.38093 .49766 L .87 .441 .026 r
F P
1 0 0 r
s
P
p
.38093 .49766 m .38991 .52161 L .39135 .50487 L .87 .441 .026 r
F
P
p
.002 w
.41923 .5122 m .43268 .52168 L .41894 .52398 L p
.398 .36 .699 r
F P
1 0 0 r
s
P
p
.002 w
.65292 .41781 m .66306 .42866 L .61042 .43816 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.61042 .43816 m .59966 .42759 L .65292 .41781 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.40499 .68177 m .39316 .62606 L .445 .55875 L p
.737 .606 .712 r
F P
1 0 0 r
s
P
p
.002 w
.445 .55875 m .43268 .52168 L .48453 .45782 L p
.776 .672 .749 r
F P
1 0 0 r
s
P
p
.002 w
.43268 .52168 m .445 .55875 L .39316 .62606 L p
.593 .463 .673 r
F P
1 0 0 r
s
P
p
.002 w
.35848 .43773 m .34421 .42367 L .38991 .52161 L p
.87 .441 .026 r
F P
1 0 0 r
s
P
p
.002 w
.52357 .49442 m .53601 .44849 L .48453 .45782 L p
.494 .175 .356 r
F P
1 0 0 r
s
P
p
.002 w
.48453 .45782 m .47072 .50343 L .52357 .49442 L p
.494 .175 .356 r
F P
1 0 0 r
s
P
p
.002 w
.47072 .50343 m .48453 .45782 L .43268 .52168 L p
.535 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.43268 .52168 m .41923 .5122 L .47072 .50343 L p
.535 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.70758 .40778 m .71706 .41891 L .66306 .42866 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.66306 .42866 m .65292 .41781 L .70758 .40778 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.64248 .40665 m .65292 .41781 L .59966 .42759 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.59966 .42759 m .58858 .41671 L .64248 .40665 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.37508 .51162 m .38991 .52161 L .34421 .42367 L p
.886 .458 .083 r
F P
1 0 0 r
s
P
p
.002 w
.34421 .42367 m .32937 .41227 L .37508 .51162 L p
.886 .458 .083 r
F P
1 0 0 r
s
P
p
.002 w
.45523 .58572 m .47072 .50343 L .41923 .5122 L p
.742 .343 .296 r
F P
1 0 0 r
s
P
p
.002 w
.41923 .5122 m .40429 .53131 L .45523 .58572 L p
.742 .343 .296 r
F P
1 0 0 r
s
P
p
.002 w
.76371 .39748 m .77249 .40891 L .71706 .41891 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71706 .41891 m .70758 .40778 L .76371 .39748 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.69782 .39632 m .70758 .40778 L .65292 .41781 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.65292 .41781 m .64248 .40665 L .69782 .39632 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.63173 .39515 m .64248 .40665 L .58858 .41671 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.58858 .41671 m .57718 .40551 L .63173 .39515 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.36131 .47136 m .37508 .51162 L .32937 .41227 L p
.789 .304 0 r
F P
1 0 0 r
s
P
p
.002 w
.32937 .41227 m .31407 .40094 L .36131 .47136 L p
.789 .304 0 r
F P
1 0 0 r
s
P
p
.002 w
.51064 .51364 m .52357 .49442 L .47072 .50343 L p
.341 .094 .387 r
F P
1 0 0 r
s
P
p
.002 w
.47072 .50343 m .45523 .58572 L .51064 .51364 L p
.341 .094 .387 r
F P
1 0 0 r
s
P
p
.002 w
.82136 .3869 m .8294 .39864 L .77249 .40891 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.77249 .40891 m .76371 .39748 L .82136 .3869 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.75466 .38571 m .76371 .39748 L .70758 .40778 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.70758 .40778 m .69782 .39632 L .75466 .38571 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.68776 .38451 m .69782 .39632 L .64248 .40665 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.64248 .40665 m .63173 .39515 L .68776 .38451 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.62065 .38331 m .63173 .39515 L .57718 .40551 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.57718 .40551 m .56544 .39398 L .62065 .38331 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.56544 .39398 m .57718 .40551 L .52357 .49442 L p
.831 .896 .478 r
F P
1 0 0 r
s
P
p
.002 w
.43972 .62888 m .45523 .58572 L .40429 .53131 L p
.887 .459 .09 r
F P
1 0 0 r
s
P
p
.002 w
.40429 .53131 m .38991 .52161 L .43972 .62888 L p
.887 .459 .09 r
F P
1 0 0 r
s
P
p
.002 w
.34893 .40155 m .36131 .47136 L .31407 .40094 L p
.131 .573 .924 r
F P
1 0 0 r
s
P
p
.002 w
.31407 .40094 m .29831 .38927 L .34893 .40155 L p
.131 .573 .924 r
F P
1 0 0 r
s
P
p
.002 w
.52357 .49442 m .51064 .51364 L .56544 .39398 L p
.831 .896 .478 r
F P
1 0 0 r
s
P
p
.002 w
.88059 .37603 m .88786 .38809 L .8294 .39864 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.8294 .39864 m .82136 .3869 L .88059 .37603 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.81306 .3748 m .82136 .3869 L .76371 .39748 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76371 .39748 m .75466 .38571 L .81306 .3748 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.74533 .37357 m .75466 .38571 L .69782 .39632 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.69782 .39632 m .68776 .38451 L .74533 .37357 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67739 .37234 m .68776 .38451 L .63173 .39515 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.63173 .39515 m .62065 .38331 L .67739 .37234 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.60925 .37152 m .62065 .38331 L .56544 .39398 L p
.559 .813 .993 r
F P
1 0 0 r
s
P
p
.002 w
.56544 .39398 m .55335 .38252 L .60925 .37152 L p
.559 .813 .993 r
F P
1 0 0 r
s
P
p
.002 w
.55335 .38252 m .56544 .39398 L .51064 .51364 L p
.953 .867 .716 r
F P
1 0 0 r
s
P
p
.002 w
.4267 .56712 m .43972 .62888 L .38991 .52161 L p
.662 .135 0 r
F P
1 0 0 r
s
P
p
.002 w
.38991 .52161 m .37508 .51162 L .4267 .56712 L p
.662 .135 0 r
F P
1 0 0 r
s
P
p
.002 w
.33429 .37015 m .34893 .40155 L .29831 .38927 L p
.508 .786 .995 r
F P
1 0 0 r
s
P
p
.002 w
.29831 .38927 m .28207 .37725 L .33429 .37015 L p
.508 .786 .995 r
F P
1 0 0 r
s
P
p
.002 w
.94147 .36485 m .94791 .37725 L .88786 .38809 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.88786 .38809 m .88059 .37603 L .94147 .36485 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.8731 .36359 m .88059 .37603 L .82136 .3869 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.82136 .3869 m .81306 .3748 L .8731 .36359 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.80451 .36233 m .81306 .3748 L .75466 .38571 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.75466 .38571 m .74533 .37357 L .80451 .36233 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.73571 .36106 m .74533 .37357 L .68776 .38451 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.68776 .38451 m .67739 .37234 L .73571 .36106 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.6667 .35979 m .67739 .37234 L .62065 .38331 L p
.564 .816 .992 r
F P
1 0 0 r
s
P
p
.002 w
.62065 .38331 m .60925 .37152 L .6667 .35979 L p
.564 .816 .992 r
F P
1 0 0 r
s
P
p
.002 w
.51064 .51364 m .4975 .5034 L .55335 .38252 L p
.953 .867 .716 r
F P
1 0 0 r
s
P
p
.002 w
.57158 .37893 m .55335 .38252 L p
.59753 .36258 L .513 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.55335 .38252 m .54087 .37388 L .59753 .36258 L p
.513 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.58559 .36934 m .59753 .36258 L .57032 .36801 L p
.03 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.57032 .36801 m .54087 .37388 L p
.58559 .36934 L .03 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.59753 .36258 m .60925 .37152 L .57158 .37893 L p
.513 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.58559 .36934 m .57343 .41775 L .60174 .37076 L p
0 0 .122 r
F P
1 0 0 r
s
P
p
.002 w
.59753 .36258 m .58559 .36934 L .62486 .34535 L p
.389 .811 .626 r
F P
1 0 0 r
s
P
p
.002 w
.62486 .34535 m .64429 .33348 L p
.59753 .36258 L .389 .811 .626 r
F P
1 0 0 r
s
P
p
.002 w
.60925 .37152 m .59753 .36258 L .65567 .34684 L p
.567 .864 .996 r
F P
1 0 0 r
s
P
p
.002 w
.64429 .33348 m .65567 .34684 L .59753 .36258 L p
.389 .811 .626 r
F P
1 0 0 r
s
P
p
.002 w
.63253 .31968 m .64429 .33348 L .58559 .36934 L p
0 0 .122 r
F P
1 0 0 r
s
P
p
.002 w
.60174 .37076 m .63253 .31968 L p
.58559 .36934 L 0 0 .122 r
F P
1 0 0 r
s
P
p
.002 w
.54087 .37388 m .55335 .38252 L .4975 .5034 L p
.951 .869 .722 r
F P
1 0 0 r
s
P
p
.002 w
.4975 .5034 m .51064 .51364 L .45523 .58572 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.41519 .46148 m .4267 .56712 L .37508 .51162 L p
.603 .579 .8 r
F P
1 0 0 r
s
P
p
.002 w
.37508 .51162 m .36131 .47136 L .41519 .46148 L p
.603 .579 .8 r
F P
1 0 0 r
s
P
p
.002 w
.45523 .58572 m .43972 .62888 L .4975 .5034 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.31835 .35379 m .33429 .37015 L .28207 .37725 L p
.558 .807 .991 r
F P
1 0 0 r
s
P
p
.002 w
.28207 .37725 m .26533 .36485 L .31835 .35379 L p
.558 .807 .991 r
F P
1 0 0 r
s
P
p
.002 w
.93483 .35207 m .94147 .36485 L .88059 .37603 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.88059 .37603 m .8731 .36359 L .93483 .35207 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86537 .35077 m .8731 .36359 L .81306 .3748 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.81306 .3748 m .80451 .36233 L .86537 .35077 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.79569 .34946 m .80451 .36233 L .74533 .37357 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.74533 .37357 m .73571 .36106 L .79569 .34946 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.36131 .47136 m .34893 .40155 L .40259 .3907 L p
.591 .494 .713 r
F P
1 0 0 r
s
P
p
.002 w
.3883 .35874 m .40259 .3907 L .34893 .40155 L p
.608 .634 .851 r
F P
1 0 0 r
s
P
p
.002 w
.34893 .40155 m .33429 .37015 L .3883 .35874 L p
.608 .634 .851 r
F P
1 0 0 r
s
P
p
.002 w
.40259 .3907 m .41519 .46148 L .36131 .47136 L p
.591 .494 .713 r
F P
1 0 0 r
s
P
p
.002 w
.72579 .34815 m .73571 .36106 L .67739 .37234 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67739 .37234 m .6667 .35979 L .72579 .34815 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.65567 .34684 m .6667 .35979 L .60925 .37152 L p
.567 .864 .996 r
F P
1 0 0 r
s
P
p
.002 w
.4975 .5034 m .48394 .49285 L .54087 .37388 L p
.951 .869 .722 r
F P
1 0 0 r
s
P
p
.002 w
.5279 .38079 m .54087 .37388 L .48394 .49285 L p
.782 .681 .752 r
F P
1 0 0 r
s
P
p
.002 w
.54087 .37388 m .5279 .38079 L .58559 .36934 L p
.03 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.48394 .49285 m .4975 .5034 L .43972 .62888 L p
.74 .609 .712 r
F P
1 0 0 r
s
P
p
.002 w
.37293 .34198 m .3883 .35874 L .33429 .37015 L p
.587 .772 .968 r
F P
1 0 0 r
s
P
p
.002 w
.33429 .37015 m .31835 .35379 L .37293 .34198 L p
.587 .772 .968 r
F P
1 0 0 r
s
P
p
.002 w
.3017 .34021 m .31835 .35379 L .26533 .36485 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.26533 .36485 m .24806 .35207 L .3017 .34021 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.92798 .33887 m .93483 .35207 L .8731 .36359 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.8731 .36359 m .86537 .35077 L .92798 .33887 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.8574 .33753 m .86537 .35077 L .80451 .36233 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.80451 .36233 m .79569 .34946 L .8574 .33753 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.41519 .46148 m .40259 .3907 L .45628 .43967 L p
.376 .343 .695 r
F P
1 0 0 r
s
P
p
.002 w
.4267 .56712 m .41519 .46148 L .47059 .45131 L p
.581 .451 .668 r
F P
1 0 0 r
s
P
p
.002 w
.45524 .45413 m .43518 .45781 L p
.44705 .44761 L .376 .343 .695 r
F P
1 0 0 r
s
P
p
.002 w
.43518 .45781 m .41519 .46148 L p
.43315 .45195 L .376 .343 .695 r
F P
1 0 0 r
s
P
p
.43315 .45195 m .45628 .43967 L .43518 .45781 L .376 .343 .695 r
F
P
p
.44705 .44761 m .45628 .43967 L .45524 .45413 L .376 .343 .695 r
F
P
p
.002 w
.4406 .45909 m .45628 .43967 L .40259 .3907 L p
0 0 .398 r
F P
1 0 0 r
s
P
p
.002 w
.42578 .43065 m .4406 .45909 L p
.4274 .43534 L 0 0 .398 r
F P
1 0 0 r
s
P
p
.40259 .3907 m .42578 .43065 L .4274 .43534 L 0 0 .398 r
F
P
p
.002 w
.42519 .44709 m .4406 .45909 L .42578 .43065 L p
.822 .383 0 r
F P
1 0 0 r
s
P
p
.002 w
.40259 .3907 m .3883 .35874 L .42578 .43065 L p
0 0 .398 r
F P
1 0 0 r
s
P
p
.002 w
.42578 .43065 m .3883 .35874 L p
.41461 .42175 L .822 .383 0 r
F P
1 0 0 r
s
P
p
.41461 .42175 m .42519 .44709 L .42578 .43065 L .822 .383 0 r
F
P
p
.002 w
.45628 .43967 m .47059 .45131 L .45524 .45413 L p
.376 .343 .695 r
F P
1 0 0 r
s
P
p
.002 w
.78659 .33618 m .79569 .34946 L .73571 .36106 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.73571 .36106 m .72579 .34815 L .78659 .33618 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71555 .33483 m .72579 .34815 L .6667 .35979 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.6667 .35979 m .65567 .34684 L .71555 .33483 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.43972 .62888 m .4267 .56712 L .48394 .49285 L p
.74 .609 .712 r
F P
1 0 0 r
s
P
p
.002 w
.48394 .49285 m .47059 .45131 L .5279 .38079 L p
.782 .681 .752 r
F P
1 0 0 r
s
P
p
.002 w
.47059 .45131 m .48394 .49285 L .4267 .56712 L p
.581 .451 .668 r
F P
1 0 0 r
s
P
p
.002 w
.3883 .35874 m .37293 .34198 L .42519 .44709 L p
.822 .383 0 r
F P
1 0 0 r
s
P
p
.002 w
.35692 .32801 m .37293 .34198 L .31835 .35379 L p
.567 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.31835 .35379 m .3017 .34021 L .35692 .32801 L p
.567 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.28449 .32663 m .3017 .34021 L .24806 .35207 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.24806 .35207 m .23023 .33887 L .28449 .32663 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.57343 .41775 m .58559 .36934 L .5279 .38079 L p
.457 .118 .302 r
F P
1 0 0 r
s
P
p
.002 w
.5279 .38079 m .514 .42887 L .57343 .41775 L p
.457 .118 .302 r
F P
1 0 0 r
s
P
p
.002 w
.514 .42887 m .5279 .38079 L .47059 .45131 L p
.535 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.92091 .32525 m .92798 .33887 L .86537 .35077 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86537 .35077 m .8574 .33753 L .92091 .32525 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.47059 .45131 m .45628 .43967 L .514 .42887 L p
.535 .814 .997 r
F P
1 0 0 r
s
P
p
.002 w
.84916 .32386 m .8574 .33753 L .79569 .34946 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.79569 .34946 m .78659 .33618 L .84916 .32386 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.77719 .32247 m .78659 .33618 L .72579 .34815 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.72579 .34815 m .71555 .33483 L .77719 .32247 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.70498 .32108 m .71555 .33483 L .65567 .34684 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.65567 .34684 m .64429 .33348 L .70498 .32108 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.40926 .43468 m .42519 .44709 L .37293 .34198 L p
.847 .404 0 r
F P
1 0 0 r
s
P
p
.002 w
.37293 .34198 m .35692 .32801 L .40926 .43468 L p
.847 .404 0 r
F P
1 0 0 r
s
P
p
.002 w
.34036 .31403 m .35692 .32801 L .3017 .34021 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.3017 .34021 m .28449 .32663 L .34036 .31403 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.26671 .31261 m .28449 .32663 L .23023 .33887 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.23023 .33887 m .21183 .32525 L .26671 .31261 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.9136 .31118 m .92091 .32525 L .8574 .33753 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.8574 .33753 m .84916 .32386 L .9136 .31118 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.49866 .51733 m .514 .42887 L .45628 .43967 L p
.73 .295 .219 r
F P
1 0 0 r
s
P
p
.002 w
.45628 .43967 m .4406 .45909 L .49866 .51733 L p
.73 .295 .219 r
F P
1 0 0 r
s
P
p
.002 w
.84066 .30974 m .84916 .32386 L .78659 .33618 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.78659 .33618 m .77719 .32247 L .84066 .30974 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76748 .30831 m .77719 .32247 L .71555 .33483 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71555 .33483 m .70498 .32108 L .76748 .30831 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.69405 .30686 m .70498 .32108 L .64429 .33348 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.64429 .33348 m .63253 .31968 L .69405 .30686 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.39416 .38912 m .40926 .43468 L .35692 .32801 L p
.724 .231 0 r
F P
1 0 0 r
s
P
p
.002 w
.35692 .32801 m .34036 .31403 L .39416 .38912 L p
.724 .231 0 r
F P
1 0 0 r
s
P
p
.002 w
.32324 .29958 m .34036 .31403 L .28449 .32663 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.28449 .32663 m .26671 .31261 L .32324 .29958 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.24834 .29811 m .26671 .31261 L .21183 .32525 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.21183 .32525 m .19282 .31118 L .24834 .29811 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.5603 .4372 m .57343 .41775 L .514 .42887 L p
.297 .041 .347 r
F P
1 0 0 r
s
P
p
.002 w
.514 .42887 m .49866 .51733 L .5603 .4372 L p
.297 .041 .347 r
F P
1 0 0 r
s
P
p
.002 w
.90605 .29663 m .9136 .31118 L .84916 .32386 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.84916 .32386 m .84066 .30974 L .90605 .29663 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.83187 .29515 m .84066 .30974 L .77719 .32247 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.77719 .32247 m .76748 .30831 L .83187 .29515 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.75744 .29366 m .76748 .30831 L .70498 .32108 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.70498 .32108 m .69405 .30686 L .75744 .29366 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.68276 .29217 m .69405 .30686 L .63253 .31968 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.63253 .31968 m .62038 .30542 L .68276 .29217 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.62038 .30542 m .63253 .31968 L .57343 .41775 L p
.806 .879 .447 r
F P
1 0 0 r
s
P
p
.002 w
.48275 .56337 m .49866 .51733 L .4406 .45909 L p
.85 .407 0 r
F P
1 0 0 r
s
P
p
.002 w
.4406 .45909 m .42519 .44709 L .48275 .56337 L p
.85 .407 0 r
F P
1 0 0 r
s
P
p
.002 w
.38031 .31126 m .39416 .38912 L .34036 .31403 L p
.174 .591 .939 r
F P
1 0 0 r
s
P
p
.002 w
.34036 .31403 m .32324 .29958 L .38031 .31126 L p
.174 .591 .939 r
F P
1 0 0 r
s
P
p
.002 w
.30555 .28464 m .32324 .29958 L .26671 .31261 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.26671 .31261 m .24834 .29811 L .30555 .28464 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.57343 .41775 m .5603 .4372 L .62038 .30542 L p
.806 .879 .447 r
F P
1 0 0 r
s
P
p
.002 w
.22933 .28312 m .24834 .29811 L .19282 .31118 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.19282 .31118 m .17318 .29663 L .22933 .28312 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.89824 .28159 m .90605 .29663 L .84066 .30974 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.84066 .30974 m .83187 .29515 L .89824 .28159 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.82278 .28006 m .83187 .29515 L .76748 .30831 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76748 .30831 m .75744 .29366 L .82278 .28006 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.74706 .27852 m .75744 .29366 L .69405 .30686 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.69405 .30686 m .68276 .29217 L .74706 .27852 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67108 .27698 m .68276 .29217 L .62038 .30542 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.62038 .30542 m .60783 .29068 L .67108 .27698 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.60783 .29068 m .62038 .30542 L .5603 .4372 L p
.964 .885 .703 r
F P
1 0 0 r
s
P
p
.002 w
.46825 .4941 m .48275 .56337 L .42519 .44709 L p
.58 .054 0 r
F P
1 0 0 r
s
P
p
.002 w
.42519 .44709 m .40926 .43468 L .46825 .4941 L p
.58 .054 0 r
F P
1 0 0 r
s
P
p
.002 w
.36431 .27515 m .38031 .31126 L .32324 .29958 L p
.511 .785 .995 r
F P
1 0 0 r
s
P
p
.002 w
.32324 .29958 m .30555 .28464 L .36431 .27515 L p
.511 .785 .995 r
F P
1 0 0 r
s
P
p
.002 w
.28724 .26918 m .30555 .28464 L .24834 .29811 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.24834 .29811 m .22933 .28312 L .28724 .26918 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.20967 .26761 m .22933 .28312 L .17318 .29663 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.17318 .29663 m .15286 .28159 L .20967 .26761 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.89015 .26603 m .89824 .28159 L .83187 .29515 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.83187 .29515 m .82278 .28006 L .89015 .26603 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.81337 .26444 m .82278 .28006 L .75744 .29366 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.75744 .29366 m .74706 .27852 L .81337 .26444 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.73631 .26285 m .74706 .27852 L .68276 .29217 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.68276 .29217 m .67108 .27698 L .73631 .26285 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.5603 .4372 m .54647 .42445 L .60783 .29068 L p
.964 .885 .703 r
F P
1 0 0 r
s
P
p
.002 w
.65899 .26125 m .67108 .27698 L .60783 .29068 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.60783 .29068 m .59484 .27543 L .65899 .26125 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.59484 .27543 m .60783 .29068 L .54647 .42445 L p
.964 .885 .703 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .42445 m .5603 .4372 L .49866 .51733 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.45492 .37678 m .46825 .4941 L .40926 .43468 L p
.593 .578 .806 r
F P
1 0 0 r
s
P
p
.002 w
.40926 .43468 m .39416 .38912 L .45492 .37678 L p
.593 .578 .806 r
F P
1 0 0 r
s
P
p
.002 w
.49866 .51733 m .48275 .56337 L .54647 .42445 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.34695 .25528 m .36431 .27515 L .30555 .28464 L p
.558 .807 .991 r
F P
1 0 0 r
s
P
p
.002 w
.30555 .28464 m .28724 .26918 L .34695 .25528 L p
.558 .807 .991 r
F P
1 0 0 r
s
P
p
.002 w
.26829 .25318 m .28724 .26918 L .22933 .28312 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.22933 .28312 m .20967 .26761 L .26829 .25318 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.18932 .25155 m .20967 .26761 L .15286 .28159 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.15286 .28159 m .13184 .26603 L .18932 .25155 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.88179 .24991 m .89015 .26603 L .82278 .28006 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.82278 .28006 m .81337 .26444 L .88179 .24991 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.39416 .38912 m .38031 .31126 L .4408 .29771 L p
.578 .485 .713 r
F P
1 0 0 r
s
P
p
.002 w
.42523 .26087 m .4408 .29771 L .38031 .31126 L p
.6 .637 .859 r
F P
1 0 0 r
s
P
p
.002 w
.38031 .31126 m .36431 .27515 L .42523 .26087 L p
.6 .637 .859 r
F P
1 0 0 r
s
P
p
.002 w
.4408 .29771 m .45492 .37678 L .39416 .38912 L p
.578 .485 .713 r
F P
1 0 0 r
s
P
p
.002 w
.80363 .24827 m .81337 .26444 L .74706 .27852 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.74706 .27852 m .73631 .26285 L .80363 .24827 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.72519 .24662 m .73631 .26285 L .67108 .27698 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67108 .27698 m .65899 .26125 L .72519 .24662 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.54647 .42445 m .53216 .41125 L .59484 .27543 L p
.964 .885 .703 r
F P
1 0 0 r
s
P
p
.002 w
.64647 .24497 m .65899 .26125 L .59484 .27543 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.59484 .27543 m .58139 .25965 L .64647 .24497 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.58139 .25965 m .59484 .27543 L .53216 .41125 L p
.834 .715 .732 r
F P
1 0 0 r
s
P
p
.002 w
.53216 .41125 m .54647 .42445 L .48275 .56337 L p
.744 .613 .713 r
F P
1 0 0 r
s
P
p
.002 w
.40861 .24044 m .42523 .26087 L .36431 .27515 L p
.583 .773 .97 r
F P
1 0 0 r
s
P
p
.002 w
.36431 .27515 m .34695 .25528 L .40861 .24044 L p
.583 .773 .97 r
F P
1 0 0 r
s
P
p
.002 w
.32879 .23829 m .34695 .25528 L .28724 .26918 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.28724 .26918 m .26829 .25318 L .32879 .23829 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.24865 .23661 m .26829 .25318 L .20967 .26761 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.20967 .26761 m .18932 .25155 L .24865 .23661 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.16823 .23492 m .18932 .25155 L .13184 .26603 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.13184 .26603 m .11007 .24991 L .16823 .23492 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.45492 .37678 m .4408 .29771 L .50321 .28374 L p
.578 .485 .713 r
F P
1 0 0 r
s
P
p
.002 w
.48812 .24614 m .50321 .28374 L .4408 .29771 L p
.6 .637 .859 r
F P
1 0 0 r
s
P
p
.002 w
.4408 .29771 m .42523 .26087 L .48812 .24614 L p
.6 .637 .859 r
F P
1 0 0 r
s
P
p
.002 w
.46825 .4941 m .45492 .37678 L .5176 .36405 L p
.566 .436 .663 r
F P
1 0 0 r
s
P
p
.002 w
.50321 .28374 m .5176 .36405 L .45492 .37678 L p
.578 .485 .713 r
F P
1 0 0 r
s
P
p
.002 w
.87312 .23322 m .88179 .24991 L .81337 .26444 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.81337 .26444 m .80363 .24827 L .87312 .23322 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.79353 .23152 m .80363 .24827 L .73631 .26285 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.73631 .26285 m .72519 .24662 L .79353 .23152 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71366 .22981 m .72519 .24662 L .65899 .26125 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.65899 .26125 m .64647 .24497 L .71366 .22981 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.53216 .41125 m .5176 .36405 L .58139 .25965 L p
.834 .715 .732 r
F P
1 0 0 r
s
P
p
.002 w
.6335 .2281 m .64647 .24497 L .58139 .25965 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.58139 .25965 m .56747 .24331 L .6335 .2281 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.56747 .24331 m .58139 .25965 L .5176 .36405 L p
.642 .529 .71 r
F P
1 0 0 r
s
P
p
.002 w
.48275 .56337 m .46825 .4941 L .53216 .41125 L p
.744 .613 .713 r
F P
1 0 0 r
s
P
p
.002 w
.5176 .36405 m .53216 .41125 L .46825 .4941 L p
.566 .436 .663 r
F P
1 0 0 r
s
P
p
.002 w
.47229 .22513 m .48812 .24614 L .42523 .26087 L p
.583 .773 .97 r
F P
1 0 0 r
s
P
p
.002 w
.42523 .26087 m .40861 .24044 L .47229 .22513 L p
.583 .773 .97 r
F P
1 0 0 r
s
P
p
.002 w
.39127 .22291 m .40861 .24044 L .34695 .25528 L p
.566 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.34695 .25528 m .32879 .23829 L .39127 .22291 L p
.566 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.30994 .22117 m .32879 .23829 L .26829 .25318 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.26829 .25318 m .24865 .23661 L .30994 .22117 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.22831 .21943 m .24865 .23661 L .18932 .25155 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.18932 .25155 m .16823 .23492 L .22831 .21943 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.5176 .36405 m .50321 .28374 L .56747 .24331 L p
.642 .529 .71 r
F P
1 0 0 r
s
P
p
.002 w
.55305 .22637 m .56747 .24331 L .50321 .28374 L p
.624 .65 .856 r
F P
1 0 0 r
s
P
p
.002 w
.50321 .28374 m .48812 .24614 L .55305 .22637 L p
.624 .65 .856 r
F P
1 0 0 r
s
P
p
.002 w
.14638 .21768 m .16823 .23492 L .11007 .24991 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.11007 .24991 m .08752 .23322 L .14638 .21768 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.86413 .21592 m .87312 .23322 L .80363 .24827 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.80363 .24827 m .79353 .23152 L .86413 .21592 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.78307 .21415 m .79353 .23152 L .72519 .24662 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.72519 .24662 m .71366 .22981 L .78307 .21415 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.70171 .21238 m .71366 .22981 L .64647 .24497 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.64647 .24497 m .6335 .2281 L .70171 .21238 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.62005 .2106 m .6335 .2281 L .56747 .24331 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.56747 .24331 m .55305 .22637 L .62005 .2106 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.53809 .20882 m .55305 .22637 L .48812 .24614 L p
.587 .775 .969 r
F P
1 0 0 r
s
P
p
.002 w
.48812 .24614 m .47229 .22513 L .53809 .20882 L p
.587 .775 .969 r
F P
1 0 0 r
s
P
p
.002 w
.45583 .20702 m .47229 .22513 L .40861 .24044 L p
.566 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.40861 .24044 m .39127 .22291 L .45583 .20702 L p
.566 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.37326 .20523 m .39127 .22291 L .32879 .23829 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.32879 .23829 m .30994 .22117 L .37326 .20523 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.29038 .20342 m .30994 .22117 L .24865 .23661 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.24865 .23661 m .22831 .21943 L .29038 .20342 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.2072 .20161 m .22831 .21943 L .16823 .23492 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.16823 .23492 m .14638 .21768 L .2072 .20161 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.12371 .19979 m .14638 .21768 L .08752 .23322 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.08752 .23322 m .06415 .21592 L .12371 .19979 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.85481 .19797 m .86413 .21592 L .79353 .23152 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.79353 .23152 m .78307 .21415 L .85481 .19797 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.77222 .19613 m .78307 .21415 L .71366 .22981 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.71366 .22981 m .70171 .21238 L .77222 .19613 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.68931 .1943 m .70171 .21238 L .6335 .2281 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.6335 .2281 m .62005 .2106 L .68931 .1943 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.60611 .19294 m .62005 .2106 L .55305 .22637 L p
.559 .807 .991 r
F P
1 0 0 r
s
P
p
.002 w
.55305 .22637 m .53809 .20882 L .60611 .19294 L p
.559 .807 .991 r
F P
1 0 0 r
s
P
p
.002 w
.52257 .1906 m .53809 .20882 L .47229 .22513 L p
.566 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.47229 .22513 m .45583 .20702 L .52257 .1906 L p
.566 .805 .989 r
F P
1 0 0 r
s
P
p
.002 w
.43873 .18874 m .45583 .20702 L .39127 .22291 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.39127 .22291 m .37326 .20523 L .43873 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.35457 .18687 m .37326 .20523 L .30994 .22117 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.30994 .22117 m .29038 .20342 L .35457 .18687 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.27009 .185 m .29038 .20342 L .22831 .21943 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.22831 .21943 m .2072 .20161 L .27009 .185 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.1853 .18312 m .2072 .20161 L .14638 .21768 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.14638 .21768 m .12371 .19979 L .1853 .18312 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.84514 .17933 m .85481 .19797 L .78307 .21415 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.78307 .21415 m .77222 .19613 L .84514 .17933 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.76095 .17743 m .77222 .19613 L .70171 .21238 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.70171 .21238 m .68931 .1943 L .76095 .17743 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.67646 .17602 m .68931 .1943 L .62005 .2106 L p
.56 .813 .993 r
F P
1 0 0 r
s
P
p
.002 w
.62005 .2106 m .60611 .19294 L .67646 .17602 L p
.56 .813 .993 r
F P
1 0 0 r
s
P
p
.002 w
.59168 .17833 m .60611 .19294 L .53809 .20882 L p
.517 .785 .993 r
F P
1 0 0 r
s
P
p
.002 w
.53809 .20882 m .52257 .1906 L .59168 .17833 L p
.517 .785 .993 r
F P
1 0 0 r
s
P
p
.002 w
.50646 .17168 m .52257 .1906 L .45583 .20702 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.45583 .20702 m .43873 .18874 L .50646 .17168 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.42097 .16975 m .43873 .18874 L .37326 .20523 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.37326 .20523 m .35457 .18687 L .42097 .16975 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.33516 .16781 m .35457 .18687 L .29038 .20342 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.29038 .20342 m .27009 .185 L .33516 .16781 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.24902 .16586 m .27009 .185 L .2072 .20161 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.2072 .20161 m .1853 .18312 L .24902 .16586 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.83509 .15998 m .84514 .17933 L .77222 .19613 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.77222 .19613 m .76095 .17743 L .83509 .15998 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.74928 .15851 m .76095 .17743 L .68931 .1943 L p
.56 .813 .993 r
F P
1 0 0 r
s
P
p
.002 w
.68931 .1943 m .67646 .17602 L .74928 .15851 L p
.56 .813 .993 r
F P
1 0 0 r
s
P
p
.002 w
.66324 .1608 m .67646 .17602 L .60611 .19294 L p
.53 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.60611 .19294 m .59168 .17833 L .66324 .1608 L p
.53 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.57457 .18137 m .52257 .1906 L p
.55835 .18479 L .249 .619 .957 r
F P
1 0 0 r
s
P
p
.55835 .18479 m .57681 .18179 L .57457 .18137 L .249 .619 .957 r
F
P
p
.002 w
.52257 .1906 m .50646 .17168 L .57681 .18179 L p
.249 .619 .957 r
F P
1 0 0 r
s
P
p
.002 w
.56135 .23402 m .57681 .18179 L .50646 .17168 L p
0 0 .472 r
F P
1 0 0 r
s
P
p
.002 w
.50646 .17168 m .48971 .15203 L .56135 .23402 L p
0 0 .472 r
F P
1 0 0 r
s
P
p
.002 w
.54455 .25239 m .56135 .23402 L .52455 .19191 L p
.699 .25 0 r
F P
1 0 0 r
s
P
p
.002 w
.48971 .15203 m .50646 .17168 L .43873 .18874 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.52455 .19191 m .48971 .15203 L p
.51285 .19437 L .699 .25 0 r
F P
1 0 0 r
s
P
p
.51285 .19437 m .54455 .25239 L .52455 .19191 L .699 .25 0 r
F
P
p
.002 w
.57681 .18179 m .59168 .17833 L .57457 .18137 L p
.249 .619 .957 r
F P
1 0 0 r
s
P
p
.002 w
.43873 .18874 m .42097 .16975 L .48971 .15203 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.40252 .15002 m .42097 .16975 L .35457 .18687 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.35457 .18687 m .33516 .16781 L .40252 .15002 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.31499 .148 m .33516 .16781 L .27009 .185 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.27009 .185 m .24902 .16586 L .31499 .148 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.82464 .13986 m .83509 .15998 L .76095 .17743 L p
.565 .815 .992 r
F P
1 0 0 r
s
P
p
.002 w
.76095 .17743 m .74928 .15851 L .82464 .13986 L p
.565 .815 .992 r
F P
1 0 0 r
s
P
p
.002 w
.73735 .14265 m .74928 .15851 L .67646 .17602 L p
.53 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.67646 .17602 m .66324 .1608 L .73735 .14265 L p
.53 .839 .999 r
F P
1 0 0 r
s
P
p
.002 w
.65003 .16385 m .66324 .1608 L .59168 .17833 L p
.173 .702 .693 r
F P
1 0 0 r
s
P
p
.002 w
.59168 .17833 m .57681 .18179 L .65003 .16385 L p
.173 .702 .693 r
F P
1 0 0 r
s
P
p
.002 w
.4723 .13159 m .48971 .15203 L .42097 .16975 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.42097 .16975 m .40252 .15002 L .4723 .13159 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.38334 .1295 m .40252 .15002 L .33516 .16781 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.33516 .16781 m .31499 .148 L .38334 .1295 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.81377 .11893 m .82464 .13986 L .74928 .15851 L p
.575 .863 .996 r
F P
1 0 0 r
s
P
p
.002 w
.74928 .15851 m .73735 .14265 L .81377 .11893 L p
.575 .863 .996 r
F P
1 0 0 r
s
P
p
.002 w
.72594 .14525 m .73735 .14265 L .70169 .15138 L p
.173 .702 .693 r
F P
1 0 0 r
s
P
p
.002 w
.80245 .09714 m .81377 .11893 L .73735 .14265 L p
.481 .879 .715 r
F P
1 0 0 r
s
P
p
.002 w
.73735 .14265 m .72594 .14525 L .80245 .09714 L p
.481 .879 .715 r
F P
1 0 0 r
s
P
p
.002 w
.72594 .14525 m .71639 .19789 L .75202 .13865 L p
0 0 .027 r
F P
1 0 0 r
s
P
p
.002 w
.79066 .07443 m .80245 .09714 L .72594 .14525 L p
0 0 .027 r
F P
1 0 0 r
s
P
p
.002 w
.75202 .13865 m .79066 .07443 L p
.72594 .14525 L 0 0 .027 r
F P
1 0 0 r
s
P
p
.002 w
.70169 .15138 m .66324 .1608 L p
.72594 .14525 L .173 .702 .693 r
F P
1 0 0 r
s
P
p
.002 w
.66324 .1608 m .65003 .16385 L .72594 .14525 L p
.173 .702 .693 r
F P
1 0 0 r
s
P
p
.002 w
.48971 .15203 m .4723 .13159 L .54455 .25239 L p
.699 .25 0 r
F P
1 0 0 r
s
P
p
.002 w
.45418 .11032 m .4723 .13159 L .40252 .15002 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.40252 .15002 m .38334 .1295 L .45418 .11032 L p
.563 .809 .991 r
F P
1 0 0 r
s
P
p
.002 w
.63741 .21629 m .65003 .16385 L .57681 .18179 L p
.341 0 .142 r
F P
1 0 0 r
s
P
p
.002 w
.57681 .18179 m .56135 .23402 L .63741 .21629 L p
.341 0 .142 r
F P
1 0 0 r
s
P
p
.002 w
.52686 .23239 m .54455 .25239 L .4723 .13159 L p
.699 .25 0 r
F P
1 0 0 r
s
P
p
.002 w
.4723 .13159 m .45418 .11032 L .52686 .23239 L p
.699 .25 0 r
F P
1 0 0 r
s
P
p
.002 w
.71639 .19789 m .72594 .14525 L .65003 .16385 L p
.341 0 .142 r
F P
1 0 0 r
s
P
p
.002 w
.65003 .16385 m .63741 .21629 L .71639 .19789 L p
.341 0 .142 r
F P
1 0 0 r
s
P
p
.002 w
.62467 .31891 m .63741 .21629 L .56135 .23402 L p
.66 .135 0 r
F P
1 0 0 r
s
P
p
.002 w
.56135 .23402 m .54455 .25239 L .62467 .31891 L p
.66 .135 0 r
F P
1 0 0 r
s
P
p
.002 w
.70413 .21577 m .71639 .19789 L .63741 .21629 L p
.177 0 .237 r
F P
1 0 0 r
s
P
p
.002 w
.63741 .21629 m .62467 .31891 L .70413 .21577 L p
.177 0 .237 r
F P
1 0 0 r
s
P
p
.002 w
.77836 .05074 m .79066 .07443 L .71639 .19789 L p
.746 .835 .38 r
F P
1 0 0 r
s
P
p
.002 w
.60923 .37077 m .62467 .31891 L .54455 .25239 L p
.699 .25 0 r
F P
1 0 0 r
s
P
p
.002 w
.54455 .25239 m .52686 .23239 L .60923 .37077 L p
.699 .25 0 r
F P
1 0 0 r
s
P
p
.002 w
.71639 .19789 m .70413 .21577 L .77836 .05074 L p
.746 .835 .38 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m .77836 .05074 L .70413 .21577 L p
.977 .917 .657 r
F P
1 0 0 r
s
P
p
.002 w
.70413 .21577 m .68931 .19414 L .76552 .02602 L p
.977 .917 .657 r
F P
1 0 0 r
s
P
p
.002 w
.68931 .19414 m .70413 .21577 L .62467 .31891 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.62467 .31891 m .60923 .37077 L .68931 .19414 L p
0 0 0 r
F P
1 0 0 r
s
P
p
.002 w
.76552 .02602 m
.94791 .37725 L
s
.94791 .37725 m
.97398 .60952 L
s
.97398 .60952 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.06415 .21592 m
.02602 .48592 L
s
.02602 .48592 m
.78659 .33618 L
s
.78659 .33618 m
.76552 .02602 L
s
.76552 .02602 m
.06415 .21592 L
s
P
p
p
.002 w
.06415 .21592 m
.76552 .02602 L
s
P
p
.002 w
.06415 .21592 m
.06324 .22236 L
s
P
[(0)] .06597 .20303 -0.14121 1 Mshowa
p
.002 w
.1853 .18312 m
.18461 .18959 L
s
P
[(2)] .18668 .17018 -0.10677 1 Mshowa
p
.002 w
.31499 .148 m
.31455 .15449 L
s
P
[(4)] .31589 .13502 -0.06914 1 Mshowa
p
.002 w
.45418 .11032 m
.454 .11682 L
s
P
[(6)] .45455 .09731 -0.02788 1 Mshowa
p
.002 w
.60394 .06977 m
.60406 .07627 L
s
P
[(8)] .60371 .05676 .01758 1 Mshowa
p
.002 w
.76552 .02602 m
.76597 .03251 L
s
P
[(10)] .76464 .01304 .06791 1 Mshowa
[(V )] .38716 .05152 -0.049 1 Mshowa
P
p
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 281},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Note that the input and output fuzzy sets which the rules refer to must have \
been created prior to using the BuildModel function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Inferencing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
To perform a fuzzy inference using the model just created, we need to provide \
a fuzzy set input. The universal space of our input fuzzy set must be equal \
to the universal space of the input used to build the model. Here we create a \
fuzzy set which will serve as input to the inferencing function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
MyModelInp = FuzzyTrapezoid[3,5,5,7,
  UniversalSpace->{0,10}]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
FuzzySet[{{4, 1/2}, {5, 1}, {6, 1/2}}, UniversalSpace -> {0, 10}]








\
\>", "\<\
              1               1
FuzzySet[{{4, -}, {5, 1}, {6, -}}, UniversalSpace -> {0, 10}]
              2               2\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
Now we can use the CompositionBasedInference function to evaluate the model \
response to the input.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
CompositionBasedInference[A,B,opts] returns a fuzzy set which is the result \
of performing a MaxMin composition-based inference, where A is the input \
fuzzy set, and B is the model fuzzy relation. The output fuzzy set which can \
be defuzzified using either the CenterOfArea or MeanOfMax function.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For this example, we use the MeanOfMax defuzzification to find a crisp output \
for our inferencing operation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
MeanOfMax[
  CompositionBasedInference[MyModelInp,FuzzyModel]]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
10








\
\>", "\<\
10\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
For this example, we see that for an input fuzzy set centered around 5, we \
receive an output response of 10.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Rule-based Inference", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The RuleBasedInference function works with two input-one output systems. What \
follows is a description of what is needed to perform a RuleBasedInference \
and a demonstration of the inferencing operation.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Inputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As with the CompositionBasedInference, the first thing we need to do to \
perform a RuleBasedInference is define our input fuzzy sets. Unlike the \
CompositionBasedInference, we need to create two sets of input fuzzy sets. We \
again use the CreateFuzzySets function to define our input fuzzy sets, and we \
use the FuzzyPlot function to look at the fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FirstInput = {LE,LC,CE,RC,RI} =
  CreateFuzzySets[5,UniversalSpace->{0,100}];\
\>", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[FirstInput,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.00980392 0.00980392 0 0.618034 [
[(0)] .0098 0 0 2 Msboxa
[(20)] .20588 0 0 2 Msboxa
[(40)] .40196 0 0 2 Msboxa
[(60)] .59804 0 0 2 Msboxa
[(80)] .79412 0 0 2 Msboxa
[(100)] .9902 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0098 0 m
.0098 .00625 L
s
P
[(0)] .0098 0 0 2 Mshowa
p
.002 w
.20588 0 m
.20588 .00625 L
s
P
[(20)] .20588 0 0 2 Mshowa
p
.002 w
.40196 0 m
.40196 .00625 L
s
P
[(40)] .40196 0 0 2 Mshowa
p
.002 w
.59804 0 m
.59804 .00625 L
s
P
[(60)] .59804 0 0 2 Mshowa
p
.002 w
.79412 0 m
.79412 .00625 L
s
P
[(80)] .79412 0 0 2 Mshowa
p
.002 w
.9902 0 m
.9902 .00625 L
s
P
[(100)] .9902 0 0 2 Mshowa
p
.001 w
.04902 0 m
.04902 .00375 L
s
P
p
.001 w
.08824 0 m
.08824 .00375 L
s
P
p
.001 w
.12745 0 m
.12745 .00375 L
s
P
p
.001 w
.16667 0 m
.16667 .00375 L
s
P
p
.001 w
.2451 0 m
.2451 .00375 L
s
P
p
.001 w
.28431 0 m
.28431 .00375 L
s
P
p
.001 w
.32353 0 m
.32353 .00375 L
s
P
p
.001 w
.36275 0 m
.36275 .00375 L
s
P
p
.001 w
.44118 0 m
.44118 .00375 L
s
P
p
.001 w
.48039 0 m
.48039 .00375 L
s
P
p
.001 w
.51961 0 m
.51961 .00375 L
s
P
p
.001 w
.55882 0 m
.55882 .00375 L
s
P
p
.001 w
.63725 0 m
.63725 .00375 L
s
P
p
.001 w
.67647 0 m
.67647 .00375 L
s
P
p
.001 w
.71569 0 m
.71569 .00375 L
s
P
p
.001 w
.7549 0 m
.7549 .00375 L
s
P
p
.001 w
.83333 0 m
.83333 .00375 L
s
P
p
.001 w
.87255 0 m
.87255 .00375 L
s
P
p
.001 w
.91176 0 m
.91176 .00375 L
s
P
p
.001 w
.95098 0 m
.95098 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.11803 Mabswid
.0098 .61803 m
.01961 .59331 L
.02941 .56859 L
.03922 .54387 L
.04902 .51915 L
.05882 .49443 L
.06863 .46971 L
.07843 .44498 L
.08824 .42026 L
.09804 .39554 L
.10784 .37082 L
.11765 .3461 L
.12745 .32138 L
.13725 .29666 L
.14706 .27193 L
.15686 .24721 L
.16667 .22249 L
.17647 .19777 L
.18627 .17305 L
.19608 .14833 L
.20588 .12361 L
.21569 .09889 L
.22549 .07416 L
.23529 .04944 L
.2451 .02472 L
.2549 0 L
.26471 0 L
.27451 0 L
.28431 0 L
.29412 0 L
.30392 0 L
.31373 0 L
.32353 0 L
.33333 0 L
.34314 0 L
.35294 0 L
.36275 0 L
.37255 0 L
.38235 0 L
.39216 0 L
.40196 0 L
.41176 0 L
.42157 0 L
.43137 0 L
.44118 0 L
.45098 0 L
.46078 0 L
.47059 0 L
.48039 0 L
.4902 0 L
Mistroke
.5 0 L
.5098 0 L
.51961 0 L
.52941 0 L
.53922 0 L
.54902 0 L
.55882 0 L
.56863 0 L
.57843 0 L
.58824 0 L
.59804 0 L
.60784 0 L
.61765 0 L
.62745 0 L
.63725 0 L
.64706 0 L
.65686 0 L
.66667 0 L
.67647 0 L
.68627 0 L
.69608 0 L
.70588 0 L
.71569 0 L
.72549 0 L
.73529 0 L
.7451 0 L
.7549 0 L
.76471 0 L
.77451 0 L
.78431 0 L
.79412 0 L
.80392 0 L
.81373 0 L
.82353 0 L
.83333 0 L
.84314 0 L
.85294 0 L
.86275 0 L
.87255 0 L
.88235 0 L
.89216 0 L
.90196 0 L
.91176 0 L
.92157 0 L
.93137 0 L
.94118 0 L
.95098 0 L
.96078 0 L
.97059 0 L
.98039 0 L
Mistroke
.9902 0 L
Mfstroke
P
p
.2 0 1 r
1.11803 Mabswid
.0098 0 m
.01961 .02472 L
.02941 .04944 L
.03922 .07416 L
.04902 .09889 L
.05882 .12361 L
.06863 .14833 L
.07843 .17305 L
.08824 .19777 L
.09804 .22249 L
.10784 .24721 L
.11765 .27193 L
.12745 .29666 L
.13725 .32138 L
.14706 .3461 L
.15686 .37082 L
.16667 .39554 L
.17647 .42026 L
.18627 .44498 L
.19608 .46971 L
.20588 .49443 L
.21569 .51915 L
.22549 .54387 L
.23529 .56859 L
.2451 .59331 L
.2549 .61803 L
.26471 .59331 L
.27451 .56859 L
.28431 .54387 L
.29412 .51915 L
.30392 .49443 L
.31373 .46971 L
.32353 .44498 L
.33333 .42026 L
.34314 .39554 L
.35294 .37082 L
.36275 .3461 L
.37255 .32138 L
.38235 .29666 L
.39216 .27193 L
.40196 .24721 L
.41176 .22249 L
.42157 .19777 L
.43137 .17305 L
.44118 .14833 L
.45098 .12361 L
.46078 .09889 L
.47059 .07416 L
.48039 .04944 L
.4902 .02472 L
Mistroke
.5 0 L
.5098 0 L
.51961 0 L
.52941 0 L
.53922 0 L
.54902 0 L
.55882 0 L
.56863 0 L
.57843 0 L
.58824 0 L
.59804 0 L
.60784 0 L
.61765 0 L
.62745 0 L
.63725 0 L
.64706 0 L
.65686 0 L
.66667 0 L
.67647 0 L
.68627 0 L
.69608 0 L
.70588 0 L
.71569 0 L
.72549 0 L
.73529 0 L
.7451 0 L
.7549 0 L
.76471 0 L
.77451 0 L
.78431 0 L
.79412 0 L
.80392 0 L
.81373 0 L
.82353 0 L
.83333 0 L
.84314 0 L
.85294 0 L
.86275 0 L
.87255 0 L
.88235 0 L
.89216 0 L
.90196 0 L
.91176 0 L
.92157 0 L
.93137 0 L
.94118 0 L
.95098 0 L
.96078 0 L
.97059 0 L
.98039 0 L
Mistroke
.9902 0 L
Mfstroke
P
p
0 1 .4 r
1.11803 Mabswid
.0098 0 m
.01961 0 L
.02941 0 L
.03922 0 L
.04902 0 L
.05882 0 L
.06863 0 L
.07843 0 L
.08824 0 L
.09804 0 L
.10784 0 L
.11765 0 L
.12745 0 L
.13725 0 L
.14706 0 L
.15686 0 L
.16667 0 L
.17647 0 L
.18627 0 L
.19608 0 L
.20588 0 L
.21569 0 L
.22549 0 L
.23529 0 L
.2451 0 L
.2549 0 L
.26471 .02472 L
.27451 .04944 L
.28431 .07416 L
.29412 .09889 L
.30392 .12361 L
.31373 .14833 L
.32353 .17305 L
.33333 .19777 L
.34314 .22249 L
.35294 .24721 L
.36275 .27193 L
.37255 .29666 L
.38235 .32138 L
.39216 .3461 L
.40196 .37082 L
.41176 .39554 L
.42157 .42026 L
.43137 .44498 L
.44118 .46971 L
.45098 .49443 L
.46078 .51915 L
.47059 .54387 L
.48039 .56859 L
.4902 .59331 L
Mistroke
.5 .61803 L
.5098 .59331 L
.51961 .56859 L
.52941 .54387 L
.53922 .51915 L
.54902 .49443 L
.55882 .46971 L
.56863 .44498 L
.57843 .42026 L
.58824 .39554 L
.59804 .37082 L
.60784 .3461 L
.61765 .32138 L
.62745 .29666 L
.63725 .27193 L
.64706 .24721 L
.65686 .22249 L
.66667 .19777 L
.67647 .17305 L
.68627 .14833 L
.69608 .12361 L
.70588 .09889 L
.71569 .07416 L
.72549 .04944 L
.73529 .02472 L
.7451 0 L
.7549 0 L
.76471 0 L
.77451 0 L
.78431 0 L
.79412 0 L
.80392 0 L
.81373 0 L
.82353 0 L
.83333 0 L
.84314 0 L
.85294 0 L
.86275 0 L
.87255 0 L
.88235 0 L
.89216 0 L
.90196 0 L
.91176 0 L
.92157 0 L
.93137 0 L
.94118 0 L
.95098 0 L
.96078 0 L
.97059 0 L
.98039 0 L
Mistroke
.9902 0 L
Mfstroke
P
p
1 .6 0 r
1.11803 Mabswid
.0098 0 m
.01961 0 L
.02941 0 L
.03922 0 L
.04902 0 L
.05882 0 L
.06863 0 L
.07843 0 L
.08824 0 L
.09804 0 L
.10784 0 L
.11765 0 L
.12745 0 L
.13725 0 L
.14706 0 L
.15686 0 L
.16667 0 L
.17647 0 L
.18627 0 L
.19608 0 L
.20588 0 L
.21569 0 L
.22549 0 L
.23529 0 L
.2451 0 L
.2549 0 L
.26471 0 L
.27451 0 L
.28431 0 L
.29412 0 L
.30392 0 L
.31373 0 L
.32353 0 L
.33333 0 L
.34314 0 L
.35294 0 L
.36275 0 L
.37255 0 L
.38235 0 L
.39216 0 L
.40196 0 L
.41176 0 L
.42157 0 L
.43137 0 L
.44118 0 L
.45098 0 L
.46078 0 L
.47059 0 L
.48039 0 L
.4902 0 L
Mistroke
.5 0 L
.5098 .02472 L
.51961 .04944 L
.52941 .07416 L
.53922 .09889 L
.54902 .12361 L
.55882 .14833 L
.56863 .17305 L
.57843 .19777 L
.58824 .22249 L
.59804 .24721 L
.60784 .27193 L
.61765 .29666 L
.62745 .32138 L
.63725 .3461 L
.64706 .37082 L
.65686 .39554 L
.66667 .42026 L
.67647 .44498 L
.68627 .46971 L
.69608 .49443 L
.70588 .51915 L
.71569 .54387 L
.72549 .56859 L
.73529 .59331 L
.7451 .61803 L
.7549 .59331 L
.76471 .56859 L
.77451 .54387 L
.78431 .51915 L
.79412 .49443 L
.80392 .46971 L
.81373 .44498 L
.82353 .42026 L
.83333 .39554 L
.84314 .37082 L
.85294 .3461 L
.86275 .32138 L
.87255 .29666 L
.88235 .27193 L
.89216 .24721 L
.90196 .22249 L
.91176 .19777 L
.92157 .17305 L
.93137 .14833 L
.94118 .12361 L
.95098 .09889 L
.96078 .07416 L
.97059 .04944 L
.98039 .02472 L
Mistroke
.9902 0 L
Mfstroke
P
p
.8 0 1 r
1.11803 Mabswid
.0098 0 m
.01961 0 L
.02941 0 L
.03922 0 L
.04902 0 L
.05882 0 L
.06863 0 L
.07843 0 L
.08824 0 L
.09804 0 L
.10784 0 L
.11765 0 L
.12745 0 L
.13725 0 L
.14706 0 L
.15686 0 L
.16667 0 L
.17647 0 L
.18627 0 L
.19608 0 L
.20588 0 L
.21569 0 L
.22549 0 L
.23529 0 L
.2451 0 L
.2549 0 L
.26471 0 L
.27451 0 L
.28431 0 L
.29412 0 L
.30392 0 L
.31373 0 L
.32353 0 L
.33333 0 L
.34314 0 L
.35294 0 L
.36275 0 L
.37255 0 L
.38235 0 L
.39216 0 L
.40196 0 L
.41176 0 L
.42157 0 L
.43137 0 L
.44118 0 L
.45098 0 L
.46078 0 L
.47059 0 L
.48039 0 L
.4902 0 L
Mistroke
.5 0 L
.5098 0 L
.51961 0 L
.52941 0 L
.53922 0 L
.54902 0 L
.55882 0 L
.56863 0 L
.57843 0 L
.58824 0 L
.59804 0 L
.60784 0 L
.61765 0 L
.62745 0 L
.63725 0 L
.64706 0 L
.65686 0 L
.66667 0 L
.67647 0 L
.68627 0 L
.69608 0 L
.70588 0 L
.71569 0 L
.72549 0 L
.73529 0 L
.7451 0 L
.7549 .02472 L
.76471 .04944 L
.77451 .07416 L
.78431 .09889 L
.79412 .12361 L
.80392 .14833 L
.81373 .17305 L
.82353 .19777 L
.83333 .22249 L
.84314 .24721 L
.85294 .27193 L
.86275 .29666 L
.87255 .32138 L
.88235 .3461 L
.89216 .37082 L
.90196 .39554 L
.91176 .42026 L
.92157 .44498 L
.93137 .46971 L
.94118 .49443 L
.95098 .51915 L
.96078 .54387 L
.97059 .56859 L
.98039 .59331 L
Mistroke
.9902 .61803 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
SecondInput = {RB,RU,RV,VE,LV,LU,LB} =
  CreateFuzzySets[7,UniversalSpace->{-90,270}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[SecondInput,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.251381 0.00276243 0 0.618034 [
[(-50)] .11326 0 0 2 Msboxa
[(0)] .25138 0 0 2 Msboxa
[(50)] .3895 0 0 2 Msboxa
[(100)] .52762 0 0 2 Msboxa
[(150)] .66575 0 0 2 Msboxa
[(200)] .80387 0 0 2 Msboxa
[(250)] .94199 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.11326 0 m
.11326 .00625 L
s
P
[(-50)] .11326 0 0 2 Mshowa
p
.002 w
.25138 0 m
.25138 .00625 L
s
P
[(0)] .25138 0 0 2 Mshowa
p
.002 w
.3895 0 m
.3895 .00625 L
s
P
[(50)] .3895 0 0 2 Mshowa
p
.002 w
.52762 0 m
.52762 .00625 L
s
P
[(100)] .52762 0 0 2 Mshowa
p
.002 w
.66575 0 m
.66575 .00625 L
s
P
[(150)] .66575 0 0 2 Mshowa
p
.002 w
.80387 0 m
.80387 .00625 L
s
P
[(200)] .80387 0 0 2 Mshowa
p
.002 w
.94199 0 m
.94199 .00625 L
s
P
[(250)] .94199 0 0 2 Mshowa
p
.001 w
.14088 0 m
.14088 .00375 L
s
P
p
.001 w
.16851 0 m
.16851 .00375 L
s
P
p
.001 w
.19613 0 m
.19613 .00375 L
s
P
p
.001 w
.22376 0 m
.22376 .00375 L
s
P
p
.001 w
.27901 0 m
.27901 .00375 L
s
P
p
.001 w
.30663 0 m
.30663 .00375 L
s
P
p
.001 w
.33425 0 m
.33425 .00375 L
s
P
p
.001 w
.36188 0 m
.36188 .00375 L
s
P
p
.001 w
.41713 0 m
.41713 .00375 L
s
P
p
.001 w
.44475 0 m
.44475 .00375 L
s
P
p
.001 w
.47238 0 m
.47238 .00375 L
s
P
p
.001 w
.5 0 m
.5 .00375 L
s
P
p
.001 w
.55525 0 m
.55525 .00375 L
s
P
p
.001 w
.58287 0 m
.58287 .00375 L
s
P
p
.001 w
.6105 0 m
.6105 .00375 L
s
P
p
.001 w
.63812 0 m
.63812 .00375 L
s
P
p
.001 w
.69337 0 m
.69337 .00375 L
s
P
p
.001 w
.72099 0 m
.72099 .00375 L
s
P
p
.001 w
.74862 0 m
.74862 .00375 L
s
P
p
.001 w
.77624 0 m
.77624 .00375 L
s
P
p
.001 w
.83149 0 m
.83149 .00375 L
s
P
p
.001 w
.85912 0 m
.85912 .00375 L
s
P
p
.001 w
.88674 0 m
.88674 .00375 L
s
P
p
.001 w
.91436 0 m
.91436 .00375 L
s
P
p
.001 w
.08564 0 m
.08564 .00375 L
s
P
p
.001 w
.05801 0 m
.05801 .00375 L
s
P
p
.001 w
.03039 0 m
.03039 .00375 L
s
P
p
.001 w
.00276 0 m
.00276 .00375 L
s
P
p
.001 w
.96961 0 m
.96961 .00375 L
s
P
p
.001 w
.99724 0 m
.99724 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
.94491 Mabswid
.00276 .61803 m
.00552 .60773 L
.00829 .59743 L
.01105 .58713 L
.01381 .57683 L
.01657 .56653 L
.01934 .55623 L
.0221 .54593 L
.02486 .53563 L
.02762 .52533 L
.03039 .51503 L
.03315 .50473 L
.03591 .49443 L
.03867 .48413 L
.04144 .47383 L
.0442 .46353 L
.04696 .45322 L
.04972 .44292 L
.05249 .43262 L
.05525 .42232 L
.05801 .41202 L
.06077 .40172 L
.06354 .39142 L
.0663 .38112 L
.06906 .37082 L
.07182 .36052 L
.07459 .35022 L
.07735 .33992 L
.08011 .32962 L
.08287 .31932 L
.08564 .30902 L
.0884 .29872 L
.09116 .28842 L
.09392 .27812 L
.09669 .26781 L
.09945 .25751 L
.10221 .24721 L
.10497 .23691 L
.10773 .22661 L
.1105 .21631 L
.11326 .20601 L
.11602 .19571 L
.11878 .18541 L
.12155 .17511 L
.12431 .16481 L
.12707 .15451 L
.12983 .14421 L
.1326 .13391 L
.13536 .12361 L
.13812 .11331 L
Mistroke
.14088 .10301 L
.14365 .09271 L
.14641 .0824 L
.14917 .0721 L
.15193 .0618 L
.1547 .0515 L
.15746 .0412 L
.16022 .0309 L
.16298 .0206 L
.16575 .0103 L
.16851 0 L
.17127 0 L
.17403 0 L
.1768 0 L
.17956 0 L
.18232 0 L
.18508 0 L
.18785 0 L
.19061 0 L
.19337 0 L
.19613 0 L
.1989 0 L
.20166 0 L
.20442 0 L
.20718 0 L
.20994 0 L
.21271 0 L
.21547 0 L
.21823 0 L
.22099 0 L
.22376 0 L
.22652 0 L
.22928 0 L
.23204 0 L
.23481 0 L
.23757 0 L
.24033 0 L
.24309 0 L
.24586 0 L
.24862 0 L
.25138 0 L
.25414 0 L
.25691 0 L
.25967 0 L
.26243 0 L
.26519 0 L
.26796 0 L
.27072 0 L
.27348 0 L
.27624 0 L
Mistroke
.27901 0 L
.28177 0 L
.28453 0 L
.28729 0 L
.29006 0 L
.29282 0 L
.29558 0 L
.29834 0 L
.3011 0 L
.30387 0 L
.30663 0 L
.30939 0 L
.31215 0 L
.31492 0 L
.31768 0 L
.32044 0 L
.3232 0 L
.32597 0 L
.32873 0 L
.33149 0 L
.33425 0 L
.33702 0 L
.33978 0 L
.34254 0 L
.3453 0 L
.34807 0 L
.35083 0 L
.35359 0 L
.35635 0 L
.35912 0 L
.36188 0 L
.36464 0 L
.3674 0 L
.37017 0 L
.37293 0 L
.37569 0 L
.37845 0 L
.38122 0 L
.38398 0 L
.38674 0 L
.3895 0 L
.39227 0 L
.39503 0 L
.39779 0 L
.40055 0 L
.40331 0 L
.40608 0 L
.40884 0 L
.4116 0 L
.41436 0 L
Mistroke
.41713 0 L
.41989 0 L
.42265 0 L
.42541 0 L
.42818 0 L
.43094 0 L
.4337 0 L
.43646 0 L
.43923 0 L
.44199 0 L
.44475 0 L
.44751 0 L
.45028 0 L
.45304 0 L
.4558 0 L
.45856 0 L
.46133 0 L
.46409 0 L
.46685 0 L
.46961 0 L
.47238 0 L
.47514 0 L
.4779 0 L
.48066 0 L
.48343 0 L
.48619 0 L
.48895 0 L
.49171 0 L
.49448 0 L
.49724 0 L
.5 0 L
.50276 0 L
.50552 0 L
.50829 0 L
.51105 0 L
.51381 0 L
.51657 0 L
.51934 0 L
.5221 0 L
.52486 0 L
.52762 0 L
.53039 0 L
.53315 0 L
.53591 0 L
.53867 0 L
.54144 0 L
.5442 0 L
.54696 0 L
.54972 0 L
.55249 0 L
Mistroke
.55525 0 L
.55801 0 L
.56077 0 L
.56354 0 L
.5663 0 L
.56906 0 L
.57182 0 L
.57459 0 L
.57735 0 L
.58011 0 L
.58287 0 L
.58564 0 L
.5884 0 L
.59116 0 L
.59392 0 L
.59669 0 L
.59945 0 L
.60221 0 L
.60497 0 L
.60773 0 L
.6105 0 L
.61326 0 L
.61602 0 L
.61878 0 L
.62155 0 L
.62431 0 L
.62707 0 L
.62983 0 L
.6326 0 L
.63536 0 L
.63812 0 L
.64088 0 L
.64365 0 L
.64641 0 L
.64917 0 L
.65193 0 L
.6547 0 L
.65746 0 L
.66022 0 L
.66298 0 L
.66575 0 L
.66851 0 L
.67127 0 L
.67403 0 L
.6768 0 L
.67956 0 L
.68232 0 L
.68508 0 L
.68785 0 L
.69061 0 L
Mistroke
.69337 0 L
.69613 0 L
.6989 0 L
.70166 0 L
.70442 0 L
.70718 0 L
.70994 0 L
.71271 0 L
.71547 0 L
.71823 0 L
.72099 0 L
.72376 0 L
.72652 0 L
.72928 0 L
.73204 0 L
.73481 0 L
.73757 0 L
.74033 0 L
.74309 0 L
.74586 0 L
.74862 0 L
.75138 0 L
.75414 0 L
.75691 0 L
.75967 0 L
.76243 0 L
.76519 0 L
.76796 0 L
.77072 0 L
.77348 0 L
.77624 0 L
.77901 0 L
.78177 0 L
.78453 0 L
.78729 0 L
.79006 0 L
.79282 0 L
.79558 0 L
.79834 0 L
.8011 0 L
.80387 0 L
.80663 0 L
.80939 0 L
.81215 0 L
.81492 0 L
.81768 0 L
.82044 0 L
.8232 0 L
.82597 0 L
.82873 0 L
Mistroke
.83149 0 L
.83425 0 L
.83702 0 L
.83978 0 L
.84254 0 L
.8453 0 L
.84807 0 L
.85083 0 L
.85359 0 L
.85635 0 L
.85912 0 L
.86188 0 L
.86464 0 L
.8674 0 L
.87017 0 L
.87293 0 L
.87569 0 L
.87845 0 L
.88122 0 L
.88398 0 L
.88674 0 L
.8895 0 L
.89227 0 L
.89503 0 L
.89779 0 L
.90055 0 L
.90331 0 L
.90608 0 L
.90884 0 L
.9116 0 L
.91436 0 L
.91713 0 L
.91989 0 L
.92265 0 L
.92541 0 L
.92818 0 L
.93094 0 L
.9337 0 L
.93646 0 L
.93923 0 L
.94199 0 L
.94475 0 L
.94751 0 L
.95028 0 L
.95304 0 L
.9558 0 L
.95856 0 L
.96133 0 L
.96409 0 L
.96685 0 L
Mistroke
.96961 0 L
.97238 0 L
.97514 0 L
.9779 0 L
.98066 0 L
.98343 0 L
.98619 0 L
.98895 0 L
.99171 0 L
.99448 0 L
.99724 0 L
Mfstroke
P
p
.2 0 1 r
.94491 Mabswid
.00276 0 m
.00552 .0103 L
.00829 .0206 L
.01105 .0309 L
.01381 .0412 L
.01657 .0515 L
.01934 .0618 L
.0221 .0721 L
.02486 .0824 L
.02762 .09271 L
.03039 .10301 L
.03315 .11331 L
.03591 .12361 L
.03867 .13391 L
.04144 .14421 L
.0442 .15451 L
.04696 .16481 L
.04972 .17511 L
.05249 .18541 L
.05525 .19571 L
.05801 .20601 L
.06077 .21631 L
.06354 .22661 L
.0663 .23691 L
.06906 .24721 L
.07182 .25751 L
.07459 .26781 L
.07735 .27812 L
.08011 .28842 L
.08287 .29872 L
.08564 .30902 L
.0884 .31932 L
.09116 .32962 L
.09392 .33992 L
.09669 .35022 L
.09945 .36052 L
.10221 .37082 L
.10497 .38112 L
.10773 .39142 L
.1105 .40172 L
.11326 .41202 L
.11602 .42232 L
.11878 .43262 L
.12155 .44292 L
.12431 .45322 L
.12707 .46353 L
.12983 .47383 L
.1326 .48413 L
.13536 .49443 L
.13812 .50473 L
Mistroke
.14088 .51503 L
.14365 .52533 L
.14641 .53563 L
.14917 .54593 L
.15193 .55623 L
.1547 .56653 L
.15746 .57683 L
.16022 .58713 L
.16298 .59743 L
.16575 .60773 L
.16851 .61803 L
.17127 .60773 L
.17403 .59743 L
.1768 .58713 L
.17956 .57683 L
.18232 .56653 L
.18508 .55623 L
.18785 .54593 L
.19061 .53563 L
.19337 .52533 L
.19613 .51503 L
.1989 .50473 L
.20166 .49443 L
.20442 .48413 L
.20718 .47383 L
.20994 .46353 L
.21271 .45322 L
.21547 .44292 L
.21823 .43262 L
.22099 .42232 L
.22376 .41202 L
.22652 .40172 L
.22928 .39142 L
.23204 .38112 L
.23481 .37082 L
.23757 .36052 L
.24033 .35022 L
.24309 .33992 L
.24586 .32962 L
.24862 .31932 L
.25138 .30902 L
.25414 .29872 L
.25691 .28842 L
.25967 .27812 L
.26243 .26781 L
.26519 .25751 L
.26796 .24721 L
.27072 .23691 L
.27348 .22661 L
.27624 .21631 L
Mistroke
.27901 .20601 L
.28177 .19571 L
.28453 .18541 L
.28729 .17511 L
.29006 .16481 L
.29282 .15451 L
.29558 .14421 L
.29834 .13391 L
.3011 .12361 L
.30387 .11331 L
.30663 .10301 L
.30939 .09271 L
.31215 .0824 L
.31492 .0721 L
.31768 .0618 L
.32044 .0515 L
.3232 .0412 L
.32597 .0309 L
.32873 .0206 L
.33149 .0103 L
.33425 0 L
.33702 0 L
.33978 0 L
.34254 0 L
.3453 0 L
.34807 0 L
.35083 0 L
.35359 0 L
.35635 0 L
.35912 0 L
.36188 0 L
.36464 0 L
.3674 0 L
.37017 0 L
.37293 0 L
.37569 0 L
.37845 0 L
.38122 0 L
.38398 0 L
.38674 0 L
.3895 0 L
.39227 0 L
.39503 0 L
.39779 0 L
.40055 0 L
.40331 0 L
.40608 0 L
.40884 0 L
.4116 0 L
.41436 0 L
Mistroke
.41713 0 L
.41989 0 L
.42265 0 L
.42541 0 L
.42818 0 L
.43094 0 L
.4337 0 L
.43646 0 L
.43923 0 L
.44199 0 L
.44475 0 L
.44751 0 L
.45028 0 L
.45304 0 L
.4558 0 L
.45856 0 L
.46133 0 L
.46409 0 L
.46685 0 L
.46961 0 L
.47238 0 L
.47514 0 L
.4779 0 L
.48066 0 L
.48343 0 L
.48619 0 L
.48895 0 L
.49171 0 L
.49448 0 L
.49724 0 L
.5 0 L
.50276 0 L
.50552 0 L
.50829 0 L
.51105 0 L
.51381 0 L
.51657 0 L
.51934 0 L
.5221 0 L
.52486 0 L
.52762 0 L
.53039 0 L
.53315 0 L
.53591 0 L
.53867 0 L
.54144 0 L
.5442 0 L
.54696 0 L
.54972 0 L
.55249 0 L
Mistroke
.55525 0 L
.55801 0 L
.56077 0 L
.56354 0 L
.5663 0 L
.56906 0 L
.57182 0 L
.57459 0 L
.57735 0 L
.58011 0 L
.58287 0 L
.58564 0 L
.5884 0 L
.59116 0 L
.59392 0 L
.59669 0 L
.59945 0 L
.60221 0 L
.60497 0 L
.60773 0 L
.6105 0 L
.61326 0 L
.61602 0 L
.61878 0 L
.62155 0 L
.62431 0 L
.62707 0 L
.62983 0 L
.6326 0 L
.63536 0 L
.63812 0 L
.64088 0 L
.64365 0 L
.64641 0 L
.64917 0 L
.65193 0 L
.6547 0 L
.65746 0 L
.66022 0 L
.66298 0 L
.66575 0 L
.66851 0 L
.67127 0 L
.67403 0 L
.6768 0 L
.67956 0 L
.68232 0 L
.68508 0 L
.68785 0 L
.69061 0 L
Mistroke
.69337 0 L
.69613 0 L
.6989 0 L
.70166 0 L
.70442 0 L
.70718 0 L
.70994 0 L
.71271 0 L
.71547 0 L
.71823 0 L
.72099 0 L
.72376 0 L
.72652 0 L
.72928 0 L
.73204 0 L
.73481 0 L
.73757 0 L
.74033 0 L
.74309 0 L
.74586 0 L
.74862 0 L
.75138 0 L
.75414 0 L
.75691 0 L
.75967 0 L
.76243 0 L
.76519 0 L
.76796 0 L
.77072 0 L
.77348 0 L
.77624 0 L
.77901 0 L
.78177 0 L
.78453 0 L
.78729 0 L
.79006 0 L
.79282 0 L
.79558 0 L
.79834 0 L
.8011 0 L
.80387 0 L
.80663 0 L
.80939 0 L
.81215 0 L
.81492 0 L
.81768 0 L
.82044 0 L
.8232 0 L
.82597 0 L
.82873 0 L
Mistroke
.83149 0 L
.83425 0 L
.83702 0 L
.83978 0 L
.84254 0 L
.8453 0 L
.84807 0 L
.85083 0 L
.85359 0 L
.85635 0 L
.85912 0 L
.86188 0 L
.86464 0 L
.8674 0 L
.87017 0 L
.87293 0 L
.87569 0 L
.87845 0 L
.88122 0 L
.88398 0 L
.88674 0 L
.8895 0 L
.89227 0 L
.89503 0 L
.89779 0 L
.90055 0 L
.90331 0 L
.90608 0 L
.90884 0 L
.9116 0 L
.91436 0 L
.91713 0 L
.91989 0 L
.92265 0 L
.92541 0 L
.92818 0 L
.93094 0 L
.9337 0 L
.93646 0 L
.93923 0 L
.94199 0 L
.94475 0 L
.94751 0 L
.95028 0 L
.95304 0 L
.9558 0 L
.95856 0 L
.96133 0 L
.96409 0 L
.96685 0 L
Mistroke
.96961 0 L
.97238 0 L
.97514 0 L
.9779 0 L
.98066 0 L
.98343 0 L
.98619 0 L
.98895 0 L
.99171 0 L
.99448 0 L
.99724 0 L
Mfstroke
P
p
0 1 .4 r
.94491 Mabswid
.00276 0 m
.00552 0 L
.00829 0 L
.01105 0 L
.01381 0 L
.01657 0 L
.01934 0 L
.0221 0 L
.02486 0 L
.02762 0 L
.03039 0 L
.03315 0 L
.03591 0 L
.03867 0 L
.04144 0 L
.0442 0 L
.04696 0 L
.04972 0 L
.05249 0 L
.05525 0 L
.05801 0 L
.06077 0 L
.06354 0 L
.0663 0 L
.06906 0 L
.07182 0 L
.07459 0 L
.07735 0 L
.08011 0 L
.08287 0 L
.08564 0 L
.0884 0 L
.09116 0 L
.09392 0 L
.09669 0 L
.09945 0 L
.10221 0 L
.10497 0 L
.10773 0 L
.1105 0 L
.11326 0 L
.11602 0 L
.11878 0 L
.12155 0 L
.12431 0 L
.12707 0 L
.12983 0 L
.1326 0 L
.13536 0 L
.13812 0 L
Mistroke
.14088 0 L
.14365 0 L
.14641 0 L
.14917 0 L
.15193 0 L
.1547 0 L
.15746 0 L
.16022 0 L
.16298 0 L
.16575 0 L
.16851 0 L
.17127 .0103 L
.17403 .0206 L
.1768 .0309 L
.17956 .0412 L
.18232 .0515 L
.18508 .0618 L
.18785 .0721 L
.19061 .0824 L
.19337 .09271 L
.19613 .10301 L
.1989 .11331 L
.20166 .12361 L
.20442 .13391 L
.20718 .14421 L
.20994 .15451 L
.21271 .16481 L
.21547 .17511 L
.21823 .18541 L
.22099 .19571 L
.22376 .20601 L
.22652 .21631 L
.22928 .22661 L
.23204 .23691 L
.23481 .24721 L
.23757 .25751 L
.24033 .26781 L
.24309 .27812 L
.24586 .28842 L
.24862 .29872 L
.25138 .30902 L
.25414 .31932 L
.25691 .32962 L
.25967 .33992 L
.26243 .35022 L
.26519 .36052 L
.26796 .37082 L
.27072 .38112 L
.27348 .39142 L
.27624 .40172 L
Mistroke
.27901 .41202 L
.28177 .42232 L
.28453 .43262 L
.28729 .44292 L
.29006 .45322 L
.29282 .46353 L
.29558 .47383 L
.29834 .48413 L
.3011 .49443 L
.30387 .50473 L
.30663 .51503 L
.30939 .52533 L
.31215 .53563 L
.31492 .54593 L
.31768 .55623 L
.32044 .56653 L
.3232 .57683 L
.32597 .58713 L
.32873 .59743 L
.33149 .60773 L
.33425 .61803 L
.33702 .60773 L
.33978 .59743 L
.34254 .58713 L
.3453 .57683 L
.34807 .56653 L
.35083 .55623 L
.35359 .54593 L
.35635 .53563 L
.35912 .52533 L
.36188 .51503 L
.36464 .50473 L
.3674 .49443 L
.37017 .48413 L
.37293 .47383 L
.37569 .46353 L
.37845 .45322 L
.38122 .44292 L
.38398 .43262 L
.38674 .42232 L
.3895 .41202 L
.39227 .40172 L
.39503 .39142 L
.39779 .38112 L
.40055 .37082 L
.40331 .36052 L
.40608 .35022 L
.40884 .33992 L
.4116 .32962 L
.41436 .31932 L
Mistroke
.41713 .30902 L
.41989 .29872 L
.42265 .28842 L
.42541 .27812 L
.42818 .26781 L
.43094 .25751 L
.4337 .24721 L
.43646 .23691 L
.43923 .22661 L
.44199 .21631 L
.44475 .20601 L
.44751 .19571 L
.45028 .18541 L
.45304 .17511 L
.4558 .16481 L
.45856 .15451 L
.46133 .14421 L
.46409 .13391 L
.46685 .12361 L
.46961 .11331 L
.47238 .10301 L
.47514 .09271 L
.4779 .0824 L
.48066 .0721 L
.48343 .0618 L
.48619 .0515 L
.48895 .0412 L
.49171 .0309 L
.49448 .0206 L
.49724 .0103 L
.5 0 L
.50276 0 L
.50552 0 L
.50829 0 L
.51105 0 L
.51381 0 L
.51657 0 L
.51934 0 L
.5221 0 L
.52486 0 L
.52762 0 L
.53039 0 L
.53315 0 L
.53591 0 L
.53867 0 L
.54144 0 L
.5442 0 L
.54696 0 L
.54972 0 L
.55249 0 L
Mistroke
.55525 0 L
.55801 0 L
.56077 0 L
.56354 0 L
.5663 0 L
.56906 0 L
.57182 0 L
.57459 0 L
.57735 0 L
.58011 0 L
.58287 0 L
.58564 0 L
.5884 0 L
.59116 0 L
.59392 0 L
.59669 0 L
.59945 0 L
.60221 0 L
.60497 0 L
.60773 0 L
.6105 0 L
.61326 0 L
.61602 0 L
.61878 0 L
.62155 0 L
.62431 0 L
.62707 0 L
.62983 0 L
.6326 0 L
.63536 0 L
.63812 0 L
.64088 0 L
.64365 0 L
.64641 0 L
.64917 0 L
.65193 0 L
.6547 0 L
.65746 0 L
.66022 0 L
.66298 0 L
.66575 0 L
.66851 0 L
.67127 0 L
.67403 0 L
.6768 0 L
.67956 0 L
.68232 0 L
.68508 0 L
.68785 0 L
.69061 0 L
Mistroke
.69337 0 L
.69613 0 L
.6989 0 L
.70166 0 L
.70442 0 L
.70718 0 L
.70994 0 L
.71271 0 L
.71547 0 L
.71823 0 L
.72099 0 L
.72376 0 L
.72652 0 L
.72928 0 L
.73204 0 L
.73481 0 L
.73757 0 L
.74033 0 L
.74309 0 L
.74586 0 L
.74862 0 L
.75138 0 L
.75414 0 L
.75691 0 L
.75967 0 L
.76243 0 L
.76519 0 L
.76796 0 L
.77072 0 L
.77348 0 L
.77624 0 L
.77901 0 L
.78177 0 L
.78453 0 L
.78729 0 L
.79006 0 L
.79282 0 L
.79558 0 L
.79834 0 L
.8011 0 L
.80387 0 L
.80663 0 L
.80939 0 L
.81215 0 L
.81492 0 L
.81768 0 L
.82044 0 L
.8232 0 L
.82597 0 L
.82873 0 L
Mistroke
.83149 0 L
.83425 0 L
.83702 0 L
.83978 0 L
.84254 0 L
.8453 0 L
.84807 0 L
.85083 0 L
.85359 0 L
.85635 0 L
.85912 0 L
.86188 0 L
.86464 0 L
.8674 0 L
.87017 0 L
.87293 0 L
.87569 0 L
.87845 0 L
.88122 0 L
.88398 0 L
.88674 0 L
.8895 0 L
.89227 0 L
.89503 0 L
.89779 0 L
.90055 0 L
.90331 0 L
.90608 0 L
.90884 0 L
.9116 0 L
.91436 0 L
.91713 0 L
.91989 0 L
.92265 0 L
.92541 0 L
.92818 0 L
.93094 0 L
.9337 0 L
.93646 0 L
.93923 0 L
.94199 0 L
.94475 0 L
.94751 0 L
.95028 0 L
.95304 0 L
.9558 0 L
.95856 0 L
.96133 0 L
.96409 0 L
.96685 0 L
Mistroke
.96961 0 L
.97238 0 L
.97514 0 L
.9779 0 L
.98066 0 L
.98343 0 L
.98619 0 L
.98895 0 L
.99171 0 L
.99448 0 L
.99724 0 L
Mfstroke
P
p
1 .6 0 r
.94491 Mabswid
.00276 0 m
.00552 0 L
.00829 0 L
.01105 0 L
.01381 0 L
.01657 0 L
.01934 0 L
.0221 0 L
.02486 0 L
.02762 0 L
.03039 0 L
.03315 0 L
.03591 0 L
.03867 0 L
.04144 0 L
.0442 0 L
.04696 0 L
.04972 0 L
.05249 0 L
.05525 0 L
.05801 0 L
.06077 0 L
.06354 0 L
.0663 0 L
.06906 0 L
.07182 0 L
.07459 0 L
.07735 0 L
.08011 0 L
.08287 0 L
.08564 0 L
.0884 0 L
.09116 0 L
.09392 0 L
.09669 0 L
.09945 0 L
.10221 0 L
.10497 0 L
.10773 0 L
.1105 0 L
.11326 0 L
.11602 0 L
.11878 0 L
.12155 0 L
.12431 0 L
.12707 0 L
.12983 0 L
.1326 0 L
.13536 0 L
.13812 0 L
Mistroke
.14088 0 L
.14365 0 L
.14641 0 L
.14917 0 L
.15193 0 L
.1547 0 L
.15746 0 L
.16022 0 L
.16298 0 L
.16575 0 L
.16851 0 L
.17127 0 L
.17403 0 L
.1768 0 L
.17956 0 L
.18232 0 L
.18508 0 L
.18785 0 L
.19061 0 L
.19337 0 L
.19613 0 L
.1989 0 L
.20166 0 L
.20442 0 L
.20718 0 L
.20994 0 L
.21271 0 L
.21547 0 L
.21823 0 L
.22099 0 L
.22376 0 L
.22652 0 L
.22928 0 L
.23204 0 L
.23481 0 L
.23757 0 L
.24033 0 L
.24309 0 L
.24586 0 L
.24862 0 L
.25138 0 L
.25414 0 L
.25691 0 L
.25967 0 L
.26243 0 L
.26519 0 L
.26796 0 L
.27072 0 L
.27348 0 L
.27624 0 L
Mistroke
.27901 0 L
.28177 0 L
.28453 0 L
.28729 0 L
.29006 0 L
.29282 0 L
.29558 0 L
.29834 0 L
.3011 0 L
.30387 0 L
.30663 0 L
.30939 0 L
.31215 0 L
.31492 0 L
.31768 0 L
.32044 0 L
.3232 0 L
.32597 0 L
.32873 0 L
.33149 0 L
.33425 0 L
.33702 .0103 L
.33978 .0206 L
.34254 .0309 L
.3453 .0412 L
.34807 .0515 L
.35083 .0618 L
.35359 .0721 L
.35635 .0824 L
.35912 .09271 L
.36188 .10301 L
.36464 .11331 L
.3674 .12361 L
.37017 .13391 L
.37293 .14421 L
.37569 .15451 L
.37845 .16481 L
.38122 .17511 L
.38398 .18541 L
.38674 .19571 L
.3895 .20601 L
.39227 .21631 L
.39503 .22661 L
.39779 .23691 L
.40055 .24721 L
.40331 .25751 L
.40608 .26781 L
.40884 .27812 L
.4116 .28842 L
.41436 .29872 L
Mistroke
.41713 .30902 L
.41989 .31932 L
.42265 .32962 L
.42541 .33992 L
.42818 .35022 L
.43094 .36052 L
.4337 .37082 L
.43646 .38112 L
.43923 .39142 L
.44199 .40172 L
.44475 .41202 L
.44751 .42232 L
.45028 .43262 L
.45304 .44292 L
.4558 .45322 L
.45856 .46353 L
.46133 .47383 L
.46409 .48413 L
.46685 .49443 L
.46961 .50473 L
.47238 .51503 L
.47514 .52533 L
.4779 .53563 L
.48066 .54593 L
.48343 .55623 L
.48619 .56653 L
.48895 .57683 L
.49171 .58713 L
.49448 .59743 L
.49724 .60773 L
.5 .61803 L
.50276 .60773 L
.50552 .59743 L
.50829 .58713 L
.51105 .57683 L
.51381 .56653 L
.51657 .55623 L
.51934 .54593 L
.5221 .53563 L
.52486 .52533 L
.52762 .51503 L
.53039 .50473 L
.53315 .49443 L
.53591 .48413 L
.53867 .47383 L
.54144 .46353 L
.5442 .45322 L
.54696 .44292 L
.54972 .43262 L
.55249 .42232 L
Mistroke
.55525 .41202 L
.55801 .40172 L
.56077 .39142 L
.56354 .38112 L
.5663 .37082 L
.56906 .36052 L
.57182 .35022 L
.57459 .33992 L
.57735 .32962 L
.58011 .31932 L
.58287 .30902 L
.58564 .29872 L
.5884 .28842 L
.59116 .27812 L
.59392 .26781 L
.59669 .25751 L
.59945 .24721 L
.60221 .23691 L
.60497 .22661 L
.60773 .21631 L
.6105 .20601 L
.61326 .19571 L
.61602 .18541 L
.61878 .17511 L
.62155 .16481 L
.62431 .15451 L
.62707 .14421 L
.62983 .13391 L
.6326 .12361 L
.63536 .11331 L
.63812 .10301 L
.64088 .09271 L
.64365 .0824 L
.64641 .0721 L
.64917 .0618 L
.65193 .0515 L
.6547 .0412 L
.65746 .0309 L
.66022 .0206 L
.66298 .0103 L
.66575 0 L
.66851 0 L
.67127 0 L
.67403 0 L
.6768 0 L
.67956 0 L
.68232 0 L
.68508 0 L
.68785 0 L
.69061 0 L
Mistroke
.69337 0 L
.69613 0 L
.6989 0 L
.70166 0 L
.70442 0 L
.70718 0 L
.70994 0 L
.71271 0 L
.71547 0 L
.71823 0 L
.72099 0 L
.72376 0 L
.72652 0 L
.72928 0 L
.73204 0 L
.73481 0 L
.73757 0 L
.74033 0 L
.74309 0 L
.74586 0 L
.74862 0 L
.75138 0 L
.75414 0 L
.75691 0 L
.75967 0 L
.76243 0 L
.76519 0 L
.76796 0 L
.77072 0 L
.77348 0 L
.77624 0 L
.77901 0 L
.78177 0 L
.78453 0 L
.78729 0 L
.79006 0 L
.79282 0 L
.79558 0 L
.79834 0 L
.8011 0 L
.80387 0 L
.80663 0 L
.80939 0 L
.81215 0 L
.81492 0 L
.81768 0 L
.82044 0 L
.8232 0 L
.82597 0 L
.82873 0 L
Mistroke
.83149 0 L
.83425 0 L
.83702 0 L
.83978 0 L
.84254 0 L
.8453 0 L
.84807 0 L
.85083 0 L
.85359 0 L
.85635 0 L
.85912 0 L
.86188 0 L
.86464 0 L
.8674 0 L
.87017 0 L
.87293 0 L
.87569 0 L
.87845 0 L
.88122 0 L
.88398 0 L
.88674 0 L
.8895 0 L
.89227 0 L
.89503 0 L
.89779 0 L
.90055 0 L
.90331 0 L
.90608 0 L
.90884 0 L
.9116 0 L
.91436 0 L
.91713 0 L
.91989 0 L
.92265 0 L
.92541 0 L
.92818 0 L
.93094 0 L
.9337 0 L
.93646 0 L
.93923 0 L
.94199 0 L
.94475 0 L
.94751 0 L
.95028 0 L
.95304 0 L
.9558 0 L
.95856 0 L
.96133 0 L
.96409 0 L
.96685 0 L
Mistroke
.96961 0 L
.97238 0 L
.97514 0 L
.9779 0 L
.98066 0 L
.98343 0 L
.98619 0 L
.98895 0 L
.99171 0 L
.99448 0 L
.99724 0 L
Mfstroke
P
p
.8 0 1 r
.94491 Mabswid
.00276 0 m
.00552 0 L
.00829 0 L
.01105 0 L
.01381 0 L
.01657 0 L
.01934 0 L
.0221 0 L
.02486 0 L
.02762 0 L
.03039 0 L
.03315 0 L
.03591 0 L
.03867 0 L
.04144 0 L
.0442 0 L
.04696 0 L
.04972 0 L
.05249 0 L
.05525 0 L
.05801 0 L
.06077 0 L
.06354 0 L
.0663 0 L
.06906 0 L
.07182 0 L
.07459 0 L
.07735 0 L
.08011 0 L
.08287 0 L
.08564 0 L
.0884 0 L
.09116 0 L
.09392 0 L
.09669 0 L
.09945 0 L
.10221 0 L
.10497 0 L
.10773 0 L
.1105 0 L
.11326 0 L
.11602 0 L
.11878 0 L
.12155 0 L
.12431 0 L
.12707 0 L
.12983 0 L
.1326 0 L
.13536 0 L
.13812 0 L
Mistroke
.14088 0 L
.14365 0 L
.14641 0 L
.14917 0 L
.15193 0 L
.1547 0 L
.15746 0 L
.16022 0 L
.16298 0 L
.16575 0 L
.16851 0 L
.17127 0 L
.17403 0 L
.1768 0 L
.17956 0 L
.18232 0 L
.18508 0 L
.18785 0 L
.19061 0 L
.19337 0 L
.19613 0 L
.1989 0 L
.20166 0 L
.20442 0 L
.20718 0 L
.20994 0 L
.21271 0 L
.21547 0 L
.21823 0 L
.22099 0 L
.22376 0 L
.22652 0 L
.22928 0 L
.23204 0 L
.23481 0 L
.23757 0 L
.24033 0 L
.24309 0 L
.24586 0 L
.24862 0 L
.25138 0 L
.25414 0 L
.25691 0 L
.25967 0 L
.26243 0 L
.26519 0 L
.26796 0 L
.27072 0 L
.27348 0 L
.27624 0 L
Mistroke
.27901 0 L
.28177 0 L
.28453 0 L
.28729 0 L
.29006 0 L
.29282 0 L
.29558 0 L
.29834 0 L
.3011 0 L
.30387 0 L
.30663 0 L
.30939 0 L
.31215 0 L
.31492 0 L
.31768 0 L
.32044 0 L
.3232 0 L
.32597 0 L
.32873 0 L
.33149 0 L
.33425 0 L
.33702 0 L
.33978 0 L
.34254 0 L
.3453 0 L
.34807 0 L
.35083 0 L
.35359 0 L
.35635 0 L
.35912 0 L
.36188 0 L
.36464 0 L
.3674 0 L
.37017 0 L
.37293 0 L
.37569 0 L
.37845 0 L
.38122 0 L
.38398 0 L
.38674 0 L
.3895 0 L
.39227 0 L
.39503 0 L
.39779 0 L
.40055 0 L
.40331 0 L
.40608 0 L
.40884 0 L
.4116 0 L
.41436 0 L
Mistroke
.41713 0 L
.41989 0 L
.42265 0 L
.42541 0 L
.42818 0 L
.43094 0 L
.4337 0 L
.43646 0 L
.43923 0 L
.44199 0 L
.44475 0 L
.44751 0 L
.45028 0 L
.45304 0 L
.4558 0 L
.45856 0 L
.46133 0 L
.46409 0 L
.46685 0 L
.46961 0 L
.47238 0 L
.47514 0 L
.4779 0 L
.48066 0 L
.48343 0 L
.48619 0 L
.48895 0 L
.49171 0 L
.49448 0 L
.49724 0 L
.5 0 L
.50276 .0103 L
.50552 .0206 L
.50829 .0309 L
.51105 .0412 L
.51381 .0515 L
.51657 .0618 L
.51934 .0721 L
.5221 .0824 L
.52486 .09271 L
.52762 .10301 L
.53039 .11331 L
.53315 .12361 L
.53591 .13391 L
.53867 .14421 L
.54144 .15451 L
.5442 .16481 L
.54696 .17511 L
.54972 .18541 L
.55249 .19571 L
Mistroke
.55525 .20601 L
.55801 .21631 L
.56077 .22661 L
.56354 .23691 L
.5663 .24721 L
.56906 .25751 L
.57182 .26781 L
.57459 .27812 L
.57735 .28842 L
.58011 .29872 L
.58287 .30902 L
.58564 .31932 L
.5884 .32962 L
.59116 .33992 L
.59392 .35022 L
.59669 .36052 L
.59945 .37082 L
.60221 .38112 L
.60497 .39142 L
.60773 .40172 L
.6105 .41202 L
.61326 .42232 L
.61602 .43262 L
.61878 .44292 L
.62155 .45322 L
.62431 .46353 L
.62707 .47383 L
.62983 .48413 L
.6326 .49443 L
.63536 .50473 L
.63812 .51503 L
.64088 .52533 L
.64365 .53563 L
.64641 .54593 L
.64917 .55623 L
.65193 .56653 L
.6547 .57683 L
.65746 .58713 L
.66022 .59743 L
.66298 .60773 L
.66575 .61803 L
.66851 .60773 L
.67127 .59743 L
.67403 .58713 L
.6768 .57683 L
.67956 .56653 L
.68232 .55623 L
.68508 .54593 L
.68785 .53563 L
.69061 .52533 L
Mistroke
.69337 .51503 L
.69613 .50473 L
.6989 .49443 L
.70166 .48413 L
.70442 .47383 L
.70718 .46353 L
.70994 .45322 L
.71271 .44292 L
.71547 .43262 L
.71823 .42232 L
.72099 .41202 L
.72376 .40172 L
.72652 .39142 L
.72928 .38112 L
.73204 .37082 L
.73481 .36052 L
.73757 .35022 L
.74033 .33992 L
.74309 .32962 L
.74586 .31932 L
.74862 .30902 L
.75138 .29872 L
.75414 .28842 L
.75691 .27812 L
.75967 .26781 L
.76243 .25751 L
.76519 .24721 L
.76796 .23691 L
.77072 .22661 L
.77348 .21631 L
.77624 .20601 L
.77901 .19571 L
.78177 .18541 L
.78453 .17511 L
.78729 .16481 L
.79006 .15451 L
.79282 .14421 L
.79558 .13391 L
.79834 .12361 L
.8011 .11331 L
.80387 .10301 L
.80663 .09271 L
.80939 .0824 L
.81215 .0721 L
.81492 .0618 L
.81768 .0515 L
.82044 .0412 L
.8232 .0309 L
.82597 .0206 L
.82873 .0103 L
Mistroke
.83149 0 L
.83425 0 L
.83702 0 L
.83978 0 L
.84254 0 L
.8453 0 L
.84807 0 L
.85083 0 L
.85359 0 L
.85635 0 L
.85912 0 L
.86188 0 L
.86464 0 L
.8674 0 L
.87017 0 L
.87293 0 L
.87569 0 L
.87845 0 L
.88122 0 L
.88398 0 L
.88674 0 L
.8895 0 L
.89227 0 L
.89503 0 L
.89779 0 L
.90055 0 L
.90331 0 L
.90608 0 L
.90884 0 L
.9116 0 L
.91436 0 L
.91713 0 L
.91989 0 L
.92265 0 L
.92541 0 L
.92818 0 L
.93094 0 L
.9337 0 L
.93646 0 L
.93923 0 L
.94199 0 L
.94475 0 L
.94751 0 L
.95028 0 L
.95304 0 L
.9558 0 L
.95856 0 L
.96133 0 L
.96409 0 L
.96685 0 L
Mistroke
.96961 0 L
.97238 0 L
.97514 0 L
.9779 0 L
.98066 0 L
.98343 0 L
.98619 0 L
.98895 0 L
.99171 0 L
.99448 0 L
.99724 0 L
Mfstroke
P
p
0 1 1 r
.94491 Mabswid
.00276 0 m
.00552 0 L
.00829 0 L
.01105 0 L
.01381 0 L
.01657 0 L
.01934 0 L
.0221 0 L
.02486 0 L
.02762 0 L
.03039 0 L
.03315 0 L
.03591 0 L
.03867 0 L
.04144 0 L
.0442 0 L
.04696 0 L
.04972 0 L
.05249 0 L
.05525 0 L
.05801 0 L
.06077 0 L
.06354 0 L
.0663 0 L
.06906 0 L
.07182 0 L
.07459 0 L
.07735 0 L
.08011 0 L
.08287 0 L
.08564 0 L
.0884 0 L
.09116 0 L
.09392 0 L
.09669 0 L
.09945 0 L
.10221 0 L
.10497 0 L
.10773 0 L
.1105 0 L
.11326 0 L
.11602 0 L
.11878 0 L
.12155 0 L
.12431 0 L
.12707 0 L
.12983 0 L
.1326 0 L
.13536 0 L
.13812 0 L
Mistroke
.14088 0 L
.14365 0 L
.14641 0 L
.14917 0 L
.15193 0 L
.1547 0 L
.15746 0 L
.16022 0 L
.16298 0 L
.16575 0 L
.16851 0 L
.17127 0 L
.17403 0 L
.1768 0 L
.17956 0 L
.18232 0 L
.18508 0 L
.18785 0 L
.19061 0 L
.19337 0 L
.19613 0 L
.1989 0 L
.20166 0 L
.20442 0 L
.20718 0 L
.20994 0 L
.21271 0 L
.21547 0 L
.21823 0 L
.22099 0 L
.22376 0 L
.22652 0 L
.22928 0 L
.23204 0 L
.23481 0 L
.23757 0 L
.24033 0 L
.24309 0 L
.24586 0 L
.24862 0 L
.25138 0 L
.25414 0 L
.25691 0 L
.25967 0 L
.26243 0 L
.26519 0 L
.26796 0 L
.27072 0 L
.27348 0 L
.27624 0 L
Mistroke
.27901 0 L
.28177 0 L
.28453 0 L
.28729 0 L
.29006 0 L
.29282 0 L
.29558 0 L
.29834 0 L
.3011 0 L
.30387 0 L
.30663 0 L
.30939 0 L
.31215 0 L
.31492 0 L
.31768 0 L
.32044 0 L
.3232 0 L
.32597 0 L
.32873 0 L
.33149 0 L
.33425 0 L
.33702 0 L
.33978 0 L
.34254 0 L
.3453 0 L
.34807 0 L
.35083 0 L
.35359 0 L
.35635 0 L
.35912 0 L
.36188 0 L
.36464 0 L
.3674 0 L
.37017 0 L
.37293 0 L
.37569 0 L
.37845 0 L
.38122 0 L
.38398 0 L
.38674 0 L
.3895 0 L
.39227 0 L
.39503 0 L
.39779 0 L
.40055 0 L
.40331 0 L
.40608 0 L
.40884 0 L
.4116 0 L
.41436 0 L
Mistroke
.41713 0 L
.41989 0 L
.42265 0 L
.42541 0 L
.42818 0 L
.43094 0 L
.4337 0 L
.43646 0 L
.43923 0 L
.44199 0 L
.44475 0 L
.44751 0 L
.45028 0 L
.45304 0 L
.4558 0 L
.45856 0 L
.46133 0 L
.46409 0 L
.46685 0 L
.46961 0 L
.47238 0 L
.47514 0 L
.4779 0 L
.48066 0 L
.48343 0 L
.48619 0 L
.48895 0 L
.49171 0 L
.49448 0 L
.49724 0 L
.5 0 L
.50276 0 L
.50552 0 L
.50829 0 L
.51105 0 L
.51381 0 L
.51657 0 L
.51934 0 L
.5221 0 L
.52486 0 L
.52762 0 L
.53039 0 L
.53315 0 L
.53591 0 L
.53867 0 L
.54144 0 L
.5442 0 L
.54696 0 L
.54972 0 L
.55249 0 L
Mistroke
.55525 0 L
.55801 0 L
.56077 0 L
.56354 0 L
.5663 0 L
.56906 0 L
.57182 0 L
.57459 0 L
.57735 0 L
.58011 0 L
.58287 0 L
.58564 0 L
.5884 0 L
.59116 0 L
.59392 0 L
.59669 0 L
.59945 0 L
.60221 0 L
.60497 0 L
.60773 0 L
.6105 0 L
.61326 0 L
.61602 0 L
.61878 0 L
.62155 0 L
.62431 0 L
.62707 0 L
.62983 0 L
.6326 0 L
.63536 0 L
.63812 0 L
.64088 0 L
.64365 0 L
.64641 0 L
.64917 0 L
.65193 0 L
.6547 0 L
.65746 0 L
.66022 0 L
.66298 0 L
.66575 0 L
.66851 .0103 L
.67127 .0206 L
.67403 .0309 L
.6768 .0412 L
.67956 .0515 L
.68232 .0618 L
.68508 .0721 L
.68785 .0824 L
.69061 .09271 L
Mistroke
.69337 .10301 L
.69613 .11331 L
.6989 .12361 L
.70166 .13391 L
.70442 .14421 L
.70718 .15451 L
.70994 .16481 L
.71271 .17511 L
.71547 .18541 L
.71823 .19571 L
.72099 .20601 L
.72376 .21631 L
.72652 .22661 L
.72928 .23691 L
.73204 .24721 L
.73481 .25751 L
.73757 .26781 L
.74033 .27812 L
.74309 .28842 L
.74586 .29872 L
.74862 .30902 L
.75138 .31932 L
.75414 .32962 L
.75691 .33992 L
.75967 .35022 L
.76243 .36052 L
.76519 .37082 L
.76796 .38112 L
.77072 .39142 L
.77348 .40172 L
.77624 .41202 L
.77901 .42232 L
.78177 .43262 L
.78453 .44292 L
.78729 .45322 L
.79006 .46353 L
.79282 .47383 L
.79558 .48413 L
.79834 .49443 L
.8011 .50473 L
.80387 .51503 L
.80663 .52533 L
.80939 .53563 L
.81215 .54593 L
.81492 .55623 L
.81768 .56653 L
.82044 .57683 L
.8232 .58713 L
.82597 .59743 L
.82873 .60773 L
Mistroke
.83149 .61803 L
.83425 .60773 L
.83702 .59743 L
.83978 .58713 L
.84254 .57683 L
.8453 .56653 L
.84807 .55623 L
.85083 .54593 L
.85359 .53563 L
.85635 .52533 L
.85912 .51503 L
.86188 .50473 L
.86464 .49443 L
.8674 .48413 L
.87017 .47383 L
.87293 .46353 L
.87569 .45322 L
.87845 .44292 L
.88122 .43262 L
.88398 .42232 L
.88674 .41202 L
.8895 .40172 L
.89227 .39142 L
.89503 .38112 L
.89779 .37082 L
.90055 .36052 L
.90331 .35022 L
.90608 .33992 L
.90884 .32962 L
.9116 .31932 L
.91436 .30902 L
.91713 .29872 L
.91989 .28842 L
.92265 .27812 L
.92541 .26781 L
.92818 .25751 L
.93094 .24721 L
.9337 .23691 L
.93646 .22661 L
.93923 .21631 L
.94199 .20601 L
.94475 .19571 L
.94751 .18541 L
.95028 .17511 L
.95304 .16481 L
.9558 .15451 L
.95856 .14421 L
.96133 .13391 L
.96409 .12361 L
.96685 .11331 L
Mistroke
.96961 .10301 L
.97238 .09271 L
.97514 .0824 L
.9779 .0721 L
.98066 .0618 L
.98343 .0515 L
.98619 .0412 L
.98895 .0309 L
.99171 .0206 L
.99448 .0103 L
.99724 0 L
Mfstroke
P
p
.8 1 0 r
.94491 Mabswid
.00276 0 m
.00552 0 L
.00829 0 L
.01105 0 L
.01381 0 L
.01657 0 L
.01934 0 L
.0221 0 L
.02486 0 L
.02762 0 L
.03039 0 L
.03315 0 L
.03591 0 L
.03867 0 L
.04144 0 L
.0442 0 L
.04696 0 L
.04972 0 L
.05249 0 L
.05525 0 L
.05801 0 L
.06077 0 L
.06354 0 L
.0663 0 L
.06906 0 L
.07182 0 L
.07459 0 L
.07735 0 L
.08011 0 L
.08287 0 L
.08564 0 L
.0884 0 L
.09116 0 L
.09392 0 L
.09669 0 L
.09945 0 L
.10221 0 L
.10497 0 L
.10773 0 L
.1105 0 L
.11326 0 L
.11602 0 L
.11878 0 L
.12155 0 L
.12431 0 L
.12707 0 L
.12983 0 L
.1326 0 L
.13536 0 L
.13812 0 L
Mistroke
.14088 0 L
.14365 0 L
.14641 0 L
.14917 0 L
.15193 0 L
.1547 0 L
.15746 0 L
.16022 0 L
.16298 0 L
.16575 0 L
.16851 0 L
.17127 0 L
.17403 0 L
.1768 0 L
.17956 0 L
.18232 0 L
.18508 0 L
.18785 0 L
.19061 0 L
.19337 0 L
.19613 0 L
.1989 0 L
.20166 0 L
.20442 0 L
.20718 0 L
.20994 0 L
.21271 0 L
.21547 0 L
.21823 0 L
.22099 0 L
.22376 0 L
.22652 0 L
.22928 0 L
.23204 0 L
.23481 0 L
.23757 0 L
.24033 0 L
.24309 0 L
.24586 0 L
.24862 0 L
.25138 0 L
.25414 0 L
.25691 0 L
.25967 0 L
.26243 0 L
.26519 0 L
.26796 0 L
.27072 0 L
.27348 0 L
.27624 0 L
Mistroke
.27901 0 L
.28177 0 L
.28453 0 L
.28729 0 L
.29006 0 L
.29282 0 L
.29558 0 L
.29834 0 L
.3011 0 L
.30387 0 L
.30663 0 L
.30939 0 L
.31215 0 L
.31492 0 L
.31768 0 L
.32044 0 L
.3232 0 L
.32597 0 L
.32873 0 L
.33149 0 L
.33425 0 L
.33702 0 L
.33978 0 L
.34254 0 L
.3453 0 L
.34807 0 L
.35083 0 L
.35359 0 L
.35635 0 L
.35912 0 L
.36188 0 L
.36464 0 L
.3674 0 L
.37017 0 L
.37293 0 L
.37569 0 L
.37845 0 L
.38122 0 L
.38398 0 L
.38674 0 L
.3895 0 L
.39227 0 L
.39503 0 L
.39779 0 L
.40055 0 L
.40331 0 L
.40608 0 L
.40884 0 L
.4116 0 L
.41436 0 L
Mistroke
.41713 0 L
.41989 0 L
.42265 0 L
.42541 0 L
.42818 0 L
.43094 0 L
.4337 0 L
.43646 0 L
.43923 0 L
.44199 0 L
.44475 0 L
.44751 0 L
.45028 0 L
.45304 0 L
.4558 0 L
.45856 0 L
.46133 0 L
.46409 0 L
.46685 0 L
.46961 0 L
.47238 0 L
.47514 0 L
.4779 0 L
.48066 0 L
.48343 0 L
.48619 0 L
.48895 0 L
.49171 0 L
.49448 0 L
.49724 0 L
.5 0 L
.50276 0 L
.50552 0 L
.50829 0 L
.51105 0 L
.51381 0 L
.51657 0 L
.51934 0 L
.5221 0 L
.52486 0 L
.52762 0 L
.53039 0 L
.53315 0 L
.53591 0 L
.53867 0 L
.54144 0 L
.5442 0 L
.54696 0 L
.54972 0 L
.55249 0 L
Mistroke
.55525 0 L
.55801 0 L
.56077 0 L
.56354 0 L
.5663 0 L
.56906 0 L
.57182 0 L
.57459 0 L
.57735 0 L
.58011 0 L
.58287 0 L
.58564 0 L
.5884 0 L
.59116 0 L
.59392 0 L
.59669 0 L
.59945 0 L
.60221 0 L
.60497 0 L
.60773 0 L
.6105 0 L
.61326 0 L
.61602 0 L
.61878 0 L
.62155 0 L
.62431 0 L
.62707 0 L
.62983 0 L
.6326 0 L
.63536 0 L
.63812 0 L
.64088 0 L
.64365 0 L
.64641 0 L
.64917 0 L
.65193 0 L
.6547 0 L
.65746 0 L
.66022 0 L
.66298 0 L
.66575 0 L
.66851 0 L
.67127 0 L
.67403 0 L
.6768 0 L
.67956 0 L
.68232 0 L
.68508 0 L
.68785 0 L
.69061 0 L
Mistroke
.69337 0 L
.69613 0 L
.6989 0 L
.70166 0 L
.70442 0 L
.70718 0 L
.70994 0 L
.71271 0 L
.71547 0 L
.71823 0 L
.72099 0 L
.72376 0 L
.72652 0 L
.72928 0 L
.73204 0 L
.73481 0 L
.73757 0 L
.74033 0 L
.74309 0 L
.74586 0 L
.74862 0 L
.75138 0 L
.75414 0 L
.75691 0 L
.75967 0 L
.76243 0 L
.76519 0 L
.76796 0 L
.77072 0 L
.77348 0 L
.77624 0 L
.77901 0 L
.78177 0 L
.78453 0 L
.78729 0 L
.79006 0 L
.79282 0 L
.79558 0 L
.79834 0 L
.8011 0 L
.80387 0 L
.80663 0 L
.80939 0 L
.81215 0 L
.81492 0 L
.81768 0 L
.82044 0 L
.8232 0 L
.82597 0 L
.82873 0 L
Mistroke
.83149 0 L
.83425 .0103 L
.83702 .0206 L
.83978 .0309 L
.84254 .0412 L
.8453 .0515 L
.84807 .0618 L
.85083 .0721 L
.85359 .0824 L
.85635 .09271 L
.85912 .10301 L
.86188 .11331 L
.86464 .12361 L
.8674 .13391 L
.87017 .14421 L
.87293 .15451 L
.87569 .16481 L
.87845 .17511 L
.88122 .18541 L
.88398 .19571 L
.88674 .20601 L
.8895 .21631 L
.89227 .22661 L
.89503 .23691 L
.89779 .24721 L
.90055 .25751 L
.90331 .26781 L
.90608 .27812 L
.90884 .28842 L
.9116 .29872 L
.91436 .30902 L
.91713 .31932 L
.91989 .32962 L
.92265 .33992 L
.92541 .35022 L
.92818 .36052 L
.93094 .37082 L
.9337 .38112 L
.93646 .39142 L
.93923 .40172 L
.94199 .41202 L
.94475 .42232 L
.94751 .43262 L
.95028 .44292 L
.95304 .45322 L
.9558 .46353 L
.95856 .47383 L
.96133 .48413 L
.96409 .49443 L
.96685 .50473 L
Mistroke
.96961 .51503 L
.97238 .52533 L
.97514 .53563 L
.9779 .54593 L
.98066 .55623 L
.98343 .56653 L
.98619 .57683 L
.98895 .58713 L
.99171 .59743 L
.99448 .60773 L
.99724 .61803 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Notice how we divided our two inputs into different numbers of membership \
functions. The choice for the number of membership functions used to define \
an input is entirely up to the designer. Notice also that the names of the \
membership functions are different. It is important that all of the input and \
output membership functions have distinct names for the inferencing to work \
correctly.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Outputs", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Again, we need to define a collection of output fuzzy sets. We define these \
just as we did the input, making sure that we use distinct names for the \
individual fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
TheOutput = {NB,NM,NS,ZE,PS,PM,PB} =
  CreateFuzzySets[7,UniversalSpace->{-30,30}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[TheOutput,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.016129 0 0.618034 [
[(-30)] .01613 0 0 2 Msboxa
[(-20)] .17742 0 0 2 Msboxa
[(-10)] .33871 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(10)] .66129 0 0 2 Msboxa
[(20)] .82258 0 0 2 Msboxa
[(30)] .98387 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.01613 0 m
.01613 .00625 L
s
P
[(-30)] .01613 0 0 2 Mshowa
p
.002 w
.17742 0 m
.17742 .00625 L
s
P
[(-20)] .17742 0 0 2 Mshowa
p
.002 w
.33871 0 m
.33871 .00625 L
s
P
[(-10)] .33871 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.66129 0 m
.66129 .00625 L
s
P
[(10)] .66129 0 0 2 Mshowa
p
.002 w
.82258 0 m
.82258 .00625 L
s
P
[(20)] .82258 0 0 2 Mshowa
p
.002 w
.98387 0 m
.98387 .00625 L
s
P
[(30)] .98387 0 0 2 Mshowa
p
.001 w
.04839 0 m
.04839 .00375 L
s
P
p
.001 w
.08065 0 m
.08065 .00375 L
s
P
p
.001 w
.1129 0 m
.1129 .00375 L
s
P
p
.001 w
.14516 0 m
.14516 .00375 L
s
P
p
.001 w
.20968 0 m
.20968 .00375 L
s
P
p
.001 w
.24194 0 m
.24194 .00375 L
s
P
p
.001 w
.27419 0 m
.27419 .00375 L
s
P
p
.001 w
.30645 0 m
.30645 .00375 L
s
P
p
.001 w
.37097 0 m
.37097 .00375 L
s
P
p
.001 w
.40323 0 m
.40323 .00375 L
s
P
p
.001 w
.43548 0 m
.43548 .00375 L
s
P
p
.001 w
.46774 0 m
.46774 .00375 L
s
P
p
.001 w
.53226 0 m
.53226 .00375 L
s
P
p
.001 w
.56452 0 m
.56452 .00375 L
s
P
p
.001 w
.59677 0 m
.59677 .00375 L
s
P
p
.001 w
.62903 0 m
.62903 .00375 L
s
P
p
.001 w
.69355 0 m
.69355 .00375 L
s
P
p
.001 w
.72581 0 m
.72581 .00375 L
s
P
p
.001 w
.75806 0 m
.75806 .00375 L
s
P
p
.001 w
.79032 0 m
.79032 .00375 L
s
P
p
.001 w
.85484 0 m
.85484 .00375 L
s
P
p
.001 w
.8871 0 m
.8871 .00375 L
s
P
p
.001 w
.91935 0 m
.91935 .00375 L
s
P
p
.001 w
.95161 0 m
.95161 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
.94491 Mabswid
.01613 .61803 m
.03226 .55623 L
.04839 .49443 L
.06452 .43262 L
.08065 .37082 L
.09677 .30902 L
.1129 .24721 L
.12903 .18541 L
.14516 .12361 L
.16129 .0618 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.2 0 1 r
.94491 Mabswid
.01613 0 m
.03226 .0618 L
.04839 .12361 L
.06452 .18541 L
.08065 .24721 L
.09677 .30902 L
.1129 .37082 L
.12903 .43262 L
.14516 .49443 L
.16129 .55623 L
.17742 .61803 L
.19355 .55623 L
.20968 .49443 L
.22581 .43262 L
.24194 .37082 L
.25806 .30902 L
.27419 .24721 L
.29032 .18541 L
.30645 .12361 L
.32258 .0618 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
0 1 .4 r
.94491 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 .0618 L
.20968 .12361 L
.22581 .18541 L
.24194 .24721 L
.25806 .30902 L
.27419 .37082 L
.29032 .43262 L
.30645 .49443 L
.32258 .55623 L
.33871 .61803 L
.35484 .55623 L
.37097 .49443 L
.3871 .43262 L
.40323 .37082 L
.41935 .30902 L
.43548 .24721 L
.45161 .18541 L
.46774 .12361 L
.48387 .0618 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
1 .6 0 r
.94491 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 .0618 L
.37097 .12361 L
.3871 .18541 L
.40323 .24721 L
.41935 .30902 L
.43548 .37082 L
.45161 .43262 L
.46774 .49443 L
.48387 .55623 L
.5 .61803 L
.51613 .55623 L
.53226 .49443 L
.54839 .43262 L
.56452 .37082 L
.58065 .30902 L
.59677 .24721 L
.6129 .18541 L
.62903 .12361 L
.64516 .0618 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
.8 0 1 r
.94491 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 .0618 L
.53226 .12361 L
.54839 .18541 L
.56452 .24721 L
.58065 .30902 L
.59677 .37082 L
.6129 .43262 L
.62903 .49443 L
.64516 .55623 L
.66129 .61803 L
.67742 .55623 L
.69355 .49443 L
.70968 .43262 L
.72581 .37082 L
.74194 .30902 L
.75806 .24721 L
.77419 .18541 L
.79032 .12361 L
.80645 .0618 L
Mistroke
.82258 0 L
.83871 0 L
.85484 0 L
.87097 0 L
.8871 0 L
.90323 0 L
.91935 0 L
.93548 0 L
.95161 0 L
.96774 0 L
.98387 0 L
Mfstroke
P
p
0 1 1 r
.94491 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 .0618 L
.69355 .12361 L
.70968 .18541 L
.72581 .24721 L
.74194 .30902 L
.75806 .37082 L
.77419 .43262 L
.79032 .49443 L
.80645 .55623 L
Mistroke
.82258 .61803 L
.83871 .55623 L
.85484 .49443 L
.87097 .43262 L
.8871 .37082 L
.90323 .30902 L
.91935 .24721 L
.93548 .18541 L
.95161 .12361 L
.96774 .0618 L
.98387 0 L
Mfstroke
P
p
.8 1 0 r
.94491 Mabswid
.01613 0 m
.03226 0 L
.04839 0 L
.06452 0 L
.08065 0 L
.09677 0 L
.1129 0 L
.12903 0 L
.14516 0 L
.16129 0 L
.17742 0 L
.19355 0 L
.20968 0 L
.22581 0 L
.24194 0 L
.25806 0 L
.27419 0 L
.29032 0 L
.30645 0 L
.32258 0 L
.33871 0 L
.35484 0 L
.37097 0 L
.3871 0 L
.40323 0 L
.41935 0 L
.43548 0 L
.45161 0 L
.46774 0 L
.48387 0 L
.5 0 L
.51613 0 L
.53226 0 L
.54839 0 L
.56452 0 L
.58065 0 L
.59677 0 L
.6129 0 L
.62903 0 L
.64516 0 L
.66129 0 L
.67742 0 L
.69355 0 L
.70968 0 L
.72581 0 L
.74194 0 L
.75806 0 L
.77419 0 L
.79032 0 L
.80645 0 L
Mistroke
.82258 0 L
.83871 .0618 L
.85484 .12361 L
.87097 .18541 L
.8871 .24721 L
.90323 .30902 L
.91935 .37082 L
.93548 .43262 L
.95161 .49443 L
.96774 .55623 L
.98387 .61803 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Defining Rules", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The final piece needed to perform a RuleBasedInference is a list of rules. \
The RuleBasedInference function expects the rules to be a list of triplets. \
The first two items in the triplet corresponds to the input conditions, and \
the third item corresponds to the output. Here we see an example.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ControlRules =
  {{LE,RB,PS},{LC,RB,PM},{CE,RB,PM},{RC,RB,PB},{RI,RB,PB},
   {LE,RU,NS},{LC,RU,PS},{CE,RU,PM},{RC,RU,PB},{RI,RU,PB},
   {LE,RV,NM},{LC,RV,NS},{CE,RV,PS},{RC,RV,PM},{RI,RV,PB},
   {LE,VE,NM},{LC,VE,NM},{CE,VE,ZE},{RC,VE,PM},{RI,VE,PM},
   {LE,LV,NB},{LC,LV,NM},{CE,LV,NS},{RC,LV,PS},{RI,LV,PM},
   {LE,LU,NB},{LC,LU,NB},{CE,LU,NM},{RC,LU,NS},{RI,LU,PS},
   {LE,LB,NB},{LC,LB,NB},{CE,LB,NM},{RC,LB,NM},{RI,LB,NS}};\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The list of rules we just created can again be interpreted as an if-then \
statement. For example, the first rule, {LE,RB,PS}, could be interpreted in \
the following manner.\
\>", "Text",
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 if the FirstInput is LE and the SecondInput is RB, then TheOutput  response \
should be PS.\
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The order of the inputs should be the same throughout the list because the \
order does matter when performing the fuzzy inference.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Inferencing", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
RuleBasedInference[{A1,..,An},{B1,..,Bn},{C1,..,Cn},
{{Ai,Bj,Ck},...},a,b] returns a fuzzy set which is the result of performing a \
rule based inference, where {A1,...,An} and {B1,...,Bn} represent the \
collections of input membership functions; {C1,...,Cn} represent the \
collection of output membership functions; the {Ai,Bj,Ck} triplets represent \
rules relating the two inputs to the one output; and a and b represent the \
crisp inputs. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For this example, we use the CenterOfArea defuzzification to come up with a \
crisp output. Here, crisp inputs are 30 and 210 give a crisp output of \
-143/6.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["\<\
CenterOfArea[
  RuleBasedInference[FirstInput,SecondInput,TheOutput,
  ControlRules,30,210]]\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[OutputFormData["\<\
-143/6








\
\>", "\<\
  143
-(---)
   6\
\>"], "Output",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell["\<\
The RuleBasedInference example shown in this section contains the \
specifications for a fuzzy logic controller which can be used to back a truck \
up to a loading dock. To see a complete simulation of the truck-backer \
example, see the FuzzyControl notebook.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{18, Automatic}, {23, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 83, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1845, 60, 67, 1, 70, "Subsection"],
Cell[1915, 63, 244, 5, 70, "Text"],
Cell[2162, 70, 143, 4, 70, "Text"],
Cell[2308, 76, 102, 2, 70, "Input"],
Cell[2413, 80, 304, 6, 70, "SmallText"],
Cell[2720, 88, 304, 6, 70, "Text"]
}, Open  ]],
Cell[3036, 96, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[3109, 99, 82, 1, 70, "Subsection"],
Cell[3194, 102, 528, 8, 70, "Text"],
Cell[3725, 112, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[3798, 115, 73, 1, 70, "Subsubsection"],
Cell[3874, 118, 569, 9, 70, "Text"],
Cell[4446, 129, 173, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[4642, 136, 107, 2, 70, "Input"],
Cell[4752, 140, 4051, 397, 70, 3893, 392, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[8815, 539, 278, 5, 70, "Text"]
}, Open  ]],
Cell[9105, 546, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[9178, 549, 74, 1, 70, "Subsubsection"],
Cell[9255, 552, 269, 5, 70, "Text"],
Cell[9527, 559, 175, 6, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[9725, 567, 108, 2, 70, "Input"],
Cell[9836, 571, 4742, 439, 70, 4584, 434, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[14599, 1012, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[14672, 1015, 72, 1, 70, "Subsubsection"],
Cell[14747, 1018, 470, 8, 70, "Text"],
Cell[15220, 1028, 148, 5, 70, "Input"],
Cell[15371, 1035, 183, 4, 70, "Text"],
Cell[15557, 1041, 148, 4, 70, "Special2"],
Cell[15708, 1047, 213, 5, 70, "Text"]
}, Open  ]],
Cell[15933, 1054, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[16006, 1057, 76, 1, 70, "Subsubsection"],
Cell[16085, 1060, 605, 10, 70, "Text"],
Cell[16693, 1072, 107, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[16823, 1076, 102, 2, 70, "Input"],
Cell[16928, 1080, 44979, 3980, 70, 44821, 3975, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[61919, 5062, 188, 4, 70, "Text"]
}, Open  ]],
Cell[62119, 5068, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[62192, 5071, 69, 1, 70, "Subsubsection"],
Cell[62264, 5074, 359, 6, 70, "Text"],

Cell[CellGroupData[{
Cell[62646, 5082, 143, 5, 70, "Input"],
Cell[62792, 5089, 309, 17, 70, "Output"]
}, Open  ]],
Cell[63113, 5108, 157, 4, 70, "Text"],
Cell[63273, 5114, 356, 6, 70, "Text"],
Cell[63632, 5122, 167, 4, 70, "Text"],

Cell[CellGroupData[{
Cell[63822, 5128, 143, 5, 70, "Input"],
Cell[63968, 5135, 123, 15, 70, "Output"]
}, Open  ]],
Cell[64103, 5152, 167, 4, 70, "Text"]
}, Open  ]]
}, Open  ]],
Cell[64291, 5158, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[64364, 5161, 75, 1, 70, "Subsection"],
Cell[64442, 5164, 263, 5, 70, "Text"],
Cell[64708, 5171, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[64781, 5174, 73, 1, 70, "Subsubsection"],
Cell[64857, 5177, 418, 7, 70, "Text"],
Cell[65278, 5186, 182, 6, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[65483, 5194, 112, 2, 70, "Input"],
Cell[65598, 5198, 10329, 929, 70, 10171, 924, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[75939, 6129, 167, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[76129, 6136, 113, 2, 70, "Input"],
Cell[76245, 6140, 35770, 3068, 70, 35612, 3063, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[112027, 9210, 456, 8, 70, "Text"]
}, Open  ]],
Cell[112495, 9220, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[112568, 9223, 74, 1, 70, "Subsubsection"],
Cell[112645, 9226, 232, 5, 70, "Text"],
Cell[112880, 9233, 164, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[113067, 9240, 111, 2, 70, "Input"],
Cell[113181, 9244, 9343, 890, 70, 9185, 885, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[122545, 10136, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[122618, 10139, 72, 1, 70, "Subsubsection"],
Cell[122693, 10142, 355, 6, 70, "Text"],
Cell[123051, 10150, 509, 11, 70, "Input"],
Cell[123563, 10163, 255, 6, 70, "Text",
  PageBreakAbove->True],
Cell[123821, 10171, 153, 4, 70, "Special2"],
Cell[123977, 10177, 188, 4, 70, "Text"]
}, Open  ]],
Cell[124177, 10183, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[124250, 10186, 69, 1, 70, "Subsubsection"],
Cell[124322, 10189, 503, 9, 70, "Text"],
Cell[124828, 10200, 215, 5, 70, "Text"],

Cell[CellGroupData[{
Cell[125066, 10207, 173, 6, 70, "Input"],
Cell[125242, 10215, 142, 17, 70, "Output"]
}, Open  ]],
Cell[125396, 10234, 317, 6, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
