(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     17897,        504]*)
(*NotebookOutlinePosition[     18767,        536]*)
(*  CellTagsIndexPosition[     18723,        532]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Fuzzy Logic Pack
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack is a collection of notebooks and packages which are \
designed to introduce fuzzy set theory and fuzzy logic in the Mathematica \
environment. The packages provided in this pack combined with Mathematica's \
standard packages provide a powerful tool for studying fuzzy logic and for \
developing fuzzy applications. The notebooks provided with this package \
demonstrate how the various fuzzy logic functions are used, and they contain \
many worked examples showing how this package can be used in real-world \
applications.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Basic familiarity with Mathematica is assumed for use of the Fuzzy Logic \
Pack. For more information on Mathematica, see below or contact Wolfram \
Research, Inc.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["The Manual", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The manual is a collection of Mathematica notebooks that show the \
capabilities of the Fuzzy Logic Pack and demonstrate the use of all of the \
functions. Notebooks are interactive documents combining Mathematica input \
and output, text, and graphics. The materials for the manual come from a wide \
variety of sources; many of the examples are from works listed in the \
Z_Bibliography.ma notebook. Following is a brief description of the types of \
examples that can be found in each of the notebooks in the manual.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
QuickReference.ma
Serves as an introduction and reference guide for the Fuzzy Logic Pack, \
containing definitions for all functions in the pack and examples of how to \
use each function. \
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
A_CreateFuzzySets.ma
Demonstrates the functions used to create fuzzy sets and options associated \
with each of the functions.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
B_CreateFuzzyRelations.ma
Demonstrates the functions used to create fuzzy relations and the options \
associated with each of these functions. \
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
C_FuzzyOperations.ma
Contains examples of different operations that can be applied to fuzzy sets, \
fuzzy relations, or both.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
D_FuzzyAggregators.ma
Contains examples of the various package functions for combining two or more \
fuzzy sets or fuzzy relations, including a full range of t-norm \
(intersection), s-norm (union), and averaging operators. Both standard and \
nonstandard operators are included.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
E_ViewFuzzySets.ma
Demonstrates the various ways to view fuzzy sets in this package, including a \
variety plotting methods.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
F_ViewFuzzyRelations.ma
Demonstrates the various ways to view fuzzy relations in this package, \
including different plot styles and membership matrices.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
G_Compositions.ma
Shows how to perform a composition between two fuzzy relations. \
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
H_FuzzyInference.ma
Shows how to perform fuzzy inferences and demonstrates some applications of \
fuzzy inferencing for modeling and control.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
I_FuzzyArithmetic.ma
Shows how to apply fuzzy arithmetic operations to fuzzy numbers. These \
functions are used only with triangular or trapezoidal fuzzy numbers. \
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
J_DiscreteFuzzyArithmetic.ma
Contains examples demonstrating the use of the discrete fuzzy arithmetic \
operations. These arithmetic operations work on any fuzzy sets or fuzzy \
numbers.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
X_Appendix.ma
Contains a partial list of the formulas for the various operations in the \
Fuzzy Logic Pack.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["The Notebooks", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The notebooks contained in the pack consist of worked examples of various \
fuzzy topics that can be studied using the Fuzzy Logic Pack. If you are just \
learning fuzzy sets, the first three notebooks are a good place to start. \
These notebooks contain information about fuzzy concepts and the mathematics \
behind fuzzy sets. Following is a list describing all of the Fuzzy Logic \
notebooks.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
1_SetVersusFuzzySet.ma
Contains an introduction to fuzzy sets and compares and contrasts fuzzy sets \
with traditional sets.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
2_StandardOperations.ma
Contains examples which demonstrate the use of the various operations which \
can be performed on fuzzy sets.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
3_FuzzyRelations.ma 
Introduces fuzzy relations and gives examples of creating, operating on, and \
using fuzzy relations.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
4_FuzzyModeling.ma
Demonstrates how fuzzy sets and fuzzy relations can be used in real-world \
process modeling.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
5_FuzzyControl.ma
Introduces fuzzy logic control. This notebook contains a truck-backing \
control example and a step-by-step description of the design process.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
 6_FuzzyArithmetic.ma
Contains an introduction to fuzzy numbers and fuzzy arithmetic, as well as a \
number of examples demonstrating the use of fuzzy arithmetic.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
7_Examples.ma
Describes a wide variety of practical situations in which fuzzy sets and \
fuzzy logic can be applied. Examples in this notebook are presented in a \
problem-solution format.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
8_Bibliography.ma
Contains a list of the references used to create this package. These \
references are sources of further examples and information about fuzzy \
sets.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["The Packages", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Mathematica packages are files written in the Mathematica programming \
language. They contain Mathematica definitions that extend Mathematica's \
capabilities in a particular area. The packages contained in the Fuzzy Logic \
Pack contain definitions that allow Mathematica to work with fuzzy sets and \
fuzzy relations. We attempted in the packages to adhere to the conventions of \
good Mathematica programming, so the packages can be used as models for your \
own algorithms. The Fuzzy Logic notebooks make use of the definitions \
contained in the packages. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The packages are found in several files, all of which can be accessed by \
loading the FuzzyLogic`Master` file. Following is a list briefly describing \
the definitions which are contained in each package. The list is provided to \
allow the user to view the code for a particular routine or group of \
routines. In addition to the packages, a manual is included with the code. \
The manual is a notebook that can be used either as an introduction to the \
functions in this pack or as a quick reference to look up function names and \
uses.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Common`
Contains definitions that are used within one or more other packages. It \
contains the code that defines fuzzy sets and fuzzy relations.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Creation`
Contains definitions that can be used to create fuzzy sets and fuzzy \
relations.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`SetToValue`
Contains definitions that take fuzzy sets or relations as arguments and \
return a single value as output.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`SetToList`
Contains functions that take fuzzy sets or fuzzy relations as inputs and \
return a list of items as ouput.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`SetToSet`
Contains programs that take fuzzy sets or fuzzy relations as arguments and \
return new fuzzy sets or fuzzy relations.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Aggregate`
Contains definitions that can be used to aggregate two or more fuzzy sets or \
fuzzy relations. Definitions of intersections and unions can be found here.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Average`
Contains functions that average two or more fuzzy sets or fuzzy relations.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Visual`
Contains functions to display fuzzy sets or fuzzy relations visually. \
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Composition`
Contains functions that perform the composition of fuzzy relations.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Arithmetic`
Contains the definitions for performing fuzzy arithmetic with fuzzy \
numbers.\
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
FuzzyLogic`Inference`
Contains the fuzzy logic inferencing functions that are used for fuzzy logic \
control and modeling. \
\>", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Loading the Pack", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
After starting a Mathematica session, the proper functions must be loaded \
from the Fuzzy Logic Pack. There are a number of ways to do this.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The most convenient way to do this is to load the subpackage \
FuzzyLogic`Master`. This can be done with the following command.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"] ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
After entering the command above, all of the functions from the Fuzzy Logic \
Pack will be available. The subpackages containing the function will be \
automatically loaded when needed.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Get command can be used instead of the Needs command, but if the package \
is already loaded and you try to reload it with the Get command, you may see \
some error messages. For this reason, we recommend using the Needs command. \
If you want to use the Get command, you can replace the word Needs with Get, \
or you can type the following.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["<<FuzzyLogic`Master`", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If you know beforehand that you will only be using the functions from a \
specific package, you can load only that particular package by using the \
Needs command and specifying the package. For instance, the following command \
is used to load the FuzzyLogic`Visual` package.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Visual`\"]", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Getting More Information about Mathematica", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
For information on standard Mathematica operations and packages or for \
general Mathematica information, Mathematica: A System for Doing Mathematics \
by Computer, Second Edition, by Stephen Wolfram is the definitive reference. \
There are a number of books that describe programming in the Mathematica \
language; we found Roman Maeder's programming books to be very helpful. In \
addition to these resources, there are many additional books and magazines \
out which are dedicated to providing information about Mathematica. For a \
list of resources or for further information regarding Mathematica, contact \
Wolfram Research, Inc. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Getting More Information about Fuzzy Sets", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
There are a large number of good publications about fuzzy sets and fuzzy \
logic on the market. The sources we used to create this pack are listed in \
the Z_Bibliography notebook in the Notebooks folder. We recommend looking at \
these sources to provide a better understanding of fuzzy concepts and to get \
ideas for different applications. A partial list of the formulas used in this \
package is provided in the X_Appendix notebook (in the Notebooks folder). \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Acknowledgments", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We would like to thank the following people, who have been of great \
assistance during the development of the Fuzzy Logic Pack. Thanks to Wolfram \
Research, Inc., and in particular to Dr. Leszek Sczaniecki and John Novak, \
for helping us develop this pack. Thanks to Maria E. Kochanska, who wrote a \
special package in Basic for graphical interpretation of fuzzy sets and its \
operations in 1982. We are grateful to Pawel P. Stachowicz for his fabulous \
\"Fuzzy as Hell-1989\" and Robert Walker for his \"Ann-1992\" programs \
written for fuzzy modeling. A special thanks to Jonathan Andersh, who wrote \
the educational version of the program. Thanks to Sister Maria Magdalena for \
helping with proofreading. Thanks to all the members of the Laboratory for \
Intelligent Systems at the University of Minnesota, Duluth for their helpful \
comments. Finally, we would like to thank Dr. Stachowicz's Fall quarter 1994 \
Fuzzy Set Theory and Its Applications class and students Guangji Shi, Mark \
Sholund, and Dan Yao, who used this package for homework assignments and \
provided useful comments.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["About the Authors", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Marian S. Stachowicz is professor and Jack Rowe chair at the University of \
Minnesota in Duluth. He heads the Laboratory for Intelligent Systems at the \
Electrical and Computer Engineering Department. He received his M.S. degree \
in Control and Computer Engineering from LETI in Leningrad and both his Ph.D. \
and D.S. from AGH in Cracow. His work centers on system theory, the fuzzy set \
theory, and their applications. Dr. Stachowicz received two awards from the \
Polish Ministry of Higher Education and Science for the introduction of the \
digital fuzzy sets into the fuzzy set theory that has facilitated \
applications of the fuzzy set theory to computer engineering. He is a member \
of the North American Fuzzy Information Processing Society, a member of the \
International Fuzzy Systems Associations, and Senior Member of IEEE.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Lance E. Beall has a Bachelor of Computer Engineering degree from the \
University of Minnesota, where he graduated summa cum laude. Lance spent the \
summer of 1994 working with Wolfram Research, Inc. to develop this package. \
He is currently an employee of the University of Minnesota and does contract \
research for Soft Control, Inc.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{91, Automatic}, {23, Automatic}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 82, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1844, 60, 67, 1, 70, "Subsection"],
Cell[1914, 63, 603, 10, 70, "Text"],
Cell[2520, 75, 220, 5, 70, "Text"]
}, Open  ]],
Cell[2752, 82, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[2825, 85, 65, 1, 70, "Subsection"],
Cell[2893, 88, 576, 9, 70, "Text"],
Cell[3472, 99, 250, 6, 70, "Special1"],
Cell[3725, 107, 187, 5, 70, "Special1"],
Cell[3915, 114, 204, 5, 70, "Special1"],
Cell[4122, 121, 186, 5, 70, "Special1"],
Cell[4311, 128, 340, 7, 70, "Special1"],
Cell[4654, 137, 185, 5, 70, "Special1"],
Cell[4842, 144, 214, 5, 70, "Special1"],
Cell[5059, 151, 143, 4, 70, "Special1"],
Cell[5205, 157, 202, 5, 70, "Special1"],
Cell[5410, 164, 225, 5, 70, "Special1"],
Cell[5638, 171, 247, 6, 70, "Special1"],
Cell[5888, 179, 168, 5, 70, "Special1"]
}, Open  ]],
Cell[6068, 186, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[6141, 189, 68, 1, 70, "Subsection"],
Cell[6212, 192, 452, 8, 70, "Text"],
Cell[6667, 202, 185, 5, 70, "Special1"],
Cell[6855, 209, 194, 5, 70, "Special1"],
Cell[7052, 216, 183, 5, 70, "Special1"],
Cell[7238, 223, 173, 5, 70, "Special1"],
Cell[7414, 230, 221, 5, 70, "Special1"],
Cell[7638, 237, 223, 5, 70, "Special1"],
Cell[7864, 244, 249, 6, 70, "Special1"],
Cell[8116, 252, 228, 6, 70, "Special1"]
}, Open  ]],
Cell[8356, 260, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[8429, 263, 67, 1, 70, "Subsection"],
Cell[8499, 266, 619, 10, 70, "Text"],
Cell[9121, 278, 598, 10, 70, "Text"],
Cell[9722, 290, 217, 5, 70, "Special1"],
Cell[9942, 297, 163, 5, 70, "Special1"],
Cell[10108, 304, 190, 5, 70, "Special1"],
Cell[10301, 311, 190, 5, 70, "Special1"],
Cell[10494, 318, 200, 5, 70, "Special1"],
Cell[10697, 325, 237, 5, 70, "Special1"],
Cell[10937, 332, 155, 4, 70, "Special1"],
Cell[11095, 338, 150, 4, 70, "Special1"],
Cell[11248, 344, 152, 4, 70, "Special1"],
Cell[11403, 350, 162, 5, 70, "Special1"],
Cell[11568, 357, 184, 5, 70, "Special1"]
}, Open  ]],
Cell[11764, 364, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[11837, 367, 71, 1, 70, "Subsection"],
Cell[11911, 370, 198, 4, 70, "Text"],
Cell[12112, 376, 184, 4, 70, "Text"],
Cell[12299, 382, 79, 1, 70, "Text"],
Cell[12381, 385, 242, 5, 70, "Text"],
Cell[12626, 392, 402, 7, 70, "Text"],
Cell[13031, 401, 69, 1, 70, "Text"],
Cell[13103, 404, 333, 6, 70, "Text"],
Cell[13439, 412, 78, 1, 70, "Text"]
}, Open  ]],
Cell[13529, 415, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[13602, 418, 97, 1, 70, "Subsection"],
Cell[13702, 421, 694, 11, 70, "Text"]
}, Open  ]],
Cell[14408, 434, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[14481, 437, 96, 1, 70, "Subsection"],
Cell[14580, 440, 521, 8, 70, "Text"]
}, Open  ]],
Cell[15113, 450, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[15186, 453, 70, 1, 70, "Subsection"],
Cell[15259, 456, 1159, 17, 70, "Text"]
}, Open  ]],
Cell[16430, 475, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[16503, 478, 72, 1, 70, "Subsection"],
Cell[16578, 481, 899, 13, 70, "Text"],
Cell[17480, 496, 396, 7, 70, "Text"]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
