(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    136852,      15146]*)
(*NotebookOutlinePosition[    137722,      15178]*)
(*  CellTagsIndexPosition[    137678,      15174]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Discrete Fuzzy Arithmetic
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Introduction", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The Fuzzy Logic Pack provides a number of functions for performing fuzzy \
arithmetic. In this chapter, we will demonstrate these functions and the \
options associated with each function. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
First we need to load the proper routines. This is done with the following \
command. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Needs[\"FuzzyLogic`Master`\"]", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
If the package loading command fails, verify that the directory containing \
the Fuzzy Logic directory is on Mathematica's $Path. You can use the command \
AppendTo[$Path, \"directory\"]. For convenience, this should be in your \
init.m file.\
\>", "SmallText",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
In this package, all of the fuzzy sets are defined in the integer space. This \
enables us to perform some quick, discrete fuzzy arithmetic operations on \
fuzzy sets. In this chapter, we examine a couple of arithmetic operations \
which are well-defined in real space and compare the discrete results with \
the real space results.

To begin, we must create some fuzzy sets to work with. We will do this later, \
but first let us extend the default universal space so we have more room to \
work with. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["SetOptions[FuzzySet, UniversalSpace->{-40,40}];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
When working with the fuzzy arithmetic operations in this package, it is \
important to choose a proper universal space. The universal space should \
range from a negative value to the corresponding positive value. This is \
because fuzzy arithmetic operations often involve working with the image of \
the fuzzy set, a fuzzy set flipped around zero. 

Another consideration is that the result of an arithmetic operation should be \
contained in the same universal space as the numbers which are used in the \
calculation. By choosing a large universal space, you can ensure that the \
results will fall in the universal space, but the calculations can take \
longer, and the graphs may be difficult to read. A general rule for setting \
the universal space is to find the smallest universal space which is still \
big enough to represent all possible results.

Now, we create some fuzzy sets. The first two fuzzy sets we create are \
triangular fuzzy sets and the second two are Gaussian fuzzy sets. These two \
types of fuzzy sets are both commonly used to represent fuzzy numbers. For \
more information on creating fuzzy sets see the chapter on creating fuzzy \
sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["TriFS1 = FuzzyTrapezoid[1,5,5,9];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["TriFS2 = FuzzyTrapezoid[4,10,10,16];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["GausFS3 = FuzzyGaussian[5,3];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["GausFS4 = FuzzyGaussian[9,5];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We use the FuzzyPlot function to see what our initial fuzzy sets look like.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[TriFS1,TriFS2,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 0 L
.35366 0 L
.36585 0 L
.37805 0 L
.39024 0 L
.40244 0 L
.41463 0 L
.42683 0 L
.43902 0 L
.45122 0 L
.46341 0 L
.47561 0 L
.4878 0 L
.5 0 L
.5122 0 L
.52439 .15451 L
.53659 .30902 L
.54878 .46353 L
.56098 .61803 L
.57317 .46353 L
.58537 .30902 L
.59756 .15451 L
.60976 0 L
Mistroke
.62195 0 L
.63415 0 L
.64634 0 L
.65854 0 L
.67073 0 L
.68293 0 L
.69512 0 L
.70732 0 L
.71951 0 L
.73171 0 L
.7439 0 L
.7561 0 L
.76829 0 L
.78049 0 L
.79268 0 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 0 L
.35366 0 L
.36585 0 L
.37805 0 L
.39024 0 L
.40244 0 L
.41463 0 L
.42683 0 L
.43902 0 L
.45122 0 L
.46341 0 L
.47561 0 L
.4878 0 L
.5 0 L
.5122 0 L
.52439 0 L
.53659 0 L
.54878 0 L
.56098 .10301 L
.57317 .20601 L
.58537 .30902 L
.59756 .41202 L
.60976 .51503 L
Mistroke
.62195 .61803 L
.63415 .51503 L
.64634 .41202 L
.65854 .30902 L
.67073 .20601 L
.68293 .10301 L
.69512 0 L
.70732 0 L
.71951 0 L
.73171 0 L
.7439 0 L
.7561 0 L
.76829 0 L
.78049 0 L
.79268 0 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell[CellGroupData[{Cell["FuzzyPlot[GausFS3,GausFS4,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 0 L
.35366 0 L
.36585 0 L
.37805 0 L
.39024 0 L
.40244 0 L
.41463 0 L
.42683 0 L
.43902 1e-05 L
.45122 8e-05 L
.46341 .0005 L
.47561 .00267 L
.4878 .01132 L
.5 .03843 L
.5122 .10446 L
.52439 .22736 L
.53659 .39627 L
.54878 .55304 L
.56098 .61803 L
.57317 .55304 L
.58537 .39627 L
.59756 .22736 L
.60976 .10446 L
Mistroke
.62195 .03843 L
.63415 .01132 L
.64634 .00267 L
.65854 .0005 L
.67073 8e-05 L
.68293 1e-05 L
.69512 0 L
.70732 0 L
.71951 0 L
.73171 0 L
.7439 0 L
.7561 0 L
.76829 0 L
.78049 0 L
.79268 0 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 0 L
.35366 0 L
.36585 0 L
.37805 0 L
.39024 0 L
.40244 1e-05 L
.41463 2e-05 L
.42683 8e-05 L
.43902 .00024 L
.45122 .00072 L
.46341 .00195 L
.47561 .00489 L
.4878 .01132 L
.5 .0242 L
.5122 .04778 L
.52439 .08706 L
.53659 .14643 L
.54878 .22736 L
.56098 .32588 L
.57317 .43119 L
.58537 .52665 L
.59756 .5938 L
.60976 .61803 L
Mistroke
.62195 .5938 L
.63415 .52665 L
.64634 .43119 L
.65854 .32588 L
.67073 .22736 L
.68293 .14643 L
.69512 .08706 L
.70732 .04778 L
.71951 .0242 L
.73171 .01132 L
.7439 .00489 L
.7561 .00195 L
.76829 .00072 L
.78049 .00024 L
.79268 8e-05 L
.80488 2e-05 L
.81707 1e-05 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Discrete Arithmetic on Triangular Fuzzy Numbers", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As mentioned earlier, triangular fuzzy sets are common representations of \
fuzzy numbers. Triangular fuzzy numbers are convenient to work with because \
in real space, adding two triangular fuzzy numbers involves adding the \
corresponding vertices used to define the triangular fuzzy numbers. Similar \
simple formulas can be used to subtract or find the image of triangular fuzzy \
numbers. Because of these properties, we demonstrate the discrete arithmetic \
operations with triangular fuzzy numbers and compare the results with the \
expected results if the fuzzy sets were defined in real space. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Addition", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyPlus[A,B] returns a fuzzy set that is the result of applying \
fuzzy addition to fuzzy sets A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["We add our first two fuzzy sets and plot the results.", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Sum1 = DiscreteFuzzyPlus[TriFS1,TriFS2];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[TriFS1,TriFS2,Sum1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
.83333 Mabswid
.0122 0 m
.0122 0 L
s
P
p
.83333 Mabswid
.02439 0 m
.02439 0 L
s
P
p
.83333 Mabswid
.03659 0 m
.03659 0 L
s
P
p
.83333 Mabswid
.04878 0 m
.04878 0 L
s
P
p
.83333 Mabswid
.06098 0 m
.06098 0 L
s
P
p
.83333 Mabswid
.07317 0 m
.07317 0 L
s
P
p
.83333 Mabswid
.08537 0 m
.08537 0 L
s
P
p
.83333 Mabswid
.09756 0 m
.09756 0 L
s
P
p
.83333 Mabswid
.10976 0 m
.10976 0 L
s
P
p
.83333 Mabswid
.12195 0 m
.12195 0 L
s
P
p
.83333 Mabswid
.13415 0 m
.13415 0 L
s
P
p
.83333 Mabswid
.14634 0 m
.14634 0 L
s
P
p
.83333 Mabswid
.15854 0 m
.15854 0 L
s
P
p
.83333 Mabswid
.17073 0 m
.17073 0 L
s
P
p
.83333 Mabswid
.18293 0 m
.18293 0 L
s
P
p
.83333 Mabswid
.19512 0 m
.19512 0 L
s
P
p
.83333 Mabswid
.20732 0 m
.20732 0 L
s
P
p
.83333 Mabswid
.21951 0 m
.21951 0 L
s
P
p
.83333 Mabswid
.23171 0 m
.23171 0 L
s
P
p
.83333 Mabswid
.2439 0 m
.2439 0 L
s
P
p
.83333 Mabswid
.2561 0 m
.2561 0 L
s
P
p
.83333 Mabswid
.26829 0 m
.26829 0 L
s
P
p
.83333 Mabswid
.28049 0 m
.28049 0 L
s
P
p
.83333 Mabswid
.29268 0 m
.29268 0 L
s
P
p
.83333 Mabswid
.30488 0 m
.30488 0 L
s
P
p
.83333 Mabswid
.31707 0 m
.31707 0 L
s
P
p
.83333 Mabswid
.32927 0 m
.32927 0 L
s
P
p
.83333 Mabswid
.34146 0 m
.34146 0 L
s
P
p
.83333 Mabswid
.35366 0 m
.35366 0 L
s
P
p
.83333 Mabswid
.36585 0 m
.36585 0 L
s
P
p
.83333 Mabswid
.37805 0 m
.37805 0 L
s
P
p
.83333 Mabswid
.39024 0 m
.39024 0 L
s
P
p
.83333 Mabswid
.40244 0 m
.40244 0 L
s
P
p
.83333 Mabswid
.41463 0 m
.41463 0 L
s
P
p
.83333 Mabswid
.42683 0 m
.42683 0 L
s
P
p
.83333 Mabswid
.43902 0 m
.43902 0 L
s
P
p
.83333 Mabswid
.45122 0 m
.45122 0 L
s
P
p
.83333 Mabswid
.46341 0 m
.46341 0 L
s
P
p
.83333 Mabswid
.47561 0 m
.47561 0 L
s
P
p
.83333 Mabswid
.4878 0 m
.4878 0 L
s
P
p
.83333 Mabswid
.5 0 m
.5 0 L
s
P
p
.83333 Mabswid
.5122 0 m
.5122 0 L
s
P
p
.83333 Mabswid
.52439 .15451 m
.52439 0 L
s
P
p
.83333 Mabswid
.53659 .30902 m
.53659 0 L
s
P
p
.83333 Mabswid
.54878 .46353 m
.54878 0 L
s
P
p
.83333 Mabswid
.56098 .61803 m
.56098 0 L
s
P
p
.83333 Mabswid
.57317 .46353 m
.57317 0 L
s
P
p
.83333 Mabswid
.58537 .30902 m
.58537 0 L
s
P
p
.83333 Mabswid
.59756 .15451 m
.59756 0 L
s
P
p
.83333 Mabswid
.60976 0 m
.60976 0 L
s
P
p
.83333 Mabswid
.62195 0 m
.62195 0 L
s
P
p
.83333 Mabswid
.63415 0 m
.63415 0 L
s
P
p
.83333 Mabswid
.64634 0 m
.64634 0 L
s
P
p
.83333 Mabswid
.65854 0 m
.65854 0 L
s
P
p
.83333 Mabswid
.67073 0 m
.67073 0 L
s
P
p
.83333 Mabswid
.68293 0 m
.68293 0 L
s
P
p
.83333 Mabswid
.69512 0 m
.69512 0 L
s
P
p
.83333 Mabswid
.70732 0 m
.70732 0 L
s
P
p
.83333 Mabswid
.71951 0 m
.71951 0 L
s
P
p
.83333 Mabswid
.73171 0 m
.73171 0 L
s
P
p
.83333 Mabswid
.7439 0 m
.7439 0 L
s
P
p
.83333 Mabswid
.7561 0 m
.7561 0 L
s
P
p
.83333 Mabswid
.76829 0 m
.76829 0 L
s
P
p
.83333 Mabswid
.78049 0 m
.78049 0 L
s
P
p
.83333 Mabswid
.79268 0 m
.79268 0 L
s
P
p
.83333 Mabswid
.80488 0 m
.80488 0 L
s
P
p
.83333 Mabswid
.81707 0 m
.81707 0 L
s
P
p
.83333 Mabswid
.82927 0 m
.82927 0 L
s
P
p
.83333 Mabswid
.84146 0 m
.84146 0 L
s
P
p
.83333 Mabswid
.85366 0 m
.85366 0 L
s
P
p
.83333 Mabswid
.86585 0 m
.86585 0 L
s
P
p
.83333 Mabswid
.87805 0 m
.87805 0 L
s
P
p
.83333 Mabswid
.89024 0 m
.89024 0 L
s
P
p
.83333 Mabswid
.90244 0 m
.90244 0 L
s
P
p
.83333 Mabswid
.91463 0 m
.91463 0 L
s
P
p
.83333 Mabswid
.92683 0 m
.92683 0 L
s
P
p
.83333 Mabswid
.93902 0 m
.93902 0 L
s
P
p
.83333 Mabswid
.95122 0 m
.95122 0 L
s
P
p
.83333 Mabswid
.96341 0 m
.96341 0 L
s
P
p
.83333 Mabswid
.97561 0 m
.97561 0 L
s
P
p
.83333 Mabswid
.9878 0 m
.9878 0 L
s
P
P
P
p
.2 0 1 r
p
p
.83333 Mabswid
.01491 0 m
.01491 0 L
s
P
p
.83333 Mabswid
.0271 0 m
.0271 0 L
s
P
p
.83333 Mabswid
.0393 0 m
.0393 0 L
s
P
p
.83333 Mabswid
.05149 0 m
.05149 0 L
s
P
p
.83333 Mabswid
.06369 0 m
.06369 0 L
s
P
p
.83333 Mabswid
.07588 0 m
.07588 0 L
s
P
p
.83333 Mabswid
.08808 0 m
.08808 0 L
s
P
p
.83333 Mabswid
.10027 0 m
.10027 0 L
s
P
p
.83333 Mabswid
.11247 0 m
.11247 0 L
s
P
p
.83333 Mabswid
.12466 0 m
.12466 0 L
s
P
p
.83333 Mabswid
.13686 0 m
.13686 0 L
s
P
p
.83333 Mabswid
.14905 0 m
.14905 0 L
s
P
p
.83333 Mabswid
.16125 0 m
.16125 0 L
s
P
p
.83333 Mabswid
.17344 0 m
.17344 0 L
s
P
p
.83333 Mabswid
.18564 0 m
.18564 0 L
s
P
p
.83333 Mabswid
.19783 0 m
.19783 0 L
s
P
p
.83333 Mabswid
.21003 0 m
.21003 0 L
s
P
p
.83333 Mabswid
.22222 0 m
.22222 0 L
s
P
p
.83333 Mabswid
.23442 0 m
.23442 0 L
s
P
p
.83333 Mabswid
.24661 0 m
.24661 0 L
s
P
p
.83333 Mabswid
.25881 0 m
.25881 0 L
s
P
p
.83333 Mabswid
.271 0 m
.271 0 L
s
P
p
.83333 Mabswid
.2832 0 m
.2832 0 L
s
P
p
.83333 Mabswid
.29539 0 m
.29539 0 L
s
P
p
.83333 Mabswid
.30759 0 m
.30759 0 L
s
P
p
.83333 Mabswid
.31978 0 m
.31978 0 L
s
P
p
.83333 Mabswid
.33198 0 m
.33198 0 L
s
P
p
.83333 Mabswid
.34417 0 m
.34417 0 L
s
P
p
.83333 Mabswid
.35637 0 m
.35637 0 L
s
P
p
.83333 Mabswid
.36856 0 m
.36856 0 L
s
P
p
.83333 Mabswid
.38076 0 m
.38076 0 L
s
P
p
.83333 Mabswid
.39295 0 m
.39295 0 L
s
P
p
.83333 Mabswid
.40515 0 m
.40515 0 L
s
P
p
.83333 Mabswid
.41734 0 m
.41734 0 L
s
P
p
.83333 Mabswid
.42954 0 m
.42954 0 L
s
P
p
.83333 Mabswid
.44173 0 m
.44173 0 L
s
P
p
.83333 Mabswid
.45393 0 m
.45393 0 L
s
P
p
.83333 Mabswid
.46612 0 m
.46612 0 L
s
P
p
.83333 Mabswid
.47832 0 m
.47832 0 L
s
P
p
.83333 Mabswid
.49051 0 m
.49051 0 L
s
P
p
.83333 Mabswid
.50271 0 m
.50271 0 L
s
P
p
.83333 Mabswid
.51491 0 m
.51491 0 L
s
P
p
.83333 Mabswid
.5271 0 m
.5271 0 L
s
P
p
.83333 Mabswid
.5393 0 m
.5393 0 L
s
P
p
.83333 Mabswid
.55149 0 m
.55149 0 L
s
P
p
.83333 Mabswid
.56369 .10301 m
.56369 0 L
s
P
p
.83333 Mabswid
.57588 .20601 m
.57588 0 L
s
P
p
.83333 Mabswid
.58808 .30902 m
.58808 0 L
s
P
p
.83333 Mabswid
.60027 .41202 m
.60027 0 L
s
P
p
.83333 Mabswid
.61247 .51503 m
.61247 0 L
s
P
p
.83333 Mabswid
.62466 .61803 m
.62466 0 L
s
P
p
.83333 Mabswid
.63686 .51503 m
.63686 0 L
s
P
p
.83333 Mabswid
.64905 .41202 m
.64905 0 L
s
P
p
.83333 Mabswid
.66125 .30902 m
.66125 0 L
s
P
p
.83333 Mabswid
.67344 .20601 m
.67344 0 L
s
P
p
.83333 Mabswid
.68564 .10301 m
.68564 0 L
s
P
p
.83333 Mabswid
.69783 0 m
.69783 0 L
s
P
p
.83333 Mabswid
.71003 0 m
.71003 0 L
s
P
p
.83333 Mabswid
.72222 0 m
.72222 0 L
s
P
p
.83333 Mabswid
.73442 0 m
.73442 0 L
s
P
p
.83333 Mabswid
.74661 0 m
.74661 0 L
s
P
p
.83333 Mabswid
.75881 0 m
.75881 0 L
s
P
p
.83333 Mabswid
.771 0 m
.771 0 L
s
P
p
.83333 Mabswid
.7832 0 m
.7832 0 L
s
P
p
.83333 Mabswid
.79539 0 m
.79539 0 L
s
P
p
.83333 Mabswid
.80759 0 m
.80759 0 L
s
P
p
.83333 Mabswid
.81978 0 m
.81978 0 L
s
P
p
.83333 Mabswid
.83198 0 m
.83198 0 L
s
P
p
.83333 Mabswid
.84417 0 m
.84417 0 L
s
P
p
.83333 Mabswid
.85637 0 m
.85637 0 L
s
P
p
.83333 Mabswid
.86856 0 m
.86856 0 L
s
P
p
.83333 Mabswid
.88076 0 m
.88076 0 L
s
P
p
.83333 Mabswid
.89295 0 m
.89295 0 L
s
P
p
.83333 Mabswid
.90515 0 m
.90515 0 L
s
P
p
.83333 Mabswid
.91734 0 m
.91734 0 L
s
P
p
.83333 Mabswid
.92954 0 m
.92954 0 L
s
P
p
.83333 Mabswid
.94173 0 m
.94173 0 L
s
P
p
.83333 Mabswid
.95393 0 m
.95393 0 L
s
P
p
.83333 Mabswid
.96612 0 m
.96612 0 L
s
P
p
.83333 Mabswid
.97832 0 m
.97832 0 L
s
P
p
.83333 Mabswid
.99051 0 m
.99051 0 L
s
P
P
P
p
0 1 .4 r
p
p
.83333 Mabswid
.01762 0 m
.01762 0 L
s
P
p
.83333 Mabswid
.02981 0 m
.02981 0 L
s
P
p
.83333 Mabswid
.04201 0 m
.04201 0 L
s
P
p
.83333 Mabswid
.0542 0 m
.0542 0 L
s
P
p
.83333 Mabswid
.0664 0 m
.0664 0 L
s
P
p
.83333 Mabswid
.07859 0 m
.07859 0 L
s
P
p
.83333 Mabswid
.09079 0 m
.09079 0 L
s
P
p
.83333 Mabswid
.10298 0 m
.10298 0 L
s
P
p
.83333 Mabswid
.11518 0 m
.11518 0 L
s
P
p
.83333 Mabswid
.12737 0 m
.12737 0 L
s
P
p
.83333 Mabswid
.13957 0 m
.13957 0 L
s
P
p
.83333 Mabswid
.15176 0 m
.15176 0 L
s
P
p
.83333 Mabswid
.16396 0 m
.16396 0 L
s
P
p
.83333 Mabswid
.17615 0 m
.17615 0 L
s
P
p
.83333 Mabswid
.18835 0 m
.18835 0 L
s
P
p
.83333 Mabswid
.20054 0 m
.20054 0 L
s
P
p
.83333 Mabswid
.21274 0 m
.21274 0 L
s
P
p
.83333 Mabswid
.22493 0 m
.22493 0 L
s
P
p
.83333 Mabswid
.23713 0 m
.23713 0 L
s
P
p
.83333 Mabswid
.24932 0 m
.24932 0 L
s
P
p
.83333 Mabswid
.26152 0 m
.26152 0 L
s
P
p
.83333 Mabswid
.27371 0 m
.27371 0 L
s
P
p
.83333 Mabswid
.28591 0 m
.28591 0 L
s
P
p
.83333 Mabswid
.2981 0 m
.2981 0 L
s
P
p
.83333 Mabswid
.3103 0 m
.3103 0 L
s
P
p
.83333 Mabswid
.32249 0 m
.32249 0 L
s
P
p
.83333 Mabswid
.33469 0 m
.33469 0 L
s
P
p
.83333 Mabswid
.34688 0 m
.34688 0 L
s
P
p
.83333 Mabswid
.35908 0 m
.35908 0 L
s
P
p
.83333 Mabswid
.37127 0 m
.37127 0 L
s
P
p
.83333 Mabswid
.38347 0 m
.38347 0 L
s
P
p
.83333 Mabswid
.39566 0 m
.39566 0 L
s
P
p
.83333 Mabswid
.40786 0 m
.40786 0 L
s
P
p
.83333 Mabswid
.42005 0 m
.42005 0 L
s
P
p
.83333 Mabswid
.43225 0 m
.43225 0 L
s
P
p
.83333 Mabswid
.44444 0 m
.44444 0 L
s
P
p
.83333 Mabswid
.45664 0 m
.45664 0 L
s
P
p
.83333 Mabswid
.46883 0 m
.46883 0 L
s
P
p
.83333 Mabswid
.48103 0 m
.48103 0 L
s
P
p
.83333 Mabswid
.49322 0 m
.49322 0 L
s
P
p
.83333 Mabswid
.50542 0 m
.50542 0 L
s
P
p
.83333 Mabswid
.51762 0 m
.51762 0 L
s
P
p
.83333 Mabswid
.52981 0 m
.52981 0 L
s
P
p
.83333 Mabswid
.54201 0 m
.54201 0 L
s
P
p
.83333 Mabswid
.5542 0 m
.5542 0 L
s
P
p
.83333 Mabswid
.5664 0 m
.5664 0 L
s
P
p
.83333 Mabswid
.57859 0 m
.57859 0 L
s
P
p
.83333 Mabswid
.59079 .10301 m
.59079 0 L
s
P
p
.83333 Mabswid
.60298 .15451 m
.60298 0 L
s
P
p
.83333 Mabswid
.61518 .20601 m
.61518 0 L
s
P
p
.83333 Mabswid
.62737 .30902 m
.62737 0 L
s
P
p
.83333 Mabswid
.63957 .30902 m
.63957 0 L
s
P
p
.83333 Mabswid
.65176 .41202 m
.65176 0 L
s
P
p
.83333 Mabswid
.66396 .46353 m
.66396 0 L
s
P
p
.83333 Mabswid
.67615 .51503 m
.67615 0 L
s
P
p
.83333 Mabswid
.68835 .61803 m
.68835 0 L
s
P
p
.83333 Mabswid
.70054 .51503 m
.70054 0 L
s
P
p
.83333 Mabswid
.71274 .46353 m
.71274 0 L
s
P
p
.83333 Mabswid
.72493 .41202 m
.72493 0 L
s
P
p
.83333 Mabswid
.73713 .30902 m
.73713 0 L
s
P
p
.83333 Mabswid
.74932 .30902 m
.74932 0 L
s
P
p
.83333 Mabswid
.76152 .20601 m
.76152 0 L
s
P
p
.83333 Mabswid
.77371 .15451 m
.77371 0 L
s
P
p
.83333 Mabswid
.78591 .10301 m
.78591 0 L
s
P
p
.83333 Mabswid
.7981 0 m
.7981 0 L
s
P
p
.83333 Mabswid
.8103 0 m
.8103 0 L
s
P
p
.83333 Mabswid
.82249 0 m
.82249 0 L
s
P
p
.83333 Mabswid
.83469 0 m
.83469 0 L
s
P
p
.83333 Mabswid
.84688 0 m
.84688 0 L
s
P
p
.83333 Mabswid
.85908 0 m
.85908 0 L
s
P
p
.83333 Mabswid
.87127 0 m
.87127 0 L
s
P
p
.83333 Mabswid
.88347 0 m
.88347 0 L
s
P
p
.83333 Mabswid
.89566 0 m
.89566 0 L
s
P
p
.83333 Mabswid
.90786 0 m
.90786 0 L
s
P
p
.83333 Mabswid
.92005 0 m
.92005 0 L
s
P
p
.83333 Mabswid
.93225 0 m
.93225 0 L
s
P
p
.83333 Mabswid
.94444 0 m
.94444 0 L
s
P
p
.83333 Mabswid
.95664 0 m
.95664 0 L
s
P
p
.83333 Mabswid
.96883 0 m
.96883 0 L
s
P
p
.83333 Mabswid
.98103 0 m
.98103 0 L
s
P
p
.83333 Mabswid
.99322 0 m
.99322 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Based on earlier discussion, the sum of the two triangular fuzzy sets in real \
space should be a triangular fuzzy set with vertices at {1+4, 5+10, 5+10, \
9+16} or {5,15,15,25}. To evaluate the results of the discrete fuzzy \
addition, we plot the expected real space result with our discrete result.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["ExpectedSum = FuzzyTrapezoid[5,15,15,25];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Sum1,ExpectedSum,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 0 L
.35366 0 L
.36585 0 L
.37805 0 L
.39024 0 L
.40244 0 L
.41463 0 L
.42683 0 L
.43902 0 L
.45122 0 L
.46341 0 L
.47561 0 L
.4878 0 L
.5 0 L
.5122 0 L
.52439 0 L
.53659 0 L
.54878 0 L
.56098 0 L
.57317 0 L
.58537 .10301 L
.59756 .15451 L
.60976 .20601 L
Mistroke
.62195 .30902 L
.63415 .30902 L
.64634 .41202 L
.65854 .46353 L
.67073 .51503 L
.68293 .61803 L
.69512 .51503 L
.70732 .46353 L
.71951 .41202 L
.73171 .30902 L
.7439 .30902 L
.7561 .20601 L
.76829 .15451 L
.78049 .10301 L
.79268 0 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 0 L
.35366 0 L
.36585 0 L
.37805 0 L
.39024 0 L
.40244 0 L
.41463 0 L
.42683 0 L
.43902 0 L
.45122 0 L
.46341 0 L
.47561 0 L
.4878 0 L
.5 0 L
.5122 0 L
.52439 0 L
.53659 0 L
.54878 0 L
.56098 0 L
.57317 .0618 L
.58537 .12361 L
.59756 .18541 L
.60976 .24721 L
Mistroke
.62195 .30902 L
.63415 .37082 L
.64634 .43262 L
.65854 .49443 L
.67073 .55623 L
.68293 .61803 L
.69512 .55623 L
.70732 .49443 L
.71951 .43262 L
.73171 .37082 L
.7439 .30902 L
.7561 .24721 L
.76829 .18541 L
.78049 .12361 L
.79268 .0618 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
From the graph we see that the discrete fuzzy sum, is bounded above by the \
expected fuzzy set for real space. This is the case for all of the discrete \
fuzzy arithmetic operations. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Subtraction", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyMinus[A,B] returns a fuzzy set that is the result of applying \
fuzzy subtraction to fuzzy set A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We will subtract our first fuzzy set from the second one and plot the \
results.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Diff1 = DiscreteFuzzyMinus[TriFS1,TriFS2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[TriFS1,TriFS2,Diff1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
.83333 Mabswid
.0122 0 m
.0122 0 L
s
P
p
.83333 Mabswid
.02439 0 m
.02439 0 L
s
P
p
.83333 Mabswid
.03659 0 m
.03659 0 L
s
P
p
.83333 Mabswid
.04878 0 m
.04878 0 L
s
P
p
.83333 Mabswid
.06098 0 m
.06098 0 L
s
P
p
.83333 Mabswid
.07317 0 m
.07317 0 L
s
P
p
.83333 Mabswid
.08537 0 m
.08537 0 L
s
P
p
.83333 Mabswid
.09756 0 m
.09756 0 L
s
P
p
.83333 Mabswid
.10976 0 m
.10976 0 L
s
P
p
.83333 Mabswid
.12195 0 m
.12195 0 L
s
P
p
.83333 Mabswid
.13415 0 m
.13415 0 L
s
P
p
.83333 Mabswid
.14634 0 m
.14634 0 L
s
P
p
.83333 Mabswid
.15854 0 m
.15854 0 L
s
P
p
.83333 Mabswid
.17073 0 m
.17073 0 L
s
P
p
.83333 Mabswid
.18293 0 m
.18293 0 L
s
P
p
.83333 Mabswid
.19512 0 m
.19512 0 L
s
P
p
.83333 Mabswid
.20732 0 m
.20732 0 L
s
P
p
.83333 Mabswid
.21951 0 m
.21951 0 L
s
P
p
.83333 Mabswid
.23171 0 m
.23171 0 L
s
P
p
.83333 Mabswid
.2439 0 m
.2439 0 L
s
P
p
.83333 Mabswid
.2561 0 m
.2561 0 L
s
P
p
.83333 Mabswid
.26829 0 m
.26829 0 L
s
P
p
.83333 Mabswid
.28049 0 m
.28049 0 L
s
P
p
.83333 Mabswid
.29268 0 m
.29268 0 L
s
P
p
.83333 Mabswid
.30488 0 m
.30488 0 L
s
P
p
.83333 Mabswid
.31707 0 m
.31707 0 L
s
P
p
.83333 Mabswid
.32927 0 m
.32927 0 L
s
P
p
.83333 Mabswid
.34146 0 m
.34146 0 L
s
P
p
.83333 Mabswid
.35366 0 m
.35366 0 L
s
P
p
.83333 Mabswid
.36585 0 m
.36585 0 L
s
P
p
.83333 Mabswid
.37805 0 m
.37805 0 L
s
P
p
.83333 Mabswid
.39024 0 m
.39024 0 L
s
P
p
.83333 Mabswid
.40244 0 m
.40244 0 L
s
P
p
.83333 Mabswid
.41463 0 m
.41463 0 L
s
P
p
.83333 Mabswid
.42683 0 m
.42683 0 L
s
P
p
.83333 Mabswid
.43902 0 m
.43902 0 L
s
P
p
.83333 Mabswid
.45122 0 m
.45122 0 L
s
P
p
.83333 Mabswid
.46341 0 m
.46341 0 L
s
P
p
.83333 Mabswid
.47561 0 m
.47561 0 L
s
P
p
.83333 Mabswid
.4878 0 m
.4878 0 L
s
P
p
.83333 Mabswid
.5 0 m
.5 0 L
s
P
p
.83333 Mabswid
.5122 0 m
.5122 0 L
s
P
p
.83333 Mabswid
.52439 .15451 m
.52439 0 L
s
P
p
.83333 Mabswid
.53659 .30902 m
.53659 0 L
s
P
p
.83333 Mabswid
.54878 .46353 m
.54878 0 L
s
P
p
.83333 Mabswid
.56098 .61803 m
.56098 0 L
s
P
p
.83333 Mabswid
.57317 .46353 m
.57317 0 L
s
P
p
.83333 Mabswid
.58537 .30902 m
.58537 0 L
s
P
p
.83333 Mabswid
.59756 .15451 m
.59756 0 L
s
P
p
.83333 Mabswid
.60976 0 m
.60976 0 L
s
P
p
.83333 Mabswid
.62195 0 m
.62195 0 L
s
P
p
.83333 Mabswid
.63415 0 m
.63415 0 L
s
P
p
.83333 Mabswid
.64634 0 m
.64634 0 L
s
P
p
.83333 Mabswid
.65854 0 m
.65854 0 L
s
P
p
.83333 Mabswid
.67073 0 m
.67073 0 L
s
P
p
.83333 Mabswid
.68293 0 m
.68293 0 L
s
P
p
.83333 Mabswid
.69512 0 m
.69512 0 L
s
P
p
.83333 Mabswid
.70732 0 m
.70732 0 L
s
P
p
.83333 Mabswid
.71951 0 m
.71951 0 L
s
P
p
.83333 Mabswid
.73171 0 m
.73171 0 L
s
P
p
.83333 Mabswid
.7439 0 m
.7439 0 L
s
P
p
.83333 Mabswid
.7561 0 m
.7561 0 L
s
P
p
.83333 Mabswid
.76829 0 m
.76829 0 L
s
P
p
.83333 Mabswid
.78049 0 m
.78049 0 L
s
P
p
.83333 Mabswid
.79268 0 m
.79268 0 L
s
P
p
.83333 Mabswid
.80488 0 m
.80488 0 L
s
P
p
.83333 Mabswid
.81707 0 m
.81707 0 L
s
P
p
.83333 Mabswid
.82927 0 m
.82927 0 L
s
P
p
.83333 Mabswid
.84146 0 m
.84146 0 L
s
P
p
.83333 Mabswid
.85366 0 m
.85366 0 L
s
P
p
.83333 Mabswid
.86585 0 m
.86585 0 L
s
P
p
.83333 Mabswid
.87805 0 m
.87805 0 L
s
P
p
.83333 Mabswid
.89024 0 m
.89024 0 L
s
P
p
.83333 Mabswid
.90244 0 m
.90244 0 L
s
P
p
.83333 Mabswid
.91463 0 m
.91463 0 L
s
P
p
.83333 Mabswid
.92683 0 m
.92683 0 L
s
P
p
.83333 Mabswid
.93902 0 m
.93902 0 L
s
P
p
.83333 Mabswid
.95122 0 m
.95122 0 L
s
P
p
.83333 Mabswid
.96341 0 m
.96341 0 L
s
P
p
.83333 Mabswid
.97561 0 m
.97561 0 L
s
P
p
.83333 Mabswid
.9878 0 m
.9878 0 L
s
P
P
P
p
.2 0 1 r
p
p
.83333 Mabswid
.01491 0 m
.01491 0 L
s
P
p
.83333 Mabswid
.0271 0 m
.0271 0 L
s
P
p
.83333 Mabswid
.0393 0 m
.0393 0 L
s
P
p
.83333 Mabswid
.05149 0 m
.05149 0 L
s
P
p
.83333 Mabswid
.06369 0 m
.06369 0 L
s
P
p
.83333 Mabswid
.07588 0 m
.07588 0 L
s
P
p
.83333 Mabswid
.08808 0 m
.08808 0 L
s
P
p
.83333 Mabswid
.10027 0 m
.10027 0 L
s
P
p
.83333 Mabswid
.11247 0 m
.11247 0 L
s
P
p
.83333 Mabswid
.12466 0 m
.12466 0 L
s
P
p
.83333 Mabswid
.13686 0 m
.13686 0 L
s
P
p
.83333 Mabswid
.14905 0 m
.14905 0 L
s
P
p
.83333 Mabswid
.16125 0 m
.16125 0 L
s
P
p
.83333 Mabswid
.17344 0 m
.17344 0 L
s
P
p
.83333 Mabswid
.18564 0 m
.18564 0 L
s
P
p
.83333 Mabswid
.19783 0 m
.19783 0 L
s
P
p
.83333 Mabswid
.21003 0 m
.21003 0 L
s
P
p
.83333 Mabswid
.22222 0 m
.22222 0 L
s
P
p
.83333 Mabswid
.23442 0 m
.23442 0 L
s
P
p
.83333 Mabswid
.24661 0 m
.24661 0 L
s
P
p
.83333 Mabswid
.25881 0 m
.25881 0 L
s
P
p
.83333 Mabswid
.271 0 m
.271 0 L
s
P
p
.83333 Mabswid
.2832 0 m
.2832 0 L
s
P
p
.83333 Mabswid
.29539 0 m
.29539 0 L
s
P
p
.83333 Mabswid
.30759 0 m
.30759 0 L
s
P
p
.83333 Mabswid
.31978 0 m
.31978 0 L
s
P
p
.83333 Mabswid
.33198 0 m
.33198 0 L
s
P
p
.83333 Mabswid
.34417 0 m
.34417 0 L
s
P
p
.83333 Mabswid
.35637 0 m
.35637 0 L
s
P
p
.83333 Mabswid
.36856 0 m
.36856 0 L
s
P
p
.83333 Mabswid
.38076 0 m
.38076 0 L
s
P
p
.83333 Mabswid
.39295 0 m
.39295 0 L
s
P
p
.83333 Mabswid
.40515 0 m
.40515 0 L
s
P
p
.83333 Mabswid
.41734 0 m
.41734 0 L
s
P
p
.83333 Mabswid
.42954 0 m
.42954 0 L
s
P
p
.83333 Mabswid
.44173 0 m
.44173 0 L
s
P
p
.83333 Mabswid
.45393 0 m
.45393 0 L
s
P
p
.83333 Mabswid
.46612 0 m
.46612 0 L
s
P
p
.83333 Mabswid
.47832 0 m
.47832 0 L
s
P
p
.83333 Mabswid
.49051 0 m
.49051 0 L
s
P
p
.83333 Mabswid
.50271 0 m
.50271 0 L
s
P
p
.83333 Mabswid
.51491 0 m
.51491 0 L
s
P
p
.83333 Mabswid
.5271 0 m
.5271 0 L
s
P
p
.83333 Mabswid
.5393 0 m
.5393 0 L
s
P
p
.83333 Mabswid
.55149 0 m
.55149 0 L
s
P
p
.83333 Mabswid
.56369 .10301 m
.56369 0 L
s
P
p
.83333 Mabswid
.57588 .20601 m
.57588 0 L
s
P
p
.83333 Mabswid
.58808 .30902 m
.58808 0 L
s
P
p
.83333 Mabswid
.60027 .41202 m
.60027 0 L
s
P
p
.83333 Mabswid
.61247 .51503 m
.61247 0 L
s
P
p
.83333 Mabswid
.62466 .61803 m
.62466 0 L
s
P
p
.83333 Mabswid
.63686 .51503 m
.63686 0 L
s
P
p
.83333 Mabswid
.64905 .41202 m
.64905 0 L
s
P
p
.83333 Mabswid
.66125 .30902 m
.66125 0 L
s
P
p
.83333 Mabswid
.67344 .20601 m
.67344 0 L
s
P
p
.83333 Mabswid
.68564 .10301 m
.68564 0 L
s
P
p
.83333 Mabswid
.69783 0 m
.69783 0 L
s
P
p
.83333 Mabswid
.71003 0 m
.71003 0 L
s
P
p
.83333 Mabswid
.72222 0 m
.72222 0 L
s
P
p
.83333 Mabswid
.73442 0 m
.73442 0 L
s
P
p
.83333 Mabswid
.74661 0 m
.74661 0 L
s
P
p
.83333 Mabswid
.75881 0 m
.75881 0 L
s
P
p
.83333 Mabswid
.771 0 m
.771 0 L
s
P
p
.83333 Mabswid
.7832 0 m
.7832 0 L
s
P
p
.83333 Mabswid
.79539 0 m
.79539 0 L
s
P
p
.83333 Mabswid
.80759 0 m
.80759 0 L
s
P
p
.83333 Mabswid
.81978 0 m
.81978 0 L
s
P
p
.83333 Mabswid
.83198 0 m
.83198 0 L
s
P
p
.83333 Mabswid
.84417 0 m
.84417 0 L
s
P
p
.83333 Mabswid
.85637 0 m
.85637 0 L
s
P
p
.83333 Mabswid
.86856 0 m
.86856 0 L
s
P
p
.83333 Mabswid
.88076 0 m
.88076 0 L
s
P
p
.83333 Mabswid
.89295 0 m
.89295 0 L
s
P
p
.83333 Mabswid
.90515 0 m
.90515 0 L
s
P
p
.83333 Mabswid
.91734 0 m
.91734 0 L
s
P
p
.83333 Mabswid
.92954 0 m
.92954 0 L
s
P
p
.83333 Mabswid
.94173 0 m
.94173 0 L
s
P
p
.83333 Mabswid
.95393 0 m
.95393 0 L
s
P
p
.83333 Mabswid
.96612 0 m
.96612 0 L
s
P
p
.83333 Mabswid
.97832 0 m
.97832 0 L
s
P
p
.83333 Mabswid
.99051 0 m
.99051 0 L
s
P
P
P
p
0 1 .4 r
p
p
.83333 Mabswid
.01762 0 m
.01762 0 L
s
P
p
.83333 Mabswid
.02981 0 m
.02981 0 L
s
P
p
.83333 Mabswid
.04201 0 m
.04201 0 L
s
P
p
.83333 Mabswid
.0542 0 m
.0542 0 L
s
P
p
.83333 Mabswid
.0664 0 m
.0664 0 L
s
P
p
.83333 Mabswid
.07859 0 m
.07859 0 L
s
P
p
.83333 Mabswid
.09079 0 m
.09079 0 L
s
P
p
.83333 Mabswid
.10298 0 m
.10298 0 L
s
P
p
.83333 Mabswid
.11518 0 m
.11518 0 L
s
P
p
.83333 Mabswid
.12737 0 m
.12737 0 L
s
P
p
.83333 Mabswid
.13957 0 m
.13957 0 L
s
P
p
.83333 Mabswid
.15176 0 m
.15176 0 L
s
P
p
.83333 Mabswid
.16396 0 m
.16396 0 L
s
P
p
.83333 Mabswid
.17615 0 m
.17615 0 L
s
P
p
.83333 Mabswid
.18835 0 m
.18835 0 L
s
P
p
.83333 Mabswid
.20054 0 m
.20054 0 L
s
P
p
.83333 Mabswid
.21274 0 m
.21274 0 L
s
P
p
.83333 Mabswid
.22493 0 m
.22493 0 L
s
P
p
.83333 Mabswid
.23713 0 m
.23713 0 L
s
P
p
.83333 Mabswid
.24932 0 m
.24932 0 L
s
P
p
.83333 Mabswid
.26152 0 m
.26152 0 L
s
P
p
.83333 Mabswid
.27371 0 m
.27371 0 L
s
P
p
.83333 Mabswid
.28591 0 m
.28591 0 L
s
P
p
.83333 Mabswid
.2981 0 m
.2981 0 L
s
P
p
.83333 Mabswid
.3103 0 m
.3103 0 L
s
P
p
.83333 Mabswid
.32249 0 m
.32249 0 L
s
P
p
.83333 Mabswid
.33469 0 m
.33469 0 L
s
P
p
.83333 Mabswid
.34688 .10301 m
.34688 0 L
s
P
p
.83333 Mabswid
.35908 .15451 m
.35908 0 L
s
P
p
.83333 Mabswid
.37127 .20601 m
.37127 0 L
s
P
p
.83333 Mabswid
.38347 .30902 m
.38347 0 L
s
P
p
.83333 Mabswid
.39566 .30902 m
.39566 0 L
s
P
p
.83333 Mabswid
.40786 .41202 m
.40786 0 L
s
P
p
.83333 Mabswid
.42005 .46353 m
.42005 0 L
s
P
p
.83333 Mabswid
.43225 .51503 m
.43225 0 L
s
P
p
.83333 Mabswid
.44444 .61803 m
.44444 0 L
s
P
p
.83333 Mabswid
.45664 .51503 m
.45664 0 L
s
P
p
.83333 Mabswid
.46883 .46353 m
.46883 0 L
s
P
p
.83333 Mabswid
.48103 .41202 m
.48103 0 L
s
P
p
.83333 Mabswid
.49322 .30902 m
.49322 0 L
s
P
p
.83333 Mabswid
.50542 .30902 m
.50542 0 L
s
P
p
.83333 Mabswid
.51762 .20601 m
.51762 0 L
s
P
p
.83333 Mabswid
.52981 .15451 m
.52981 0 L
s
P
p
.83333 Mabswid
.54201 .10301 m
.54201 0 L
s
P
p
.83333 Mabswid
.5542 0 m
.5542 0 L
s
P
p
.83333 Mabswid
.5664 0 m
.5664 0 L
s
P
p
.83333 Mabswid
.57859 0 m
.57859 0 L
s
P
p
.83333 Mabswid
.59079 0 m
.59079 0 L
s
P
p
.83333 Mabswid
.60298 0 m
.60298 0 L
s
P
p
.83333 Mabswid
.61518 0 m
.61518 0 L
s
P
p
.83333 Mabswid
.62737 0 m
.62737 0 L
s
P
p
.83333 Mabswid
.63957 0 m
.63957 0 L
s
P
p
.83333 Mabswid
.65176 0 m
.65176 0 L
s
P
p
.83333 Mabswid
.66396 0 m
.66396 0 L
s
P
p
.83333 Mabswid
.67615 0 m
.67615 0 L
s
P
p
.83333 Mabswid
.68835 0 m
.68835 0 L
s
P
p
.83333 Mabswid
.70054 0 m
.70054 0 L
s
P
p
.83333 Mabswid
.71274 0 m
.71274 0 L
s
P
p
.83333 Mabswid
.72493 0 m
.72493 0 L
s
P
p
.83333 Mabswid
.73713 0 m
.73713 0 L
s
P
p
.83333 Mabswid
.74932 0 m
.74932 0 L
s
P
p
.83333 Mabswid
.76152 0 m
.76152 0 L
s
P
p
.83333 Mabswid
.77371 0 m
.77371 0 L
s
P
p
.83333 Mabswid
.78591 0 m
.78591 0 L
s
P
p
.83333 Mabswid
.7981 0 m
.7981 0 L
s
P
p
.83333 Mabswid
.8103 0 m
.8103 0 L
s
P
p
.83333 Mabswid
.82249 0 m
.82249 0 L
s
P
p
.83333 Mabswid
.83469 0 m
.83469 0 L
s
P
p
.83333 Mabswid
.84688 0 m
.84688 0 L
s
P
p
.83333 Mabswid
.85908 0 m
.85908 0 L
s
P
p
.83333 Mabswid
.87127 0 m
.87127 0 L
s
P
p
.83333 Mabswid
.88347 0 m
.88347 0 L
s
P
p
.83333 Mabswid
.89566 0 m
.89566 0 L
s
P
p
.83333 Mabswid
.90786 0 m
.90786 0 L
s
P
p
.83333 Mabswid
.92005 0 m
.92005 0 L
s
P
p
.83333 Mabswid
.93225 0 m
.93225 0 L
s
P
p
.83333 Mabswid
.94444 0 m
.94444 0 L
s
P
p
.83333 Mabswid
.95664 0 m
.95664 0 L
s
P
p
.83333 Mabswid
.96883 0 m
.96883 0 L
s
P
p
.83333 Mabswid
.98103 0 m
.98103 0 L
s
P
p
.83333 Mabswid
.99322 0 m
.99322 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
In real space the difference between the two triangular fuzzy sets would be a \
triangular fuzzy set with vertices at {1-16,5-10,5-10,9-4} or {-15,-5,-5,5}. \
To evaluate the results of the discrete fuzzy subtraction, we plot this \
expected result with the discrete result.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["ExpectedDiff = FuzzyTrapezoid[-15,-5,-5,5];", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Diff1,ExpectedDiff,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 0 L
.34146 .10301 L
.35366 .15451 L
.36585 .20601 L
.37805 .30902 L
.39024 .30902 L
.40244 .41202 L
.41463 .46353 L
.42683 .51503 L
.43902 .61803 L
.45122 .51503 L
.46341 .46353 L
.47561 .41202 L
.4878 .30902 L
.5 .30902 L
.5122 .20601 L
.52439 .15451 L
.53659 .10301 L
.54878 0 L
.56098 0 L
.57317 0 L
.58537 0 L
.59756 0 L
.60976 0 L
Mistroke
.62195 0 L
.63415 0 L
.64634 0 L
.65854 0 L
.67073 0 L
.68293 0 L
.69512 0 L
.70732 0 L
.71951 0 L
.73171 0 L
.7439 0 L
.7561 0 L
.76829 0 L
.78049 0 L
.79268 0 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.0122 0 m
.02439 0 L
.03659 0 L
.04878 0 L
.06098 0 L
.07317 0 L
.08537 0 L
.09756 0 L
.10976 0 L
.12195 0 L
.13415 0 L
.14634 0 L
.15854 0 L
.17073 0 L
.18293 0 L
.19512 0 L
.20732 0 L
.21951 0 L
.23171 0 L
.2439 0 L
.2561 0 L
.26829 0 L
.28049 0 L
.29268 0 L
.30488 0 L
.31707 0 L
.32927 .0618 L
.34146 .12361 L
.35366 .18541 L
.36585 .24721 L
.37805 .30902 L
.39024 .37082 L
.40244 .43262 L
.41463 .49443 L
.42683 .55623 L
.43902 .61803 L
.45122 .55623 L
.46341 .49443 L
.47561 .43262 L
.4878 .37082 L
.5 .30902 L
.5122 .24721 L
.52439 .18541 L
.53659 .12361 L
.54878 .0618 L
.56098 0 L
.57317 0 L
.58537 0 L
.59756 0 L
.60976 0 L
Mistroke
.62195 0 L
.63415 0 L
.64634 0 L
.65854 0 L
.67073 0 L
.68293 0 L
.69512 0 L
.70732 0 L
.71951 0 L
.73171 0 L
.7439 0 L
.7561 0 L
.76829 0 L
.78049 0 L
.79268 0 L
.80488 0 L
.81707 0 L
.82927 0 L
.84146 0 L
.85366 0 L
.86585 0 L
.87805 0 L
.89024 0 L
.90244 0 L
.91463 0 L
.92683 0 L
.93902 0 L
.95122 0 L
.96341 0 L
.97561 0 L
.9878 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{399, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Multiplication", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyMultiply[A,B] returns a fuzzy set which is the result of \
performing a discrete fuzzy multiplication of fuzzy sets A and B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Since fuzzy multiplication causes a fuzzy number to be quite spread out, we \
use a smaller fuzzy number, TriFS3, to demonstrate the fuzzy \
multiplication.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["TriFS3 = FuzzyTrapezoid[1,3,3,5];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Prod1 = DiscreteFuzzyMultiply[TriFS1,TriFS3];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[TriFS1,TriFS3,Prod1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
.83333 Mabswid
.0122 0 m
.0122 0 L
s
P
p
.83333 Mabswid
.02439 0 m
.02439 0 L
s
P
p
.83333 Mabswid
.03659 0 m
.03659 0 L
s
P
p
.83333 Mabswid
.04878 0 m
.04878 0 L
s
P
p
.83333 Mabswid
.06098 0 m
.06098 0 L
s
P
p
.83333 Mabswid
.07317 0 m
.07317 0 L
s
P
p
.83333 Mabswid
.08537 0 m
.08537 0 L
s
P
p
.83333 Mabswid
.09756 0 m
.09756 0 L
s
P
p
.83333 Mabswid
.10976 0 m
.10976 0 L
s
P
p
.83333 Mabswid
.12195 0 m
.12195 0 L
s
P
p
.83333 Mabswid
.13415 0 m
.13415 0 L
s
P
p
.83333 Mabswid
.14634 0 m
.14634 0 L
s
P
p
.83333 Mabswid
.15854 0 m
.15854 0 L
s
P
p
.83333 Mabswid
.17073 0 m
.17073 0 L
s
P
p
.83333 Mabswid
.18293 0 m
.18293 0 L
s
P
p
.83333 Mabswid
.19512 0 m
.19512 0 L
s
P
p
.83333 Mabswid
.20732 0 m
.20732 0 L
s
P
p
.83333 Mabswid
.21951 0 m
.21951 0 L
s
P
p
.83333 Mabswid
.23171 0 m
.23171 0 L
s
P
p
.83333 Mabswid
.2439 0 m
.2439 0 L
s
P
p
.83333 Mabswid
.2561 0 m
.2561 0 L
s
P
p
.83333 Mabswid
.26829 0 m
.26829 0 L
s
P
p
.83333 Mabswid
.28049 0 m
.28049 0 L
s
P
p
.83333 Mabswid
.29268 0 m
.29268 0 L
s
P
p
.83333 Mabswid
.30488 0 m
.30488 0 L
s
P
p
.83333 Mabswid
.31707 0 m
.31707 0 L
s
P
p
.83333 Mabswid
.32927 0 m
.32927 0 L
s
P
p
.83333 Mabswid
.34146 0 m
.34146 0 L
s
P
p
.83333 Mabswid
.35366 0 m
.35366 0 L
s
P
p
.83333 Mabswid
.36585 0 m
.36585 0 L
s
P
p
.83333 Mabswid
.37805 0 m
.37805 0 L
s
P
p
.83333 Mabswid
.39024 0 m
.39024 0 L
s
P
p
.83333 Mabswid
.40244 0 m
.40244 0 L
s
P
p
.83333 Mabswid
.41463 0 m
.41463 0 L
s
P
p
.83333 Mabswid
.42683 0 m
.42683 0 L
s
P
p
.83333 Mabswid
.43902 0 m
.43902 0 L
s
P
p
.83333 Mabswid
.45122 0 m
.45122 0 L
s
P
p
.83333 Mabswid
.46341 0 m
.46341 0 L
s
P
p
.83333 Mabswid
.47561 0 m
.47561 0 L
s
P
p
.83333 Mabswid
.4878 0 m
.4878 0 L
s
P
p
.83333 Mabswid
.5 0 m
.5 0 L
s
P
p
.83333 Mabswid
.5122 0 m
.5122 0 L
s
P
p
.83333 Mabswid
.52439 .15451 m
.52439 0 L
s
P
p
.83333 Mabswid
.53659 .30902 m
.53659 0 L
s
P
p
.83333 Mabswid
.54878 .46353 m
.54878 0 L
s
P
p
.83333 Mabswid
.56098 .61803 m
.56098 0 L
s
P
p
.83333 Mabswid
.57317 .46353 m
.57317 0 L
s
P
p
.83333 Mabswid
.58537 .30902 m
.58537 0 L
s
P
p
.83333 Mabswid
.59756 .15451 m
.59756 0 L
s
P
p
.83333 Mabswid
.60976 0 m
.60976 0 L
s
P
p
.83333 Mabswid
.62195 0 m
.62195 0 L
s
P
p
.83333 Mabswid
.63415 0 m
.63415 0 L
s
P
p
.83333 Mabswid
.64634 0 m
.64634 0 L
s
P
p
.83333 Mabswid
.65854 0 m
.65854 0 L
s
P
p
.83333 Mabswid
.67073 0 m
.67073 0 L
s
P
p
.83333 Mabswid
.68293 0 m
.68293 0 L
s
P
p
.83333 Mabswid
.69512 0 m
.69512 0 L
s
P
p
.83333 Mabswid
.70732 0 m
.70732 0 L
s
P
p
.83333 Mabswid
.71951 0 m
.71951 0 L
s
P
p
.83333 Mabswid
.73171 0 m
.73171 0 L
s
P
p
.83333 Mabswid
.7439 0 m
.7439 0 L
s
P
p
.83333 Mabswid
.7561 0 m
.7561 0 L
s
P
p
.83333 Mabswid
.76829 0 m
.76829 0 L
s
P
p
.83333 Mabswid
.78049 0 m
.78049 0 L
s
P
p
.83333 Mabswid
.79268 0 m
.79268 0 L
s
P
p
.83333 Mabswid
.80488 0 m
.80488 0 L
s
P
p
.83333 Mabswid
.81707 0 m
.81707 0 L
s
P
p
.83333 Mabswid
.82927 0 m
.82927 0 L
s
P
p
.83333 Mabswid
.84146 0 m
.84146 0 L
s
P
p
.83333 Mabswid
.85366 0 m
.85366 0 L
s
P
p
.83333 Mabswid
.86585 0 m
.86585 0 L
s
P
p
.83333 Mabswid
.87805 0 m
.87805 0 L
s
P
p
.83333 Mabswid
.89024 0 m
.89024 0 L
s
P
p
.83333 Mabswid
.90244 0 m
.90244 0 L
s
P
p
.83333 Mabswid
.91463 0 m
.91463 0 L
s
P
p
.83333 Mabswid
.92683 0 m
.92683 0 L
s
P
p
.83333 Mabswid
.93902 0 m
.93902 0 L
s
P
p
.83333 Mabswid
.95122 0 m
.95122 0 L
s
P
p
.83333 Mabswid
.96341 0 m
.96341 0 L
s
P
p
.83333 Mabswid
.97561 0 m
.97561 0 L
s
P
p
.83333 Mabswid
.9878 0 m
.9878 0 L
s
P
P
P
p
.2 0 1 r
p
p
.83333 Mabswid
.01491 0 m
.01491 0 L
s
P
p
.83333 Mabswid
.0271 0 m
.0271 0 L
s
P
p
.83333 Mabswid
.0393 0 m
.0393 0 L
s
P
p
.83333 Mabswid
.05149 0 m
.05149 0 L
s
P
p
.83333 Mabswid
.06369 0 m
.06369 0 L
s
P
p
.83333 Mabswid
.07588 0 m
.07588 0 L
s
P
p
.83333 Mabswid
.08808 0 m
.08808 0 L
s
P
p
.83333 Mabswid
.10027 0 m
.10027 0 L
s
P
p
.83333 Mabswid
.11247 0 m
.11247 0 L
s
P
p
.83333 Mabswid
.12466 0 m
.12466 0 L
s
P
p
.83333 Mabswid
.13686 0 m
.13686 0 L
s
P
p
.83333 Mabswid
.14905 0 m
.14905 0 L
s
P
p
.83333 Mabswid
.16125 0 m
.16125 0 L
s
P
p
.83333 Mabswid
.17344 0 m
.17344 0 L
s
P
p
.83333 Mabswid
.18564 0 m
.18564 0 L
s
P
p
.83333 Mabswid
.19783 0 m
.19783 0 L
s
P
p
.83333 Mabswid
.21003 0 m
.21003 0 L
s
P
p
.83333 Mabswid
.22222 0 m
.22222 0 L
s
P
p
.83333 Mabswid
.23442 0 m
.23442 0 L
s
P
p
.83333 Mabswid
.24661 0 m
.24661 0 L
s
P
p
.83333 Mabswid
.25881 0 m
.25881 0 L
s
P
p
.83333 Mabswid
.271 0 m
.271 0 L
s
P
p
.83333 Mabswid
.2832 0 m
.2832 0 L
s
P
p
.83333 Mabswid
.29539 0 m
.29539 0 L
s
P
p
.83333 Mabswid
.30759 0 m
.30759 0 L
s
P
p
.83333 Mabswid
.31978 0 m
.31978 0 L
s
P
p
.83333 Mabswid
.33198 0 m
.33198 0 L
s
P
p
.83333 Mabswid
.34417 0 m
.34417 0 L
s
P
p
.83333 Mabswid
.35637 0 m
.35637 0 L
s
P
p
.83333 Mabswid
.36856 0 m
.36856 0 L
s
P
p
.83333 Mabswid
.38076 0 m
.38076 0 L
s
P
p
.83333 Mabswid
.39295 0 m
.39295 0 L
s
P
p
.83333 Mabswid
.40515 0 m
.40515 0 L
s
P
p
.83333 Mabswid
.41734 0 m
.41734 0 L
s
P
p
.83333 Mabswid
.42954 0 m
.42954 0 L
s
P
p
.83333 Mabswid
.44173 0 m
.44173 0 L
s
P
p
.83333 Mabswid
.45393 0 m
.45393 0 L
s
P
p
.83333 Mabswid
.46612 0 m
.46612 0 L
s
P
p
.83333 Mabswid
.47832 0 m
.47832 0 L
s
P
p
.83333 Mabswid
.49051 0 m
.49051 0 L
s
P
p
.83333 Mabswid
.50271 0 m
.50271 0 L
s
P
p
.83333 Mabswid
.51491 0 m
.51491 0 L
s
P
p
.83333 Mabswid
.5271 .30902 m
.5271 0 L
s
P
p
.83333 Mabswid
.5393 .61803 m
.5393 0 L
s
P
p
.83333 Mabswid
.55149 .30902 m
.55149 0 L
s
P
p
.83333 Mabswid
.56369 0 m
.56369 0 L
s
P
p
.83333 Mabswid
.57588 0 m
.57588 0 L
s
P
p
.83333 Mabswid
.58808 0 m
.58808 0 L
s
P
p
.83333 Mabswid
.60027 0 m
.60027 0 L
s
P
p
.83333 Mabswid
.61247 0 m
.61247 0 L
s
P
p
.83333 Mabswid
.62466 0 m
.62466 0 L
s
P
p
.83333 Mabswid
.63686 0 m
.63686 0 L
s
P
p
.83333 Mabswid
.64905 0 m
.64905 0 L
s
P
p
.83333 Mabswid
.66125 0 m
.66125 0 L
s
P
p
.83333 Mabswid
.67344 0 m
.67344 0 L
s
P
p
.83333 Mabswid
.68564 0 m
.68564 0 L
s
P
p
.83333 Mabswid
.69783 0 m
.69783 0 L
s
P
p
.83333 Mabswid
.71003 0 m
.71003 0 L
s
P
p
.83333 Mabswid
.72222 0 m
.72222 0 L
s
P
p
.83333 Mabswid
.73442 0 m
.73442 0 L
s
P
p
.83333 Mabswid
.74661 0 m
.74661 0 L
s
P
p
.83333 Mabswid
.75881 0 m
.75881 0 L
s
P
p
.83333 Mabswid
.771 0 m
.771 0 L
s
P
p
.83333 Mabswid
.7832 0 m
.7832 0 L
s
P
p
.83333 Mabswid
.79539 0 m
.79539 0 L
s
P
p
.83333 Mabswid
.80759 0 m
.80759 0 L
s
P
p
.83333 Mabswid
.81978 0 m
.81978 0 L
s
P
p
.83333 Mabswid
.83198 0 m
.83198 0 L
s
P
p
.83333 Mabswid
.84417 0 m
.84417 0 L
s
P
p
.83333 Mabswid
.85637 0 m
.85637 0 L
s
P
p
.83333 Mabswid
.86856 0 m
.86856 0 L
s
P
p
.83333 Mabswid
.88076 0 m
.88076 0 L
s
P
p
.83333 Mabswid
.89295 0 m
.89295 0 L
s
P
p
.83333 Mabswid
.90515 0 m
.90515 0 L
s
P
p
.83333 Mabswid
.91734 0 m
.91734 0 L
s
P
p
.83333 Mabswid
.92954 0 m
.92954 0 L
s
P
p
.83333 Mabswid
.94173 0 m
.94173 0 L
s
P
p
.83333 Mabswid
.95393 0 m
.95393 0 L
s
P
p
.83333 Mabswid
.96612 0 m
.96612 0 L
s
P
p
.83333 Mabswid
.97832 0 m
.97832 0 L
s
P
p
.83333 Mabswid
.99051 0 m
.99051 0 L
s
P
P
P
p
0 1 .4 r
p
p
.83333 Mabswid
.01762 0 m
.01762 0 L
s
P
p
.83333 Mabswid
.02981 0 m
.02981 0 L
s
P
p
.83333 Mabswid
.04201 0 m
.04201 0 L
s
P
p
.83333 Mabswid
.0542 0 m
.0542 0 L
s
P
p
.83333 Mabswid
.0664 0 m
.0664 0 L
s
P
p
.83333 Mabswid
.07859 0 m
.07859 0 L
s
P
p
.83333 Mabswid
.09079 0 m
.09079 0 L
s
P
p
.83333 Mabswid
.10298 0 m
.10298 0 L
s
P
p
.83333 Mabswid
.11518 0 m
.11518 0 L
s
P
p
.83333 Mabswid
.12737 0 m
.12737 0 L
s
P
p
.83333 Mabswid
.13957 0 m
.13957 0 L
s
P
p
.83333 Mabswid
.15176 0 m
.15176 0 L
s
P
p
.83333 Mabswid
.16396 0 m
.16396 0 L
s
P
p
.83333 Mabswid
.17615 0 m
.17615 0 L
s
P
p
.83333 Mabswid
.18835 0 m
.18835 0 L
s
P
p
.83333 Mabswid
.20054 0 m
.20054 0 L
s
P
p
.83333 Mabswid
.21274 0 m
.21274 0 L
s
P
p
.83333 Mabswid
.22493 0 m
.22493 0 L
s
P
p
.83333 Mabswid
.23713 0 m
.23713 0 L
s
P
p
.83333 Mabswid
.24932 0 m
.24932 0 L
s
P
p
.83333 Mabswid
.26152 0 m
.26152 0 L
s
P
p
.83333 Mabswid
.27371 0 m
.27371 0 L
s
P
p
.83333 Mabswid
.28591 0 m
.28591 0 L
s
P
p
.83333 Mabswid
.2981 0 m
.2981 0 L
s
P
p
.83333 Mabswid
.3103 0 m
.3103 0 L
s
P
p
.83333 Mabswid
.32249 0 m
.32249 0 L
s
P
p
.83333 Mabswid
.33469 0 m
.33469 0 L
s
P
p
.83333 Mabswid
.34688 0 m
.34688 0 L
s
P
p
.83333 Mabswid
.35908 0 m
.35908 0 L
s
P
p
.83333 Mabswid
.37127 0 m
.37127 0 L
s
P
p
.83333 Mabswid
.38347 0 m
.38347 0 L
s
P
p
.83333 Mabswid
.39566 0 m
.39566 0 L
s
P
p
.83333 Mabswid
.40786 0 m
.40786 0 L
s
P
p
.83333 Mabswid
.42005 0 m
.42005 0 L
s
P
p
.83333 Mabswid
.43225 0 m
.43225 0 L
s
P
p
.83333 Mabswid
.44444 0 m
.44444 0 L
s
P
p
.83333 Mabswid
.45664 0 m
.45664 0 L
s
P
p
.83333 Mabswid
.46883 0 m
.46883 0 L
s
P
p
.83333 Mabswid
.48103 0 m
.48103 0 L
s
P
p
.83333 Mabswid
.49322 0 m
.49322 0 L
s
P
p
.83333 Mabswid
.50542 0 m
.50542 0 L
s
P
p
.83333 Mabswid
.51762 0 m
.51762 0 L
s
P
p
.83333 Mabswid
.52981 0 m
.52981 0 L
s
P
p
.83333 Mabswid
.54201 0 m
.54201 0 L
s
P
p
.83333 Mabswid
.5542 .15451 m
.5542 0 L
s
P
p
.83333 Mabswid
.5664 .15451 m
.5664 0 L
s
P
p
.83333 Mabswid
.57859 .30902 m
.57859 0 L
s
P
p
.83333 Mabswid
.59079 .30902 m
.59079 0 L
s
P
p
.83333 Mabswid
.60298 .30902 m
.60298 0 L
s
P
p
.83333 Mabswid
.61518 .30902 m
.61518 0 L
s
P
p
.83333 Mabswid
.62737 .30902 m
.62737 0 L
s
P
p
.83333 Mabswid
.63957 .30902 m
.63957 0 L
s
P
p
.83333 Mabswid
.65176 .46353 m
.65176 0 L
s
P
p
.83333 Mabswid
.66396 .46353 m
.66396 0 L
s
P
p
.83333 Mabswid
.67615 .46353 m
.67615 0 L
s
P
p
.83333 Mabswid
.68835 .61803 m
.68835 0 L
s
P
p
.83333 Mabswid
.70054 .46353 m
.70054 0 L
s
P
p
.83333 Mabswid
.71274 .46353 m
.71274 0 L
s
P
p
.83333 Mabswid
.72493 .46353 m
.72493 0 L
s
P
p
.83333 Mabswid
.73713 .30902 m
.73713 0 L
s
P
p
.83333 Mabswid
.74932 .30902 m
.74932 0 L
s
P
p
.83333 Mabswid
.76152 .30902 m
.76152 0 L
s
P
p
.83333 Mabswid
.77371 .30902 m
.77371 0 L
s
P
p
.83333 Mabswid
.78591 .30902 m
.78591 0 L
s
P
p
.83333 Mabswid
.7981 .30902 m
.7981 0 L
s
P
p
.83333 Mabswid
.8103 .30902 m
.8103 0 L
s
P
p
.83333 Mabswid
.82249 .30902 m
.82249 0 L
s
P
p
.83333 Mabswid
.83469 .30902 m
.83469 0 L
s
P
p
.83333 Mabswid
.84688 .30902 m
.84688 0 L
s
P
p
.83333 Mabswid
.85908 .15451 m
.85908 0 L
s
P
p
.83333 Mabswid
.87127 .15451 m
.87127 0 L
s
P
p
.83333 Mabswid
.88347 .15451 m
.88347 0 L
s
P
p
.83333 Mabswid
.89566 .15451 m
.89566 0 L
s
P
p
.83333 Mabswid
.90786 0 m
.90786 0 L
s
P
p
.83333 Mabswid
.92005 0 m
.92005 0 L
s
P
p
.83333 Mabswid
.93225 0 m
.93225 0 L
s
P
p
.83333 Mabswid
.94444 0 m
.94444 0 L
s
P
p
.83333 Mabswid
.95664 0 m
.95664 0 L
s
P
p
.83333 Mabswid
.96883 0 m
.96883 0 L
s
P
p
.83333 Mabswid
.98103 0 m
.98103 0 L
s
P
p
.83333 Mabswid
.99322 0 m
.99322 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{401, 247},
  ImageMargins->{{31, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Image", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
DiscreteFuzzyImage[A] returns a fuzzy set that is the image of fuzzy set A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We will find the image of our first fuzzy set and plot the results here.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Im1 = DiscreteFuzzyImage[TriFS1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[TriFS1,Im1];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.0122 0 m
.0122 0 L
s
P
p
1.25 Mabswid
.02439 0 m
.02439 0 L
s
P
p
1.25 Mabswid
.03659 0 m
.03659 0 L
s
P
p
1.25 Mabswid
.04878 0 m
.04878 0 L
s
P
p
1.25 Mabswid
.06098 0 m
.06098 0 L
s
P
p
1.25 Mabswid
.07317 0 m
.07317 0 L
s
P
p
1.25 Mabswid
.08537 0 m
.08537 0 L
s
P
p
1.25 Mabswid
.09756 0 m
.09756 0 L
s
P
p
1.25 Mabswid
.10976 0 m
.10976 0 L
s
P
p
1.25 Mabswid
.12195 0 m
.12195 0 L
s
P
p
1.25 Mabswid
.13415 0 m
.13415 0 L
s
P
p
1.25 Mabswid
.14634 0 m
.14634 0 L
s
P
p
1.25 Mabswid
.15854 0 m
.15854 0 L
s
P
p
1.25 Mabswid
.17073 0 m
.17073 0 L
s
P
p
1.25 Mabswid
.18293 0 m
.18293 0 L
s
P
p
1.25 Mabswid
.19512 0 m
.19512 0 L
s
P
p
1.25 Mabswid
.20732 0 m
.20732 0 L
s
P
p
1.25 Mabswid
.21951 0 m
.21951 0 L
s
P
p
1.25 Mabswid
.23171 0 m
.23171 0 L
s
P
p
1.25 Mabswid
.2439 0 m
.2439 0 L
s
P
p
1.25 Mabswid
.2561 0 m
.2561 0 L
s
P
p
1.25 Mabswid
.26829 0 m
.26829 0 L
s
P
p
1.25 Mabswid
.28049 0 m
.28049 0 L
s
P
p
1.25 Mabswid
.29268 0 m
.29268 0 L
s
P
p
1.25 Mabswid
.30488 0 m
.30488 0 L
s
P
p
1.25 Mabswid
.31707 0 m
.31707 0 L
s
P
p
1.25 Mabswid
.32927 0 m
.32927 0 L
s
P
p
1.25 Mabswid
.34146 0 m
.34146 0 L
s
P
p
1.25 Mabswid
.35366 0 m
.35366 0 L
s
P
p
1.25 Mabswid
.36585 0 m
.36585 0 L
s
P
p
1.25 Mabswid
.37805 0 m
.37805 0 L
s
P
p
1.25 Mabswid
.39024 0 m
.39024 0 L
s
P
p
1.25 Mabswid
.40244 0 m
.40244 0 L
s
P
p
1.25 Mabswid
.41463 0 m
.41463 0 L
s
P
p
1.25 Mabswid
.42683 0 m
.42683 0 L
s
P
p
1.25 Mabswid
.43902 0 m
.43902 0 L
s
P
p
1.25 Mabswid
.45122 0 m
.45122 0 L
s
P
p
1.25 Mabswid
.46341 0 m
.46341 0 L
s
P
p
1.25 Mabswid
.47561 0 m
.47561 0 L
s
P
p
1.25 Mabswid
.4878 0 m
.4878 0 L
s
P
p
1.25 Mabswid
.5 0 m
.5 0 L
s
P
p
1.25 Mabswid
.5122 0 m
.5122 0 L
s
P
p
1.25 Mabswid
.52439 .15451 m
.52439 0 L
s
P
p
1.25 Mabswid
.53659 .30902 m
.53659 0 L
s
P
p
1.25 Mabswid
.54878 .46353 m
.54878 0 L
s
P
p
1.25 Mabswid
.56098 .61803 m
.56098 0 L
s
P
p
1.25 Mabswid
.57317 .46353 m
.57317 0 L
s
P
p
1.25 Mabswid
.58537 .30902 m
.58537 0 L
s
P
p
1.25 Mabswid
.59756 .15451 m
.59756 0 L
s
P
p
1.25 Mabswid
.60976 0 m
.60976 0 L
s
P
p
1.25 Mabswid
.62195 0 m
.62195 0 L
s
P
p
1.25 Mabswid
.63415 0 m
.63415 0 L
s
P
p
1.25 Mabswid
.64634 0 m
.64634 0 L
s
P
p
1.25 Mabswid
.65854 0 m
.65854 0 L
s
P
p
1.25 Mabswid
.67073 0 m
.67073 0 L
s
P
p
1.25 Mabswid
.68293 0 m
.68293 0 L
s
P
p
1.25 Mabswid
.69512 0 m
.69512 0 L
s
P
p
1.25 Mabswid
.70732 0 m
.70732 0 L
s
P
p
1.25 Mabswid
.71951 0 m
.71951 0 L
s
P
p
1.25 Mabswid
.73171 0 m
.73171 0 L
s
P
p
1.25 Mabswid
.7439 0 m
.7439 0 L
s
P
p
1.25 Mabswid
.7561 0 m
.7561 0 L
s
P
p
1.25 Mabswid
.76829 0 m
.76829 0 L
s
P
p
1.25 Mabswid
.78049 0 m
.78049 0 L
s
P
p
1.25 Mabswid
.79268 0 m
.79268 0 L
s
P
p
1.25 Mabswid
.80488 0 m
.80488 0 L
s
P
p
1.25 Mabswid
.81707 0 m
.81707 0 L
s
P
p
1.25 Mabswid
.82927 0 m
.82927 0 L
s
P
p
1.25 Mabswid
.84146 0 m
.84146 0 L
s
P
p
1.25 Mabswid
.85366 0 m
.85366 0 L
s
P
p
1.25 Mabswid
.86585 0 m
.86585 0 L
s
P
p
1.25 Mabswid
.87805 0 m
.87805 0 L
s
P
p
1.25 Mabswid
.89024 0 m
.89024 0 L
s
P
p
1.25 Mabswid
.90244 0 m
.90244 0 L
s
P
p
1.25 Mabswid
.91463 0 m
.91463 0 L
s
P
p
1.25 Mabswid
.92683 0 m
.92683 0 L
s
P
p
1.25 Mabswid
.93902 0 m
.93902 0 L
s
P
p
1.25 Mabswid
.95122 0 m
.95122 0 L
s
P
p
1.25 Mabswid
.96341 0 m
.96341 0 L
s
P
p
1.25 Mabswid
.97561 0 m
.97561 0 L
s
P
p
1.25 Mabswid
.9878 0 m
.9878 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.01626 0 m
.01626 0 L
s
P
p
1.25 Mabswid
.02846 0 m
.02846 0 L
s
P
p
1.25 Mabswid
.04065 0 m
.04065 0 L
s
P
p
1.25 Mabswid
.05285 0 m
.05285 0 L
s
P
p
1.25 Mabswid
.06504 0 m
.06504 0 L
s
P
p
1.25 Mabswid
.07724 0 m
.07724 0 L
s
P
p
1.25 Mabswid
.08943 0 m
.08943 0 L
s
P
p
1.25 Mabswid
.10163 0 m
.10163 0 L
s
P
p
1.25 Mabswid
.11382 0 m
.11382 0 L
s
P
p
1.25 Mabswid
.12602 0 m
.12602 0 L
s
P
p
1.25 Mabswid
.13821 0 m
.13821 0 L
s
P
p
1.25 Mabswid
.15041 0 m
.15041 0 L
s
P
p
1.25 Mabswid
.1626 0 m
.1626 0 L
s
P
p
1.25 Mabswid
.1748 0 m
.1748 0 L
s
P
p
1.25 Mabswid
.18699 0 m
.18699 0 L
s
P
p
1.25 Mabswid
.19919 0 m
.19919 0 L
s
P
p
1.25 Mabswid
.21138 0 m
.21138 0 L
s
P
p
1.25 Mabswid
.22358 0 m
.22358 0 L
s
P
p
1.25 Mabswid
.23577 0 m
.23577 0 L
s
P
p
1.25 Mabswid
.24797 0 m
.24797 0 L
s
P
p
1.25 Mabswid
.26016 0 m
.26016 0 L
s
P
p
1.25 Mabswid
.27236 0 m
.27236 0 L
s
P
p
1.25 Mabswid
.28455 0 m
.28455 0 L
s
P
p
1.25 Mabswid
.29675 0 m
.29675 0 L
s
P
p
1.25 Mabswid
.30894 0 m
.30894 0 L
s
P
p
1.25 Mabswid
.32114 0 m
.32114 0 L
s
P
p
1.25 Mabswid
.33333 0 m
.33333 0 L
s
P
p
1.25 Mabswid
.34553 0 m
.34553 0 L
s
P
p
1.25 Mabswid
.35772 0 m
.35772 0 L
s
P
p
1.25 Mabswid
.36992 0 m
.36992 0 L
s
P
p
1.25 Mabswid
.38211 0 m
.38211 0 L
s
P
p
1.25 Mabswid
.39431 0 m
.39431 0 L
s
P
p
1.25 Mabswid
.4065 .15451 m
.4065 0 L
s
P
p
1.25 Mabswid
.4187 .30902 m
.4187 0 L
s
P
p
1.25 Mabswid
.43089 .46353 m
.43089 0 L
s
P
p
1.25 Mabswid
.44309 .61803 m
.44309 0 L
s
P
p
1.25 Mabswid
.45528 .46353 m
.45528 0 L
s
P
p
1.25 Mabswid
.46748 .30902 m
.46748 0 L
s
P
p
1.25 Mabswid
.47967 .15451 m
.47967 0 L
s
P
p
1.25 Mabswid
.49187 0 m
.49187 0 L
s
P
p
1.25 Mabswid
.50407 0 m
.50407 0 L
s
P
p
1.25 Mabswid
.51626 0 m
.51626 0 L
s
P
p
1.25 Mabswid
.52846 0 m
.52846 0 L
s
P
p
1.25 Mabswid
.54065 0 m
.54065 0 L
s
P
p
1.25 Mabswid
.55285 0 m
.55285 0 L
s
P
p
1.25 Mabswid
.56504 0 m
.56504 0 L
s
P
p
1.25 Mabswid
.57724 0 m
.57724 0 L
s
P
p
1.25 Mabswid
.58943 0 m
.58943 0 L
s
P
p
1.25 Mabswid
.60163 0 m
.60163 0 L
s
P
p
1.25 Mabswid
.61382 0 m
.61382 0 L
s
P
p
1.25 Mabswid
.62602 0 m
.62602 0 L
s
P
p
1.25 Mabswid
.63821 0 m
.63821 0 L
s
P
p
1.25 Mabswid
.65041 0 m
.65041 0 L
s
P
p
1.25 Mabswid
.6626 0 m
.6626 0 L
s
P
p
1.25 Mabswid
.6748 0 m
.6748 0 L
s
P
p
1.25 Mabswid
.68699 0 m
.68699 0 L
s
P
p
1.25 Mabswid
.69919 0 m
.69919 0 L
s
P
p
1.25 Mabswid
.71138 0 m
.71138 0 L
s
P
p
1.25 Mabswid
.72358 0 m
.72358 0 L
s
P
p
1.25 Mabswid
.73577 0 m
.73577 0 L
s
P
p
1.25 Mabswid
.74797 0 m
.74797 0 L
s
P
p
1.25 Mabswid
.76016 0 m
.76016 0 L
s
P
p
1.25 Mabswid
.77236 0 m
.77236 0 L
s
P
p
1.25 Mabswid
.78455 0 m
.78455 0 L
s
P
p
1.25 Mabswid
.79675 0 m
.79675 0 L
s
P
p
1.25 Mabswid
.80894 0 m
.80894 0 L
s
P
p
1.25 Mabswid
.82114 0 m
.82114 0 L
s
P
p
1.25 Mabswid
.83333 0 m
.83333 0 L
s
P
p
1.25 Mabswid
.84553 0 m
.84553 0 L
s
P
p
1.25 Mabswid
.85772 0 m
.85772 0 L
s
P
p
1.25 Mabswid
.86992 0 m
.86992 0 L
s
P
p
1.25 Mabswid
.88211 0 m
.88211 0 L
s
P
p
1.25 Mabswid
.89431 0 m
.89431 0 L
s
P
p
1.25 Mabswid
.9065 0 m
.9065 0 L
s
P
p
1.25 Mabswid
.9187 0 m
.9187 0 L
s
P
p
1.25 Mabswid
.93089 0 m
.93089 0 L
s
P
p
1.25 Mabswid
.94309 0 m
.94309 0 L
s
P
p
1.25 Mabswid
.95528 0 m
.95528 0 L
s
P
p
1.25 Mabswid
.96748 0 m
.96748 0 L
s
P
p
1.25 Mabswid
.97967 0 m
.97967 0 L
s
P
p
1.25 Mabswid
.99187 0 m
.99187 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
In the graph, the fuzzy set to the right is our original fuzzy set, and the \
fuzzy set to the left is the image of the original fuzzy set. In the discrete \
case, the image of a fuzzy set will look the same as it would in real \
space.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Discrete Arithmetic on Gaussian Fuzzy Numbers", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Using Gaussian fuzzy sets is another common way to represent fuzzy numbers. \
Gaussian fuzzy numbers are convenient to work with because in real space, \
adding two Gaussian fuzzy numbers involves adding the mean and standard \
deviation used to define the original Gaussian fuzzy numbers. To subtract two \
Gaussian fuzzy numbers, subtract the means and add the standard deviations. \
Because of these properties, we further demonstrate the discrete arithmetic \
operations using Gaussian fuzzy numbers. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Addition", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We start by adding the two Gaussian fuzzy numbers which we created earlier, \
and we plot the results.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Sum2 = DiscreteFuzzyPlus[GausFS3,GausFS4];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Sum2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00617284 0 0.618034 [
[(-75)] .03704 0 0 2 Msboxa
[(-50)] .19136 0 0 2 Msboxa
[(-25)] .34568 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(25)] .65432 0 0 2 Msboxa
[(50)] .80864 0 0 2 Msboxa
[(75)] .96296 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.03704 0 m
.03704 .00625 L
s
P
[(-75)] .03704 0 0 2 Mshowa
p
.002 w
.19136 0 m
.19136 .00625 L
s
P
[(-50)] .19136 0 0 2 Mshowa
p
.002 w
.34568 0 m
.34568 .00625 L
s
P
[(-25)] .34568 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.65432 0 m
.65432 .00625 L
s
P
[(25)] .65432 0 0 2 Mshowa
p
.002 w
.80864 0 m
.80864 .00625 L
s
P
[(50)] .80864 0 0 2 Mshowa
p
.002 w
.96296 0 m
.96296 .00625 L
s
P
[(75)] .96296 0 0 2 Mshowa
p
.001 w
.0679 0 m
.0679 .00375 L
s
P
p
.001 w
.09877 0 m
.09877 .00375 L
s
P
p
.001 w
.12963 0 m
.12963 .00375 L
s
P
p
.001 w
.16049 0 m
.16049 .00375 L
s
P
p
.001 w
.22222 0 m
.22222 .00375 L
s
P
p
.001 w
.25309 0 m
.25309 .00375 L
s
P
p
.001 w
.28395 0 m
.28395 .00375 L
s
P
p
.001 w
.31481 0 m
.31481 .00375 L
s
P
p
.001 w
.37654 0 m
.37654 .00375 L
s
P
p
.001 w
.40741 0 m
.40741 .00375 L
s
P
p
.001 w
.43827 0 m
.43827 .00375 L
s
P
p
.001 w
.46914 0 m
.46914 .00375 L
s
P
p
.001 w
.53086 0 m
.53086 .00375 L
s
P
p
.001 w
.56173 0 m
.56173 .00375 L
s
P
p
.001 w
.59259 0 m
.59259 .00375 L
s
P
p
.001 w
.62346 0 m
.62346 .00375 L
s
P
p
.001 w
.68519 0 m
.68519 .00375 L
s
P
p
.001 w
.71605 0 m
.71605 .00375 L
s
P
p
.001 w
.74691 0 m
.74691 .00375 L
s
P
p
.001 w
.77778 0 m
.77778 .00375 L
s
P
p
.001 w
.83951 0 m
.83951 .00375 L
s
P
p
.001 w
.87037 0 m
.87037 .00375 L
s
P
p
.001 w
.90123 0 m
.90123 .00375 L
s
P
p
.001 w
.9321 0 m
.9321 .00375 L
s
P
p
.001 w
.00617 0 m
.00617 .00375 L
s
P
p
.001 w
.99383 0 m
.99383 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.00617 0 m
.00617 0 L
s
P
p
2.5 Mabswid
.01235 0 m
.01235 0 L
s
P
p
2.5 Mabswid
.01852 0 m
.01852 0 L
s
P
p
2.5 Mabswid
.02469 0 m
.02469 0 L
s
P
p
2.5 Mabswid
.03086 0 m
.03086 0 L
s
P
p
2.5 Mabswid
.03704 0 m
.03704 0 L
s
P
p
2.5 Mabswid
.04321 0 m
.04321 0 L
s
P
p
2.5 Mabswid
.04938 0 m
.04938 0 L
s
P
p
2.5 Mabswid
.05556 0 m
.05556 0 L
s
P
p
2.5 Mabswid
.06173 0 m
.06173 0 L
s
P
p
2.5 Mabswid
.0679 0 m
.0679 0 L
s
P
p
2.5 Mabswid
.07407 0 m
.07407 0 L
s
P
p
2.5 Mabswid
.08025 0 m
.08025 0 L
s
P
p
2.5 Mabswid
.08642 0 m
.08642 0 L
s
P
p
2.5 Mabswid
.09259 0 m
.09259 0 L
s
P
p
2.5 Mabswid
.09877 0 m
.09877 0 L
s
P
p
2.5 Mabswid
.10494 0 m
.10494 0 L
s
P
p
2.5 Mabswid
.11111 0 m
.11111 0 L
s
P
p
2.5 Mabswid
.11728 0 m
.11728 0 L
s
P
p
2.5 Mabswid
.12346 0 m
.12346 0 L
s
P
p
2.5 Mabswid
.12963 0 m
.12963 0 L
s
P
p
2.5 Mabswid
.1358 0 m
.1358 0 L
s
P
p
2.5 Mabswid
.14198 0 m
.14198 0 L
s
P
p
2.5 Mabswid
.14815 0 m
.14815 0 L
s
P
p
2.5 Mabswid
.15432 0 m
.15432 0 L
s
P
p
2.5 Mabswid
.16049 0 m
.16049 0 L
s
P
p
2.5 Mabswid
.16667 0 m
.16667 0 L
s
P
p
2.5 Mabswid
.17284 0 m
.17284 0 L
s
P
p
2.5 Mabswid
.17901 0 m
.17901 0 L
s
P
p
2.5 Mabswid
.18519 0 m
.18519 0 L
s
P
p
2.5 Mabswid
.19136 0 m
.19136 0 L
s
P
p
2.5 Mabswid
.19753 0 m
.19753 0 L
s
P
p
2.5 Mabswid
.2037 0 m
.2037 0 L
s
P
p
2.5 Mabswid
.20988 0 m
.20988 0 L
s
P
p
2.5 Mabswid
.21605 0 m
.21605 0 L
s
P
p
2.5 Mabswid
.22222 0 m
.22222 0 L
s
P
p
2.5 Mabswid
.2284 0 m
.2284 0 L
s
P
p
2.5 Mabswid
.23457 0 m
.23457 0 L
s
P
p
2.5 Mabswid
.24074 0 m
.24074 0 L
s
P
p
2.5 Mabswid
.24691 0 m
.24691 0 L
s
P
p
2.5 Mabswid
.25309 0 m
.25309 0 L
s
P
p
2.5 Mabswid
.25926 0 m
.25926 0 L
s
P
p
2.5 Mabswid
.26543 0 m
.26543 0 L
s
P
p
2.5 Mabswid
.2716 0 m
.2716 0 L
s
P
p
2.5 Mabswid
.27778 0 m
.27778 0 L
s
P
p
2.5 Mabswid
.28395 0 m
.28395 0 L
s
P
p
2.5 Mabswid
.29012 0 m
.29012 0 L
s
P
p
2.5 Mabswid
.2963 0 m
.2963 0 L
s
P
p
2.5 Mabswid
.30247 0 m
.30247 0 L
s
P
p
2.5 Mabswid
.30864 0 m
.30864 0 L
s
P
p
2.5 Mabswid
.31481 0 m
.31481 0 L
s
P
p
2.5 Mabswid
.32099 0 m
.32099 0 L
s
P
p
2.5 Mabswid
.32716 0 m
.32716 0 L
s
P
p
2.5 Mabswid
.33333 0 m
.33333 0 L
s
P
p
2.5 Mabswid
.33951 0 m
.33951 0 L
s
P
p
2.5 Mabswid
.34568 0 m
.34568 0 L
s
P
p
2.5 Mabswid
.35185 0 m
.35185 0 L
s
P
p
2.5 Mabswid
.35802 0 m
.35802 0 L
s
P
p
2.5 Mabswid
.3642 0 m
.3642 0 L
s
P
p
2.5 Mabswid
.37037 0 m
.37037 0 L
s
P
p
2.5 Mabswid
.37654 0 m
.37654 0 L
s
P
p
2.5 Mabswid
.38272 0 m
.38272 0 L
s
P
p
2.5 Mabswid
.38889 0 m
.38889 0 L
s
P
p
2.5 Mabswid
.39506 0 m
.39506 0 L
s
P
p
2.5 Mabswid
.40123 0 m
.40123 0 L
s
P
p
2.5 Mabswid
.40741 0 m
.40741 0 L
s
P
p
2.5 Mabswid
.41358 0 m
.41358 0 L
s
P
p
2.5 Mabswid
.41975 1e-05 m
.41975 0 L
s
P
p
2.5 Mabswid
.42593 1e-05 m
.42593 0 L
s
P
p
2.5 Mabswid
.4321 2e-05 m
.4321 0 L
s
P
p
2.5 Mabswid
.43827 8e-05 m
.43827 0 L
s
P
p
2.5 Mabswid
.44444 8e-05 m
.44444 0 L
s
P
p
2.5 Mabswid
.45062 .00024 m
.45062 0 L
s
P
p
2.5 Mabswid
.45679 .0005 m
.45679 0 L
s
P
p
2.5 Mabswid
.46296 .00072 m
.46296 0 L
s
P
p
2.5 Mabswid
.46914 .00195 m
.46914 0 L
s
P
p
2.5 Mabswid
.47531 .00267 m
.47531 0 L
s
P
p
2.5 Mabswid
.48148 .00489 m
.48148 0 L
s
P
p
2.5 Mabswid
.48765 .01132 m
.48765 0 L
s
P
p
2.5 Mabswid
.49383 .01132 m
.49383 0 L
s
P
p
2.5 Mabswid
.5 .0242 m
.5 0 L
s
P
p
2.5 Mabswid
.50617 .03843 m
.50617 0 L
s
P
p
2.5 Mabswid
.51235 .04778 m
.51235 0 L
s
P
p
2.5 Mabswid
.51852 .08706 m
.51852 0 L
s
P
p
2.5 Mabswid
.52469 .10446 m
.52469 0 L
s
P
p
2.5 Mabswid
.53086 .14643 m
.53086 0 L
s
P
p
2.5 Mabswid
.53704 .22736 m
.53704 0 L
s
P
p
2.5 Mabswid
.54321 .22736 m
.54321 0 L
s
P
p
2.5 Mabswid
.54938 .32588 m
.54938 0 L
s
P
p
2.5 Mabswid
.55556 .39627 m
.55556 0 L
s
P
p
2.5 Mabswid
.56173 .43119 m
.56173 0 L
s
P
p
2.5 Mabswid
.5679 .52665 m
.5679 0 L
s
P
p
2.5 Mabswid
.57407 .55304 m
.57407 0 L
s
P
p
2.5 Mabswid
.58025 .5938 m
.58025 0 L
s
P
p
2.5 Mabswid
.58642 .61803 m
.58642 0 L
s
P
p
2.5 Mabswid
.59259 .5938 m
.59259 0 L
s
P
p
2.5 Mabswid
.59877 .55304 m
.59877 0 L
s
P
p
2.5 Mabswid
.60494 .52665 m
.60494 0 L
s
P
p
2.5 Mabswid
.61111 .43119 m
.61111 0 L
s
P
p
2.5 Mabswid
.61728 .39627 m
.61728 0 L
s
P
p
2.5 Mabswid
.62346 .32588 m
.62346 0 L
s
P
p
2.5 Mabswid
.62963 .22736 m
.62963 0 L
s
P
p
2.5 Mabswid
.6358 .22736 m
.6358 0 L
s
P
p
2.5 Mabswid
.64198 .14643 m
.64198 0 L
s
P
p
2.5 Mabswid
.64815 .10446 m
.64815 0 L
s
P
p
2.5 Mabswid
.65432 .08706 m
.65432 0 L
s
P
p
2.5 Mabswid
.66049 .04778 m
.66049 0 L
s
P
p
2.5 Mabswid
.66667 .03843 m
.66667 0 L
s
P
p
2.5 Mabswid
.67284 .0242 m
.67284 0 L
s
P
p
2.5 Mabswid
.67901 .01132 m
.67901 0 L
s
P
p
2.5 Mabswid
.68519 .01132 m
.68519 0 L
s
P
p
2.5 Mabswid
.69136 .00489 m
.69136 0 L
s
P
p
2.5 Mabswid
.69753 .00267 m
.69753 0 L
s
P
p
2.5 Mabswid
.7037 .00195 m
.7037 0 L
s
P
p
2.5 Mabswid
.70988 .00072 m
.70988 0 L
s
P
p
2.5 Mabswid
.71605 .0005 m
.71605 0 L
s
P
p
2.5 Mabswid
.72222 .00024 m
.72222 0 L
s
P
p
2.5 Mabswid
.7284 8e-05 m
.7284 0 L
s
P
p
2.5 Mabswid
.73457 8e-05 m
.73457 0 L
s
P
p
2.5 Mabswid
.74074 2e-05 m
.74074 0 L
s
P
p
2.5 Mabswid
.74691 1e-05 m
.74691 0 L
s
P
p
2.5 Mabswid
.75309 1e-05 m
.75309 0 L
s
P
p
2.5 Mabswid
.75926 0 m
.75926 0 L
s
P
p
2.5 Mabswid
.76543 0 m
.76543 0 L
s
P
p
2.5 Mabswid
.7716 0 m
.7716 0 L
s
P
p
2.5 Mabswid
.77778 0 m
.77778 0 L
s
P
p
2.5 Mabswid
.78395 0 m
.78395 0 L
s
P
p
2.5 Mabswid
.79012 0 m
.79012 0 L
s
P
p
2.5 Mabswid
.7963 0 m
.7963 0 L
s
P
p
2.5 Mabswid
.80247 0 m
.80247 0 L
s
P
p
2.5 Mabswid
.80864 0 m
.80864 0 L
s
P
p
2.5 Mabswid
.81481 0 m
.81481 0 L
s
P
p
2.5 Mabswid
.82099 0 m
.82099 0 L
s
P
p
2.5 Mabswid
.82716 0 m
.82716 0 L
s
P
p
2.5 Mabswid
.83333 0 m
.83333 0 L
s
P
p
2.5 Mabswid
.83951 0 m
.83951 0 L
s
P
p
2.5 Mabswid
.84568 0 m
.84568 0 L
s
P
p
2.5 Mabswid
.85185 0 m
.85185 0 L
s
P
p
2.5 Mabswid
.85802 0 m
.85802 0 L
s
P
p
2.5 Mabswid
.8642 0 m
.8642 0 L
s
P
p
2.5 Mabswid
.87037 0 m
.87037 0 L
s
P
p
2.5 Mabswid
.87654 0 m
.87654 0 L
s
P
p
2.5 Mabswid
.88272 0 m
.88272 0 L
s
P
p
2.5 Mabswid
.88889 0 m
.88889 0 L
s
P
p
2.5 Mabswid
.89506 0 m
.89506 0 L
s
P
p
2.5 Mabswid
.90123 0 m
.90123 0 L
s
P
p
2.5 Mabswid
.90741 0 m
.90741 0 L
s
P
p
2.5 Mabswid
.91358 0 m
.91358 0 L
s
P
p
2.5 Mabswid
.91975 0 m
.91975 0 L
s
P
p
2.5 Mabswid
.92593 0 m
.92593 0 L
s
P
p
2.5 Mabswid
.9321 0 m
.9321 0 L
s
P
p
2.5 Mabswid
.93827 0 m
.93827 0 L
s
P
p
2.5 Mabswid
.94444 0 m
.94444 0 L
s
P
p
2.5 Mabswid
.95062 0 m
.95062 0 L
s
P
p
2.5 Mabswid
.95679 0 m
.95679 0 L
s
P
p
2.5 Mabswid
.96296 0 m
.96296 0 L
s
P
p
2.5 Mabswid
.96914 0 m
.96914 0 L
s
P
p
2.5 Mabswid
.97531 0 m
.97531 0 L
s
P
p
2.5 Mabswid
.98148 0 m
.98148 0 L
s
P
p
2.5 Mabswid
.98765 0 m
.98765 0 L
s
P
p
2.5 Mabswid
.99383 0 m
.99383 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Notice that when two Gaussian fuzzy numbers are added, the universal space is \
doubled.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
As discussed above, after adding two Gaussian fuzzy sets defined in real \
space, the result is a Gaussian fuzzy set with mean and standard deviation \
equal to the sum of the means and standard deviations of the original fuzzy \
sets. In our example, we expect to get a result with mean of 5+9 = 14 and a \
standard deviation of 3+5 = 8. We can examine the results of our discrete \
fuzzy addition by plotting it with the expected results.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ExpectedSum2 = FuzzyGaussian[14,8,
  UniversalSpace->{-80,80}];\
\>", "Input",
  PageWidth->Infinity,
  PageBreakAbove->True,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Sum2,ExpectedSum2,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00617284 0 0.618034 [
[(-75)] .03704 0 0 2 Msboxa
[(-50)] .19136 0 0 2 Msboxa
[(-25)] .34568 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(25)] .65432 0 0 2 Msboxa
[(50)] .80864 0 0 2 Msboxa
[(75)] .96296 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.03704 0 m
.03704 .00625 L
s
P
[(-75)] .03704 0 0 2 Mshowa
p
.002 w
.19136 0 m
.19136 .00625 L
s
P
[(-50)] .19136 0 0 2 Mshowa
p
.002 w
.34568 0 m
.34568 .00625 L
s
P
[(-25)] .34568 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.65432 0 m
.65432 .00625 L
s
P
[(25)] .65432 0 0 2 Mshowa
p
.002 w
.80864 0 m
.80864 .00625 L
s
P
[(50)] .80864 0 0 2 Mshowa
p
.002 w
.96296 0 m
.96296 .00625 L
s
P
[(75)] .96296 0 0 2 Mshowa
p
.001 w
.0679 0 m
.0679 .00375 L
s
P
p
.001 w
.09877 0 m
.09877 .00375 L
s
P
p
.001 w
.12963 0 m
.12963 .00375 L
s
P
p
.001 w
.16049 0 m
.16049 .00375 L
s
P
p
.001 w
.22222 0 m
.22222 .00375 L
s
P
p
.001 w
.25309 0 m
.25309 .00375 L
s
P
p
.001 w
.28395 0 m
.28395 .00375 L
s
P
p
.001 w
.31481 0 m
.31481 .00375 L
s
P
p
.001 w
.37654 0 m
.37654 .00375 L
s
P
p
.001 w
.40741 0 m
.40741 .00375 L
s
P
p
.001 w
.43827 0 m
.43827 .00375 L
s
P
p
.001 w
.46914 0 m
.46914 .00375 L
s
P
p
.001 w
.53086 0 m
.53086 .00375 L
s
P
p
.001 w
.56173 0 m
.56173 .00375 L
s
P
p
.001 w
.59259 0 m
.59259 .00375 L
s
P
p
.001 w
.62346 0 m
.62346 .00375 L
s
P
p
.001 w
.68519 0 m
.68519 .00375 L
s
P
p
.001 w
.71605 0 m
.71605 .00375 L
s
P
p
.001 w
.74691 0 m
.74691 .00375 L
s
P
p
.001 w
.77778 0 m
.77778 .00375 L
s
P
p
.001 w
.83951 0 m
.83951 .00375 L
s
P
p
.001 w
.87037 0 m
.87037 .00375 L
s
P
p
.001 w
.90123 0 m
.90123 .00375 L
s
P
p
.001 w
.9321 0 m
.9321 .00375 L
s
P
p
.001 w
.00617 0 m
.00617 .00375 L
s
P
p
.001 w
.99383 0 m
.99383 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.00617 0 m
.01235 0 L
.01852 0 L
.02469 0 L
.03086 0 L
.03704 0 L
.04321 0 L
.04938 0 L
.05556 0 L
.06173 0 L
.0679 0 L
.07407 0 L
.08025 0 L
.08642 0 L
.09259 0 L
.09877 0 L
.10494 0 L
.11111 0 L
.11728 0 L
.12346 0 L
.12963 0 L
.1358 0 L
.14198 0 L
.14815 0 L
.15432 0 L
.16049 0 L
.16667 0 L
.17284 0 L
.17901 0 L
.18519 0 L
.19136 0 L
.19753 0 L
.2037 0 L
.20988 0 L
.21605 0 L
.22222 0 L
.2284 0 L
.23457 0 L
.24074 0 L
.24691 0 L
.25309 0 L
.25926 0 L
.26543 0 L
.2716 0 L
.27778 0 L
.28395 0 L
.29012 0 L
.2963 0 L
.30247 0 L
.30864 0 L
Mistroke
.31481 0 L
.32099 0 L
.32716 0 L
.33333 0 L
.33951 0 L
.34568 0 L
.35185 0 L
.35802 0 L
.3642 0 L
.37037 0 L
.37654 0 L
.38272 0 L
.38889 0 L
.39506 0 L
.40123 0 L
.40741 0 L
.41358 0 L
.41975 1e-05 L
.42593 1e-05 L
.4321 2e-05 L
.43827 8e-05 L
.44444 8e-05 L
.45062 .00024 L
.45679 .0005 L
.46296 .00072 L
.46914 .00195 L
.47531 .00267 L
.48148 .00489 L
.48765 .01132 L
.49383 .01132 L
.5 .0242 L
.50617 .03843 L
.51235 .04778 L
.51852 .08706 L
.52469 .10446 L
.53086 .14643 L
.53704 .22736 L
.54321 .22736 L
.54938 .32588 L
.55556 .39627 L
.56173 .43119 L
.5679 .52665 L
.57407 .55304 L
.58025 .5938 L
.58642 .61803 L
.59259 .5938 L
.59877 .55304 L
.60494 .52665 L
.61111 .43119 L
.61728 .39627 L
Mistroke
.62346 .32588 L
.62963 .22736 L
.6358 .22736 L
.64198 .14643 L
.64815 .10446 L
.65432 .08706 L
.66049 .04778 L
.66667 .03843 L
.67284 .0242 L
.67901 .01132 L
.68519 .01132 L
.69136 .00489 L
.69753 .00267 L
.7037 .00195 L
.70988 .00072 L
.71605 .0005 L
.72222 .00024 L
.7284 8e-05 L
.73457 8e-05 L
.74074 2e-05 L
.74691 1e-05 L
.75309 1e-05 L
.75926 0 L
.76543 0 L
.7716 0 L
.77778 0 L
.78395 0 L
.79012 0 L
.7963 0 L
.80247 0 L
.80864 0 L
.81481 0 L
.82099 0 L
.82716 0 L
.83333 0 L
.83951 0 L
.84568 0 L
.85185 0 L
.85802 0 L
.8642 0 L
.87037 0 L
.87654 0 L
.88272 0 L
.88889 0 L
.89506 0 L
.90123 0 L
.90741 0 L
.91358 0 L
.91975 0 L
.92593 0 L
Mistroke
.9321 0 L
.93827 0 L
.94444 0 L
.95062 0 L
.95679 0 L
.96296 0 L
.96914 0 L
.97531 0 L
.98148 0 L
.98765 0 L
.99383 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.00617 0 m
.01235 0 L
.01852 0 L
.02469 0 L
.03086 0 L
.03704 0 L
.04321 0 L
.04938 0 L
.05556 0 L
.06173 0 L
.0679 0 L
.07407 0 L
.08025 0 L
.08642 0 L
.09259 0 L
.09877 0 L
.10494 0 L
.11111 0 L
.11728 0 L
.12346 0 L
.12963 0 L
.1358 0 L
.14198 0 L
.14815 0 L
.15432 0 L
.16049 0 L
.16667 0 L
.17284 0 L
.17901 0 L
.18519 0 L
.19136 0 L
.19753 0 L
.2037 0 L
.20988 0 L
.21605 0 L
.22222 0 L
.2284 0 L
.23457 0 L
.24074 0 L
.24691 0 L
.25309 0 L
.25926 0 L
.26543 0 L
.2716 0 L
.27778 0 L
.28395 0 L
.29012 0 L
.2963 0 L
.30247 0 L
.30864 0 L
Mistroke
.31481 0 L
.32099 0 L
.32716 0 L
.33333 0 L
.33951 0 L
.34568 0 L
.35185 0 L
.35802 0 L
.3642 0 L
.37037 0 L
.37654 0 L
.38272 0 L
.38889 0 L
.39506 0 L
.40123 0 L
.40741 0 L
.41358 0 L
.41975 1e-05 L
.42593 2e-05 L
.4321 4e-05 L
.43827 8e-05 L
.44444 .00016 L
.45062 .00032 L
.45679 .00063 L
.46296 .00119 L
.46914 .00219 L
.47531 .00391 L
.48148 .00676 L
.48765 .01132 L
.49383 .01837 L
.5 .02891 L
.50617 .04408 L
.51235 .06514 L
.51852 .09331 L
.52469 .12955 L
.53086 .17432 L
.53704 .22736 L
.54321 .28741 L
.54938 .35215 L
.55556 .41818 L
.56173 .48133 L
.5679 .53696 L
.57407 .58059 L
.58025 .60845 L
.58642 .61803 L
.59259 .60845 L
.59877 .58059 L
.60494 .53696 L
.61111 .48133 L
.61728 .41818 L
Mistroke
.62346 .35215 L
.62963 .28741 L
.6358 .22736 L
.64198 .17432 L
.64815 .12955 L
.65432 .09331 L
.66049 .06514 L
.66667 .04408 L
.67284 .02891 L
.67901 .01837 L
.68519 .01132 L
.69136 .00676 L
.69753 .00391 L
.7037 .00219 L
.70988 .00119 L
.71605 .00063 L
.72222 .00032 L
.7284 .00016 L
.73457 8e-05 L
.74074 4e-05 L
.74691 2e-05 L
.75309 1e-05 L
.75926 0 L
.76543 0 L
.7716 0 L
.77778 0 L
.78395 0 L
.79012 0 L
.7963 0 L
.80247 0 L
.80864 0 L
.81481 0 L
.82099 0 L
.82716 0 L
.83333 0 L
.83951 0 L
.84568 0 L
.85185 0 L
.85802 0 L
.8642 0 L
.87037 0 L
.87654 0 L
.88272 0 L
.88889 0 L
.89506 0 L
.90123 0 L
.90741 0 L
.91358 0 L
.91975 0 L
.92593 0 L
Mistroke
.9321 0 L
.93827 0 L
.94444 0 L
.95062 0 L
.95679 0 L
.96296 0 L
.96914 0 L
.97531 0 L
.98148 0 L
.98765 0 L
.99383 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
Again, as with triangular fuzzy numbers, the discrete fuzzy sum is bounded \
above by the expected result in real space. This will be true for all fuzzy \
arithmetic operations.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Subtraction", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Here we subtract the two Gaussian fuzzy numbers and plot the result.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Diff2 = DiscreteFuzzyMinus[GausFS3,GausFS4];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Diff2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00617284 0 0.618034 [
[(-75)] .03704 0 0 2 Msboxa
[(-50)] .19136 0 0 2 Msboxa
[(-25)] .34568 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(25)] .65432 0 0 2 Msboxa
[(50)] .80864 0 0 2 Msboxa
[(75)] .96296 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.03704 0 m
.03704 .00625 L
s
P
[(-75)] .03704 0 0 2 Mshowa
p
.002 w
.19136 0 m
.19136 .00625 L
s
P
[(-50)] .19136 0 0 2 Mshowa
p
.002 w
.34568 0 m
.34568 .00625 L
s
P
[(-25)] .34568 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.65432 0 m
.65432 .00625 L
s
P
[(25)] .65432 0 0 2 Mshowa
p
.002 w
.80864 0 m
.80864 .00625 L
s
P
[(50)] .80864 0 0 2 Mshowa
p
.002 w
.96296 0 m
.96296 .00625 L
s
P
[(75)] .96296 0 0 2 Mshowa
p
.001 w
.0679 0 m
.0679 .00375 L
s
P
p
.001 w
.09877 0 m
.09877 .00375 L
s
P
p
.001 w
.12963 0 m
.12963 .00375 L
s
P
p
.001 w
.16049 0 m
.16049 .00375 L
s
P
p
.001 w
.22222 0 m
.22222 .00375 L
s
P
p
.001 w
.25309 0 m
.25309 .00375 L
s
P
p
.001 w
.28395 0 m
.28395 .00375 L
s
P
p
.001 w
.31481 0 m
.31481 .00375 L
s
P
p
.001 w
.37654 0 m
.37654 .00375 L
s
P
p
.001 w
.40741 0 m
.40741 .00375 L
s
P
p
.001 w
.43827 0 m
.43827 .00375 L
s
P
p
.001 w
.46914 0 m
.46914 .00375 L
s
P
p
.001 w
.53086 0 m
.53086 .00375 L
s
P
p
.001 w
.56173 0 m
.56173 .00375 L
s
P
p
.001 w
.59259 0 m
.59259 .00375 L
s
P
p
.001 w
.62346 0 m
.62346 .00375 L
s
P
p
.001 w
.68519 0 m
.68519 .00375 L
s
P
p
.001 w
.71605 0 m
.71605 .00375 L
s
P
p
.001 w
.74691 0 m
.74691 .00375 L
s
P
p
.001 w
.77778 0 m
.77778 .00375 L
s
P
p
.001 w
.83951 0 m
.83951 .00375 L
s
P
p
.001 w
.87037 0 m
.87037 .00375 L
s
P
p
.001 w
.90123 0 m
.90123 .00375 L
s
P
p
.001 w
.9321 0 m
.9321 .00375 L
s
P
p
.001 w
.00617 0 m
.00617 .00375 L
s
P
p
.001 w
.99383 0 m
.99383 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
2.5 Mabswid
.00617 0 m
.00617 0 L
s
P
p
2.5 Mabswid
.01235 0 m
.01235 0 L
s
P
p
2.5 Mabswid
.01852 0 m
.01852 0 L
s
P
p
2.5 Mabswid
.02469 0 m
.02469 0 L
s
P
p
2.5 Mabswid
.03086 0 m
.03086 0 L
s
P
p
2.5 Mabswid
.03704 0 m
.03704 0 L
s
P
p
2.5 Mabswid
.04321 0 m
.04321 0 L
s
P
p
2.5 Mabswid
.04938 0 m
.04938 0 L
s
P
p
2.5 Mabswid
.05556 0 m
.05556 0 L
s
P
p
2.5 Mabswid
.06173 0 m
.06173 0 L
s
P
p
2.5 Mabswid
.0679 0 m
.0679 0 L
s
P
p
2.5 Mabswid
.07407 0 m
.07407 0 L
s
P
p
2.5 Mabswid
.08025 0 m
.08025 0 L
s
P
p
2.5 Mabswid
.08642 0 m
.08642 0 L
s
P
p
2.5 Mabswid
.09259 0 m
.09259 0 L
s
P
p
2.5 Mabswid
.09877 0 m
.09877 0 L
s
P
p
2.5 Mabswid
.10494 0 m
.10494 0 L
s
P
p
2.5 Mabswid
.11111 0 m
.11111 0 L
s
P
p
2.5 Mabswid
.11728 0 m
.11728 0 L
s
P
p
2.5 Mabswid
.12346 0 m
.12346 0 L
s
P
p
2.5 Mabswid
.12963 0 m
.12963 0 L
s
P
p
2.5 Mabswid
.1358 0 m
.1358 0 L
s
P
p
2.5 Mabswid
.14198 0 m
.14198 0 L
s
P
p
2.5 Mabswid
.14815 0 m
.14815 0 L
s
P
p
2.5 Mabswid
.15432 0 m
.15432 0 L
s
P
p
2.5 Mabswid
.16049 0 m
.16049 0 L
s
P
p
2.5 Mabswid
.16667 0 m
.16667 0 L
s
P
p
2.5 Mabswid
.17284 0 m
.17284 0 L
s
P
p
2.5 Mabswid
.17901 0 m
.17901 0 L
s
P
p
2.5 Mabswid
.18519 0 m
.18519 0 L
s
P
p
2.5 Mabswid
.19136 0 m
.19136 0 L
s
P
p
2.5 Mabswid
.19753 0 m
.19753 0 L
s
P
p
2.5 Mabswid
.2037 0 m
.2037 0 L
s
P
p
2.5 Mabswid
.20988 0 m
.20988 0 L
s
P
p
2.5 Mabswid
.21605 0 m
.21605 0 L
s
P
p
2.5 Mabswid
.22222 0 m
.22222 0 L
s
P
p
2.5 Mabswid
.2284 0 m
.2284 0 L
s
P
p
2.5 Mabswid
.23457 0 m
.23457 0 L
s
P
p
2.5 Mabswid
.24074 0 m
.24074 0 L
s
P
p
2.5 Mabswid
.24691 0 m
.24691 0 L
s
P
p
2.5 Mabswid
.25309 0 m
.25309 0 L
s
P
p
2.5 Mabswid
.25926 0 m
.25926 0 L
s
P
p
2.5 Mabswid
.26543 0 m
.26543 0 L
s
P
p
2.5 Mabswid
.2716 0 m
.2716 0 L
s
P
p
2.5 Mabswid
.27778 0 m
.27778 0 L
s
P
p
2.5 Mabswid
.28395 0 m
.28395 0 L
s
P
p
2.5 Mabswid
.29012 0 m
.29012 0 L
s
P
p
2.5 Mabswid
.2963 0 m
.2963 0 L
s
P
p
2.5 Mabswid
.30247 0 m
.30247 0 L
s
P
p
2.5 Mabswid
.30864 1e-05 m
.30864 0 L
s
P
p
2.5 Mabswid
.31481 1e-05 m
.31481 0 L
s
P
p
2.5 Mabswid
.32099 2e-05 m
.32099 0 L
s
P
p
2.5 Mabswid
.32716 8e-05 m
.32716 0 L
s
P
p
2.5 Mabswid
.33333 8e-05 m
.33333 0 L
s
P
p
2.5 Mabswid
.33951 .00024 m
.33951 0 L
s
P
p
2.5 Mabswid
.34568 .0005 m
.34568 0 L
s
P
p
2.5 Mabswid
.35185 .00072 m
.35185 0 L
s
P
p
2.5 Mabswid
.35802 .00195 m
.35802 0 L
s
P
p
2.5 Mabswid
.3642 .00267 m
.3642 0 L
s
P
p
2.5 Mabswid
.37037 .00489 m
.37037 0 L
s
P
p
2.5 Mabswid
.37654 .01132 m
.37654 0 L
s
P
p
2.5 Mabswid
.38272 .01132 m
.38272 0 L
s
P
p
2.5 Mabswid
.38889 .0242 m
.38889 0 L
s
P
p
2.5 Mabswid
.39506 .03843 m
.39506 0 L
s
P
p
2.5 Mabswid
.40123 .04778 m
.40123 0 L
s
P
p
2.5 Mabswid
.40741 .08706 m
.40741 0 L
s
P
p
2.5 Mabswid
.41358 .10446 m
.41358 0 L
s
P
p
2.5 Mabswid
.41975 .14643 m
.41975 0 L
s
P
p
2.5 Mabswid
.42593 .22736 m
.42593 0 L
s
P
p
2.5 Mabswid
.4321 .22736 m
.4321 0 L
s
P
p
2.5 Mabswid
.43827 .32588 m
.43827 0 L
s
P
p
2.5 Mabswid
.44444 .39627 m
.44444 0 L
s
P
p
2.5 Mabswid
.45062 .43119 m
.45062 0 L
s
P
p
2.5 Mabswid
.45679 .52665 m
.45679 0 L
s
P
p
2.5 Mabswid
.46296 .55304 m
.46296 0 L
s
P
p
2.5 Mabswid
.46914 .5938 m
.46914 0 L
s
P
p
2.5 Mabswid
.47531 .61803 m
.47531 0 L
s
P
p
2.5 Mabswid
.48148 .5938 m
.48148 0 L
s
P
p
2.5 Mabswid
.48765 .55304 m
.48765 0 L
s
P
p
2.5 Mabswid
.49383 .52665 m
.49383 0 L
s
P
p
2.5 Mabswid
.5 .43119 m
.5 0 L
s
P
p
2.5 Mabswid
.50617 .39627 m
.50617 0 L
s
P
p
2.5 Mabswid
.51235 .32588 m
.51235 0 L
s
P
p
2.5 Mabswid
.51852 .22736 m
.51852 0 L
s
P
p
2.5 Mabswid
.52469 .22736 m
.52469 0 L
s
P
p
2.5 Mabswid
.53086 .14643 m
.53086 0 L
s
P
p
2.5 Mabswid
.53704 .10446 m
.53704 0 L
s
P
p
2.5 Mabswid
.54321 .08706 m
.54321 0 L
s
P
p
2.5 Mabswid
.54938 .04778 m
.54938 0 L
s
P
p
2.5 Mabswid
.55556 .03843 m
.55556 0 L
s
P
p
2.5 Mabswid
.56173 .0242 m
.56173 0 L
s
P
p
2.5 Mabswid
.5679 .01132 m
.5679 0 L
s
P
p
2.5 Mabswid
.57407 .01132 m
.57407 0 L
s
P
p
2.5 Mabswid
.58025 .00489 m
.58025 0 L
s
P
p
2.5 Mabswid
.58642 .00267 m
.58642 0 L
s
P
p
2.5 Mabswid
.59259 .00195 m
.59259 0 L
s
P
p
2.5 Mabswid
.59877 .00072 m
.59877 0 L
s
P
p
2.5 Mabswid
.60494 .0005 m
.60494 0 L
s
P
p
2.5 Mabswid
.61111 .00024 m
.61111 0 L
s
P
p
2.5 Mabswid
.61728 8e-05 m
.61728 0 L
s
P
p
2.5 Mabswid
.62346 8e-05 m
.62346 0 L
s
P
p
2.5 Mabswid
.62963 2e-05 m
.62963 0 L
s
P
p
2.5 Mabswid
.6358 1e-05 m
.6358 0 L
s
P
p
2.5 Mabswid
.64198 1e-05 m
.64198 0 L
s
P
p
2.5 Mabswid
.64815 0 m
.64815 0 L
s
P
p
2.5 Mabswid
.65432 0 m
.65432 0 L
s
P
p
2.5 Mabswid
.66049 0 m
.66049 0 L
s
P
p
2.5 Mabswid
.66667 0 m
.66667 0 L
s
P
p
2.5 Mabswid
.67284 0 m
.67284 0 L
s
P
p
2.5 Mabswid
.67901 0 m
.67901 0 L
s
P
p
2.5 Mabswid
.68519 0 m
.68519 0 L
s
P
p
2.5 Mabswid
.69136 0 m
.69136 0 L
s
P
p
2.5 Mabswid
.69753 0 m
.69753 0 L
s
P
p
2.5 Mabswid
.7037 0 m
.7037 0 L
s
P
p
2.5 Mabswid
.70988 0 m
.70988 0 L
s
P
p
2.5 Mabswid
.71605 0 m
.71605 0 L
s
P
p
2.5 Mabswid
.72222 0 m
.72222 0 L
s
P
p
2.5 Mabswid
.7284 0 m
.7284 0 L
s
P
p
2.5 Mabswid
.73457 0 m
.73457 0 L
s
P
p
2.5 Mabswid
.74074 0 m
.74074 0 L
s
P
p
2.5 Mabswid
.74691 0 m
.74691 0 L
s
P
p
2.5 Mabswid
.75309 0 m
.75309 0 L
s
P
p
2.5 Mabswid
.75926 0 m
.75926 0 L
s
P
p
2.5 Mabswid
.76543 0 m
.76543 0 L
s
P
p
2.5 Mabswid
.7716 0 m
.7716 0 L
s
P
p
2.5 Mabswid
.77778 0 m
.77778 0 L
s
P
p
2.5 Mabswid
.78395 0 m
.78395 0 L
s
P
p
2.5 Mabswid
.79012 0 m
.79012 0 L
s
P
p
2.5 Mabswid
.7963 0 m
.7963 0 L
s
P
p
2.5 Mabswid
.80247 0 m
.80247 0 L
s
P
p
2.5 Mabswid
.80864 0 m
.80864 0 L
s
P
p
2.5 Mabswid
.81481 0 m
.81481 0 L
s
P
p
2.5 Mabswid
.82099 0 m
.82099 0 L
s
P
p
2.5 Mabswid
.82716 0 m
.82716 0 L
s
P
p
2.5 Mabswid
.83333 0 m
.83333 0 L
s
P
p
2.5 Mabswid
.83951 0 m
.83951 0 L
s
P
p
2.5 Mabswid
.84568 0 m
.84568 0 L
s
P
p
2.5 Mabswid
.85185 0 m
.85185 0 L
s
P
p
2.5 Mabswid
.85802 0 m
.85802 0 L
s
P
p
2.5 Mabswid
.8642 0 m
.8642 0 L
s
P
p
2.5 Mabswid
.87037 0 m
.87037 0 L
s
P
p
2.5 Mabswid
.87654 0 m
.87654 0 L
s
P
p
2.5 Mabswid
.88272 0 m
.88272 0 L
s
P
p
2.5 Mabswid
.88889 0 m
.88889 0 L
s
P
p
2.5 Mabswid
.89506 0 m
.89506 0 L
s
P
p
2.5 Mabswid
.90123 0 m
.90123 0 L
s
P
p
2.5 Mabswid
.90741 0 m
.90741 0 L
s
P
p
2.5 Mabswid
.91358 0 m
.91358 0 L
s
P
p
2.5 Mabswid
.91975 0 m
.91975 0 L
s
P
p
2.5 Mabswid
.92593 0 m
.92593 0 L
s
P
p
2.5 Mabswid
.9321 0 m
.9321 0 L
s
P
p
2.5 Mabswid
.93827 0 m
.93827 0 L
s
P
p
2.5 Mabswid
.94444 0 m
.94444 0 L
s
P
p
2.5 Mabswid
.95062 0 m
.95062 0 L
s
P
p
2.5 Mabswid
.95679 0 m
.95679 0 L
s
P
p
2.5 Mabswid
.96296 0 m
.96296 0 L
s
P
p
2.5 Mabswid
.96914 0 m
.96914 0 L
s
P
p
2.5 Mabswid
.97531 0 m
.97531 0 L
s
P
p
2.5 Mabswid
.98148 0 m
.98148 0 L
s
P
p
2.5 Mabswid
.98765 0 m
.98765 0 L
s
P
p
2.5 Mabswid
.99383 0 m
.99383 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
The expected fuzzy difference for our example would be a Gaussian fuzzy set \
with a mean of 5-9 = -4 and a standard deviation of 3+5 = 8. We plot the \
discrete result with this expected result below.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
ExpectedDiff2 = FuzzyGaussian[-4,8,
  UniversalSpace->{-80,80}];\
\>", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[Diff2,ExpectedDiff2,PlotJoined->True];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.00617284 0 0.618034 [
[(-75)] .03704 0 0 2 Msboxa
[(-50)] .19136 0 0 2 Msboxa
[(-25)] .34568 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(25)] .65432 0 0 2 Msboxa
[(50)] .80864 0 0 2 Msboxa
[(75)] .96296 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.03704 0 m
.03704 .00625 L
s
P
[(-75)] .03704 0 0 2 Mshowa
p
.002 w
.19136 0 m
.19136 .00625 L
s
P
[(-50)] .19136 0 0 2 Mshowa
p
.002 w
.34568 0 m
.34568 .00625 L
s
P
[(-25)] .34568 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.65432 0 m
.65432 .00625 L
s
P
[(25)] .65432 0 0 2 Mshowa
p
.002 w
.80864 0 m
.80864 .00625 L
s
P
[(50)] .80864 0 0 2 Mshowa
p
.002 w
.96296 0 m
.96296 .00625 L
s
P
[(75)] .96296 0 0 2 Mshowa
p
.001 w
.0679 0 m
.0679 .00375 L
s
P
p
.001 w
.09877 0 m
.09877 .00375 L
s
P
p
.001 w
.12963 0 m
.12963 .00375 L
s
P
p
.001 w
.16049 0 m
.16049 .00375 L
s
P
p
.001 w
.22222 0 m
.22222 .00375 L
s
P
p
.001 w
.25309 0 m
.25309 .00375 L
s
P
p
.001 w
.28395 0 m
.28395 .00375 L
s
P
p
.001 w
.31481 0 m
.31481 .00375 L
s
P
p
.001 w
.37654 0 m
.37654 .00375 L
s
P
p
.001 w
.40741 0 m
.40741 .00375 L
s
P
p
.001 w
.43827 0 m
.43827 .00375 L
s
P
p
.001 w
.46914 0 m
.46914 .00375 L
s
P
p
.001 w
.53086 0 m
.53086 .00375 L
s
P
p
.001 w
.56173 0 m
.56173 .00375 L
s
P
p
.001 w
.59259 0 m
.59259 .00375 L
s
P
p
.001 w
.62346 0 m
.62346 .00375 L
s
P
p
.001 w
.68519 0 m
.68519 .00375 L
s
P
p
.001 w
.71605 0 m
.71605 .00375 L
s
P
p
.001 w
.74691 0 m
.74691 .00375 L
s
P
p
.001 w
.77778 0 m
.77778 .00375 L
s
P
p
.001 w
.83951 0 m
.83951 .00375 L
s
P
p
.001 w
.87037 0 m
.87037 .00375 L
s
P
p
.001 w
.90123 0 m
.90123 .00375 L
s
P
p
.001 w
.9321 0 m
.9321 .00375 L
s
P
p
.001 w
.00617 0 m
.00617 .00375 L
s
P
p
.001 w
.99383 0 m
.99383 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
1.76777 Mabswid
.00617 0 m
.01235 0 L
.01852 0 L
.02469 0 L
.03086 0 L
.03704 0 L
.04321 0 L
.04938 0 L
.05556 0 L
.06173 0 L
.0679 0 L
.07407 0 L
.08025 0 L
.08642 0 L
.09259 0 L
.09877 0 L
.10494 0 L
.11111 0 L
.11728 0 L
.12346 0 L
.12963 0 L
.1358 0 L
.14198 0 L
.14815 0 L
.15432 0 L
.16049 0 L
.16667 0 L
.17284 0 L
.17901 0 L
.18519 0 L
.19136 0 L
.19753 0 L
.2037 0 L
.20988 0 L
.21605 0 L
.22222 0 L
.2284 0 L
.23457 0 L
.24074 0 L
.24691 0 L
.25309 0 L
.25926 0 L
.26543 0 L
.2716 0 L
.27778 0 L
.28395 0 L
.29012 0 L
.2963 0 L
.30247 0 L
.30864 1e-05 L
Mistroke
.31481 1e-05 L
.32099 2e-05 L
.32716 8e-05 L
.33333 8e-05 L
.33951 .00024 L
.34568 .0005 L
.35185 .00072 L
.35802 .00195 L
.3642 .00267 L
.37037 .00489 L
.37654 .01132 L
.38272 .01132 L
.38889 .0242 L
.39506 .03843 L
.40123 .04778 L
.40741 .08706 L
.41358 .10446 L
.41975 .14643 L
.42593 .22736 L
.4321 .22736 L
.43827 .32588 L
.44444 .39627 L
.45062 .43119 L
.45679 .52665 L
.46296 .55304 L
.46914 .5938 L
.47531 .61803 L
.48148 .5938 L
.48765 .55304 L
.49383 .52665 L
.5 .43119 L
.50617 .39627 L
.51235 .32588 L
.51852 .22736 L
.52469 .22736 L
.53086 .14643 L
.53704 .10446 L
.54321 .08706 L
.54938 .04778 L
.55556 .03843 L
.56173 .0242 L
.5679 .01132 L
.57407 .01132 L
.58025 .00489 L
.58642 .00267 L
.59259 .00195 L
.59877 .00072 L
.60494 .0005 L
.61111 .00024 L
.61728 8e-05 L
Mistroke
.62346 8e-05 L
.62963 2e-05 L
.6358 1e-05 L
.64198 1e-05 L
.64815 0 L
.65432 0 L
.66049 0 L
.66667 0 L
.67284 0 L
.67901 0 L
.68519 0 L
.69136 0 L
.69753 0 L
.7037 0 L
.70988 0 L
.71605 0 L
.72222 0 L
.7284 0 L
.73457 0 L
.74074 0 L
.74691 0 L
.75309 0 L
.75926 0 L
.76543 0 L
.7716 0 L
.77778 0 L
.78395 0 L
.79012 0 L
.7963 0 L
.80247 0 L
.80864 0 L
.81481 0 L
.82099 0 L
.82716 0 L
.83333 0 L
.83951 0 L
.84568 0 L
.85185 0 L
.85802 0 L
.8642 0 L
.87037 0 L
.87654 0 L
.88272 0 L
.88889 0 L
.89506 0 L
.90123 0 L
.90741 0 L
.91358 0 L
.91975 0 L
.92593 0 L
Mistroke
.9321 0 L
.93827 0 L
.94444 0 L
.95062 0 L
.95679 0 L
.96296 0 L
.96914 0 L
.97531 0 L
.98148 0 L
.98765 0 L
.99383 0 L
Mfstroke
P
p
.2 0 1 r
1.76777 Mabswid
.00617 0 m
.01235 0 L
.01852 0 L
.02469 0 L
.03086 0 L
.03704 0 L
.04321 0 L
.04938 0 L
.05556 0 L
.06173 0 L
.0679 0 L
.07407 0 L
.08025 0 L
.08642 0 L
.09259 0 L
.09877 0 L
.10494 0 L
.11111 0 L
.11728 0 L
.12346 0 L
.12963 0 L
.1358 0 L
.14198 0 L
.14815 0 L
.15432 0 L
.16049 0 L
.16667 0 L
.17284 0 L
.17901 0 L
.18519 0 L
.19136 0 L
.19753 0 L
.2037 0 L
.20988 0 L
.21605 0 L
.22222 0 L
.2284 0 L
.23457 0 L
.24074 0 L
.24691 0 L
.25309 0 L
.25926 0 L
.26543 0 L
.2716 0 L
.27778 0 L
.28395 0 L
.29012 0 L
.2963 0 L
.30247 0 L
.30864 1e-05 L
Mistroke
.31481 2e-05 L
.32099 4e-05 L
.32716 8e-05 L
.33333 .00016 L
.33951 .00032 L
.34568 .00063 L
.35185 .00119 L
.35802 .00219 L
.3642 .00391 L
.37037 .00676 L
.37654 .01132 L
.38272 .01837 L
.38889 .02891 L
.39506 .04408 L
.40123 .06514 L
.40741 .09331 L
.41358 .12955 L
.41975 .17432 L
.42593 .22736 L
.4321 .28741 L
.43827 .35215 L
.44444 .41818 L
.45062 .48133 L
.45679 .53696 L
.46296 .58059 L
.46914 .60845 L
.47531 .61803 L
.48148 .60845 L
.48765 .58059 L
.49383 .53696 L
.5 .48133 L
.50617 .41818 L
.51235 .35215 L
.51852 .28741 L
.52469 .22736 L
.53086 .17432 L
.53704 .12955 L
.54321 .09331 L
.54938 .06514 L
.55556 .04408 L
.56173 .02891 L
.5679 .01837 L
.57407 .01132 L
.58025 .00676 L
.58642 .00391 L
.59259 .00219 L
.59877 .00119 L
.60494 .00063 L
.61111 .00032 L
.61728 .00016 L
Mistroke
.62346 8e-05 L
.62963 4e-05 L
.6358 2e-05 L
.64198 1e-05 L
.64815 0 L
.65432 0 L
.66049 0 L
.66667 0 L
.67284 0 L
.67901 0 L
.68519 0 L
.69136 0 L
.69753 0 L
.7037 0 L
.70988 0 L
.71605 0 L
.72222 0 L
.7284 0 L
.73457 0 L
.74074 0 L
.74691 0 L
.75309 0 L
.75926 0 L
.76543 0 L
.7716 0 L
.77778 0 L
.78395 0 L
.79012 0 L
.7963 0 L
.80247 0 L
.80864 0 L
.81481 0 L
.82099 0 L
.82716 0 L
.83333 0 L
.83951 0 L
.84568 0 L
.85185 0 L
.85802 0 L
.8642 0 L
.87037 0 L
.87654 0 L
.88272 0 L
.88889 0 L
.89506 0 L
.90123 0 L
.90741 0 L
.91358 0 L
.91975 0 L
.92593 0 L
Mistroke
.9321 0 L
.93827 0 L
.94444 0 L
.95062 0 L
.95679 0 L
.96296 0 L
.96914 0 L
.97531 0 L
.98148 0 L
.98765 0 L
.99383 0 L
Mfstroke
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{398, 246},
  ImageMargins->{{34, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Multiplication", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
We can perform a discrete fuzzy multiplication with Gaussian fuzzy numbers, \
but since Gaussian fuzzy sets are defined for every element in the universal \
space, the result would be defined on a large universal space. If we \
multiplied our two Gaussian fuzzy sets from this notebook, the universal \
space would extend from -1600 to 1600, and the calculations would take a long \
time. For this reason, we will not demonstrate the DiscreteFuzzyMultiply \
function on the Gaussian fuzzy sets.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Image", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Here we find the image of our last fuzzy set and we plot the results.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Im2 = DiscreteFuzzyImage[GausFS4];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["FuzzyPlot[GausFS4,Im2];", "Input",
  PageWidth->Infinity,
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
%% Graphics
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0121951 0 0.618034 [
[(-40)] .0122 0 0 2 Msboxa
[(-20)] .2561 0 0 2 Msboxa
[(0)] .5 0 0 2 Msboxa
[(20)] .7439 0 0 2 Msboxa
[(40)] .9878 0 0 2 Msboxa
[(U)] 1.025 0 -1 0 Msboxa
[(0)] -0.0125 0 1 0 Msboxa
[(0.2)] -0.0125 .12361 1 0 Msboxa
[(0.4)] -0.0125 .24721 1 0 Msboxa
[(0.6)] -0.0125 .37082 1 0 Msboxa
[(0.8)] -0.0125 .49443 1 0 Msboxa
[(1)] -0.0125 .61803 1 0 Msboxa
[(Membership Grade)] 0 .61803 0 -4 Msboxa
[ -0.001 -0.001 0 0 ]
[ 1.001 .61903 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
[ ] 0 setdash
0 g
p
p
.002 w
.0122 0 m
.0122 .00625 L
s
P
[(-40)] .0122 0 0 2 Mshowa
p
.002 w
.2561 0 m
.2561 .00625 L
s
P
[(-20)] .2561 0 0 2 Mshowa
p
.002 w
.5 0 m
.5 .00625 L
s
P
[(0)] .5 0 0 2 Mshowa
p
.002 w
.7439 0 m
.7439 .00625 L
s
P
[(20)] .7439 0 0 2 Mshowa
p
.002 w
.9878 0 m
.9878 .00625 L
s
P
[(40)] .9878 0 0 2 Mshowa
p
.001 w
.06098 0 m
.06098 .00375 L
s
P
p
.001 w
.10976 0 m
.10976 .00375 L
s
P
p
.001 w
.15854 0 m
.15854 .00375 L
s
P
p
.001 w
.20732 0 m
.20732 .00375 L
s
P
p
.001 w
.30488 0 m
.30488 .00375 L
s
P
p
.001 w
.35366 0 m
.35366 .00375 L
s
P
p
.001 w
.40244 0 m
.40244 .00375 L
s
P
p
.001 w
.45122 0 m
.45122 .00375 L
s
P
p
.001 w
.54878 0 m
.54878 .00375 L
s
P
p
.001 w
.59756 0 m
.59756 .00375 L
s
P
p
.001 w
.64634 0 m
.64634 .00375 L
s
P
p
.001 w
.69512 0 m
.69512 .00375 L
s
P
p
.001 w
.79268 0 m
.79268 .00375 L
s
P
p
.001 w
.84146 0 m
.84146 .00375 L
s
P
p
.001 w
.89024 0 m
.89024 .00375 L
s
P
p
.001 w
.93902 0 m
.93902 .00375 L
s
P
[(U)] 1.025 0 -1 0 Mshowa
p
.002 w
0 0 m
1 0 L
s
P
p
.002 w
0 0 m
.00625 0 L
s
P
[(0)] -0.0125 0 1 0 Mshowa
p
.002 w
0 .12361 m
.00625 .12361 L
s
P
[(0.2)] -0.0125 .12361 1 0 Mshowa
p
.002 w
0 .24721 m
.00625 .24721 L
s
P
[(0.4)] -0.0125 .24721 1 0 Mshowa
p
.002 w
0 .37082 m
.00625 .37082 L
s
P
[(0.6)] -0.0125 .37082 1 0 Mshowa
p
.002 w
0 .49443 m
.00625 .49443 L
s
P
[(0.8)] -0.0125 .49443 1 0 Mshowa
p
.002 w
0 .61803 m
.00625 .61803 L
s
P
[(1)] -0.0125 .61803 1 0 Mshowa
p
.001 w
0 .02472 m
.00375 .02472 L
s
P
p
.001 w
0 .04944 m
.00375 .04944 L
s
P
p
.001 w
0 .07416 m
.00375 .07416 L
s
P
p
.001 w
0 .09889 m
.00375 .09889 L
s
P
p
.001 w
0 .14833 m
.00375 .14833 L
s
P
p
.001 w
0 .17305 m
.00375 .17305 L
s
P
p
.001 w
0 .19777 m
.00375 .19777 L
s
P
p
.001 w
0 .22249 m
.00375 .22249 L
s
P
p
.001 w
0 .27193 m
.00375 .27193 L
s
P
p
.001 w
0 .29666 m
.00375 .29666 L
s
P
p
.001 w
0 .32138 m
.00375 .32138 L
s
P
p
.001 w
0 .3461 m
.00375 .3461 L
s
P
p
.001 w
0 .39554 m
.00375 .39554 L
s
P
p
.001 w
0 .42026 m
.00375 .42026 L
s
P
p
.001 w
0 .44498 m
.00375 .44498 L
s
P
p
.001 w
0 .46971 m
.00375 .46971 L
s
P
p
.001 w
0 .51915 m
.00375 .51915 L
s
P
p
.001 w
0 .54387 m
.00375 .54387 L
s
P
p
.001 w
0 .56859 m
.00375 .56859 L
s
P
p
.001 w
0 .59331 m
.00375 .59331 L
s
P
[(Membership Grade)] 0 .61803 0 -4 Mshowa
p
.002 w
0 0 m
0 .61803 L
s
P
P
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
p
p
1 0 0 r
p
p
1.25 Mabswid
.0122 0 m
.0122 0 L
s
P
p
1.25 Mabswid
.02439 0 m
.02439 0 L
s
P
p
1.25 Mabswid
.03659 0 m
.03659 0 L
s
P
p
1.25 Mabswid
.04878 0 m
.04878 0 L
s
P
p
1.25 Mabswid
.06098 0 m
.06098 0 L
s
P
p
1.25 Mabswid
.07317 0 m
.07317 0 L
s
P
p
1.25 Mabswid
.08537 0 m
.08537 0 L
s
P
p
1.25 Mabswid
.09756 0 m
.09756 0 L
s
P
p
1.25 Mabswid
.10976 0 m
.10976 0 L
s
P
p
1.25 Mabswid
.12195 0 m
.12195 0 L
s
P
p
1.25 Mabswid
.13415 0 m
.13415 0 L
s
P
p
1.25 Mabswid
.14634 0 m
.14634 0 L
s
P
p
1.25 Mabswid
.15854 0 m
.15854 0 L
s
P
p
1.25 Mabswid
.17073 0 m
.17073 0 L
s
P
p
1.25 Mabswid
.18293 0 m
.18293 0 L
s
P
p
1.25 Mabswid
.19512 0 m
.19512 0 L
s
P
p
1.25 Mabswid
.20732 0 m
.20732 0 L
s
P
p
1.25 Mabswid
.21951 0 m
.21951 0 L
s
P
p
1.25 Mabswid
.23171 0 m
.23171 0 L
s
P
p
1.25 Mabswid
.2439 0 m
.2439 0 L
s
P
p
1.25 Mabswid
.2561 0 m
.2561 0 L
s
P
p
1.25 Mabswid
.26829 0 m
.26829 0 L
s
P
p
1.25 Mabswid
.28049 0 m
.28049 0 L
s
P
p
1.25 Mabswid
.29268 0 m
.29268 0 L
s
P
p
1.25 Mabswid
.30488 0 m
.30488 0 L
s
P
p
1.25 Mabswid
.31707 0 m
.31707 0 L
s
P
p
1.25 Mabswid
.32927 0 m
.32927 0 L
s
P
p
1.25 Mabswid
.34146 0 m
.34146 0 L
s
P
p
1.25 Mabswid
.35366 0 m
.35366 0 L
s
P
p
1.25 Mabswid
.36585 0 m
.36585 0 L
s
P
p
1.25 Mabswid
.37805 0 m
.37805 0 L
s
P
p
1.25 Mabswid
.39024 0 m
.39024 0 L
s
P
p
1.25 Mabswid
.40244 1e-05 m
.40244 0 L
s
P
p
1.25 Mabswid
.41463 2e-05 m
.41463 0 L
s
P
p
1.25 Mabswid
.42683 8e-05 m
.42683 0 L
s
P
p
1.25 Mabswid
.43902 .00024 m
.43902 0 L
s
P
p
1.25 Mabswid
.45122 .00072 m
.45122 0 L
s
P
p
1.25 Mabswid
.46341 .00195 m
.46341 0 L
s
P
p
1.25 Mabswid
.47561 .00489 m
.47561 0 L
s
P
p
1.25 Mabswid
.4878 .01132 m
.4878 0 L
s
P
p
1.25 Mabswid
.5 .0242 m
.5 0 L
s
P
p
1.25 Mabswid
.5122 .04778 m
.5122 0 L
s
P
p
1.25 Mabswid
.52439 .08706 m
.52439 0 L
s
P
p
1.25 Mabswid
.53659 .14643 m
.53659 0 L
s
P
p
1.25 Mabswid
.54878 .22736 m
.54878 0 L
s
P
p
1.25 Mabswid
.56098 .32588 m
.56098 0 L
s
P
p
1.25 Mabswid
.57317 .43119 m
.57317 0 L
s
P
p
1.25 Mabswid
.58537 .52665 m
.58537 0 L
s
P
p
1.25 Mabswid
.59756 .5938 m
.59756 0 L
s
P
p
1.25 Mabswid
.60976 .61803 m
.60976 0 L
s
P
p
1.25 Mabswid
.62195 .5938 m
.62195 0 L
s
P
p
1.25 Mabswid
.63415 .52665 m
.63415 0 L
s
P
p
1.25 Mabswid
.64634 .43119 m
.64634 0 L
s
P
p
1.25 Mabswid
.65854 .32588 m
.65854 0 L
s
P
p
1.25 Mabswid
.67073 .22736 m
.67073 0 L
s
P
p
1.25 Mabswid
.68293 .14643 m
.68293 0 L
s
P
p
1.25 Mabswid
.69512 .08706 m
.69512 0 L
s
P
p
1.25 Mabswid
.70732 .04778 m
.70732 0 L
s
P
p
1.25 Mabswid
.71951 .0242 m
.71951 0 L
s
P
p
1.25 Mabswid
.73171 .01132 m
.73171 0 L
s
P
p
1.25 Mabswid
.7439 .00489 m
.7439 0 L
s
P
p
1.25 Mabswid
.7561 .00195 m
.7561 0 L
s
P
p
1.25 Mabswid
.76829 .00072 m
.76829 0 L
s
P
p
1.25 Mabswid
.78049 .00024 m
.78049 0 L
s
P
p
1.25 Mabswid
.79268 8e-05 m
.79268 0 L
s
P
p
1.25 Mabswid
.80488 2e-05 m
.80488 0 L
s
P
p
1.25 Mabswid
.81707 1e-05 m
.81707 0 L
s
P
p
1.25 Mabswid
.82927 0 m
.82927 0 L
s
P
p
1.25 Mabswid
.84146 0 m
.84146 0 L
s
P
p
1.25 Mabswid
.85366 0 m
.85366 0 L
s
P
p
1.25 Mabswid
.86585 0 m
.86585 0 L
s
P
p
1.25 Mabswid
.87805 0 m
.87805 0 L
s
P
p
1.25 Mabswid
.89024 0 m
.89024 0 L
s
P
p
1.25 Mabswid
.90244 0 m
.90244 0 L
s
P
p
1.25 Mabswid
.91463 0 m
.91463 0 L
s
P
p
1.25 Mabswid
.92683 0 m
.92683 0 L
s
P
p
1.25 Mabswid
.93902 0 m
.93902 0 L
s
P
p
1.25 Mabswid
.95122 0 m
.95122 0 L
s
P
p
1.25 Mabswid
.96341 0 m
.96341 0 L
s
P
p
1.25 Mabswid
.97561 0 m
.97561 0 L
s
P
p
1.25 Mabswid
.9878 0 m
.9878 0 L
s
P
P
P
p
.2 0 1 r
p
p
1.25 Mabswid
.01626 0 m
.01626 0 L
s
P
p
1.25 Mabswid
.02846 0 m
.02846 0 L
s
P
p
1.25 Mabswid
.04065 0 m
.04065 0 L
s
P
p
1.25 Mabswid
.05285 0 m
.05285 0 L
s
P
p
1.25 Mabswid
.06504 0 m
.06504 0 L
s
P
p
1.25 Mabswid
.07724 0 m
.07724 0 L
s
P
p
1.25 Mabswid
.08943 0 m
.08943 0 L
s
P
p
1.25 Mabswid
.10163 0 m
.10163 0 L
s
P
p
1.25 Mabswid
.11382 0 m
.11382 0 L
s
P
p
1.25 Mabswid
.12602 0 m
.12602 0 L
s
P
p
1.25 Mabswid
.13821 0 m
.13821 0 L
s
P
p
1.25 Mabswid
.15041 0 m
.15041 0 L
s
P
p
1.25 Mabswid
.1626 0 m
.1626 0 L
s
P
p
1.25 Mabswid
.1748 0 m
.1748 0 L
s
P
p
1.25 Mabswid
.18699 1e-05 m
.18699 0 L
s
P
p
1.25 Mabswid
.19919 2e-05 m
.19919 0 L
s
P
p
1.25 Mabswid
.21138 8e-05 m
.21138 0 L
s
P
p
1.25 Mabswid
.22358 .00024 m
.22358 0 L
s
P
p
1.25 Mabswid
.23577 .00072 m
.23577 0 L
s
P
p
1.25 Mabswid
.24797 .00195 m
.24797 0 L
s
P
p
1.25 Mabswid
.26016 .00489 m
.26016 0 L
s
P
p
1.25 Mabswid
.27236 .01132 m
.27236 0 L
s
P
p
1.25 Mabswid
.28455 .0242 m
.28455 0 L
s
P
p
1.25 Mabswid
.29675 .04778 m
.29675 0 L
s
P
p
1.25 Mabswid
.30894 .08706 m
.30894 0 L
s
P
p
1.25 Mabswid
.32114 .14643 m
.32114 0 L
s
P
p
1.25 Mabswid
.33333 .22736 m
.33333 0 L
s
P
p
1.25 Mabswid
.34553 .32588 m
.34553 0 L
s
P
p
1.25 Mabswid
.35772 .43119 m
.35772 0 L
s
P
p
1.25 Mabswid
.36992 .52665 m
.36992 0 L
s
P
p
1.25 Mabswid
.38211 .5938 m
.38211 0 L
s
P
p
1.25 Mabswid
.39431 .61803 m
.39431 0 L
s
P
p
1.25 Mabswid
.4065 .5938 m
.4065 0 L
s
P
p
1.25 Mabswid
.4187 .52665 m
.4187 0 L
s
P
p
1.25 Mabswid
.43089 .43119 m
.43089 0 L
s
P
p
1.25 Mabswid
.44309 .32588 m
.44309 0 L
s
P
p
1.25 Mabswid
.45528 .22736 m
.45528 0 L
s
P
p
1.25 Mabswid
.46748 .14643 m
.46748 0 L
s
P
p
1.25 Mabswid
.47967 .08706 m
.47967 0 L
s
P
p
1.25 Mabswid
.49187 .04778 m
.49187 0 L
s
P
p
1.25 Mabswid
.50407 .0242 m
.50407 0 L
s
P
p
1.25 Mabswid
.51626 .01132 m
.51626 0 L
s
P
p
1.25 Mabswid
.52846 .00489 m
.52846 0 L
s
P
p
1.25 Mabswid
.54065 .00195 m
.54065 0 L
s
P
p
1.25 Mabswid
.55285 .00072 m
.55285 0 L
s
P
p
1.25 Mabswid
.56504 .00024 m
.56504 0 L
s
P
p
1.25 Mabswid
.57724 8e-05 m
.57724 0 L
s
P
p
1.25 Mabswid
.58943 2e-05 m
.58943 0 L
s
P
p
1.25 Mabswid
.60163 1e-05 m
.60163 0 L
s
P
p
1.25 Mabswid
.61382 0 m
.61382 0 L
s
P
p
1.25 Mabswid
.62602 0 m
.62602 0 L
s
P
p
1.25 Mabswid
.63821 0 m
.63821 0 L
s
P
p
1.25 Mabswid
.65041 0 m
.65041 0 L
s
P
p
1.25 Mabswid
.6626 0 m
.6626 0 L
s
P
p
1.25 Mabswid
.6748 0 m
.6748 0 L
s
P
p
1.25 Mabswid
.68699 0 m
.68699 0 L
s
P
p
1.25 Mabswid
.69919 0 m
.69919 0 L
s
P
p
1.25 Mabswid
.71138 0 m
.71138 0 L
s
P
p
1.25 Mabswid
.72358 0 m
.72358 0 L
s
P
p
1.25 Mabswid
.73577 0 m
.73577 0 L
s
P
p
1.25 Mabswid
.74797 0 m
.74797 0 L
s
P
p
1.25 Mabswid
.76016 0 m
.76016 0 L
s
P
p
1.25 Mabswid
.77236 0 m
.77236 0 L
s
P
p
1.25 Mabswid
.78455 0 m
.78455 0 L
s
P
p
1.25 Mabswid
.79675 0 m
.79675 0 L
s
P
p
1.25 Mabswid
.80894 0 m
.80894 0 L
s
P
p
1.25 Mabswid
.82114 0 m
.82114 0 L
s
P
p
1.25 Mabswid
.83333 0 m
.83333 0 L
s
P
p
1.25 Mabswid
.84553 0 m
.84553 0 L
s
P
p
1.25 Mabswid
.85772 0 m
.85772 0 L
s
P
p
1.25 Mabswid
.86992 0 m
.86992 0 L
s
P
p
1.25 Mabswid
.88211 0 m
.88211 0 L
s
P
p
1.25 Mabswid
.89431 0 m
.89431 0 L
s
P
p
1.25 Mabswid
.9065 0 m
.9065 0 L
s
P
p
1.25 Mabswid
.9187 0 m
.9187 0 L
s
P
p
1.25 Mabswid
.93089 0 m
.93089 0 L
s
P
p
1.25 Mabswid
.94309 0 m
.94309 0 L
s
P
p
1.25 Mabswid
.95528 0 m
.95528 0 L
s
P
p
1.25 Mabswid
.96748 0 m
.96748 0 L
s
P
p
1.25 Mabswid
.97967 0 m
.97967 0 L
s
P
p
1.25 Mabswid
.99187 0 m
.99187 0 L
s
P
P
P
P
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  PageWidth->Infinity,
  ImageSize->{397, 245},
  ImageMargins->{{35, Inherited}, {Inherited, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False]}, Open]],

Cell["\<\
The image is a fuzzy set which is the mirror image of the original fuzzy set \
flipped about zero. \
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{128, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 91, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1853, 60, 67, 1, 70, "Subsection"],
Cell[1923, 63, 246, 5, 70, "Text"],
Cell[2172, 70, 143, 4, 70, "Text"],
Cell[2318, 76, 102, 2, 70, "Input"],
Cell[2423, 80, 304, 6, 70, "SmallText"],
Cell[2730, 88, 560, 11, 70, "Text"],
Cell[3293, 101, 120, 2, 70, "Input"],
Cell[3416, 105, 1228, 21, 70, "Text"],
Cell[4647, 128, 106, 2, 70, "Input"],
Cell[4756, 132, 109, 2, 70, "Input"],
Cell[4868, 136, 102, 2, 70, "Input"],
Cell[4973, 140, 102, 2, 70, "Input"],
Cell[5078, 144, 132, 3, 70, "Text"],

Cell[CellGroupData[{
Cell[5233, 149, 115, 2, 70, "Input"],
Cell[5351, 153, 5239, 531, 70, 5081, 526, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10622, 686, 117, 2, 70, "Input"],
Cell[10742, 690, 5413, 531, 70, 5255, 526, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[16176, 1223, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[16249, 1226, 102, 1, 70, "Subsection"],
Cell[16354, 1229, 660, 10, 70, "Text"],
Cell[17017, 1241, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[17090, 1244, 72, 1, 70, "Subsubsection"],
Cell[17165, 1247, 170, 4, 70, "Text"],
Cell[17338, 1253, 102, 1, 70, "Text"],
Cell[17443, 1256, 137, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[17603, 1261, 103, 2, 70, "Input"],
Cell[17709, 1265, 13912, 1830, 70, 13754, 1825, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[31633, 3097, 358, 6, 70, "Text"],
Cell[31994, 3105, 114, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[32131, 3109, 118, 2, 70, "Input"],
Cell[32252, 3113, 5327, 531, 70, 5169, 526, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[37591, 3646, 241, 5, 70, "Text"]
}, Open  ]],
Cell[37844, 3653, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[37917, 3656, 75, 1, 70, "Subsubsection"],
Cell[37995, 3659, 173, 4, 70, "Text"],
Cell[38171, 3665, 137, 4, 70, "Text"],
Cell[38311, 3671, 115, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[38449, 3675, 104, 2, 70, "Input"],
Cell[38556, 3679, 13912, 1830, 70, 13754, 1825, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[52480, 5511, 331, 6, 70, "Text"],
Cell[52814, 5519, 140, 3, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[52977, 5524, 120, 2, 70, "Input"],
Cell[53100, 5528, 5327, 531, 70, 5169, 526, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[58448, 6061, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[58521, 6064, 78, 1, 70, "Subsubsection"],
Cell[58602, 6067, 194, 4, 70, "Text"],
Cell[58799, 6073, 213, 5, 70, "Text"],
Cell[59015, 6080, 106, 2, 70, "Input"],
Cell[59124, 6084, 118, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[59265, 6088, 104, 2, 70, "Input"],
Cell[59372, 6092, 13932, 1830, 70, 13774, 1825, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[73325, 7924, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[73398, 7927, 69, 1, 70, "Subsubsection"],
Cell[73470, 7930, 132, 3, 70, "Text"],
Cell[73605, 7935, 129, 3, 70, "Text"],
Cell[73737, 7940, 106, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[73866, 7944, 95, 2, 70, "Input"],
Cell[73964, 7948, 10003, 1339, 70, 9845, 1334, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[83979, 9289, 293, 6, 70, "Text"]
}, Open  ]]
}, Open  ]],
Cell[84293, 9297, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[84366, 9300, 100, 1, 70, "Subsection"],
Cell[84469, 9303, 562, 9, 70, "Text"],
Cell[85034, 9314, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[85107, 9317, 72, 1, 70, "Subsubsection"],
Cell[85182, 9320, 159, 4, 70, "Text"],
Cell[85344, 9326, 115, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[85482, 9330, 89, 2, 70, "Input"],
Cell[85574, 9334, 10576, 1404, 70, 10418, 1399, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[96162, 10740, 145, 4, 70, "Text"],
Cell[96310, 10746, 497, 8, 70, "Text"],
Cell[96810, 10756, 168, 6, 70, "Input",
  PageBreakAbove->True],

Cell[CellGroupData[{
Cell[97001, 10764, 119, 2, 70, "Input"],
Cell[97123, 10768, 8058, 771, 70, 7900, 766, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[105193, 11541, 234, 5, 70, "Text"]
}, Open  ]],
Cell[105439, 11548, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[105512, 11551, 75, 1, 70, "Subsubsection"],
Cell[105590, 11554, 125, 3, 70, "Text"],
Cell[105718, 11559, 117, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[105858, 11563, 90, 2, 70, "Input"],
Cell[105951, 11567, 10576, 1404, 70, 10418, 1399, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[116539, 12973, 258, 5, 70, "Text"],
Cell[116800, 12980, 145, 5, 70, "Input"],

Cell[CellGroupData[{
Cell[116968, 12987, 121, 2, 70, "Input"],
Cell[117092, 12991, 8058, 771, 70, 7900, 766, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]]
}, Open  ]],
Cell[125171, 13764, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[125244, 13767, 78, 1, 70, "Subsubsection"],
Cell[125325, 13770, 551, 9, 70, "Text"]
}, Open  ]],
Cell[125888, 13781, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[125961, 13784, 69, 1, 70, "Subsubsection"],
Cell[126033, 13787, 126, 3, 70, "Text"],
Cell[126162, 13792, 107, 2, 70, "Input"],

Cell[CellGroupData[{
Cell[126292, 13796, 96, 2, 70, "Input"],
Cell[126391, 13800, 10263, 1339, 70, 10105, 1334, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[136666, 15141, 156, 4, 70, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
