(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10452,        345]*)
(*NotebookOutlinePosition[     11322,        377]*)
(*  CellTagsIndexPosition[     11278,        373]*)
(*WindowFrame->Normal*)



Notebook[{


Cell[CellGroupData[{Cell["\<\
Appendix
 
 
 
 \
\>", "Title",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Fuzzy Operator Formulas", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Following is a list of formulas used to operate on the membership grades of \
fuzzy set A for selected general operations on fuzzy sets. In the following \
formulas, xn represents the new membership grades after applying the \
operators, and yn represents the original membership grades for the elements \
of fuzzy set A.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Concentrate", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["xn = yn^2", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Dilate", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["xn = Sqrt[yn]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["IntensifyContrast", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
xn = 2*yn^2            if yn <= 0.5
1-2(1-yn)^2             otherwise\
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Normalize", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["xn = yn / Height[A]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Complement", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Standard   ", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["xn = 1-yn", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Sugeno[alpha]", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["xn = (1-yn) / (1+alpha*yn)", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Yager[w]", "Special1",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["xn = (1-yn^w)^(1/w)", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Intersection Formulas", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Following is a list of the formulas used to take the various intersections \
between two fuzzy sets, A and B. The following formulas indicate how the \
membership grades for corresponding elements in fuzzy sets A and B should be \
combined. In the formulas, a represent the membership grade for an element in \
fuzzy set A, and b represents the membership grade for an element in fuzzy \
set B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Standard", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i(a,b) = Min[a,b]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Hamacher[v] - v in the range [0, infinity]", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i(a,b) = (a*b) / (v-(1-v)(a+b-a*b))", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Frank[s] - s in the range (0, infinity) except 1.", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i(a,b) = Logs[1+((s^a-1)*(s^b-1)) / (s-1)]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Yager[w] - w in the range [0, infinity]", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i(a,b) = 1-Min[1,((1-a)^w+(1-b)^w)^(1/w)]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["DuboisPrade[alpha] - alpha in the range [0, 1]", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i(a,b) = (a*b) / Max[a,b,alpha]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Dombi[alpha] - alpha in the range (0, infinity)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["i(a,b) = 1 / (1+[(1/a-1)^alpha+(1/b-1)^alpha]^(1/alpha))", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Union Formulas", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
The following is a list of the formulas used to take the varous unions \
between two fuzzy sets, A and B. The following formulas indicate how the \
membership grades for corresponding elements in fuzzy sets A and B should be \
combined. In the formulas, a represent the membership grade for an element in \
fuzzy set A, and b represents the membership grade for the corresponding \
element in fuzzy set B.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Standard", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["u(a,b) = Max[a,b]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Hamacher[v] - v in the range [0, infinity]", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["u(a,b) = (a+b-(2-v)*a*b) / (1-(1-v)*a*b)", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Frank[s] - s in the range (0, infinity) except 1.", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["u(a,b) = 1-Logs[1+((s^(1-a)-1)*(s^(1-b)-1)) / (s-1)]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Yager[w] - w in the range [0, infinity]", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["u(a,b) = Min[1,(a^w+b^w)^(1/w)]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["DuboisPrade[alpha] - alpha in the range [0, 1]", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["u(a,b) = (a+b-a*b-min[a,b,1-alpha]) / Max[1-a,1-b,alpha]", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["Dombi[alpha] - alpha in the range (0, infinity)", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["u(a,b) = 1 / (1+[(1/a-1)^-alpha+(1/b-1)^-alpha]^-(1/alpha))", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Averaging Formulas", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Following is a list of the formulas for taking the various averages used in \
this package. The averaging operations are denoted by the letter h, and \
a1,...,an represent the membership grades for corresponding elements in the n \
fuzzy sets being averaged.\
\>", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["ArithmeticMean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["h(a1,a2,...,an) = (a1+a2+...+an) / n", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["GeometricMean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["h(a1,a2,...,an) = (a1*a2*...*an)^(1/n)", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["HarmonicMean", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["h(a1,a2,...,an) = n / (1/a1+1/a2+...+1/an)", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]],

Cell[CellGroupData[{Cell["\<\
GeneralizedMean[alpha] - alpha in the range (-infinity , infinity)\
\>", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
halpha(a1,a2,...,an) = ((a1^alpha+a2^alpha+...+an^alpha) / n)^(1/alpha)\
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]],

Cell[CellGroupData[{Cell["Miscellaneous Formulas", "Subsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[" ", "Text",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{Cell["Gaussian Fuzzy Sets", "Subsubsection",
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Exp[-((x-m)/s)], where m is the mean, s is the width, and x is the element.\
\>", "Special2",
  ImageRegion->{{0, 1}, {0, 1}}]}, Open]]}, Open]]}, Open]]
},
FrontEndVersion->"4.0 for Microsoft Windows",
ScreenRectangle->{{0, 1024}, {0, 695}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{496, 599},
WindowMargins->{{202, Automatic}, {Automatic, 0}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False}
]



(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 74, 7, 70, "Title"],

Cell[CellGroupData[{
Cell[1836, 60, 78, 1, 70, "Subsection"],
Cell[1917, 63, 378, 7, 70, "Text"],
Cell[2298, 72, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[2371, 75, 69, 1, 70, "Subsubsection"],
Cell[2443, 78, 62, 1, 70, "Special2"],
Cell[2508, 81, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2590, 84, 64, 1, 70, "Subsubsection"],
Cell[2657, 87, 66, 1, 70, "Special2"],
Cell[2726, 90, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2808, 93, 75, 1, 70, "Subsubsection"],
Cell[2886, 96, 130, 4, 70, "Special2"],
Cell[3019, 102, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3101, 105, 67, 1, 70, "Subsubsection"],
Cell[3171, 108, 72, 1, 70, "Special2"],
Cell[3246, 111, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3328, 114, 68, 1, 70, "Subsubsection"],
Cell[3399, 117, 64, 1, 70, "Special1"],
Cell[3466, 120, 62, 1, 70, "Special2"],
Cell[3531, 123, 66, 1, 70, "Special1"],
Cell[3600, 126, 79, 1, 70, "Special2"],
Cell[3682, 129, 61, 1, 70, "Special1"],
Cell[3746, 132, 72, 1, 70, "Special2"],
Cell[3821, 135, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3912, 138, 76, 1, 70, "Subsection"],
Cell[3991, 141, 451, 8, 70, "Text"],
Cell[4445, 151, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[4518, 154, 66, 1, 70, "Subsubsection"],
Cell[4587, 157, 70, 1, 70, "Special2"],
Cell[4660, 160, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4742, 163, 100, 1, 70, "Subsubsection"],
Cell[4845, 166, 88, 1, 70, "Special2"],
Cell[4936, 169, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5018, 172, 107, 1, 70, "Subsubsection"],
Cell[5128, 175, 95, 1, 70, "Special2"],
Cell[5226, 178, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5308, 181, 97, 1, 70, "Subsubsection"],
Cell[5408, 184, 94, 1, 70, "Special2"],
Cell[5505, 187, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5587, 190, 104, 1, 70, "Subsubsection"],
Cell[5694, 193, 84, 1, 70, "Special2"],
Cell[5781, 196, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5863, 199, 105, 1, 70, "Subsubsection"],
Cell[5971, 202, 109, 1, 70, "Special2"],
Cell[6083, 205, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[6174, 208, 69, 1, 70, "Subsection"],
Cell[6246, 211, 462, 8, 70, "Text"],
Cell[6711, 221, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[6784, 224, 66, 1, 70, "Subsubsection"],
Cell[6853, 227, 70, 1, 70, "Special2"],
Cell[6926, 230, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7008, 233, 100, 1, 70, "Subsubsection"],
Cell[7111, 236, 93, 1, 70, "Special2"],
Cell[7207, 239, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7289, 242, 107, 1, 70, "Subsubsection"],
Cell[7399, 245, 105, 1, 70, "Special2"],
Cell[7507, 248, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7589, 251, 97, 1, 70, "Subsubsection"],
Cell[7689, 254, 84, 1, 70, "Special2"],
Cell[7776, 257, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7858, 260, 104, 1, 70, "Subsubsection"],
Cell[7965, 263, 109, 1, 70, "Special2"],
Cell[8077, 266, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8159, 269, 105, 1, 70, "Subsubsection"],
Cell[8267, 272, 112, 1, 70, "Special2"],
Cell[8382, 275, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[8473, 278, 73, 1, 70, "Subsection"],
Cell[8549, 281, 315, 6, 70, "Text"],
Cell[8867, 289, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[8940, 292, 72, 1, 70, "Subsubsection"],
Cell[9015, 295, 89, 1, 70, "Special2"],
Cell[9107, 298, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9189, 301, 71, 1, 70, "Subsubsection"],
Cell[9263, 304, 91, 1, 70, "Special2"],
Cell[9357, 307, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9439, 310, 70, 1, 70, "Subsubsection"],
Cell[9512, 313, 95, 1, 70, "Special2"],
Cell[9610, 316, 50, 1, 70, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9692, 319, 132, 3, 70, "Subsubsection"],
Cell[9827, 324, 132, 3, 70, "Special2"],
Cell[9962, 329, 50, 1, 70, "Text"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[10053, 332, 77, 1, 70, "Subsection"],
Cell[10133, 335, 50, 1, 70, "Text"],

Cell[CellGroupData[{
Cell[10206, 338, 77, 1, 70, "Subsubsection"],
Cell[10286, 341, 136, 3, 70, "Special2"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)
